@@ -32,11 +32,9 @@ void Widget::nukeOverlayElement(Ogre::OverlayElement *element)
     if (container)
     {
         std::vector<Ogre::OverlayElement*> toDelete;
-
-        Ogre::OverlayContainer::ChildIterator children = container->getChildIterator();
-        while (children.hasMoreElements())
+        for (const auto& p : container->getChildren())
         {
-            toDelete.push_back(children.getNext());
+            toDelete.push_back(p.second);
         }
 
         for (unsigned int i = 0; i < toDelete.size(); i++)
@@ -679,7 +677,7 @@ void SelectMenu::_cursorMoved(const Ogre::Vector2 &cursorPos, float wheelDelta)
             if (newIndex != mDisplayIndex) setDisplayIndex(newIndex);
             return;
         }
-        else if(fabsf(wheelDelta) > 0.5f * 120.0f) // seems that OIS uses click == WHEEL_DELTA == 120 for all platforms
+        else if(fabsf(wheelDelta) > 0.5f)
         {
             int newIndex = Ogre::Math::Clamp<int>(mDisplayIndex + (wheelDelta > 0 ? -1 : 1), 0, (int)(mItems.size() - mItemElements.size()));
             Ogre::Real lowerBoundary = mScrollTrack->getHeight() - mScrollHandle->getHeight();
@@ -2132,10 +2130,11 @@ bool TrayManager::mouseReleased(const MouseButtonEvent &evt)
 
 bool TrayManager::mouseMoved(const MouseMotionEvent &evt)
 {
+    // thats a separate event. Ignore for now.
+    static float wheelDelta = 0;
+
     // always keep track of the mouse pos for refreshCursor()
     mCursorPos = Ogre::Vector2(evt.x, evt.y);
-
-    float wheelDelta = 0;//evt.state.Z.rel;
     mCursor->setPosition(mCursorPos.x, mCursorPos.y);
 
     if (mExpandedMenu)   // only check top priority widget until it passes on
@@ -2174,6 +2173,16 @@ bool TrayManager::mouseMoved(const MouseMotionEvent &evt)
     return false;
 }
 
+bool TrayManager::mouseWheelRolled(const MouseWheelEvent& evt)
+{
+    if (mExpandedMenu)
+    {
+        mExpandedMenu->_cursorMoved(mCursorPos, evt.y);
+        return true;
+    }
+    return false;
+}
+
 void TrayManager::setExpandedMenu(SelectMenu *m)
 {
     if (!mExpandedMenu && m)
