@@ -35,6 +35,16 @@ THE SOFTWARE.
 #include "OgreFontManager.h"
 
 namespace Ogre {
+    //---------------------------------------------------------------------
+    template<> OverlaySystem *Singleton<OverlaySystem>::msSingleton = 0;
+    OverlaySystem* OverlaySystem::getSingletonPtr()
+    {
+        return msSingleton;
+    }
+    OverlaySystem& OverlaySystem::getSingleton()
+    {
+        assert( msSingleton );  return ( *msSingleton );
+    }
     //---------------------------------------------------------------------
     OverlaySystem::OverlaySystem()
     {
