@@ -103,13 +103,11 @@ class _OgreRTSSExport Function : public RTShaderSystemAlloc
     friend ProgramManager;
 // Interface.
 public:
+    /// @deprecated do not use
     enum FunctionType
     {
-        // internal function (default)
         FFT_INTERNAL,
-        // Vertex program main
         FFT_VS_MAIN,
-        // Pixel shader main
         FFT_PS_MAIN
     };
 
@@ -182,7 +180,13 @@ public:
     @param type The type of the desired parameter.  
     Return parameter instance in case of that resolve operation succeeded.
     */
-    ParameterPtr resolveLocalParameter(const String& name, GpuConstantType type)
+    ParameterPtr resolveLocalParameter(GpuConstantType type, const String& name)
+    {
+        return resolveLocalParameter(Parameter::SPS_UNKNOWN, 0, name, type);
+    }
+
+    /// @deprecated
+    OGRE_DEPRECATED ParameterPtr resolveLocalParameter(const String& name, GpuConstantType type)
     {
         return resolveLocalParameter(Parameter::SPS_UNKNOWN, 0, name, type);
     }
@@ -261,8 +265,8 @@ public:
     /** Delete all output parameters from this function. */
     void deleteAllOutputParameters();
 
-    /** get function type. */
-    FunctionType getFunctionType() const;
+    /// @deprecated do not use
+    OGRE_DEPRECATED FunctionType getFunctionType() const;
 
 
 protected:
