@@ -165,7 +165,7 @@ public:
     const String& getShaderCachePath() const { return mShaderCachePath; }
 
     /** 
-    Flush the shader cache. This operation will cause all active sachems to be invalidated and will
+    Flush the shader cache. This operation will cause all active schemes to be invalidated and will
     destroy any CPU/GPU program that created by this shader generator.
     */
     void flushShaderCache();
@@ -481,15 +481,9 @@ protected:
 		SGPass(SGTechnique* parent, Pass* srcPass, Pass* dstPass, IlluminationStage stage);
         ~SGPass();
     
-        /** Build the render state. */
+        /** Build the render state and acquire the CPU/GPU programs */
         void buildTargetRenderState();
 
-        /** Acquire the CPU/GPU programs for this pass. */
-        void acquirePrograms();
-
-        /** Release the CPU/GPU programs of this pass. */
-        void releasePrograms();
-
         /** Get source pass. */
         Pass* getSrcPass() { return mSrcPass; }
 
@@ -520,8 +514,6 @@ protected:
 		IlluminationStage mStage;
         // Custom render state.
         RenderState* mCustomRenderState;
-        // The compiled render state.
-        std::unique_ptr<TargetRenderState> mTargetRenderState;
     };
 
     
@@ -548,15 +540,9 @@ protected:
         /** Build the render state. */
         void buildTargetRenderState();
 
-        /** Acquire the CPU/GPU programs for this technique. */
-        void acquirePrograms();
-
 		/** Build the render state for illumination passes. */
 		void buildIlluminationTargetRenderState();
 
-		/** Acquire the CPU/GPU programs for illumination passes of this technique. */
-		void acquireIlluminationPrograms();
-
 		/** Destroy the illumination passes entries. */
 		void destroyIlluminationSGPasses();
 
