@@ -90,6 +90,12 @@ public:
     */
     UniformParameterPtr resolveParameter(GpuConstantType type, int index, uint16 variability, const String& suggestedName, size_t size = 0);
     
+    /// @overload
+    UniformParameterPtr resolveParameter(GpuConstantType type, const String& name, int index = -1)
+    {
+        return resolveParameter(type, index, GPV_GLOBAL, name);
+    }
+
     /** Resolve uniform auto constant parameter
     @param autoType The auto type of the desired parameter
     @param data The data to associate with the auto parameter. 
@@ -120,30 +126,23 @@ public:
     */
     const UniformParameterList& getParameters() const { return mParameters; };
 
-    /** Create new function in this program. Return the newly created function instance.
-    @param name The name of the function to create.
-    @param desc The description of the function.
-    @param functionType
-    */
-    Function* createFunction(const String& name, const String& desc, const Function::FunctionType functionType);
+    /// @deprecated do not use
+    OGRE_DEPRECATED Function* createFunction(const String& name, const String& desc, const Function::FunctionType functionType);
 
-    /** Get a function by a given name. Return NULL if no matching function found.
-    @param name The name of the function to search for.
-    */
+    /// @deprecated do not use
     Function* getFunctionByName(const String& name);
 
-    /** Get the function list of this program.
-    */
+    /// @deprecated do not use
     const ShaderFunctionList& getFunctions() const { return mFunctions; };
 
-    /** Set the entry point function.
-    @param function The function that will use as entry point of this program.
-    */
-    void setEntryPointFunction(Function* function) { mEntryPointFunction = function; }
+    /// @deprecated do not use
+    OGRE_DEPRECATED void setEntryPointFunction(Function* function) { mEntryPointFunction = function; }
 
-    /** Get the entry point function of this program.*/
+    /// @deprecated use getMain()
     Function* getEntryPointFunction()                    { return mEntryPointFunction; }
 
+    Function* getMain() { return mEntryPointFunction; }
+
     /** Add dependency for this program. Basically a filename that will be included in this
     program and provide predefined shader functions code.
     One should verify that the given library file he provides can be reached by the resource manager.
