@@ -59,15 +59,15 @@ namespace RTShader {
 		mVSOutPosition = vsMain->resolveOutputParameter(Parameter::SPS_TEXTURE_COORDINATES, -1, Parameter::SPC_POSITION_OBJECT_SPACE, GCT_FLOAT4);
 		mPSInPosition = psMain->resolveInputParameter(mVSOutPosition);
 
-		mSamplerFromX = psProgram->resolveParameter(GCT_SAMPLER2D, mTextureSamplerIndexFromX, (uint16)GPV_GLOBAL, "tp_sampler_from_x");
+		mSamplerFromX = psProgram->resolveParameter(GCT_SAMPLER2D, "tp_sampler_from_x", mTextureSamplerIndexFromX);
 		if (mSamplerFromX.get() == NULL)
 			return false;
 
-		mSamplerFromY = psProgram->resolveParameter(GCT_SAMPLER2D, mTextureSamplerIndexFromY, (uint16)GPV_GLOBAL, "tp_sampler_from_y");
+		mSamplerFromY = psProgram->resolveParameter(GCT_SAMPLER2D, "tp_sampler_from_y", mTextureSamplerIndexFromY);
 		if (mSamplerFromY.get() == NULL)
 			return false;
 
-		mSamplerFromZ = psProgram->resolveParameter(GCT_SAMPLER2D, mTextureSamplerIndexFromZ, (uint16)GPV_GLOBAL, "tp_sampler_from_z");
+		mSamplerFromZ = psProgram->resolveParameter(GCT_SAMPLER2D, "tp_sampler_from_z", mTextureSamplerIndexFromZ);
 		if (mSamplerFromZ.get() == NULL)
 			return false;
 
@@ -75,7 +75,7 @@ namespace RTShader {
         if (mPSOutDiffuse.get() == NULL)    
             return false;
     
-        mPSTPParams = psProgram->resolveParameter(GCT_FLOAT3, -1, (uint16)GPV_GLOBAL, "gTPParams");
+        mPSTPParams = psProgram->resolveParameter(GCT_FLOAT3, "gTPParams");
         if (mPSTPParams.get() == NULL)
             return false;
         return true;
