@@ -59,9 +59,8 @@ SubRenderState* SGScriptTranslator::getGeneratedSubRenderState(const String& typ
     if (mGeneratedRenderState)
     {
         /** Get the list of the template sub render states composing this render state. */
-        const SubRenderStateList& rsList =
-            mGeneratedRenderState->getTemplateSubRenderStateList();
-        
+        const SubRenderStateList& rsList = mGeneratedRenderState->getSubRenderStates();
+
         SubRenderStateList::const_iterator it = rsList.begin();
         SubRenderStateList::const_iterator itEnd = rsList.end();
         for(; it != itEnd; ++it)
@@ -129,6 +128,10 @@ void SGScriptTranslator::translateTextureUnit(ScriptCompiler* compiler, const Ab
                     addSubRenderState(subRenderState, dstTechniqueSchemeName, material->getName(), 
                         material->getGroup(), pass->getIndex());
                 }
+                else
+                {
+                    compiler->addError(ScriptCompiler::CE_INVALIDPARAMETERS, prop->file, prop->line, prop->name);
+                }
             }
             else
             {
@@ -207,6 +210,10 @@ void SGScriptTranslator::translatePass(ScriptCompiler* compiler, const AbstractN
                     {
                         addSubRenderState(subRenderState, dstTechniqueSchemeName, material->getName(), material->getGroup(), pass->getIndex());
                     }
+                    else
+                    {
+                        compiler->addError(ScriptCompiler::CE_INVALIDPARAMETERS, prop->file, prop->line, prop->name);
+                    }
                 }               
             }
             else
