@@ -70,7 +70,7 @@ namespace Ogre
             uint16 currentPreparedLod;
             uint16 currentLoadedLod;
             uint16 requestedLod;
-            _OgreTerrainExport friend std::ostream& operator<<(std::ostream& o, const LoadLodRequest& r)
+            OGRE_DEPRECATED _OgreTerrainExport friend std::ostream& operator<<(std::ostream& o, const LoadLodRequest& r)
             { return o; }
         };
 
@@ -103,7 +103,7 @@ namespace Ogre
 
         /** Copy geometry data from buffer to mHeightData/mDeltaData
           @param lodLevel A LOD level to work with
-          @param data Buffer which holds geometry data if separated form
+          @param data, dataSize Buffer which holds geometry data if separated form
           @remarks Data in buffer has to be both height and delta data. First half is height data.
                 Seconds half is delta data.
           */
