@@ -28,16 +28,18 @@ THE SOFTWARE.
 #include "OgreTerrainMaterialShaderHelpers.h"
 #include "OgreTerrain.h"
 #include "OgreHighLevelGpuProgramManager.h"
-#include "OgreRoot.h"
 #include "OgreShadowCameraSetupPSSM.h"
 #include "OgreHighLevelGpuProgram.h"
+#include "OgreGpuProgramManager.h"
 
 namespace Ogre
 {
     //---------------------------------------------------------------------
-    ShaderHelperGLSL::ShaderHelperGLSL() : ShaderHelper(true)
+    ShaderHelperGLSL::ShaderHelperGLSL() : ShaderHelper()
     {
-        mIsGLES = HighLevelGpuProgramManager::getSingleton().isLanguageSupported("glsles");
+        const auto& hmgr = HighLevelGpuProgramManager::getSingleton();
+        mIsGLES = hmgr.isLanguageSupported("glsles");
+        mIsGLSL = hmgr.isLanguageSupported("glsl") || mIsGLES;
     }
     //---------------------------------------------------------------------
     HighLevelGpuProgramPtr
@@ -47,7 +49,9 @@ namespace Ogre
         HighLevelGpuProgramManager& mgr = HighLevelGpuProgramManager::getSingleton();
         String progName = getVertexProgramName(prof, terrain, tt);
 
-        String lang = mgr.isLanguageSupported("glsles") ? "glsles" : "glsl";
+        String lang = "hlsl";
+        if(mIsGLSL)
+            lang = mIsGLES ? "glsles" : "glsl";
 
         HighLevelGpuProgramPtr ret = mgr.getByName(progName, ResourceGroupManager::DEFAULT_RESOURCE_GROUP_NAME);
         if (!ret)
@@ -60,6 +64,12 @@ namespace Ogre
             ret->unload();
         }
 
+        if (prof->getParent()->getDebugLevel())
+        {
+            ret->setPreprocessorDefines(
+                StringUtil::format("TERRAIN_DEBUG,NUM_LODS=%d", terrain->getNumLodLevels()));
+        }
+
         return ret;
     }
     //---------------------------------------------------------------------
@@ -70,7 +80,9 @@ namespace Ogre
         HighLevelGpuProgramManager& mgr = HighLevelGpuProgramManager::getSingleton();
         String progName = getFragmentProgramName(prof, terrain, tt);
 
-        String lang = mgr.isLanguageSupported("glsles") ? "glsles" : "glsl";
+        String lang = "hlsl";
+        if(mIsGLSL)
+            lang = mIsGLES ? "glsles" : "glsl";
 
         HighLevelGpuProgramPtr ret = mgr.getByName(progName, ResourceGroupManager::DEFAULT_RESOURCE_GROUP_NAME);
         if (!ret)
@@ -83,94 +95,102 @@ namespace Ogre
             ret->unload();
         }
 
+        if (prof->getReceiveDynamicShadowsPSSM())
+        {
+            uint numShadowTextures = prof->getReceiveDynamicShadowsPSSM()->getSplitCount();
+            ret->setPreprocessorDefines(StringUtil::format("PSSM_NUM_SPLITS=%d", numShadowTextures));
+        }
+
+        if(!mIsGLSL)
+        {
+            ret->setParameter("enable_backwards_compatibility", "true");
+            ret->setParameter("target", "ps_4_0 ps_3_0 ps_2_b");
+        }
+
         return ret;
     }
 
     //---------------------------------------------------------------------
-    void ShaderHelperGLSL::generateVpHeader(const SM2Profile* prof, const Terrain* terrain,
+    void ShaderHelperGLSL::generateVertexProgramSource(const SM2Profile* prof, const Terrain* terrain,
                                                                                    TechniqueType tt, StringStream& outStream)
     {
-        int version = mIsGLES ? 100 : 120;
-
-        outStream << "#version "<< version << "\n";
+        if(mIsGLSL)
+        {
+            int version = mIsGLES ? 100 : 120;
+            outStream << "#version " << version << "\n";
+        }
 
         if(mIsGLES) {
             outStream << "precision highp int;\n";
             outStream << "precision highp float;\n";
         }
 
-        bool compression = terrain->_getUseVertexCompression() && tt != RENDER_COMPOSITE_MAP;
-        if (compression)
-        {
-            outStream <<
-                "attribute vec2 posIndex;\n"
-                "attribute float height;\n";
-        }
-        else
-        {
-            outStream <<
-                "attribute vec4 position;\n"
-                "attribute vec2 uv0;\n";
-        }
-        if (tt != RENDER_COMPOSITE_MAP)
-            outStream << "attribute vec2 delta;\n"; // lodDelta, lodThreshold
+        outStream << "#include <OgreUnifiedShader.h>\n";
+        outStream << "#include <FFPLib_Fog.glsl>\n";
+        outStream << "#include <TerrainTransforms.glsl>\n";
 
         outStream <<
             "uniform mat4 worldMatrix;\n"
             "uniform mat4 viewProjMatrix;\n"
             "uniform vec2 lodMorph;\n"; // morph amount, morph LOD target
 
+        bool compression = terrain->_getUseVertexCompression() && tt != RENDER_COMPOSITE_MAP;
+        bool fog = terrain->getSceneManager()->getFogMode() != FOG_NONE && tt != RENDER_COMPOSITE_MAP;
+
         if (compression)
         {
             outStream <<
                 "uniform mat4 posIndexToObjectSpace;\n"
                 "uniform float baseUVScale;\n";
         }
-        // uv multipliers
-        uint maxLayers = prof->getMaxLayers(terrain);
-        uint numLayers = std::min(maxLayers, static_cast<uint>(terrain->getLayerCount()));
-        uint numUVMultipliers = (numLayers / 4);
-        if (numLayers % 4)
-            ++numUVMultipliers;
-        for (uint i = 0; i < numUVMultipliers; ++i)
-            outStream << "uniform vec4 uvMul_" << i << ";\n";
 
-        outStream <<
-            "varying vec4 oPosObj;\n";
+        if (fog)
+            outStream << "uniform vec4 fogParams;\n";
 
-        uint texCoordSet = 1;
-        outStream <<
-            "varying vec4 oUVMisc; // xy = uv, z = camDepth\n";
-
-        // layer UV's premultiplied, packed as xy/zw
-        uint numUVSets = numLayers / 2;
-        if (numLayers % 2)
-            ++numUVSets;
-        if (tt != LOW_LOD)
+        uint numShadowTextures = uint(prof->isShadowingEnabled(tt, terrain));
+        if (numShadowTextures)
         {
-            for (uint i = 0; i < numUVSets; ++i)
+            if (prof->getReceiveDynamicShadowsPSSM())
             {
-                outStream <<
-                    "varying vec4 layerUV" << i << ";\n";
+                numShadowTextures = prof->getReceiveDynamicShadowsPSSM()->getSplitCount();
+            }
+            for (uint i = 0; i < numShadowTextures; ++i)
+            {
+                outStream << "uniform mat4 texViewProjMatrix" << i << ";\n";
             }
         }
 
+        outStream << "MAIN_PARAMETERS\n";
+        if (compression)
+        {
+            const char* idx2 = mIsGLSL ? "vec2" : "int2";
+            outStream << "IN(" << idx2 << " vertex, POSITION)\n"
+                         "IN(float uv0, TEXCOORD0)\n";
+        }
+        else
+        {
+            outStream << "IN(vec4 position, POSITION)\n"
+                         "IN(vec2 uv0, TEXCOORD0)\n";
+        }
+        if (tt != RENDER_COMPOSITE_MAP)
+            outStream << "IN(vec2 delta, TEXCOORD1)\n"; // lodDelta, lodThreshold
+
+        outStream << "OUT(vec4 oPosObj, TEXCOORD0)\n";
+
+        uint texCoordSet = 1;
+        outStream << "OUT(vec4 oUVMisc, TEXCOORD" << texCoordSet++ << ")\n"; // xy = uv, z = camDepth;
+
         if (prof->getParent()->getDebugLevel() && tt != RENDER_COMPOSITE_MAP)
         {
-            outStream << "varying vec2 lodInfo;\n";
+            outStream << "OUT(vec2 lodInfo, TEXCOORD" << texCoordSet++ << ")\n";
         }
 
-        bool fog = terrain->getSceneManager()->getFogMode() != FOG_NONE && tt != RENDER_COMPOSITE_MAP;
         if (fog)
-        {
-            outStream <<
-                "uniform vec4 fogParams;\n"
-                "varying float fogVal;\n";
-        }
+            outStream << "OUT(float fogVal, COLOR)\n";
 
-        if (prof->isShadowingEnabled(tt, terrain))
+        for (uint i = 0; i < numShadowTextures; ++i)
         {
-            texCoordSet = generateVpDynamicShadowsParams(texCoordSet, prof, terrain, tt, outStream);
+	        outStream << StringUtil::format("OUT(vec4 oLightSpacePos%d, TEXCOORD%d)\n", i, texCoordSet++);
         }
 
         // check we haven't exceeded texture coordinates
@@ -180,123 +200,144 @@ namespace Ogre
                         "Requested options require too many texture coordinate sets! Try reducing the number of layers.");
         }
 
-        outStream << "void main(void) {\n";
+        outStream <<
+            "MAIN_DECLARATION\n"
+            "{\n";
         if (compression)
         {
             outStream <<
-                "    vec4 position = posIndexToObjectSpace * vec4(posIndex, height, 1);\n"
-                "    vec2 uv0 = vec2(posIndex.x * baseUVScale, 1.0 - (posIndex.y * baseUVScale));\n";
+                "    vec2 _uv0; vec4 position;\n"
+                "    expandVertex(posIndexToObjectSpace, baseUVScale, vertex, uv0, position, _uv0);\n"
+                "#define uv0 _uv0\n"; // alias uv0 to _uv0
         }
         outStream <<
-            "    vec4 worldPos = worldMatrix * position;\n"
+            "    vec4 worldPos = mul(worldMatrix, position);\n"
             "    oPosObj = position;\n";
 
+        // morph
         if (tt != RENDER_COMPOSITE_MAP)
         {
-            // determine whether to apply the LOD morph to this vertex
-            // we store the deltas against all vertices so we only want to apply
-            // the morph to the ones which would disappear. The target LOD which is
-            // being morphed to is stored in lodMorph.y, and the LOD at which
-            // the vertex should be morphed is stored in uv.w. If we subtract
-            // the former from the latter, and arrange to only morph if the
-            // result is negative (it will only be -1 in fact, since after that
-            // the vertex will never be indexed), we will achieve our aim.
-            // sign(vertexLOD - targetLOD) == -1 is to morph
-            outStream <<
-                "    float toMorph = -min(0.0, sign(delta.y - lodMorph.y));\n";
-            // this will either be 1 (morph) or 0 (don't morph)
+            static char heightAxis[] = "yzx";
+            outStream << "    applyLODMorph(delta, lodMorph, worldPos."
+                      << heightAxis[terrain->getAlignment()];
+
             if (prof->getParent()->getDebugLevel())
-            {
-                // x == LOD level (-1 since value is target level, we want to display actual)
-                outStream << "    lodInfo.x = (lodMorph.y - 1) / " << terrain->getNumLodLevels() << ";\n";
-                // y == LOD morph
-                outStream << "    lodInfo.y = toMorph * lodMorph.x;\n";
-            }
-
-            // morph
-            switch (terrain->getAlignment())
-            {
-                case Terrain::ALIGN_X_Y:
-                    outStream << "    worldPos.z += delta.x * toMorph * lodMorph.x;\n";
-                    break;
-                case Terrain::ALIGN_X_Z:
-                    outStream << "    worldPos.y += delta.x * toMorph * lodMorph.x;\n";
-                    break;
-                case Terrain::ALIGN_Y_Z:
-                    outStream << "    worldPos.x += delta.x * toMorph * lodMorph.x;\n";
-                    break;
-            };
+                outStream << ", lodInfo";
+            outStream << ");\n";
         }
 
-        // generate UVs
-        if (tt != LOW_LOD)
+        outStream <<
+            "    gl_Position = mul(viewProjMatrix, worldPos);\n"
+            "    oUVMisc.xy = uv0.xy;\n";
+
+        if (fog)
         {
-            for (uint i = 0; i < numUVSets; ++i)
+            if (terrain->getSceneManager()->getFogMode() == FOG_LINEAR)
             {
-                uint layer  =  i * 2;
-                uint uvMulIdx = layer / 4;
-
-                outStream <<
-                    "    layerUV" << i << ".xy = " << " uv0.xy * uvMul_" << uvMulIdx << "." << getChannel(layer) << ";\n";
-                outStream <<
-                    "    layerUV" << i << ".zw = " << " uv0.xy * uvMul_" << uvMulIdx << "." << getChannel(layer+1) << ";\n";
+                outStream << "    FFP_VertexFog_Linear(gl_Position, fogParams, fogVal);\n";
+            }
+            else
+            {
+                outStream << "    FFP_VertexFog_Exp(gl_Position, fogParams, fogVal);\n";
             }
         }
+
+        if (numShadowTextures)
+            generateVpDynamicShadows(prof, terrain, tt, outStream);
+
+        outStream << "}\n";
     }
     //---------------------------------------------------------------------
     void ShaderHelperGLSL::generateFpHeader(const SM2Profile* prof, const Terrain* terrain,
                                                                                    TechniqueType tt, StringStream& outStream)
     {
-        int version = mIsGLES ? 100 : 120;
-
-        // Main header
-        outStream << "#version " << version << "\n";
+        if (mIsGLSL)
+        {
+            int version = mIsGLES ? 100 : 120;
+            outStream << "#version " << version << "\n";
+        }
 
         if(mIsGLES) {
             outStream << "precision highp int;\n";
             outStream << "precision highp float;\n";
         }
 
+        outStream << "#include <OgreUnifiedShader.h>\n";
         // helpers
         outStream << "#include <TerrainHelpers.glsl>\n";
-
-        if (prof->isShadowingEnabled(tt, terrain))
-            generateFpDynamicShadowsHelpers(prof, terrain, tt, outStream);
-
-        outStream << "varying vec4 oPosObj;\n"
-                     "varying vec4 oUVMisc;\n";
-
-        uint texCoordSet = 1;
+        outStream << "#include <SGXLib_PerPixelLighting.glsl>\n";
+        outStream << "#include <SGXLib_IntegratedPSSM.glsl>\n";
 
         // UV's premultiplied, packed as xy/zw
         uint maxLayers = prof->getMaxLayers(terrain);
-        uint numBlendTextures = std::min(terrain->getBlendTextureCount(maxLayers), terrain->getBlendTextureCount());
+        uint numBlendTextures =
+            std::min<uint8>(Terrain::getBlendTextureCount(maxLayers), terrain->getBlendTextures().size());
         uint numLayers = std::min(maxLayers, static_cast<uint>(terrain->getLayerCount()));
-        uint numUVSets = numLayers / 2;
-        if (numLayers % 2)
-            ++numUVSets;
-        if (tt != LOW_LOD)
-        {
-            for (uint i = 0; i < numUVSets; ++i)
-            {
-                outStream <<
-                    "varying vec4 layerUV" << i << ";\n";
-            }
-        }
-        if (prof->getParent()->getDebugLevel() && tt != RENDER_COMPOSITE_MAP)
-        {
-            outStream << "varying vec2 lodInfo;\n";
-        }
-
-        bool fog = terrain->getSceneManager()->getFogMode() != FOG_NONE && tt != RENDER_COMPOSITE_MAP;
-        if (fog)
-        {
-            outStream <<
-                "uniform vec3 fogColour;\n"
-                "varying float fogVal;\n";
-        }
 
         uint currentSamplerIdx = 0;
+        if (tt == LOW_LOD)
+        {
+            // single composite map covers all the others below
+            outStream << StringUtil::format("uniform SAMPLER2D(compositeMap, %d);\n", currentSamplerIdx++);
+        }
+        else
+        {
+            outStream << StringUtil::format("uniform SAMPLER2D(globalNormal, %d);\n", currentSamplerIdx++);
+
+            if (terrain->getGlobalColourMapEnabled() && prof->isGlobalColourMapEnabled())
+            {
+                outStream << StringUtil::format("uniform SAMPLER2D(globalColourMap, %d);\n", currentSamplerIdx++);
+            }
+            if (prof->isLightmapEnabled())
+            {
+                outStream << StringUtil::format("uniform SAMPLER2D(lightMap, %d);\n", currentSamplerIdx++);
+            }
+            // Blend textures - sampler definitions
+            for (uint i = 0; i < numBlendTextures; ++i)
+            {
+                outStream << StringUtil::format("uniform SAMPLER2D(blendTex%d, %d);\n", i, currentSamplerIdx++);
+            }
+
+            // Layer textures - sampler definitions & UV multipliers
+            for (uint i = 0; i < numLayers; ++i)
+            {
+                outStream << StringUtil::format("uniform SAMPLER2D(difftex%d, %d);\n", i, currentSamplerIdx++);
+                outStream << StringUtil::format("uniform SAMPLER2D(normtex%d, %d);\n", i, currentSamplerIdx++);
+            }
+
+            // uv multipliers
+            uint numUVMultipliers = (numLayers + 3) / 4; // integer ceil
+            for (uint i = 0; i < numUVMultipliers; ++i)
+                outStream << "uniform vec4 uvMul_" << i << ";\n";
+        }
+
+        uint numShadowTextures = uint(prof->isShadowingEnabled(tt, terrain));
+        if (numShadowTextures)
+        {
+            if (tt == HIGH_LOD)
+                mShadowSamplerStartHi = currentSamplerIdx;
+            else if (tt == LOW_LOD)
+                mShadowSamplerStartLo = currentSamplerIdx;
+
+            if (prof->getReceiveDynamicShadowsPSSM())
+            {
+                numShadowTextures = prof->getReceiveDynamicShadowsPSSM()->getSplitCount();
+                outStream << "uniform vec4 pssmSplitPoints;\n";
+            }
+            for (uint i = 0; i < numShadowTextures; ++i)
+            {
+                outStream << StringUtil::format("uniform SAMPLER2D(shadowMap%d, %d);\n", i, currentSamplerIdx++);
+                if (prof->getReceiveDynamicShadowsDepth())
+                {
+                    outStream << "uniform float inverseShadowmapSize" << i << ";\n";
+                }
+            }
+        }
+
+        // check we haven't exceeded samplers
+        OgreAssert(
+            currentSamplerIdx < OGRE_MAX_TEXTURE_LAYERS,
+            "Requested options require too many texture samplers! Try reducing the number of layers.");
 
         outStream <<
             // Only 1 light supported in this version
@@ -309,52 +350,31 @@ namespace Ogre
             // pack scale, bias and specular
             "uniform vec4 scaleBiasSpecular;\n";
 
-        if (tt == LOW_LOD)
-        {
-            // single composite map covers all the others below
-            outStream <<
-                "uniform sampler2D compositeMap;\n";
-        }
-        else
-        {
-            outStream <<
-                "uniform sampler2D globalNormal;\n";
+        bool fog = terrain->getSceneManager()->getFogMode() != FOG_NONE && tt != RENDER_COMPOSITE_MAP;
 
-            if (terrain->getGlobalColourMapEnabled() && prof->isGlobalColourMapEnabled())
-            {
-                outStream << "uniform sampler2D globalColourMap;\n";
-            }
-            if (prof->isLightmapEnabled())
-            {
-                outStream << "uniform sampler2D lightMap;\n";
-            }
-            // Blend textures - sampler definitions
-            for (uint i = 0; i < numBlendTextures; ++i)
-            {
-                outStream << "uniform sampler2D blendTex" << i << ";\n";
-            }
+        if (fog)
+            outStream << "uniform vec3 fogColour;\n";
 
-            // Layer textures - sampler definitions & UV multipliers
-            for (uint i = 0; i < numLayers; ++i)
-            {
-                outStream << "uniform sampler2D difftex" << i << ";\n";
-                outStream << "uniform sampler2D normtex" << i << ";\n";
-            }
+        outStream << "MAIN_PARAMETERS\n"
+                     "IN(vec4 oPosObj, TEXCOORD0)\n";
+        uint texCoordSet = 1;
+        outStream << "IN(vec4 oUVMisc, TEXCOORD" << texCoordSet++ << ")\n";
+
+        if (prof->getParent()->getDebugLevel() && tt != RENDER_COMPOSITE_MAP)
+        {
+            outStream << "IN(vec2 lodInfo, TEXCOORD" << texCoordSet++ << ")\n";
         }
 
-        if (prof->isShadowingEnabled(tt, terrain))
+        if (fog)
+            outStream << "IN(float fogVal, COLOR)\n";
+
+        for (uint i = 0; i < numShadowTextures; ++i)
         {
-            generateFpDynamicShadowsParams(&texCoordSet, &currentSamplerIdx, prof, terrain, tt, outStream);
+            outStream << StringUtil::format("IN(vec4 oLightSpacePos%d, TEXCOORD%d)\n", i, texCoordSet++);
         }
 
-        // check we haven't exceeded samplers
-        if (currentSamplerIdx > 16)
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                        "Requested options require too many texture samplers! Try reducing the number of layers.");
-        }
-
-        outStream << "void main(void) {\n"
+        outStream << "MAIN_DECLARATION\n"
+            "{\n"
             "    float shadow = 1.0;\n"
             "    vec2 uv = oUVMisc.xy;\n"
             // base colour
@@ -364,7 +384,8 @@ namespace Ogre
         {
             outStream <<
                 // global normal
-                "    vec3 normal = expand(texture2D(globalNormal, uv)).rgb;\n";
+            "    vec3 normal;\n"
+            "    SGX_FetchNormal(globalNormal, uv, normal);\n";
         }
 
         outStream <<
@@ -413,51 +434,35 @@ namespace Ogre
                 // note, now we need to re-cross to derive tangent again because it wasn't orthonormal
                 outStream << "    tangent = normalize(cross(normal, binormal));\n";
                 // derive final matrix
-                outStream << "    mat3 TBN = mat3(tangent, binormal, normal);\n";
+                outStream << "    mat3 TBN = mtxFromRows(tangent, binormal, normal);\n";
 
                 // set up lighting result placeholders for interpolation
-                outStream << "    vec4 litRes, litResLayer;\n";
-                outStream << "    vec3 TSlightDir, TSeyeDir, TShalfAngle, TSnormal;\n";
+                outStream << "    vec3 TSnormal;\n";
                 if (prof->isLayerParallaxMappingEnabled())
                     outStream << "    float displacement;\n";
                 // move
-                outStream << "    TSlightDir = normalize(TBN * lightDir);\n";
-                outStream << "    TSeyeDir = normalize(TBN * eyeDir);\n";
+                outStream << "    lightDir = normalize(mul(TBN, lightDir));\n";
+                outStream << "    eyeDir = normalize(mul(TBN, eyeDir));\n";
             }
             else
             {
                 // simple per-pixel lighting with no normal mapping
                 outStream << "    lightDir = normalize(lightDir);\n";
                 outStream << "    eyeDir = normalize(eyeDir);\n";
-                outStream << "    vec3 halfAngle = normalize(lightDir + eyeDir);\n";
-                outStream << "    vec4 litRes = lit(dot(normal, lightDir), dot(normal, halfAngle), scaleBiasSpecular.z);\n";
             }
+            outStream << "    vec3 halfAngle = normalize(lightDir + eyeDir);\n";
         }
     }
     //---------------------------------------------------------------------
-    void ShaderHelperGLSL::generateVpLayer(const SM2Profile* prof, const Terrain* terrain,
-                                                                                  TechniqueType tt, uint layer, StringStream& outStream)
-    {
-        // nothing to do
-    }
-    //---------------------------------------------------------------------
     void ShaderHelperGLSL::generateFpLayer(const SM2Profile* prof, const Terrain* terrain,
                                                                                   TechniqueType tt, uint layer, StringStream& outStream)
     {
-        uint uvIdx = layer / 2;
-        String uvChannels = (layer % 2) ? ".zw" : ".xy";
+        uint uvMulIdx = layer / 4;
         uint blendIdx = (layer-1) / 4;
-        String blendChannel = getChannel(layer-1);
-        String blendWeightStr = String("blendTexVal") + StringConverter::toString(blendIdx) + "." + blendChannel;
-
-        // generate early-out conditional
-        /* Disable - causing some issues even when trying to force the use of texldd
-         if (layer && prof->_isSM3Available())
-         outStream << "  if (" << blendWeightStr << " > 0.0003)\n  { \n";
-         */
+        String blendWeightStr = StringUtil::format("blendTexVal%d.%s", blendIdx, getChannel(layer-1));
 
         // generate UV
-        outStream << "    vec2 uv" << layer << " = layerUV" << uvIdx << uvChannels << ";\n";
+        outStream << "    vec2 uv" << layer << " = uv * uvMul_" << uvMulIdx << "." << getChannel(layer) << ";\n";
 
         // calculate lighting here if normal mapping
         if (prof->isLayerNormalMappingEnabled())
@@ -467,17 +472,16 @@ namespace Ogre
                 // modify UV - note we have to sample an extra time
                 outStream << "    displacement = texture2D(normtex" << layer << ", uv" << layer << ").a\n"
                              "        * scaleBiasSpecular.x + scaleBiasSpecular.y;\n";
-                outStream << "    uv" << layer << " += TSeyeDir.xy * displacement;\n";
+                outStream << "    uv" << layer << " += eyeDir.xy * displacement;\n";
             }
 
             // access TS normal map
-            outStream << "    TSnormal = expand(texture2D(normtex" << layer << ", uv" << layer << ")).rgb;\n";
-            outStream << "    TShalfAngle = normalize(TSlightDir + TSeyeDir);\n";
-            outStream << "    litResLayer = lit(dot(TSnormal, TSlightDir), dot(TSnormal, TShalfAngle), scaleBiasSpecular.z);\n";
+            outStream << StringUtil::format("    SGX_FetchNormal(normtex%d, uv%d, TSnormal);\n", layer, layer);
+
             if (!layer)
-                outStream << "    litRes = litResLayer;\n";
+                outStream << "    normal = TSnormal;\n";
             else
-                outStream << "    litRes = mix(litRes, litResLayer, " << blendWeightStr << ");\n";
+                outStream << "    normal += TSnormal * " << blendWeightStr << ";\n";
 
         }
 
@@ -500,40 +504,6 @@ namespace Ogre
                 outStream << "    specular = mix(specular, diffuseSpecTex" << layer
                     << ".a, " << blendWeightStr << ");\n";
         }
-
-        // End early-out
-        /* Disable - causing some issues even when trying to force the use of texldd
-         if (layer && prof->_isSM3Available())
-         outStream << "  } // early-out blend value\n";
-         */
-    }
-    //---------------------------------------------------------------------
-    void ShaderHelperGLSL::generateVpFooter(const SM2Profile* prof, const Terrain* terrain,
-                                                                                   TechniqueType tt, StringStream& outStream)
-    {
-        outStream <<
-            "    gl_Position = viewProjMatrix * worldPos;\n"
-            "    oUVMisc.xy = uv0.xy;\n";
-
-        bool fog = terrain->getSceneManager()->getFogMode() != FOG_NONE && tt != RENDER_COMPOSITE_MAP;
-        if (fog)
-        {
-            if (terrain->getSceneManager()->getFogMode() == FOG_LINEAR)
-            {
-                outStream <<
-                    "    fogVal = clamp((gl_Position.z - fogParams.y) * fogParams.w, 0.0, 1.0);\n";
-            }
-            else
-            {
-                outStream <<
-                    "    fogVal = 1.0 - clamp(1.0 / (exp(gl_Position.z * fogParams.x)), 0.0, 1.0);\n";
-            }
-        }
-
-        if (prof->isShadowingEnabled(tt, terrain))
-            generateVpDynamicShadows(prof, terrain, tt, outStream);
-
-        outStream << "}\n";
     }
     //---------------------------------------------------------------------
     void ShaderHelperGLSL::generateFpFooter(const SM2Profile* prof, const Terrain* terrain,
@@ -571,127 +541,42 @@ namespace Ogre
                 generateFpDynamicShadows(prof, terrain, tt, outStream);
             }
 
-            // diffuse lighting
-            outStream << "    gl_FragColor.rgb += ambient.rgb * diffuse + litRes.y * lightDiffuseColour * diffuse * shadow;\n";
-
             // specular default
             if (!prof->isLayerSpecularMappingEnabled())
                 outStream << "    specular = 1.0;\n";
 
             if (tt == RENDER_COMPOSITE_MAP)
             {
+                outStream << "    SGX_Light_Directional_Diffuse(normal, lightDir, diffuse, gl_FragColor.rgb);\n";
                 // Lighting embedded in alpha
-                outStream <<
-                    "    gl_FragColor.a = shadow;\n";
+                outStream << "    gl_FragColor.a = shadow;\n";
             }
             else
             {
-                // Apply specular
-                outStream << "    gl_FragColor.rgb += litRes.z * lightSpecularColour * specular * shadow;\n";
+                outStream << "    vec3 specularCol = vec3(0,0,0);\n";
+                outStream << "    SGX_Light_Directional_DiffuseSpecular(normal, eyeDir, lightDir, lightDiffuseColour * diffuse, "
+                             "lightSpecularColour * specular, scaleBiasSpecular.z, gl_FragColor.rgb, specularCol);\n";
 
-                if (prof->getParent()->getDebugLevel())
-                {
-                    outStream << "    gl_FragColor.rg += lodInfo.xy;\n";
-                }
+                // Apply specular
+                outStream << "    gl_FragColor.rgb += specularCol;\n";
             }
+            outStream << "    gl_FragColor.rgb = gl_FragColor.rgb * shadow + ambient.rgb * diffuse;\n";
+        }
+
+        if (prof->getParent()->getDebugLevel())
+        {
+            outStream << "    gl_FragColor.rg += lodInfo.xy;\n";
         }
 
         bool fog = terrain->getSceneManager()->getFogMode() != FOG_NONE && tt != RENDER_COMPOSITE_MAP;
         if (fog)
         {
-            outStream << "    gl_FragColor.rgb = mix(gl_FragColor.rgb, fogColour, fogVal);\n";
+            outStream << "    gl_FragColor.rgb = mix(fogColour, gl_FragColor.rgb, fogVal);\n";
         }
 
-        // Final return
         outStream << "}\n";
     }
     //---------------------------------------------------------------------
-    void ShaderHelperGLSL::generateFpDynamicShadowsHelpers(const SM2Profile* prof, const Terrain* terrain,
-                                                                                                  TechniqueType tt, StringStream& outStream)
-    {
-        if (prof->getReceiveDynamicShadowsPSSM())
-        {
-            uint numTextures = prof->getReceiveDynamicShadowsPSSM()->getSplitCount();
-
-            if (prof->getReceiveDynamicShadowsDepth())
-            {
-                outStream <<
-                    "float calcPSSMDepthShadow(";
-            }
-            else
-            {
-                outStream <<
-                    "float calcPSSMSimpleShadow(";
-            }
-
-            outStream << "\n    ";
-            for (uint i = 0; i < numTextures; ++i)
-                outStream << "sampler2D shadowMap" << i << ", ";
-            outStream << "\n    ";
-            for (uint i = 0; i < numTextures; ++i)
-                outStream << "vec4 lsPos" << i << ", ";
-            if (prof->getReceiveDynamicShadowsDepth())
-            {
-                outStream << "\n    ";
-                for (uint i = 0; i < numTextures; ++i)
-                    outStream << "float invShadowmapSize" << i << ", ";
-            }
-            outStream << "\n"
-                "    vec4 pssmSplitPoints, float camDepth) \n"
-                "    { \n"
-                "    float shadow; \n"
-                "    // calculate shadow \n";
-
-            for (uint i = 0; i < numTextures; ++i)
-            {
-                if (!i)
-                    outStream << "    if (camDepth <= pssmSplitPoints." << ShaderHelper::getChannel(i) << ") \n";
-                else if (i < numTextures - 1)
-                    outStream << "    else if (camDepth <= pssmSplitPoints." << ShaderHelper::getChannel(i) << ") \n";
-                else
-                    outStream << "    else \n";
-
-                outStream <<
-                    "    { \n";
-                if (prof->getReceiveDynamicShadowsDepth())
-                {
-                    outStream <<
-                        "        shadow = calcDepthShadow(shadowMap" << i << ", lsPos" << i << ", invShadowmapSize" << i << "); \n";
-                }
-                else
-                {
-                    outStream <<
-                        "        shadow = calcSimpleShadow(shadowMap" << i << ", lsPos" << i << "); \n";
-                }
-                outStream << "    } \n";
-            }
-
-            outStream <<
-                "    return shadow; \n"
-                "} \n\n\n";
-        }
-    }
-    //---------------------------------------------------------------------
-    uint ShaderHelperGLSL::generateVpDynamicShadowsParams(uint texCoord, const SM2Profile* prof,
-                                                                                                 const Terrain* terrain, TechniqueType tt,
-                                                                                                 StringStream& outStream)
-    {
-        // out semantics & params
-        uint numTextures = 1;
-        if (prof->getReceiveDynamicShadowsPSSM())
-        {
-            numTextures = prof->getReceiveDynamicShadowsPSSM()->getSplitCount();
-        }
-        for (uint i = 0; i < numTextures; ++i)
-        {
-            outStream <<
-                "    varying vec4 oLightSpacePos" << i << ";\n" <<
-                "    uniform mat4 texViewProjMatrix" << i << ";\n";
-        }
-
-        return texCoord;
-    }
-    //---------------------------------------------------------------------
     void ShaderHelperGLSL::generateVpDynamicShadows(const SM2Profile* prof, const Terrain* terrain,
                                                                                            TechniqueType tt, StringStream& outStream)
     {
@@ -705,7 +590,7 @@ namespace Ogre
         for (uint i = 0; i < numTextures; ++i)
         {
             outStream <<
-                "    oLightSpacePos" << i << " = texViewProjMatrix" << i << " * worldPos; \n";
+                "    oLightSpacePos" << i << " = mul(texViewProjMatrix" << i << ", worldPos); \n";
         }
 
         if (prof->getReceiveDynamicShadowsPSSM())
@@ -716,83 +601,47 @@ namespace Ogre
         }
     }
     //---------------------------------------------------------------------
-    void ShaderHelperGLSL::generateFpDynamicShadowsParams(uint* texCoord, uint* sampler,
-                                                                                                 const SM2Profile* prof, const Terrain* terrain,
-                                                                                                 TechniqueType tt, StringStream& outStream)
-    {
-        if (tt == HIGH_LOD)
-            mShadowSamplerStartHi = *sampler;
-        else if (tt == LOW_LOD)
-            mShadowSamplerStartLo = *sampler;
-        
-        // in semantics & params
-        uint numTextures = 1;
-        if (prof->getReceiveDynamicShadowsPSSM())
-        {
-            numTextures = prof->getReceiveDynamicShadowsPSSM()->getSplitCount();
-            outStream <<
-                "uniform vec4 pssmSplitPoints;\n";
-        }
-        for (uint i = 0; i < numTextures; ++i)
-        {
-            outStream <<
-                "varying vec4 oLightSpacePos" << i << ";\n" <<
-                "uniform sampler2D shadowMap" << i << ";\n";
-            *sampler = *sampler + 1;
-            *texCoord = *texCoord + 1;
-            if (prof->getReceiveDynamicShadowsDepth())
-            {
-                outStream <<
-                    "uniform float inverseShadowmapSize" << i << ";\n";
-            }
-        }
-    }
-    //---------------------------------------------------------------------
     void ShaderHelperGLSL::generateFpDynamicShadows(const SM2Profile* prof, const Terrain* terrain,
                                                                                            TechniqueType tt, StringStream& outStream)
     {
+        outStream << "    float rtshadow;";
         if (prof->getReceiveDynamicShadowsPSSM())
         {
             uint numTextures = prof->getReceiveDynamicShadowsPSSM()->getSplitCount();
-            outStream << 
-                "    float camDepth = oUVMisc.z;\n";
 
             if (prof->getReceiveDynamicShadowsDepth())
             {
                 outStream << 
-                    "    float rtshadow = calcPSSMDepthShadow(";
+                    "    SGX_ComputeShadowFactor_PSSM3(";
             }
             else
             {
                 outStream << 
-                    "    float rtshadow = calcPSSMSimpleShadow(";
+                    "    calcPSSMSimpleShadow(";
             }
+            outStream << "oUVMisc.z, pssmSplitPoints,\n        ";
             for (uint i = 0; i < numTextures; ++i)
-                outStream << "shadowMap" << i << ", ";
-            outStream << "\n        ";
-
-            for (uint i = 0; i < numTextures; ++i)
-                outStream << "oLightSpacePos" << i << ", ";
-            if (prof->getReceiveDynamicShadowsDepth())
             {
+                outStream << "oLightSpacePos" << i << ", ";
+                outStream << "shadowMap" << i << ", ";
+                if (prof->getReceiveDynamicShadowsDepth())
+                    outStream << "vec2_splat(inverseShadowmapSize" << i << "), ";
                 outStream << "\n        ";
-                for (uint i = 0; i < numTextures; ++i)
-                    outStream << "inverseShadowmapSize" << i << ", ";
             }
-            outStream << "\n" <<
-                "        pssmSplitPoints, camDepth);\n";
+
+            outStream << "        rtshadow);\n";
         }
         else
         {
             if (prof->getReceiveDynamicShadowsDepth())
             {
                 outStream <<
-                    "    float rtshadow = calcDepthShadow(shadowMap0, oLightSpacePos0, inverseShadowmapSize0);";
+                    "    SGX_ShadowPCF4(shadowMap0, oLightSpacePos0, vec2_splat(inverseShadowmapSize0), rtshadow);";
             }
             else
             {
                 outStream <<
-                    "    float rtshadow = calcSimpleShadow(shadowMap0, oLightSpacePos0);";
+                    "    rtshadow = calcSimpleShadow(shadowMap0, oLightSpacePos0);";
             }
         }
 
