@@ -4,7 +4,7 @@ This source file is part of OGRE
 (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -25,6 +25,9 @@ THE SOFTWARE.
 -----------------------------------------------------------------------------
 */
 #include "OgreVolumeDualGridGenerator.h"
+#include "OgreManualObject.h"
+#include "OgreSceneManager.h"
+#include "OgreVolumeMeshBuilder.h"
 
 namespace Ogre {
 namespace Volume {
@@ -532,10 +535,10 @@ namespace Volume {
 
             manual->end();
             mDualGridI++;
-            StringUtil::StrStreamType meshName;
+            StringStream meshName;
             meshName << "VolumeDualGridGridMesh" << mDualGridI;
             manual->convertToMesh(meshName.str());
-            StringUtil::StrStreamType entityName;
+            StringStream entityName;
             entityName << "VolumeDualGrid" << mDualGridI;
             mDualGrid = sceneManager->createEntity(entityName.str(), meshName.str());
         }
