@@ -108,95 +108,46 @@ namespace Ogre {
             void doSet(void* target, const String& val);
         };
 
-        /** Sets the type of billboard to render.
-        @remarks
-            The default sort of billboard (BBT_POINT), always has both x and y axes parallel to 
-            the camera's local axes. This is fine for 'point' style billboards (e.g. flares,
-            smoke, anything which is symmetrical about a central point) but does not look good for
-            billboards which have an orientation (e.g. an elongated raindrop). In this case, the
-            oriented billboards are more suitable (BBT_ORIENTED_COMMON or BBT_ORIENTED_SELF) since they retain an independent Y axis
-            and only the X axis is generated, perpendicular to both the local Y and the camera Z.
-        @param bbt The type of billboard to render
-        */
-        void setBillboardType(BillboardType bbt);
-
-        /** Returns the billboard type in use. */
-        BillboardType getBillboardType(void) const;
+        /// @copydoc BillboardSet::setTextureStacksAndSlices
+        void setTextureStacksAndSlices(uchar stacks, uchar slices)
+        {
+            mBillboardSet->setTextureStacksAndSlices(stacks, slices);
+        }
 
+        /// @copydoc BillboardSet::setBillboardType
+        void setBillboardType(BillboardType bbt) { mBillboardSet->setBillboardType(bbt); }
+        /// @copydoc BillboardSet::getBillboardType
+        BillboardType getBillboardType(void) const { return mBillboardSet->getBillboardType(); }
         /// @copydoc BillboardSet::setUseAccurateFacing
-        void setUseAccurateFacing(bool acc);
+        void setUseAccurateFacing(bool acc) { mBillboardSet->setUseAccurateFacing(acc); }
         /// @copydoc BillboardSet::getUseAccurateFacing
-        bool getUseAccurateFacing(void) const;
-
-        /** Sets the point which acts as the origin point for all billboards in this set.
-        @remarks
-            This setting controls the fine tuning of where a billboard appears in relation to it's
-            position. It could be that a billboard's position represents it's center (e.g. for fireballs),
-            it could mean the center of the bottom edge (e.g. a tree which is positioned on the ground),
-            the top-left corner (e.g. a cursor).
-        @par
-            The default setting is BBO_CENTER.
-        @param origin
-            A member of the BillboardOrigin enum specifying the origin for all the billboards in this set.
-        */
+        bool getUseAccurateFacing(void) const { return mBillboardSet->getUseAccurateFacing(); }
+        /// @copydoc BillboardSet::setBillboardOrigin
         void setBillboardOrigin(BillboardOrigin origin) { mBillboardSet->setBillboardOrigin(origin); }
-
-        /** Gets the point which acts as the origin point for all billboards in this set.
-        @return
-            A member of the BillboardOrigin enum specifying the origin for all the billboards in this set.
-        */
+        /// @copydoc BillboardSet::getBillboardOrigin
         BillboardOrigin getBillboardOrigin(void) const { return mBillboardSet->getBillboardOrigin(); }
-
-        /** Sets billboard rotation type.
-        @remarks
-            This setting controls the billboard rotation type, you can deciding rotate the billboard's vertices
-            around their facing direction or rotate the billboard's texture coordinates.
-        @par
-            The default settings is BBR_TEXCOORD.
-        @param rotationType
-            A member of the BillboardRotationType enum specifying the rotation type for all the billboards in this set.
-        */
-        void setBillboardRotationType(BillboardRotationType rotationType);
-
-        /** Gets billboard rotation type.
-        @return
-            A member of the BillboardRotationType enum specifying the rotation type for all the billboards in this set.
-        */
-        BillboardRotationType getBillboardRotationType(void) const;
-
-        /** Use this to specify the common direction given to billboards of type BBT_ORIENTED_COMMON.
-        @remarks
-            Use BBT_ORIENTED_COMMON when you want oriented billboards but you know they are always going to 
-            be oriented the same way (e.g. rain in calm weather). It is faster for the system to calculate
-            the billboard vertices if they have a common direction.
-        @param vec The direction for all billboards.
-        */
-        void setCommonDirection(const Vector3& vec);
-
-        /** Gets the common direction for all billboards (BBT_ORIENTED_COMMON) */
-        const Vector3& getCommonDirection(void) const;
-
-        /** Use this to specify the common up-vector given to billboards of type BBT_PERPENDICULAR_SELF.
-        @remarks
-            Use BBT_PERPENDICULAR_SELF when you want oriented billboards perpendicular to their own
-            direction vector and doesn't face to camera. In this case, we need an additional vector
-            to determine the billboard X, Y axis. The generated X axis perpendicular to both the own
-            direction and up-vector, the Y axis will coplanar with both own direction and up-vector,
-            and perpendicular to own direction.
-        @param vec The up-vector for all billboards.
-        */
-        void setCommonUpVector(const Vector3& vec);
-
-        /** Gets the common up-vector for all billboards (BBT_PERPENDICULAR_SELF) */
-        const Vector3& getCommonUpVector(void) const;
-
+        /// @copydoc BillboardSet::setBillboardRotationType
+        void setBillboardRotationType(BillboardRotationType rotationType)
+        {
+            mBillboardSet->setBillboardRotationType(rotationType);
+        }
+        /// @copydoc BillboardSet::getBillboardRotationType
+        BillboardRotationType getBillboardRotationType() const
+        {
+            return mBillboardSet->getBillboardRotationType();
+        }
+        /// @copydoc BillboardSet::setCommonDirection
+        void setCommonDirection(const Vector3& vec) { mBillboardSet->setCommonDirection(vec); }
+        /// @copydoc BillboardSet::getCommonDirection
+        const Vector3& getCommonDirection(void) const { return mBillboardSet->getCommonDirection(); }
+        /// @copydoc BillboardSet::setCommonUpVector
+        void setCommonUpVector(const Vector3& vec) { mBillboardSet->setCommonUpVector(vec); }
+        /// @copydoc BillboardSet::getCommonUpVector
+        const Vector3& getCommonUpVector(void) const { return mBillboardSet->getCommonUpVector(); }
         /// @copydoc BillboardSet::setPointRenderingEnabled
-        void setPointRenderingEnabled(bool enabled);
-
+        void setPointRenderingEnabled(bool enabled) { mBillboardSet->setPointRenderingEnabled(enabled); }
         /// @copydoc BillboardSet::isPointRenderingEnabled
-        bool isPointRenderingEnabled(void) const;
-
-
+        bool isPointRenderingEnabled(void) const { return mBillboardSet->isPointRenderingEnabled(); }
 
         /// @copydoc ParticleSystemRenderer::getType
         const String& getType(void) const;
@@ -204,34 +155,44 @@ namespace Ogre {
         void _updateRenderQueue(RenderQueue* queue, 
             std::list<Particle*>& currentParticles, bool cullIndividually);
         /// @copydoc ParticleSystemRenderer::visitRenderables
-        void visitRenderables(Renderable::Visitor* visitor, 
-            bool debugRenderables = false);
-        /// @copydoc ParticleSystemRenderer::_setMaterial
-        void _setMaterial(MaterialPtr& mat);
+        void visitRenderables(Renderable::Visitor* visitor, bool debugRenderables = false)
+        {
+            mBillboardSet->visitRenderables(visitor, debugRenderables);
+        }
+        void _setMaterial(MaterialPtr& mat) { mBillboardSet->setMaterial(mat); }
         /// @copydoc ParticleSystemRenderer::_notifyCurrentCamera
-        void _notifyCurrentCamera(Camera* cam);
-        /// @copydoc ParticleSystemRenderer::_notifyParticleRotated
-        void _notifyParticleRotated(void);
-        /// @copydoc ParticleSystemRenderer::_notifyParticleResized
-        void _notifyParticleResized(void);
+        void _notifyCurrentCamera(Camera* cam) { mBillboardSet->_notifyCurrentCamera(cam); }
         /// @copydoc ParticleSystemRenderer::_notifyParticleQuota
-        void _notifyParticleQuota(size_t quota);
+        void _notifyParticleQuota(size_t quota) { mBillboardSet->setPoolSize(quota); }
         /// @copydoc ParticleSystemRenderer::_notifyAttached
-        void _notifyAttached(Node* parent, bool isTagPoint = false);
+        void _notifyAttached(Node* parent, bool isTagPoint = false)
+        {
+            mBillboardSet->_notifyAttached(parent, isTagPoint);
+        }
         /// @copydoc ParticleSystemRenderer::_notifyDefaultDimensions
-        void _notifyDefaultDimensions(Real width, Real height);
+        void _notifyDefaultDimensions(Real width, Real height)
+        {
+            mBillboardSet->setDefaultDimensions(width, height);
+        }
         /// @copydoc ParticleSystemRenderer::setRenderQueueGroup
-        void setRenderQueueGroup(uint8 queueID);
+        void setRenderQueueGroup(uint8 queueID) { mBillboardSet->setRenderQueueGroup(queueID); }
         /// @copydoc MovableObject::setRenderQueueGroupAndPriority
-        void setRenderQueueGroupAndPriority(uint8 queueID, ushort priority);
+        void setRenderQueueGroupAndPriority(uint8 queueID, ushort priority)
+        {
+            mBillboardSet->setRenderQueueGroupAndPriority(queueID, priority);
+        }
         /// @copydoc ParticleSystemRenderer::setKeepParticlesInLocalSpace
-        void setKeepParticlesInLocalSpace(bool keepLocal);
+        void setKeepParticlesInLocalSpace(bool keepLocal)
+        {
+            mBillboardSet->setBillboardsInWorldSpace(!keepLocal);
+        }
         /// @copydoc ParticleSystemRenderer::_getSortMode
-        SortMode _getSortMode(void) const;
+        SortMode _getSortMode(void) const { return mBillboardSet->_getSortMode(); }
 
         /// Access BillboardSet in use
         BillboardSet* getBillboardSet(void) const { return mBillboardSet; }
 
+        void _notifyBoundingBox(const AxisAlignedBox& aabb) override;
     protected:
         static CmdBillboardType msBillboardTypeCmd;
         static CmdBillboardOrigin msBillboardOriginCmd;
@@ -240,8 +201,6 @@ namespace Ogre {
         static CmdCommonUpVector msCommonUpVectorCmd;
         static CmdPointRendering msPointRenderingCmd;
         static CmdAccurateFacing msAccurateFacingCmd;
-
-
     };
 
     /** Factory class for BillboardParticleRenderer */
