@@ -48,8 +48,11 @@ namespace Ogre {
 
     /** Enum covering what exactly a billboard's position means (center,
         top-left etc).
-    @see
-        BillboardSet::setBillboardOrigin
+
+        This setting controls the fine tuning of where a billboard appears in relation to it's
+        position. It could be that a billboard's position represents it's center (e.g. for fireballs),
+        it could mean the center of the bottom edge (e.g. a tree which is positioned on the ground),
+        the top-left corner (e.g. a cursor).
     */
     enum BillboardOrigin
     {
@@ -63,7 +66,13 @@ namespace Ogre {
         BBO_BOTTOM_CENTER,
         BBO_BOTTOM_RIGHT
     };
-    /** The rotation type of billboard. */
+    /** The rotation type of billboard.
+     *
+     * By default, billboard particles will rotate the texture coordinates to according with particle
+     * rotation. But rotate texture coordinates has some disadvantage, e.g. the corners of the texture will
+     * lost after rotate, and the corners of the billboard will fill with unwanted texture area when using
+     * wrap address mode or sub-texture sampling. This settings allow you specifying other rotation type.
+     */
     enum BillboardRotationType
     {
         /// Rotate the billboard's vertices around their facing direction
@@ -132,9 +141,6 @@ namespace Ogre {
         /// Pointer to the material to use
         MaterialPtr mMaterial;
 
-        /// True if no billboards in this set have been resized - greater efficiency.
-        bool mAllDefaultSize;
-
         /// Flag indicating whether to autoextend pool
         bool mAutoExtendPool;
 
@@ -144,33 +150,19 @@ namespace Ogre {
         /// Use 'true' billboard to cam position facing, rather than camera direcion
         bool mAccurateFacing;
 
-        bool mAllDefaultRotation;
         bool mWorldSpace;
 
-        typedef std::list<Billboard*> ActiveBillboardList;
-        typedef std::list<Billboard*> FreeBillboardList;
         typedef std::vector<Billboard*> BillboardPool;
 
-        /** Active billboard list.
-        @remarks
-            This is a linked list of pointers to billboards in the billboard pool.
-        @par
-            This allows very fast insertions and deletions from anywhere in the list to activate / deactivate billboards
+        /** Active billboard count.
+
+            This allows very fast activation / deactivation of billboards
             (required for particle systems etc.) as well as reuse of Billboard instances in the pool
             without construction & destruction which avoids memory thrashing.
         */
-        ActiveBillboardList mActiveBillboards;
+        size_t mActiveBillboards;
 
-        /** Free billboard queue.
-        @remarks
-            This contains a list of the billboards free for use as new instances
-            as required by the set. Billboard instances are preconstructed up to the estimated size in the
-            mBillboardPool vector and are referenced on this deque at startup. As they get used this deque
-            reduces, as they get released back to to the set they get added back to the deque.
-        */
-        FreeBillboardList mFreeBillboards;
-
-        /** Pool of billboard instances for use and reuse in the active billboard list.
+        /** Pool of billboard instances for use and reuse.
         @remarks
             This vector will be preallocated with the estimated size of the set,and will extend as required.
         */
@@ -246,7 +238,9 @@ namespace Ogre {
         @param offsets Array of 4 Vector3 offsets
         @param pBillboard Reference to billboard
         */
-        void genVertices(const Vector3* const offsets, const Billboard& pBillboard);
+        void genQuadVertices(const Vector3* const offsets, const Billboard& pBillboard);
+
+        void genPointVertices(const Billboard& pBillboard);
 
         /** Internal method generates vertex offsets.
         @remarks
@@ -255,7 +249,7 @@ namespace Ogre {
             Fills output array of 4 vectors with vector offsets
             from origin for left-top, right-top, left-bottom, right-bottom corners.
         */
-        void genVertOffsets(Real inleft, Real inright, Real intop, Real inbottom,
+        static void genVertOffsets(Real inleft, Real inright, Real intop, Real inbottom,
             Real width, Real height,
             const Vector3& x, const Vector3& y, Vector3* pDestVec);
 
@@ -280,7 +274,7 @@ namespace Ogre {
             float operator()(Billboard* bill) const;
         };
 
-        static RadixSort<ActiveBillboardList, Billboard*, float> mRadixSorter;
+        static RadixSort<BillboardPool, Billboard*, float> mRadixSorter;
 
         /// Use point rendering?
         bool mPointRendering;
@@ -353,34 +347,15 @@ namespace Ogre {
             const Vector3& position,
             const ColourValue& colour = ColourValue::White );
 
-        /** Creates a new billboard and adds it to this set.
-        @remarks
-            Behaviour once the billboard pool has been exhausted depends on the
-            BillboardSet::setAutoextend option.
-        @param x
-            The @c x position of the new billboard relative to the center of the set
-        @param y
-            The @c y position of the new billboard relative to the center of the set
-        @param z
-            The @c z position of the new billboard relative to the center of the set
-        @param colour
-            Optional base colour of the billboard.
-        @return
-            On success, a pointer to a newly created Billboard is
-            returned.
-        @par
-            On failure (i.e. no more space and can't autoextend),
-            @c NULL is returned.
-        @see
-            BillboardSet::setAutoextend
-        */
-        Billboard* createBillboard(
-            Real x, Real y, Real z,
-            const ColourValue& colour = ColourValue::White );
+        /// @overload
+        Billboard* createBillboard(Real x, Real y, Real z, const ColourValue& colour = ColourValue::White)
+        {
+            return createBillboard(Vector3(x, y, z), colour);
+        }
 
         /** Returns the number of active billboards which currently make up this set.
         */
-        virtual int getNumBillboards(void) const;
+        int getNumBillboards(void) const { return static_cast<int>(mActiveBillboards); }
 
         /** Tells the set whether to allow automatic extension of the pool of billboards.
         @remarks
@@ -397,24 +372,24 @@ namespace Ogre {
         @param autoextend
             @c true to double the pool every time it runs out, @c false to fail silently.
         */
-        virtual void setAutoextend(bool autoextend);
+        void setAutoextend(bool autoextend) { mAutoExtendPool = autoextend; }
 
         /** Returns true if the billboard pool automatically extends.
         @see
             BillboardSet::setAutoextend
         */
-        virtual bool getAutoextend(void) const;
+        bool getAutoextend(void) const { return mAutoExtendPool; }
 
         /** Enables sorting for this BillboardSet. (default: off)
         @param sortenable true to sort the billboards according to their distance to the camera
         */
-        virtual void setSortingEnabled(bool sortenable);
+        void setSortingEnabled(bool sortenable) { mSortingEnabled = sortenable; }
 
         /** Returns true if sorting of billboards is enabled based on their distance from the camera
         @see
             BillboardSet::setSortingEnabled
         */
-        virtual bool getSortingEnabled(void) const;
+        bool getSortingEnabled(void) const { return mSortingEnabled; }
 
         /** Adjusts the size of the pool of billboards available in this set.
         @remarks
@@ -434,16 +409,14 @@ namespace Ogre {
         @see
             BillboardSet::setAutoextend
         */
-        virtual unsigned int getPoolSize(void) const;
-
+        unsigned int getPoolSize() const { return static_cast<unsigned int>(mBillboardPool.size()); }
 
         /** Empties this set of all billboards.
         */
         virtual void clear();
 
         /** Returns a pointer to the billboard at the supplied index.
-        @note
-            This method requires linear time since the billboard list is a linked list.
+
         @param index
             The index of the billboard that is requested.
         @return
@@ -455,19 +428,15 @@ namespace Ogre {
         virtual Billboard* getBillboard(unsigned int index) const;
 
         /** Removes the billboard at the supplied index.
-        @note
-            This method requires linear time since the billboard list is a linked list.
         */
         virtual void removeBillboard(unsigned int index);
 
         /** Removes a billboard from the set.
-        @note
-            This version is more efficient than removing by index.
         */
         virtual void removeBillboard(Billboard* pBill);
 
         /** Sets the point which acts as the origin point for all billboards in this set.
-        @remarks
+
             This setting controls the fine tuning of where a billboard appears in relation to it's
             position. It could be that a billboard's position represents it's center (e.g. for fireballs),
             it could mean the center of the bottom edge (e.g. a tree which is positioned on the ground),
@@ -477,13 +446,13 @@ namespace Ogre {
         @param origin
             A member of the BillboardOrigin enum specifying the origin for all the billboards in this set.
         */
-        virtual void setBillboardOrigin(BillboardOrigin origin);
+        void setBillboardOrigin(BillboardOrigin origin) { mOriginType = origin; }
 
         /** Gets the point which acts as the origin point for all billboards in this set.
         @return
             A member of the BillboardOrigin enum specifying the origin for all the billboards in this set.
         */
-        virtual BillboardOrigin getBillboardOrigin(void) const;
+        BillboardOrigin getBillboardOrigin(void) const { return mOriginType; }
 
         /** Sets billboard rotation type.
         @remarks
@@ -494,13 +463,13 @@ namespace Ogre {
         @param rotationType
             A member of the BillboardRotationType enum specifying the rotation type for all the billboards in this set.
         */
-        virtual void setBillboardRotationType(BillboardRotationType rotationType);
+        void setBillboardRotationType(BillboardRotationType rotationType) { mRotationType = rotationType; }
 
         /** Sets billboard rotation type.
         @return
             A member of the BillboardRotationType enum specifying the rotation type for all the billboards in this set.
         */
-        virtual BillboardRotationType getBillboardRotationType(void) const;
+        BillboardRotationType getBillboardRotationType(void) const { return mRotationType; }
 
         /** Sets the default dimensions of the billboards in this set.
         @remarks
@@ -512,16 +481,20 @@ namespace Ogre {
         @param height
             The new default height for the billboards in this set.
         */
-        virtual void setDefaultDimensions(Real width, Real height);
+        void setDefaultDimensions(Real width, Real height)
+        {
+            mDefaultWidth = width;
+            mDefaultHeight = height;
+        }
 
         /** See setDefaultDimensions - this sets 1 component individually. */
-        virtual void setDefaultWidth(Real width);
+        void setDefaultWidth(Real width) { mDefaultWidth = width; }
         /** See setDefaultDimensions - this gets 1 component individually. */
-        virtual Real getDefaultWidth(void) const;
+        Real getDefaultWidth(void) const { return mDefaultWidth; }
         /** See setDefaultDimensions - this sets 1 component individually. */
-        virtual void setDefaultHeight(Real height);
+        void setDefaultHeight(Real height) { mDefaultHeight = height; }
         /** See setDefaultDimensions - this gets 1 component individually. */
-        virtual Real getDefaultHeight(void) const;
+        Real getDefaultHeight(void) const { return mDefaultHeight; }
 
         /** Sets the name of the material to be used for this billboard set.
         */
@@ -530,7 +503,7 @@ namespace Ogre {
         /** Sets the name of the material to be used for this billboard set.
         @return The name of the material that is used for this set.
         */
-        virtual const String& getMaterialName(void) const;
+        const String& getMaterialName(void) const { return mMaterial->getName(); }
 
         virtual void _notifyCurrentCamera(Camera* cam) override;
 
@@ -551,11 +524,10 @@ namespace Ogre {
         */
         void setBounds(const AxisAlignedBox& box, Real radius);
 
-
-        virtual const AxisAlignedBox& getBoundingBox(void) const override;
-        virtual Real getBoundingRadius(void) const override;
+        const AxisAlignedBox& getBoundingBox(void) const override { return mAABB; }
+        Real getBoundingRadius(void) const override { return mBoundingRadius; }
         virtual void _updateRenderQueue(RenderQueue* queue) override;
-        virtual const MaterialPtr& getMaterial(void) const override;
+        const MaterialPtr& getMaterial(void) const override { return mMaterial; }
 
         /** Sets the name of the material to be used for this billboard set.
         @param material
@@ -567,16 +539,13 @@ namespace Ogre {
         virtual void getRenderOperation(RenderOperation& op) override;
         virtual void getWorldTransforms(Matrix4* xform) const override;
 
-        /** Internal callback used by Billboards to notify their parent that they have been resized.
-        */
-        virtual void _notifyBillboardResized(void);
-
-        /** Internal callback used by Billboards to notify their parent that they have been rotated.
-        */
-        virtual void _notifyBillboardRotated(void);
+        /// @deprecated do not use
+        OGRE_DEPRECATED void _notifyBillboardResized() {}
+        /// @deprecated do not use
+        OGRE_DEPRECATED void _notifyBillboardRotated() {}
 
         /** Returns whether or not billboards in this are tested individually for culling. */
-        virtual bool getCullIndividually(void) const;
+        bool getCullIndividually(void) const { return mCullIndividual; }
         /** Sets whether culling tests billboards in this individually as well as in a group.
         @remarks
             Billboard sets are always culled as a whole group, based on a bounding box which 
@@ -597,7 +566,7 @@ namespace Ogre {
         @param cullIndividual If true, each billboard is tested before being sent to the pipeline as well 
             as the whole set having to pass the coarse group bounding test.
         */
-        virtual void setCullIndividually(bool cullIndividual);
+        void setCullIndividually(bool cullIndividual) { mCullIndividual = cullIndividual; }
 
         /** Sets the type of billboard to render.
         @remarks
@@ -619,10 +588,10 @@ namespace Ogre {
             use double-side material (<b>cull_hardware node</b>) to ensure no billboard are culled.
         @param bbt The type of billboard to render
         */
-        virtual void setBillboardType(BillboardType bbt);
+        void setBillboardType(BillboardType bbt) { mBillboardType = bbt; }
 
         /** Returns the billboard type in use. */
-        virtual BillboardType getBillboardType(void) const;
+        BillboardType getBillboardType(void) const { return mBillboardType; }
 
         /** Use this to specify the common direction given to billboards of type BBT_ORIENTED_COMMON or BBT_PERPENDICULAR_COMMON.
         @remarks
@@ -638,10 +607,10 @@ namespace Ogre {
         @note
             The direction are use as is, never normalised in internal, user are supposed to normalise it himself.
         */
-        virtual void setCommonDirection(const Vector3& vec);
+        void setCommonDirection(const Vector3& vec) { mCommonDirection = vec; }
 
         /** Gets the common direction for all billboards (BBT_ORIENTED_COMMON) */
-        virtual const Vector3& getCommonDirection(void) const;
+        const Vector3& getCommonDirection(void) const { return mCommonDirection; }
 
         /** Use this to specify the common up-vector given to billboards of type BBT_PERPENDICULAR_SELF or BBT_PERPENDICULAR_COMMON.
         @remarks
@@ -657,11 +626,11 @@ namespace Ogre {
         @note
             The up-vector are use as is, never normalised in internal, user are supposed to normalise it himself.
         */
-        virtual void setCommonUpVector(const Vector3& vec);
+        void setCommonUpVector(const Vector3& vec) { mCommonUpVector = vec; }
 
         /** Gets the common up-vector for all billboards (BBT_PERPENDICULAR_SELF and BBT_PERPENDICULAR_COMMON) */
-        virtual const Vector3& getCommonUpVector(void) const;
-        
+        const Vector3& getCommonUpVector(void) const { return mCommonUpVector; }
+
         /** Sets whether or not billboards should use an 'accurate' facing model
             based on the vector from each billboard to the camera, rather than 
             an optimised version using just the camera direction.
@@ -675,12 +644,12 @@ namespace Ogre {
             more expensive, but more accurate version.
         @param acc True to use the slower but more accurate model. Default is false.
         */
-        virtual void setUseAccurateFacing(bool acc) { mAccurateFacing = acc; }
+        void setUseAccurateFacing(bool acc) { mAccurateFacing = acc; }
         /** Gets whether or not billboards use an 'accurate' facing model
             based on the vector from each billboard to the camera, rather than 
             an optimised version using just the camera direction.
         */
-        virtual bool getUseAccurateFacing(void) const { return mAccurateFacing; }
+        bool getUseAccurateFacing(void) const { return mAccurateFacing; }
 
 
         virtual const String& getMovableType(void) const override;
@@ -706,7 +675,7 @@ namespace Ogre {
             This is most useful when you are driving the billboard set from 
             an external data source.
         */
-        virtual void setBillboardsInWorldSpace(bool ws) { mWorldSpace = ws; }
+        void setBillboardsInWorldSpace(bool ws) { mWorldSpace = ws; }
 
         /** Gets whether billboards are treated as being in world space.
          */
@@ -729,8 +698,6 @@ namespace Ogre {
 
         @param coords is a vector of texture coordinates (in UV space) to choose 
             from for each billboard created in the set.
-        @param numCoords is how many such coordinate rectangles there are to 
-            choose from.
         @remarks
             Set 'coords' to 0 and/or 'numCoords' to 0 to reset the texture coord 
             rects to the initial set of a single rectangle spanning 0 through 1 in 
@@ -739,22 +706,33 @@ namespace Ogre {
             BillboardSet::setTextureStacksAndSlices()
             Billboard::setTexcoordIndex()
         */
-        virtual void setTextureCoords( Ogre::FloatRect const * coords, uint16 numCoords );
+        void setTextureCoords(const std::vector<FloatRect>& coords);
 
-        /** setTextureStacksAndSlices() will generate texture coordinate rects as if the 
-            texture for the billboard set contained 'stacks' rows of 'slices' 
-            images each, all equal size. Thus, if the texture size is 512x512 
-            and 'stacks' is 4 and 'slices' is 8, each sub-rectangle of the texture 
+        /// @deprecated
+        OGRE_DEPRECATED void setTextureCoords(FloatRect const* coords, uint16 numCoords)
+        {
+            setTextureCoords(std::vector<FloatRect>(coords, coords + numCoords));
+        }
+
+        /** Generate texture coordinate rects for a tiled texture sheet
+
+            A texture sheet is a grid of images that can be used to create simple animations.
+            This method will generate the uv coordinates for the individual sub-rectangles.
+
+            These can then be addressed by Ogre::Billboard::setTexcoordIndex().
+
+            If the texture size is 512x512 and 'stacks' is 4 and 'slices' is 8, each sub-rectangle of the texture
             would be 128 texels tall and 64 texels wide.
-        @remarks
-            This function is short-hand for creating a regular set and calling 
-            setTextureCoords() yourself. The numbering used for Billboard::setTexcoordIndex() 
-            counts first across, then down, so top-left is 0, the one to the right 
+
+            The numbering counts first across, then down, so top-left is 0, the one to the right
             of that is 1, and the lower-right is stacks*slices-1.
-        @see
-            BillboardSet::setTextureCoords()
+
+            If you need more flexibility, you can use Ogre::BillboardSet::setTextureCoords() instead.
+
+            @param stacks number of vertical tiles (rows)
+            @param slices number of horizontal tiles (columns)
         */
-        virtual void setTextureStacksAndSlices( uchar stacks, uchar slices );
+        void setTextureStacksAndSlices( uchar stacks, uchar slices );
 
         /** getTextureCoords() returns the current texture coordinate rects in 
             effect. By default, there is only one texture coordinate rect in the 
@@ -762,11 +740,14 @@ namespace Ogre {
         @see
             BillboardSet::setTextureCoords()
         */
-        virtual Ogre::FloatRect const * getTextureCoords( uint16 * oNumCoords );
+        const std::vector<FloatRect>& getTextureCoords() const { return mTextureCoords; }
+
+        /// @deprecated
+        OGRE_DEPRECATED Ogre::FloatRect const * getTextureCoords( uint16 * oNumCoords );
 
         /** Set whether or not the BillboardSet will use point rendering
             rather than manually generated quads.
-        @remarks
+
             By default a billboardset is rendered by generating geometry for a
             textured quad in memory, taking into account the size and 
             orientation settings, and uploading it to the video card. 
@@ -774,30 +755,28 @@ namespace Ogre {
             only one position needs to be sent per billboard rather than 4 and
             the hardware sorts out how this is rendered based on the render
             state.
-        @par
+
             Using point rendering is faster than generating quads manually, but
             is more restrictive. The following restrictions apply:
-            \li Only the BBT_POINT type is supported
-            \li Size and appearance of each billboard is controlled by the 
-                material (Pass::setPointSize, Pass::setPointSizeAttenuation, 
-                Pass::setPointSpritesEnabled)
-            \li Per-billboard size is not supported (stems from the above)
-            \li Per-billboard rotation is not supported, this can only be 
+            - Only the Ogre::BBT_POINT type is supported
+            - Size and appearance of each billboard is controlled by the material
+              - Ogre::Pass::setPointSize
+              - Ogre::Pass::setPointAttenuation
+              - Ogre::Pass::setPointSpritesEnabled
+            - Per-billboard size is not supported (stems from the above)
+            - Per-billboard rotation is not supported, this can only be
                 controlled through texture unit rotation
-            \li Only BBO_CENTER origin is supported
-            \li Per-billboard texture coordinates are not supported
+            - Only Ogre::BBO_CENTER origin is supported
+            - Per-billboard texture coordinates are not supported
 
-        @par
             You will almost certainly want to enable in your material pass
-            both point attenuation and point sprites if you use this option. 
-        @param enabled True to enable point rendering, false otherwise
+            both point attenuation and point sprites if you use this option.
         */
         virtual void setPointRenderingEnabled(bool enabled);
 
         /** Returns whether point rendering is enabled. */
-        virtual bool isPointRenderingEnabled(void) const
-        { return mPointRendering; }
-        
+        bool isPointRenderingEnabled(void) const { return mPointRendering; }
+
         /// Override to return specific type flag
         uint32 getTypeFlags(void) const;
 
@@ -838,8 +817,6 @@ namespace Ogre {
         static String FACTORY_TYPE_NAME;
 
         const String& getType(void) const;
-        void destroyInstance( MovableObject* obj);  
-
     };
     /** @} */
     /** @} */
