@@ -354,17 +354,9 @@ namespace Ogre {
         /** Inputs (for material used for rendering the quad).
             An empty string signifies that no input is used */
         InputTex mInputs[OGRE_MAX_TEXTURE_LAYERS];
-        /// Stencil operation parameters
-        bool mStencilCheck;
-        CompareFunction mStencilFunc; 
-        uint32 mStencilRefValue;
-        uint32 mStencilMask;
-        StencilOperation mStencilFailOp;
-        StencilOperation mStencilDepthFailOp;
-        StencilOperation mStencilPassOp;
         Vector3i mThreadGroups;
-
-        bool mStencilTwoSidedOperation;
+        /// Stencil operation parameters
+        StencilState mStencilState;
         bool mStencilReadBackAsTexture;
 
         /// True if quad should not cover whole screen
