@@ -42,7 +42,6 @@ namespace Ogre {
     /** \addtogroup Effects
     *  @{
     */
-    const size_t RENDER_QUEUE_COUNT = RENDER_QUEUE_MAX+1;       
             
     /** An instance of a Compositor object for one Viewport. It is part of the CompositorChain
         for a Viewport.
@@ -217,7 +216,7 @@ namespace Ogre {
         @return
             The texture pointer, corresponds to a real texture.
         */
-        TexturePtr getTextureInstance(const String& name, size_t mrtIndex);
+        const TexturePtr& getTextureInstance(const String& name, size_t mrtIndex);
 
         /** Get the render target for a given render texture name. 
         @remarks
@@ -375,7 +374,7 @@ namespace Ogre {
         @param mrtIndex
             For MRTs, which attached surface to retrieve.
         */
-        const String &getSourceForTex(const String &name, size_t mrtIndex = 0);
+        const TexturePtr &getSourceForTex(const String &name, size_t mrtIndex = 0);
 
         /** Queue a render system operation.
         */
