@@ -4,7 +4,7 @@ This source file is part of OGRE
     (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2012 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -29,17 +29,27 @@ THE SOFTWARE.
 #define _DynLib_H__
 
 #include "OgrePrerequisites.h"
+#include "OgreHeaderPrefix.h"
 
 #if OGRE_PLATFORM == OGRE_PLATFORM_WIN32
 #    define DYNLIB_HANDLE hInstance
-#    define DYNLIB_LOAD( a ) LoadLibraryEx( a, NULL, LOAD_WITH_ALTERED_SEARCH_PATH )
+#    define DYNLIB_LOAD( a ) LoadLibraryEx( a, NULL, 0 ) // we can not use LOAD_WITH_ALTERED_SEARCH_PATH with relative paths
 #    define DYNLIB_GETSYM( a, b ) GetProcAddress( a, b )
 #    define DYNLIB_UNLOAD( a ) !FreeLibrary( a )
 
 struct HINSTANCE__;
 typedef struct HINSTANCE__* hInstance;
 
-#elif OGRE_PLATFORM == OGRE_PLATFORM_LINUX || OGRE_PLATFORM == OGRE_PLATFORM_ANDROID
+#elif OGRE_PLATFORM == OGRE_PLATFORM_WINRT
+#    define DYNLIB_HANDLE hInstance
+#    define DYNLIB_LOAD( a ) LoadPackagedLibrary( stringToWstring(a).c_str(), 0 )
+#    define DYNLIB_GETSYM( a, b ) GetProcAddress( a, b )
+#    define DYNLIB_UNLOAD( a ) !FreeLibrary( a )
+
+struct HINSTANCE__;
+typedef struct HINSTANCE__* hInstance;
+
+#elif OGRE_PLATFORM == OGRE_PLATFORM_LINUX || OGRE_PLATFORM == OGRE_PLATFORM_ANDROID || OGRE_PLATFORM == OGRE_PLATFORM_EMSCRIPTEN
 #    define DYNLIB_HANDLE void*
 #    define DYNLIB_LOAD( a ) dlopen( a, RTLD_LAZY | RTLD_GLOBAL)
 #    define DYNLIB_GETSYM( a, b ) dlsym( a, b )
@@ -48,24 +58,19 @@ typedef struct HINSTANCE__* hInstance;
 #elif OGRE_PLATFORM == OGRE_PLATFORM_APPLE || OGRE_PLATFORM == OGRE_PLATFORM_APPLE_IOS
 #    define DYNLIB_HANDLE void*
 #    define DYNLIB_LOAD( a ) mac_loadDylib( a )
+#    define FRAMEWORK_LOAD( a ) mac_loadFramework( a )
 #    define DYNLIB_GETSYM( a, b ) dlsym( a, b )
 #    define DYNLIB_UNLOAD( a ) dlclose( a )
 
-#elif OGRE_PLATFORM == OGRE_PLATFORM_SYMBIAN || OGRE_PLATFORM == OGRE_PLATFORM_NACL
-#    define DYNLIB_HANDLE void*
-#    define DYNLIB_LOAD( a ) 0
-#    define DYNLIB_GETSYM( a, b ) 0
-#    define DYNLIB_UNLOAD( a ) 0
-
 #endif
 
 namespace Ogre {
-	/** \addtogroup Core
-	*  @{
-	*/
-	/** \addtogroup General
-	*  @{
-	*/
+    /** \addtogroup Core
+    *  @{
+    */
+    /** \addtogroup General
+    *  @{
+    */
 
     /** Resource holding data about a dynamic library.
         @remarks
@@ -75,13 +80,11 @@ namespace Ogre {
             Adrian Cearn„u (cearny@cearny.ro)
         @since
             27 January 2002
-        @see
-            Resource
     */
-	class _OgreExport DynLib : public DynLibAlloc
+    class _OgreExport DynLib : public DynLibAlloc
     {
-	protected:
-		String mName;
+    protected:
+        String mName;
         /// Gets the last loading error
         String dynlibError(void);
     public:
@@ -101,8 +104,8 @@ namespace Ogre {
         /** Unload the library
         */
         void unload();
-		/// Get the name of the library
-		const String& getName(void) const { return mName; }
+        /// Get the name of the library
+        const String& getName(void) const { return mName; }
 
         /**
             Returns the address of the given symbol from the loaded library.
@@ -122,9 +125,11 @@ namespace Ogre {
         /// Handle to the loaded library.
         DYNLIB_HANDLE mInst;
     };
-	/** @} */
-	/** @} */
+    /** @} */
+    /** @} */
 
 }
 
+#include "OgreHeaderSuffix.h"
+
 #endif
