@@ -40,7 +40,7 @@ namespace Ogre
     /** \addtogroup Core
     *  @{
     */
-    /** \addtogroup Math
+    /** \addtogroup Scene
     *  @{
     */
     /** Specifies orientation mode.
@@ -168,6 +168,7 @@ namespace Ogre
         mutable AxisAlignedBox mBoundingBox;
         mutable VertexData mVertexData;
 
+        ColourValue mDebugColour;
         MaterialPtr mMaterial;
         mutable Vector3 mWorldSpaceCorners[8];
 
@@ -207,8 +208,6 @@ namespace Ogre
         @par
             This value represents the VERTICAL field-of-view. The horizontal field of view is calculated from
             this depending on the dimensions of the viewport (they will only be the same if the viewport is square).
-        @note
-            Setting the FOV overrides the value supplied for frustum::setNearClipPlane.
          */
         void setFOVy(const Radian& fovy);
 
@@ -480,8 +479,11 @@ namespace Ogre
         const String& getMovableType(void) const override;
         void _notifyCurrentCamera(Camera* cam) override;
 
-        /// material to use for debug display
-        void setMaterial(const MaterialPtr& mat);
+        /// @deprecated use setDebugColour
+        OGRE_DEPRECATED void setMaterial(const MaterialPtr& mat);
+
+        void setDebugColour(const ColourValue& col) { mDebugColour = col; }
+        const ColourValue& getDebugColour() const { return mDebugColour; }
 
         const MaterialPtr& getMaterial(void) const override;
         void getRenderOperation(RenderOperation& op) override;
@@ -489,13 +491,15 @@ namespace Ogre
         Real getSquaredViewDepth(const Camera* cam) const override;
         const LightList& getLights(void) const override;
 
+        typedef Vector3 Corners[8];
+
         /** Gets the world space corners of the frustum.
         @remarks
             The corners are ordered as follows: top-right near, 
             top-left near, bottom-left near, bottom-right near, 
             top-right far, top-left far, bottom-left far, bottom-right far.
         */
-        virtual const Vector3* getWorldSpaceCorners(void) const;
+        virtual const Corners& getWorldSpaceCorners(void) const;
 
         /** Sets the type of projection to use (orthographic or perspective). Default is perspective.
         */
