@@ -56,19 +56,19 @@ namespace Ogre
     */
     class Radian
     {
-        Real mRad;
+        float mRad;
 
     public:
-        explicit Radian ( Real r=0 ) : mRad(r) {}
+        explicit Radian ( float r=0 ) : mRad(r) {}
         Radian ( const Degree& d );
         Radian (const Ogre::Radian& rhs) : mRad(rhs.mRad) {}
-        Radian& operator = ( const Real& f ) { mRad = f; return *this; }
+        Radian& operator = ( const float& f ) { mRad = f; return *this; }
         Radian& operator = ( const Radian& r ) { mRad = r.mRad; return *this; }
         Radian& operator = ( const Degree& d );
 
-        Real valueDegrees() const; // see bottom of this file
-        Real valueRadians() const { return mRad; }
-        Real valueAngleUnits() const;
+        float valueDegrees() const; // see bottom of this file
+        float valueRadians() const { return mRad; }
+        float valueAngleUnits() const;
 
         const Radian& operator + () const { return *this; }
         Radian operator + ( const Radian& r ) const { return Radian ( mRad + r.mRad ); }
@@ -80,11 +80,11 @@ namespace Ogre
         Radian operator - ( const Degree& d ) const;
         Radian& operator -= ( const Radian& r ) { mRad -= r.mRad; return *this; }
         Radian& operator -= ( const Degree& d );
-        Radian operator * ( Real f ) const { return Radian ( mRad * f ); }
+        Radian operator * ( float f ) const { return Radian ( mRad * f ); }
         Radian operator * ( const Radian& f ) const { return Radian ( mRad * f.mRad ); }
-        Radian& operator *= ( Real f ) { mRad *= f; return *this; }
-        Radian operator / ( Real f ) const { return Radian ( mRad / f ); }
-        Radian& operator /= ( Real f ) { mRad /= f; return *this; }
+        Radian& operator *= ( float f ) { mRad *= f; return *this; }
+        Radian operator / ( float f ) const { return Radian ( mRad / f ); }
+        Radian& operator /= ( float f ) { mRad /= f; return *this; }
 
         bool operator <  ( const Radian& r ) const { return mRad <  r.mRad; }
         bool operator <= ( const Radian& r ) const { return mRad <= r.mRad; }
@@ -108,19 +108,19 @@ namespace Ogre
     */
     class Degree
     {
-        Real mDeg; // if you get an error here - make sure to define/typedef 'Real' first
+        float mDeg; // if you get an error here - make sure to define/typedef 'Real' first
 
     public:
-        explicit Degree ( Real d=0 ) : mDeg(d) {}
+        explicit Degree ( float d=0 ) : mDeg(d) {}
         Degree ( const Radian& r ) : mDeg(r.valueDegrees()) {}
         Degree (const Ogre::Degree& rhs) : mDeg(rhs.mDeg) {}
-        Degree& operator = ( const Real& f ) { mDeg = f; return *this; }
+        Degree& operator = ( const float& f ) { mDeg = f; return *this; }
         Degree& operator = ( const Degree& d ) { mDeg = d.mDeg; return *this; }
         Degree& operator = ( const Radian& r ) { mDeg = r.valueDegrees(); return *this; }
 
-        Real valueDegrees() const { return mDeg; }
-        Real valueRadians() const; // see bottom of this file
-        Real valueAngleUnits() const;
+        float valueDegrees() const { return mDeg; }
+        float valueRadians() const; // see bottom of this file
+        float valueAngleUnits() const;
 
         const Degree& operator + () const { return *this; }
         Degree operator + ( const Degree& d ) const { return Degree ( mDeg + d.mDeg ); }
@@ -132,11 +132,11 @@ namespace Ogre
         Degree operator - ( const Radian& r ) const { return Degree ( mDeg - r.valueDegrees() ); }
         Degree& operator -= ( const Degree& d ) { mDeg -= d.mDeg; return *this; }
         Degree& operator -= ( const Radian& r ) { mDeg -= r.valueDegrees(); return *this; }
-        Degree operator * ( Real f ) const { return Degree ( mDeg * f ); }
+        Degree operator * ( float f ) const { return Degree ( mDeg * f ); }
         Degree operator * ( const Degree& f ) const { return Degree ( mDeg * f.mDeg ); }
-        Degree& operator *= ( Real f ) { mDeg *= f; return *this; }
-        Degree operator / ( Real f ) const { return Degree ( mDeg / f ); }
-        Degree& operator /= ( Real f ) { mDeg /= f; return *this; }
+        Degree& operator *= ( float f ) { mDeg *= f; return *this; }
+        Degree operator / ( float f ) const { return Degree ( mDeg / f ); }
+        Degree& operator /= ( float f ) { mDeg /= f; return *this; }
 
         bool operator <  ( const Degree& d ) const { return mDeg <  d.mDeg; }
         bool operator <= ( const Degree& d ) const { return mDeg <= d.mDeg; }
@@ -161,9 +161,9 @@ namespace Ogre
     */
     class Angle
     {
-        Real mAngle;
+        float mAngle;
     public:
-        explicit Angle ( Real angle ) : mAngle(angle) {}
+        explicit Angle ( float angle ) : mAngle(angle) {}
         operator Radian() const;
         operator Degree() const;
     };
@@ -233,9 +233,9 @@ namespace Ogre
         static int mTrigTableSize;
 
         /// Radian -> index factor value ( mTrigTableSize / 2 * PI )
-        static Real mTrigTableFactor;
-        static Real* mSinTable;
-        static Real* mTanTable;
+        static float mTrigTableFactor;
+        static float* mSinTable;
+        static float* mTanTable;
 
         /// A random value provider. overriding the default random number generator.
         static RandomValueProvider* mRandProvider;
@@ -244,8 +244,8 @@ namespace Ogre
         */
         void buildTrigTables();
 
-        static Real SinTable (Real fValue);
-        static Real TanTable (Real fValue);
+        static float SinTable (float fValue);
+        static float TanTable (float fValue);
     public:
         /** Default constructor.
             @param
@@ -299,7 +299,7 @@ namespace Ogre
             @param fValue
                 The value whose arc tangent will be returned.
          */
-        static inline Radian ATan (Real fValue) { return Radian(std::atan(fValue)); }
+        static inline Radian ATan (float fValue) { return Radian(std::atan(fValue)); }
 
         /** Arc tangent between two values function
             @param fY
@@ -307,7 +307,7 @@ namespace Ogre
             @param fX
                 The second value to calculate the arc tangent with.
          */
-        static inline Radian ATan2 (Real fY, Real fX) { return Radian(std::atan2(fY,fX)); }
+        static inline Radian ATan2 (float fY, float fX) { return Radian(std::atan2(fY,fX)); }
 
         /** Ceiling function
             Returns the smallest following integer. (example: Ceil(1.1) = 2)
@@ -330,7 +330,7 @@ namespace Ogre
                 If true, uses lookup tables rather than
                 calculation - faster but less accurate.
         */
-        static inline Real Cos (const Radian& fValue, bool useTables = false) {
+        static inline float Cos (const Radian& fValue, bool useTables = false) {
             return (!useTables) ? std::cos(fValue.valueRadians()) : SinTable(fValue.valueRadians() + HALF_PI);
         }
         /** Cosine function.
@@ -340,7 +340,7 @@ namespace Ogre
                 If true, uses lookup tables rather than
                 calculation - faster but less accurate.
         */
-        static inline Real Cos (Real fValue, bool useTables = false) {
+        static inline float Cos (float fValue, bool useTables = false) {
             return (!useTables) ? std::cos(fValue) : SinTable(fValue + HALF_PI);
         }
 
@@ -408,7 +408,7 @@ namespace Ogre
                 If true, uses lookup tables rather than
                 calculation - faster but less accurate.
         */
-        static inline Real Sin (const Radian& fValue, bool useTables = false) {
+        static inline float Sin (const Radian& fValue, bool useTables = false) {
             return (!useTables) ? std::sin(fValue.valueRadians()) : SinTable(fValue.valueRadians());
         }
         /** Sine function.
@@ -418,7 +418,7 @@ namespace Ogre
                 If true, uses lookup tables rather than
                 calculation - faster but less accurate.
         */
-        static inline Real Sin (Real fValue, bool useTables = false) {
+        static inline float Sin (Real fValue, bool useTables = false) {
             return (!useTables) ? std::sin(fValue) : SinTable(fValue);
         }
 
@@ -494,7 +494,7 @@ namespace Ogre
                 If true, uses lookup tables rather than
                 calculation - faster but less accurate.
         */
-        static inline Real Tan (const Radian& fValue, bool useTables = false) {
+        static inline float Tan (const Radian& fValue, bool useTables = false) {
             return (!useTables) ? std::tan(fValue.valueRadians()) : TanTable(fValue.valueRadians());
         }
         /** Tangent function.
@@ -504,12 +504,12 @@ namespace Ogre
                 If true, uses lookup tables rather than
                 calculation - faster but less accurate.
         */
-        static inline Real Tan (Real fValue, bool useTables = false) {
+        static inline float Tan (Real fValue, bool useTables = false) {
             return (!useTables) ? std::tan(fValue) : TanTable(fValue);
         }
 
-        static inline Real DegreesToRadians(Real degrees) { return degrees * fDeg2Rad; }
-        static inline Real RadiansToDegrees(Real radians) { return radians * fRad2Deg; }
+        static inline float DegreesToRadians(float degrees) { return degrees * fDeg2Rad; }
+        static inline float RadiansToDegrees(float radians) { return radians * fRad2Deg; }
 
        /** These functions used to set the assumed angle units (radians or degrees) 
             expected when using the Angle type.
@@ -522,13 +522,13 @@ namespace Ogre
        static AngleUnit getAngleUnit(void);
 
        /** Convert from the current AngleUnit to radians. */
-       static Real AngleUnitsToRadians(Real units);
+       static float AngleUnitsToRadians(float units);
        /** Convert from radians to the current AngleUnit . */
-       static Real RadiansToAngleUnits(Real radians);
+       static float RadiansToAngleUnits(float radians);
        /** Convert from the current AngleUnit to degrees. */
-       static Real AngleUnitsToDegrees(Real units);
+       static float AngleUnitsToDegrees(float units);
        /** Convert from degrees to the current AngleUnit. */
-       static Real DegreesToAngleUnits(Real degrees);
+       static float DegreesToAngleUnits(float degrees);
 
        /** Checks whether a given point is inside a triangle, in a
             2-dimensional (Cartesian) space.
@@ -721,6 +721,12 @@ namespace Ogre
         static Affine3 makeViewMatrix(const Vector3& position, const Quaternion& orientation,
             const Affine3* reflectMatrix = 0);
 
+        /** Create a rotation matrix from direction and yaw
+        @param direction the direction to look in. Must be normalised.
+        @param yaw the yaw axis to use
+        */
+        static Matrix3 lookRotation(const Vector3& direction, const Vector3& yaw);
+
         /** This creates 'uniform' perspective projection matrix,
             which depth range [-1,1], right-handed rules
 
@@ -750,30 +756,30 @@ namespace Ogre
         static const Real PI;
         static const Real TWO_PI;
         static const Real HALF_PI;
-        static const Real fDeg2Rad;
-        static const Real fRad2Deg;
+        static const float fDeg2Rad;
+        static const float fRad2Deg;
 
     };
 
     // these functions must be defined down here, because they rely on the
     // angle unit conversion functions in class Math:
 
-    inline Real Radian::valueDegrees() const
+    inline float Radian::valueDegrees() const
     {
         return Math::RadiansToDegrees ( mRad );
     }
 
-    inline Real Radian::valueAngleUnits() const
+    inline float Radian::valueAngleUnits() const
     {
         return Math::RadiansToAngleUnits ( mRad );
     }
 
-    inline Real Degree::valueRadians() const
+    inline float Degree::valueRadians() const
     {
         return Math::DegreesToRadians ( mDeg );
     }
 
-    inline Real Degree::valueAngleUnits() const
+    inline float Degree::valueAngleUnits() const
     {
         return Math::DegreesToAngleUnits ( mDeg );
     }
@@ -788,22 +794,22 @@ namespace Ogre
         return Degree(Math::AngleUnitsToDegrees(mAngle));
     }
 
-    inline Radian operator * ( Real a, const Radian& b )
+    inline Radian operator * ( float a, const Radian& b )
     {
         return Radian ( a * b.valueRadians() );
     }
 
-    inline Radian operator / ( Real a, const Radian& b )
+    inline Radian operator / ( float a, const Radian& b )
     {
         return Radian ( a / b.valueRadians() );
     }
 
-    inline Degree operator * ( Real a, const Degree& b )
+    inline Degree operator * ( float a, const Degree& b )
     {
         return Degree ( a * b.valueDegrees() );
     }
 
-    inline Degree operator / ( Real a, const Degree& b )
+    inline Degree operator / ( float a, const Degree& b )
     {
         return Degree ( a / b.valueDegrees() );
     }
