@@ -72,8 +72,12 @@ namespace Ogre {
     protected:
         /// Parent particle system
         ParticleSystem* mParent;
+
         /// Position relative to the center of the ParticleSystem
-        Vector3 mPosition;
+        // inherited: Vector3 mPosition;
+        // Note, that position of the emitter becomes a position in worldspace if mLocalSpace is set
+        // to false (will this become a problem?)
+
         /// Rate in particles per second at which this emitter wishes to emit particles
         Real mEmissionRate;
         /// Name of the type of emitter, MUST be initialised by subclasses
