@@ -4,7 +4,7 @@ This source file is part of OGRE
 (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2011 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -30,61 +30,58 @@ THE SOFTWARE.
 
 
 #include "OgrePrerequisites.h"
-#include "OgreParticleSystem.h"
-#include "OgreFrameListener.h"
 #include "OgreSingleton.h"
-#include "OgreIteratorWrappers.h"
 #include "OgreScriptLoader.h"
-#include "OgreResourceGroupManager.h"
+#include "OgreHeaderPrefix.h"
 
 namespace Ogre {
 
-	// Forward decl
-	class ParticleSystemFactory;
-	
-	/** \addtogroup Core
-	*  @{
-	*/
-	/** \addtogroup Effects
-	*  @{
-	*/
-	/** Manages particle systems, particle system scripts (templates) and the 
-		available emitter & affector factories.
+    // Forward decl
+    class ParticleSystemFactory;
+    
+    /** \addtogroup Core
+    *  @{
+    */
+    /** \addtogroup Effects
+    *  @{
+    */
+    /** Manages particle systems, particle system scripts (templates) and the 
+        available emitter & affector factories.
     @remarks
         This singleton class is responsible for creating and managing particle 
-		systems. All particle systems must be created and destroyed using this 
-		object, although the user interface to creating them is via
-		SceneManager. Remember that like all other MovableObject
+        systems. All particle systems must be created and destroyed using this 
+        object, although the user interface to creating them is via
+        SceneManager. Remember that like all other MovableObject
         subclasses, ParticleSystems do not get rendered until they are 
-		attached to a SceneNode object.
+        attached to a SceneNode object.
     @par
         This class also manages factories for ParticleEmitter and 
-		ParticleAffector classes. To enable easy extensions to the types of 
-		emitters (particle sources) and affectors (particle modifiers), the
+        ParticleAffector classes. To enable easy extensions to the types of 
+        emitters (particle sources) and affectors (particle modifiers), the
         ParticleSystemManager lets plugins or applications register factory 
-		classes which submit new subclasses to ParticleEmitter and 
-		ParticleAffector. Ogre comes with a number of them already provided,
+        classes which submit new subclasses to ParticleEmitter and 
+        ParticleAffector. Ogre comes with a number of them already provided,
         such as cone, sphere and box-shaped emitters, and simple affectors such
-	   	as constant directional force and colour faders. However using this 
-		registration process, a plugin can create any behaviour required.
+        as constant directional force and colour faders. However using this 
+        registration process, a plugin can create any behaviour required.
     @par
         This class also manages the loading and parsing of particle system 
-		scripts, which are text files describing named particle system 
-		templates. Instances of particle systems using these templates can
+        scripts, which are text files describing named particle system 
+        templates. Instances of particle systems using these templates can
         then be created easily through the createParticleSystem method.
     */
     class _OgreExport ParticleSystemManager: 
-		public Singleton<ParticleSystemManager>, public ScriptLoader, public FXAlloc
+        public Singleton<ParticleSystemManager>, public ScriptLoader, public FXAlloc
     {
-		friend class ParticleSystemFactory;
-	public:
-        typedef map<String, ParticleSystem*>::type ParticleTemplateMap;
-		typedef map<String, ParticleAffectorFactory*>::type ParticleAffectorFactoryMap;
-		typedef map<String, ParticleEmitterFactory*>::type ParticleEmitterFactoryMap;
-		typedef map<String, ParticleSystemRendererFactory*>::type ParticleSystemRendererFactoryMap;
+        friend class ParticleSystemFactory;
+    public:
+        typedef std::map<String, ParticleSystem*> ParticleTemplateMap;
+        typedef std::map<String, ParticleAffectorFactory*> ParticleAffectorFactoryMap;
+        typedef std::map<String, ParticleEmitterFactory*> ParticleEmitterFactoryMap;
+        typedef std::map<String, ParticleSystemRendererFactory*> ParticleSystemRendererFactoryMap;
     protected:
-		OGRE_AUTO_MUTEX
-			
+        OGRE_AUTO_MUTEX;
+            
         /// Templates based on scripts
         ParticleTemplateMap mSystemTemplates;
         
@@ -94,38 +91,23 @@ namespace Ogre {
         /// Factories for named affector types (can be extended using plugins)
         ParticleAffectorFactoryMap mAffectorFactories;
 
-		/// Map of renderer types to factories
-		ParticleSystemRendererFactoryMap mRendererFactories;
+        /// Map of renderer types to factories
+        ParticleSystemRendererFactoryMap mRendererFactories;
 
         StringVector mScriptPatterns;
 
-		// Factory instance
-		ParticleSystemFactory* mFactory;
+        // Factory instance
+        ParticleSystemFactory* mFactory;
 
-        /** Internal script parsing method. */
-        void parseNewEmitter(const String& type, DataStreamPtr& chunk, ParticleSystem* sys);
-        /** Internal script parsing method. */
-        void parseNewAffector(const String& type, DataStreamPtr& chunk, ParticleSystem* sys);
-        /** Internal script parsing method. */
-        void parseAttrib(const String& line, ParticleSystem* sys);
-        /** Internal script parsing method. */
-        void parseEmitterAttrib(const String& line, ParticleEmitter* sys);
-        /** Internal script parsing method. */
-        void parseAffectorAttrib(const String& line, ParticleAffector* sys);
-        /** Internal script parsing method. */
-        void skipToNextCloseBrace(DataStreamPtr& chunk);
-        /** Internal script parsing method. */
-        void skipToNextOpenBrace(DataStreamPtr& chunk);
-
-		/// Internal implementation of createSystem
+        /// Internal implementation of createSystem
         ParticleSystem* createSystemImpl(const String& name, size_t quota, 
-			const String& resourceGroup);
-		/// Internal implementation of createSystem
+            const String& resourceGroup);
+        /// Internal implementation of createSystem
         ParticleSystem* createSystemImpl(const String& name, const String& templateName);
-		/// Internal implementation of destroySystem
+        /// Internal implementation of destroySystem
         void destroySystemImpl(ParticleSystem* sys);
-		
-		
+        
+        
     public:
 
         ParticleSystemManager();
@@ -145,8 +127,8 @@ namespace Ogre {
             Note that the object passed to this function will not be destroyed by the ParticleSystemManager,
             since it may have been allocated on a different heap in the case of plugins. The caller must
             destroy the object later on, probably on plugin shutdown.
-        @param
-            factory Pointer to a ParticleEmitterFactory subclass created by the plugin or application code.
+        @param factory
+            Pointer to a ParticleEmitterFactory subclass created by the plugin or application code.
         */
         void addEmitterFactory(ParticleEmitterFactory* factory);
 
@@ -164,20 +146,20 @@ namespace Ogre {
             Note that the object passed to this function will not be destroyed by the ParticleSystemManager,
             since it may have been allocated on a different heap in the case of plugins. The caller must
             destroy the object later on, probably on plugin shutdown.
-        @param
-            factory Pointer to a ParticleAffectorFactory subclass created by the plugin or application code.
+        @param factory
+            Pointer to a ParticleAffectorFactory subclass created by the plugin or application code.
         */
         void addAffectorFactory(ParticleAffectorFactory* factory);
 
-		/** Registers a factory class for creating ParticleSystemRenderer instances. 
+        /** Registers a factory class for creating ParticleSystemRenderer instances. 
         @par
             Note that the object passed to this function will not be destroyed by the ParticleSystemManager,
             since it may have been allocated on a different heap in the case of plugins. The caller must
             destroy the object later on, probably on plugin shutdown.
-        @param
-            factory Pointer to a ParticleSystemRendererFactory subclass created by the plugin or application code.
-		*/
-		void addRendererFactory(ParticleSystemRendererFactory* factory);
+        @param factory
+            Pointer to a ParticleSystemRendererFactory subclass created by the plugin or application code.
+        */
+        void addRendererFactory(ParticleSystemRendererFactory* factory);
 
         /** Adds a new particle system template to the list of available templates. 
         @remarks
@@ -188,11 +170,11 @@ namespace Ogre {
             Note that particle system templates can either be created programmatically by an application 
             and registered using this method, or they can be defined in a script file (*.particle) which is
             loaded by the engine at startup, very much like Material scripts.
-        @param
-            name The name of the template. Must be unique across all templates.
-        @param
-            sysTemplate A pointer to a particle system to be used as a template. The manager
-                will take over ownership of this pointer.
+        @param name
+            The name of the template. Must be unique across all templates.
+        @param sysTemplate
+            A pointer to a particle system to be used as a template. The manager
+            will take over ownership of this pointer.
             
         */
         void addTemplate(const String& name, ParticleSystem* sysTemplate);
@@ -202,18 +184,18 @@ namespace Ogre {
             This method removes a given template from the particle system manager, optionally deleting
             the template if the deleteTemplate method is called.  Throws an exception if the template
             could not be found.
-        @param
-            name The name of the template to remove.
-        @param
-            deleteTemplate Whether or not to delete the template before removing it.
+        @param name
+            The name of the template to remove.
+        @param deleteTemplate
+            Whether or not to delete the template before removing it.
         */
         void removeTemplate(const String& name, bool deleteTemplate = true);
 
         /** Removes a specified template from the ParticleSystemManager.
         @remarks
             This method removes all templates from the ParticleSystemManager.
-        @param
-            deleteTemplate Whether or not to delete the templates before removing them.
+        @param deleteTemplate
+            Whether or not to delete the templates before removing them.
         */
         void removeAllTemplates(bool deleteTemplate = true);
 
@@ -221,8 +203,8 @@ namespace Ogre {
         /** Removes all templates that belong to a secific Resource Group from the ParticleSystemManager.
         @remarks
             This method removes all templates that belong in a particular resource group from the ParticleSystemManager.
-        @param
-            resourceGroup to delete templates for
+        @param resourceGroup
+            Resource group to delete templates for
         */
         void removeTemplatesByResourceGroup(const String& resourceGroup);
 
@@ -231,11 +213,11 @@ namespace Ogre {
             This method is similar to the addTemplate method, except this just creates a new template
             and returns a pointer to it to be populated. Use this when you don't already have a system
             to add as a template and just want to create a new template which you will build up in-place.
-        @param
-            name The name of the template. Must be unique across all templates.
-        @param
-            resourceGroup The name of the resource group which will be used to 
-                load any dependent resources.
+        @param name
+            The name of the template. Must be unique across all templates.
+        @param resourceGroup
+            The name of the resource group which will be used to 
+            load any dependent resources.
             
         */
         ParticleSystem* createTemplate(const String& name, const String& resourceGroup);
@@ -252,10 +234,10 @@ namespace Ogre {
             Used internally by the engine to create new ParticleEmitter instances from named
             factories. Applications should use the ParticleSystem::addEmitter method instead, 
             which calls this method to create an instance.
-        @param
-            emitterType String name of the emitter type to be created. A factory of this type must have been registered.
-        @param 
-            psys The particle system this is being created for
+        @param emitterType
+            String name of the emitter type to be created. A factory of this type must have been registered.
+        @param psys
+            The particle system this is being created for
         */
         ParticleEmitter* _createEmitter(const String& emitterType, ParticleSystem* psys);
 
@@ -264,8 +246,8 @@ namespace Ogre {
             Because emitters are created by factories which may allocate memory from separate heaps,
             the memory allocated must be freed from the same place. This method is used to ask the factory
             to destroy the instance passed in as a pointer.
-        @param
-            emitter Pointer to emitter to be destroyed. On return this pointer will point to invalid (freed) memory.
+        @param emitter
+            Pointer to emitter to be destroyed. On return this pointer will point to invalid (freed) memory.
         */
         void _destroyEmitter(ParticleEmitter* emitter);
 
@@ -274,10 +256,10 @@ namespace Ogre {
             Used internally by the engine to create new ParticleAffector instances from named
             factories. Applications should use the ParticleSystem::addAffector method instead, 
             which calls this method to create an instance.
-        @param
-            effectorType String name of the affector type to be created. A factory of this type must have been registered.
-        @param
-            psys The particle system it is being created for
+        @param affectorType
+            String name of the affector type to be created. A factory of this type must have been registered.
+        @param psys
+            The particle system it is being created for
         */
         ParticleAffector* _createAffector(const String& affectorType, ParticleSystem* psys);
 
@@ -286,8 +268,8 @@ namespace Ogre {
             Because affectors are created by factories which may allocate memory from separate heaps,
             the memory allocated must be freed from the same place. This method is used to ask the factory
             to destroy the instance passed in as a pointer.
-        @param
-            affector Pointer to affector to be destroyed. On return this pointer will point to invalid (freed) memory.
+        @param affector
+            Pointer to affector to be destroyed. On return this pointer will point to invalid (freed) memory.
         */
         void _destroyAffector(ParticleAffector* affector);
 
@@ -296,8 +278,8 @@ namespace Ogre {
             Used internally by the engine to create new ParticleSystemRenderer instances from named
             factories. Applications should use the ParticleSystem::setRenderer method instead, 
             which calls this method to create an instance.
-        @param
-            rendererType String name of the renderer type to be created. A factory of this type must have been registered.
+        @param rendererType
+            String name of the renderer type to be created. A factory of this type must have been registered.
         */
         ParticleSystemRenderer* _createRenderer(const String& rendererType);
 
@@ -306,8 +288,8 @@ namespace Ogre {
             Because renderer are created by factories which may allocate memory from separate heaps,
             the memory allocated must be freed from the same place. This method is used to ask the factory
             to destroy the instance passed in as a pointer.
-        @param
-            renderer Pointer to renderer to be destroyed. On return this pointer will point to invalid (freed) memory.
+        @param renderer
+            Pointer to renderer to be destroyed. On return this pointer will point to invalid (freed) memory.
         */
         void _destroyRenderer(ParticleSystemRenderer* renderer);
 
@@ -325,15 +307,15 @@ namespace Ogre {
         /// @copydoc ScriptLoader::getLoadingOrder
         Real getLoadingOrder(void) const;
 
-		typedef MapIterator<ParticleAffectorFactoryMap> ParticleAffectorFactoryIterator;
-		typedef MapIterator<ParticleEmitterFactoryMap> ParticleEmitterFactoryIterator;
-		typedef MapIterator<ParticleSystemRendererFactoryMap> ParticleRendererFactoryIterator;
-		/** Return an iterator over the affector factories currently registered */
-		ParticleAffectorFactoryIterator getAffectorFactoryIterator(void);
-		/** Return an iterator over the emitter factories currently registered */
-		ParticleEmitterFactoryIterator getEmitterFactoryIterator(void);
-		/** Return an iterator over the renderer factories currently registered */
-		ParticleRendererFactoryIterator getRendererFactoryIterator(void);
+        typedef MapIterator<ParticleAffectorFactoryMap> ParticleAffectorFactoryIterator;
+        typedef MapIterator<ParticleEmitterFactoryMap> ParticleEmitterFactoryIterator;
+        typedef MapIterator<ParticleSystemRendererFactoryMap> ParticleRendererFactoryIterator;
+        /** Return an iterator over the affector factories currently registered */
+        ParticleAffectorFactoryIterator getAffectorFactoryIterator(void);
+        /** Return an iterator over the emitter factories currently registered */
+        ParticleEmitterFactoryIterator getEmitterFactoryIterator(void);
+        /** Return an iterator over the renderer factories currently registered */
+        ParticleRendererFactoryIterator getRendererFactoryIterator(void);
 
 
         typedef MapIterator<ParticleTemplateMap> ParticleSystemTemplateIterator;
@@ -345,62 +327,36 @@ namespace Ogre {
         } 
 
         /** Get an instance of ParticleSystemFactory (internal use). */
-		ParticleSystemFactory* _getFactory(void) { return mFactory; }
-		
-		/** Override standard Singleton retrieval.
-        @remarks
-        Why do we do this? Well, it's because the Singleton
-        implementation is in a .h file, which means it gets compiled
-        into anybody who includes it. This is needed for the
-        Singleton template to work, but we actually only want it
-        compiled into the implementation of the class based on the
-        Singleton, not all of them. If we don't change this, we get
-        link errors when trying to use the Singleton-based class from
-        an outside dll.
-        @par
-        This method just delegates to the template version anyway,
-        but the implementation stays in this single compilation unit,
-        preventing link errors.
-        */
+        ParticleSystemFactory* _getFactory(void) { return mFactory; }
+        
+        /// @copydoc Singleton::getSingleton()
         static ParticleSystemManager& getSingleton(void);
-        /** Override standard Singleton retrieval.
-        @remarks
-        Why do we do this? Well, it's because the Singleton
-        implementation is in a .h file, which means it gets compiled
-        into anybody who includes it. This is needed for the
-        Singleton template to work, but we actually only want it
-        compiled into the implementation of the class based on the
-        Singleton, not all of them. If we don't change this, we get
-        link errors when trying to use the Singleton-based class from
-        an outside dll.
-        @par
-        This method just delegates to the template version anyway,
-        but the implementation stays in this single compilation unit,
-        preventing link errors.
-        */
+        /// @copydoc Singleton::getSingleton()
         static ParticleSystemManager* getSingletonPtr(void);
 
     };
 
-	/** Factory object for creating ParticleSystem instances */
-	class _OgreExport ParticleSystemFactory : public MovableObjectFactory
-	{
-	protected:
-		MovableObject* createInstanceImpl(const String& name, const NameValuePairList* params);
-	public:
-		ParticleSystemFactory() {}
-		~ParticleSystemFactory() {}
-		
-		static String FACTORY_TYPE_NAME;
+    /** Factory object for creating ParticleSystem instances */
+    class _OgreExport ParticleSystemFactory : public MovableObjectFactory
+    {
+    protected:
+        MovableObject* createInstanceImpl(const String& name, const NameValuePairList* params);
+    public:
+        ParticleSystemFactory() {}
+        ~ParticleSystemFactory() {}
+        
+        static String FACTORY_TYPE_NAME;
 
-		const String& getType(void) const;
-		void destroyInstance( MovableObject* obj);  
+        const String& getType(void) const;
+        void destroyInstance( MovableObject* obj);  
 
-	};
-	/** @} */
-	/** @} */
+    };
+    /** @} */
+    /** @} */
 
 }
 
+#include "OgreHeaderSuffix.h"
+
 #endif
 
