@@ -63,15 +63,16 @@ namespace Ogre {
     class _OgreExport Renderable
     {
     public:
-        /** An internal class that should be used only by a render system for internal use 
-        @remarks
-            This class was created so a render system can associate internal data to this class.
-            The need for this class started when the DX10 render system needed to save state objects.
-        */
-        class RenderSystemData {}; 
+        /// @deprecated do not use
+        class RenderSystemData {};
         typedef SharedPtr<RenderSystemData> RenderSystemDataPtr;
         
     public:
+        enum
+        {
+            DEFAULT_PRIORITY = 100
+        };
+
         Renderable() : mPolygonModeOverrideable(true), mUseIdentityProjection(false), mUseIdentityView(false){}
         /** Virtual destructor needed as class has virtual methods. */
         virtual ~Renderable() {}
@@ -233,47 +234,25 @@ namespace Ogre {
             two is performed by the ACT_CUSTOM entry, if that is used.
         @param value The value to associate.
         */
-        void setCustomParameter(size_t index, const Vector4& value) 
-        {
-            mCustomParameters[index] = value;
-        }
+        void setCustomParameter(size_t index, const Vector4& value);
 
         /** Removes a custom value which is associated with this Renderable at the given index.
         @param index Index of the parameter to remove.
             @see setCustomParameter for full details.
         */
-        void removeCustomParameter(size_t index)
-        {
-            mCustomParameters.erase(index);
-        }
+        void removeCustomParameter(size_t index);
 
         /** Checks whether a custom value is associated with this Renderable at the given index.
         @param index Index of the parameter to check for existence.
             @see setCustomParameter for full details.
         */
-        bool hasCustomParameter(size_t index) const
-        {
-            return mCustomParameters.find(index) != mCustomParameters.end();
-        }
+        bool hasCustomParameter(size_t index) const;
 
         /** Gets the custom value associated with this Renderable at the given index.
         @param index Index of the parameter to retrieve.
             @see setCustomParameter for full details.
         */
-        const Vector4& getCustomParameter(size_t index) const
-        {
-            CustomParameterMap::const_iterator i = mCustomParameters.find(index);
-            if (i != mCustomParameters.end())
-            {
-                return i->second;
-            }
-            else
-            {
-                OGRE_EXCEPT(Exception::ERR_ITEM_NOT_FOUND, 
-                    "Parameter at the given index was not found.",
-                    "Renderable::getCustomParameter");
-            }
-        }
+        const Vector4& getCustomParameter(size_t index) const;
 
         /** Update a custom GpuProgramParameters constant which is derived from 
             information only this Renderable knows.
@@ -299,17 +278,8 @@ namespace Ogre {
         @param params The parameters object which this method should call to 
             set the updated parameters.
         */
-        virtual void _updateCustomGpuParameter(
-            const GpuProgramParameters::AutoConstantEntry& constantEntry,
-            GpuProgramParameters* params) const
-        {
-            CustomParameterMap::const_iterator i = mCustomParameters.find(constantEntry.data);
-            if (i != mCustomParameters.end())
-            {
-                params->_writeRawConstant(constantEntry.physicalIndex, i->second, 
-                    constantEntry.elementCount);
-            }
-        }
+        virtual void _updateCustomGpuParameter(const GpuProgramParameters::AutoConstantEntry& constantEntry,
+                                               GpuProgramParameters* params) const;
 
         /** Sets whether this renderable's chosen detail level can be
             overridden (downgraded) by the camera setting. 
@@ -387,19 +357,13 @@ namespace Ogre {
                 Any* pAny = 0) = 0;
         };
 
-        /** Gets RenderSystem private data
-        @remarks
-            This should only be used by a RenderSystem
-        */
-        const RenderSystemDataPtr& getRenderSystemData() const
+        /// @deprecated do not use
+        OGRE_DEPRECATED const RenderSystemDataPtr& getRenderSystemData() const
         { 
             return mRenderSystemData; 
         }
-        /** Sets RenderSystem private data
-        @remarks
-            This should only be used by a RenderSystem
-        */
-        void setRenderSystemData(RenderSystemDataPtr val) const
+        /// @deprecated do not use
+        OGRE_DEPRECATED void setRenderSystemData(RenderSystemDataPtr val) const
         { 
             mRenderSystemData = val; 
         }
