@@ -4,7 +4,7 @@ This source file is part of OGRE
     (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -33,29 +33,28 @@ THE SOFTWARE.
 #include "OgreMovableObject.h"
 #include "OgreRenderable.h"
 #include "OgreAxisAlignedBox.h"
-#include "OgreMaterial.h"
+#include "OgreRenderOperation.h"
 #include "OgreHeaderPrefix.h"
 
 namespace Ogre {
 
-	/** \addtogroup Core
-	*  @{
-	*/
-	/** \addtogroup Scene
-	*  @{
-	*/
-	/** Simple implementation of MovableObject and Renderable for single-part custom objects. 
-	@see ManualObject for a simpler interface with more flexibility
-	*/
-	class _OgreExport SimpleRenderable : public MovableObject, public Renderable
+    /** \addtogroup Core
+    *  @{
+    */
+    /** \addtogroup Scene
+    *  @{
+    */
+    /** Simple implementation of MovableObject and Renderable for single-part custom objects. 
+    @see ManualObject for a simpler interface with more flexibility
+    */
+    class _OgreExport SimpleRenderable : public MovableObject, public Renderable
     {
     protected:
         RenderOperation mRenderOp;
 
-        Matrix4 mWorldTransform;
+        Affine3 mTransform;
         AxisAlignedBox mBox;
 
-        String mMatName;
         MaterialPtr mMaterial;
 
         /// The scene manager for the current frame.
@@ -74,13 +73,13 @@ namespace Ogre {
         /// Named constructor
         SimpleRenderable(const String& name);
 
-        virtual void setMaterial( const String& matName );
+        virtual void setMaterial(const MaterialPtr& mat);
         virtual const MaterialPtr& getMaterial(void) const;
 
         virtual void setRenderOperation( const RenderOperation& rend );
         virtual void getRenderOperation(RenderOperation& op);
 
-        void setWorldTransform( const Matrix4& xform );
+        void setTransform( const Affine3& xform );
         virtual void getWorldTransforms( Matrix4* xform ) const;
 
 
@@ -90,22 +89,15 @@ namespace Ogre {
         virtual const AxisAlignedBox& getBoundingBox(void) const;
 
         virtual void _updateRenderQueue(RenderQueue* queue);
-		/// @copydoc MovableObject::visitRenderables
-		void visitRenderables(Renderable::Visitor* visitor, 
-			bool debugRenderables = false);
 
-        virtual ~SimpleRenderable();
-
-
-        /** Overridden from MovableObject */
-        virtual const String& getMovableType(void) const;
-
-        /** @copydoc Renderable::getLights */
-        const LightList& getLights(void) const;
+        void visitRenderables(Renderable::Visitor* visitor,
+            bool debugRenderables = false) override;
+        virtual const String& getMovableType(void) const override;
+        const LightList& getLights(void) const override;
 
     };
-	/** @} */
-	/** @} */
+    /** @} */
+    /** @} */
 }
 
 #include "OgreHeaderSuffix.h"
