@@ -4,7 +4,7 @@ This source file is part of OGRE
     (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2011 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -31,31 +31,31 @@ THE SOFTWARE.
 
 #include "OgrePrerequisites.h"
 #include "OgreResource.h"
-#include "OgreQuaternion.h"
-#include "OgreVector3.h"
-#include "OgreIteratorWrappers.h"
 #include "OgreStringVector.h"
+#include "OgreAnimation.h"
+#include "OgreHeaderPrefix.h"
+#include "OgreSharedPtr.h"
 
 namespace Ogre {
-	/** \addtogroup Core
-	*  @{
-	*/
-	/** \addtogroup Animation
-	*  @{
-	*/
+    /** \addtogroup Core
+    *  @{
+    */
+    /** \addtogroup Animation
+    *  @{
+    */
 
     /**  */
     enum SkeletonAnimationBlendMode {
         /// Animations are applied by calculating a weighted average of all animations
-	    ANIMBLEND_AVERAGE,
+        ANIMBLEND_AVERAGE = 0,
         /// Animations are applied by calculating a weighted cumulative total
-	    ANIMBLEND_CUMULATIVE
+        ANIMBLEND_CUMULATIVE = 1
     };
 
 #define OGRE_MAX_NUM_BONES 256
 
-	
-	struct LinkedSkeletonAnimationSource;
+    
+    struct LinkedSkeletonAnimationSource;
 
     /** A collection of Bone objects used to animate a skinned mesh.
     @remarks
@@ -82,12 +82,12 @@ namespace Ogre {
         Skeleton definitions are loaded from datafiles, namely the .skeleton file format. They
         are loaded on demand, especially when referenced by a Mesh.
     */
-    class _OgreExport Skeleton : public Resource
+    class _OgreExport Skeleton : public Resource, public AnimationContainer
     {
-		friend class SkeletonInstance;
-	protected:
-		/// Internal constructor for use by SkeletonInstance only
-		Skeleton();
+        friend class SkeletonInstance;
+    protected:
+        /// Internal constructor for use by SkeletonInstance only
+        Skeleton();
 
     public:
         /** Constructor, don't call directly, use SkeletonManager.
@@ -103,8 +103,8 @@ namespace Ogre {
         /** Creates a brand new Bone owned by this Skeleton. 
         @remarks
             This method creates an unattached new Bone for this skeleton.
-			Unless this is to be a root bone (there may be more than one of 
-			these), you must attach it to another Bone in the skeleton using addChild for it to be any use.
+            Unless this is to be a root bone (there may be more than one of 
+            these), you must attach it to another Bone in the skeleton using addChild for it to be any use.
             For this reason you will likely be better off creating child bones using the
             Bone::createChild method instead, once you have created the root bone. 
         @par
@@ -119,7 +119,7 @@ namespace Ogre {
         @remarks
             This method creates an unattached new Bone for this skeleton and assigns it a 
             specific handle. Unless this is to be a root bone (there may be more than one of 
-			these), you must attach it to another Bone in the skeleton using addChild for it to be any use. 
+            these), you must attach it to another Bone in the skeleton using addChild for it to be any use. 
             For this reason you will likely be better off creating child bones using the
             Bone::createChild method instead, once you have created a root bone. 
         @param handle The handle to give to this new bone - must be unique within this skeleton. 
@@ -134,7 +134,7 @@ namespace Ogre {
         @remarks
             This method creates an unattached new Bone for this skeleton and assigns it a 
             specific name.Unless this is to be a root bone (there may be more than one of 
-			these), you must attach it to another Bone in the skeleton using addChild for it to be any use.
+            these), you must attach it to another Bone in the skeleton using addChild for it to be any use.
             For this reason you will likely be better off creating child bones using the
             Bone::createChild method instead, once you have created the root bone. 
         @param name The name to give to this new bone - must be unique within this skeleton. 
@@ -149,7 +149,7 @@ namespace Ogre {
         @remarks
             This method creates an unattached new Bone for this skeleton and assigns it a 
             specific name and handle. Unless this is to be a root bone (there may be more than one of 
-			these), you must attach it to another Bone in the skeleton using addChild for it to be any use.
+            these), you must attach it to another Bone in the skeleton using addChild for it to be any use.
             For this reason you will likely be better off creating child bones using the
             Bone::createChild method instead, once you have created the root bone. 
         @param name The name to give to this new bone - must be unique within this skeleton. 
@@ -160,25 +160,32 @@ namespace Ogre {
         /** Returns the number of bones in this skeleton. */
         virtual unsigned short getNumBones(void) const;
 
-        /** Gets the root bone of the skeleton: deprecated in favour of getRootBoneIterator. 
-        @remarks
+        typedef std::vector<Bone*> BoneList;
+        typedef VectorIterator<BoneList> BoneIterator;
+        /// Get an iterator over the root bones in the skeleton, ie those with no parents
+        /// @deprecated use Skeleton::getRootBones
+        OGRE_DEPRECATED virtual BoneIterator getRootBoneIterator(void);
+
+        /** Get the root bones in the skeleton, ie those with no parents
+
             The system derives the root bone the first time you ask for it. The root bone is the
             only bone in the skeleton which has no parent. The system locates it by taking the
             first bone in the list and going up the bone tree until there are no more parents,
             and saves this top bone as the root. If you are building the skeleton manually using
-            createBone then you must ensure there is only one bone which is not a child of 
+            createBone then you must ensure there is only one bone which is not a child of
             another bone, otherwise your skeleton will not work properly. If you use createBone
             only once, and then use Bone::createChild from then on, then inherently the first
             bone you create will by default be the root.
         */
-        virtual Bone* getRootBone(void) const;
+        const BoneList& getRootBones() const;
 
-        typedef vector<Bone*>::type BoneList;
-        typedef VectorIterator<BoneList> BoneIterator;
-        /// Get an iterator over the root bones in the skeleton, ie those with no parents
-        virtual BoneIterator getRootBoneIterator(void);
         /// Get an iterator over all the bones in the skeleton
-        virtual BoneIterator getBoneIterator(void);
+        /// @deprecated use getBones()
+        OGRE_DEPRECATED virtual BoneIterator getBoneIterator(void);
+        /// Get all the bones in the skeleton
+        const BoneList& getBones() const {
+            return mBoneList;
+        }
 
         /** Gets a bone by it's handle. */
         virtual Bone* getBone(unsigned short handle) const;
@@ -186,7 +193,7 @@ namespace Ogre {
         /** Gets a bone by it's name. */
         virtual Bone* getBone(const String& name) const;
 
-		/** Returns whether this skeleton contains the named bone. */
+        /** Returns whether this skeleton contains the named bone. */
         virtual bool hasBone(const String& name) const;
 
         /** Sets the current position / orientation to be the 'binding pose' i.e. the layout in which 
@@ -212,23 +219,31 @@ namespace Ogre {
         virtual Animation* createAnimation(const String& name, Real length);
 
         /** Returns the named Animation object. 
-		@remarks
-			Will pick up animations in linked skeletons 
-			(@see addLinkedSkeletonAnimationSource). 
-		@param name The name of the animation
-		@param linker Optional pointer to a pointer to the linked skeleton animation
-			where this is coming from.
-		*/
+        @remarks
+            Will pick up animations in linked skeletons 
+            (@see addLinkedSkeletonAnimationSource). 
+        @param name The name of the animation
+        @param linker Optional pointer to a pointer to the linked skeleton animation
+            where this is coming from.
+        */
         virtual Animation* getAnimation(const String& name, 
-			const LinkedSkeletonAnimationSource** linker = 0) const;
+            const LinkedSkeletonAnimationSource** linker) const;
 
-		/// Internal accessor for animations (returns null if animation does not exist)
-		virtual Animation* _getAnimationImpl(const String& name, 
-			const LinkedSkeletonAnimationSource** linker = 0) const;
+        /** Returns the named Animation object.
+         @remarks
+             Will pick up animations in linked skeletons 
+             (@see addLinkedSkeletonAnimationSource). 
+         @param name The name of the animation
+         */
+        virtual Animation* getAnimation(const String& name) const;
+
+        /// Internal accessor for animations (returns null if animation does not exist)
+        virtual Animation* _getAnimationImpl(const String& name, 
+            const LinkedSkeletonAnimationSource** linker = 0) const;
 
 
-		/** Returns whether this skeleton contains the named animation. */
-		virtual bool hasAnimation(const String& name);
+        /** Returns whether this skeleton contains the named animation. */
+        virtual bool hasAnimation(const String& name) const;
 
         /** Removes an Animation from this skeleton. */
         virtual void removeAnimation(const String& name);
@@ -242,7 +257,6 @@ namespace Ogre {
             animations do not have to sum to 1.0, because some animations may affect only subsets
             of the skeleton. If the weights exceed 1.0 for the same area of the skeleton, the 
             movement will just be exaggerated.
-            @param 
         */
         virtual void setAnimationState(const AnimationStateSet& animSet);
 
@@ -253,104 +267,110 @@ namespace Ogre {
         */
         virtual void _initAnimationState(AnimationStateSet* animSet);
 
-		/** Refresh an animation set suitable for use with this skeleton. 
-		@remarks
-			Only recommended for use inside the engine, not by applications.
-		*/
-		virtual void _refreshAnimationState(AnimationStateSet* animSet);
+        /** Refresh an animation set suitable for use with this skeleton. 
+        @remarks
+            Only recommended for use inside the engine, not by applications.
+        */
+        virtual void _refreshAnimationState(AnimationStateSet* animSet);
 
-		/** Populates the passed in array with the bone matrices based on the current position.
+        /** Populates the passed in array with the bone matrices based on the current position.
         @remarks
             Internal use only. The array pointed to by the passed in pointer must
             be at least as large as the number of bones.
             Assumes animation has already been updated.
         */
-        virtual void _getBoneMatrices(Matrix4* pMatrices);
+        virtual void _getBoneMatrices(Affine3* pMatrices);
 
         /** Gets the number of animations on this skeleton. */
         virtual unsigned short getNumAnimations(void) const;
 
         /** Gets a single animation by index. 
-		@remarks
-			Will NOT pick up animations in linked skeletons 
-			(@see addLinkedSkeletonAnimationSource).
-		*/
+        @remarks
+            Will NOT pick up animations in linked skeletons 
+            (@see addLinkedSkeletonAnimationSource).
+        */
         virtual Animation* getAnimation(unsigned short index) const;
 
 
-		/** Gets the animation blending mode which this skeleton will use. */
+        /** Gets the animation blending mode which this skeleton will use. */
         virtual SkeletonAnimationBlendMode getBlendMode() const;
         /** Sets the animation blending mode this skeleton will use. */
-		virtual void setBlendMode(SkeletonAnimationBlendMode state);
+        virtual void setBlendMode(SkeletonAnimationBlendMode state);
 
         /// Updates all the derived transforms in the skeleton
         virtual void _updateTransforms(void);
 
-		/** Optimise all of this skeleton's animations.
-		@see Animation::optimise
+        /** Optimise all of this skeleton's animations.
+        @see Animation::optimise
         @param
             preservingIdentityNodeTracks If true, don't destroy identity node tracks.
-		*/
-		virtual void optimiseAllAnimations(bool preservingIdentityNodeTracks = false);
+        */
+        virtual void optimiseAllAnimations(bool preservingIdentityNodeTracks = false);
 
-		/** Allows you to use the animations from another Skeleton object to animate
-			this skeleton.
-		@remarks
-			If you have skeletons of identical structure (that means identically
-			named bones with identical handles, and with the same hierarchy), but
-			slightly different proportions or binding poses, you can re-use animations
-			from one in the other. Because animations are actually stored as
-			changes to bones from their bind positions, it's possible to use the
-			same animation data for different skeletons, provided the skeletal
-			structure matches and the 'deltas' stored in the keyframes apply
-			equally well to the other skeletons bind position (so they must be
-			roughly similar, but don't have to be identical). You can use the 
-			'scale' option to adjust the translation and scale keyframes where
-			there are large differences in size between the skeletons.
-		@note
-			This method takes a skeleton name, rather than a more specific 
-			animation name, for two reasons; firstly it allows some validation 
-			of compatibility of skeletal structure, and secondly skeletons are
-			the unit of loading. Linking a skeleton to another in this way means
-			that the linkee will be prevented from being destroyed until the 
-			linker is destroyed.
+        /** Allows you to use the animations from another Skeleton object to animate
+            this skeleton.
+        @remarks
+            If you have skeletons of identical structure (that means identically
+            named bones with identical handles, and with the same hierarchy), but
+            slightly different proportions or binding poses, you can re-use animations
+            from one in the other. Because animations are actually stored as
+            changes to bones from their bind positions, it's possible to use the
+            same animation data for different skeletons, provided the skeletal
+            structure matches and the 'deltas' stored in the keyframes apply
+            equally well to the other skeletons bind position (so they must be
+            roughly similar, but don't have to be identical). You can use the 
+            'scale' option to adjust the translation and scale keyframes where
+            there are large differences in size between the skeletons.
+        @note
+            This method takes a skeleton name, rather than a more specific 
+            animation name, for two reasons; firstly it allows some validation 
+            of compatibility of skeletal structure, and secondly skeletons are
+            the unit of loading. Linking a skeleton to another in this way means
+            that the linkee will be prevented from being destroyed until the 
+            linker is destroyed.
 
-			You cannot set up cyclic relationships, e.g. SkeletonA uses SkeletonB's
-			animations, and SkeletonB uses SkeletonA's animations. This is because
-			it would set up a circular dependency which would prevent proper 
-			unloading - make one of the skeletons the 'master' in this case.
-		@param skelName Name of the skeleton to link animations from. This 
-			skeleton will be loaded immediately if this skeleton is already 
-			loaded, otherwise it will be loaded when this skeleton is.
-		@param scale A scale factor to apply to translation and scaling elements
-			of the keyframes in the other skeleton when applying the animations
-			to this one. Compensates for skeleton size differences.
-		*/
-		virtual void addLinkedSkeletonAnimationSource(const String& skelName, 
-			Real scale = 1.0f);
-		/// Remove all links to other skeletons for the purposes of sharing animation
-		virtual void removeAllLinkedSkeletonAnimationSources(void);
-		
-		typedef vector<LinkedSkeletonAnimationSource>::type 
-			LinkedSkeletonAnimSourceList;
-		typedef ConstVectorIterator<LinkedSkeletonAnimSourceList> 
-			LinkedSkeletonAnimSourceIterator;
-		/// Get an iterator over the linked skeletons used as animation sources
-		virtual LinkedSkeletonAnimSourceIterator 
-			getLinkedSkeletonAnimationSourceIterator(void) const;
+            You cannot set up cyclic relationships, e.g. SkeletonA uses SkeletonB's
+            animations, and SkeletonB uses SkeletonA's animations. This is because
+            it would set up a circular dependency which would prevent proper 
+            unloading - make one of the skeletons the 'master' in this case.
+        @param skelName Name of the skeleton to link animations from. This 
+            skeleton will be loaded immediately if this skeleton is already 
+            loaded, otherwise it will be loaded when this skeleton is.
+        @param scale A scale factor to apply to translation and scaling elements
+            of the keyframes in the other skeleton when applying the animations
+            to this one. Compensates for skeleton size differences.
+        */
+        virtual void addLinkedSkeletonAnimationSource(const String& skelName, 
+            Real scale = 1.0f);
+        /// Remove all links to other skeletons for the purposes of sharing animation
+        virtual void removeAllLinkedSkeletonAnimationSources(void);
+        
+        typedef std::vector<LinkedSkeletonAnimationSource> 
+            LinkedSkeletonAnimSourceList;
+        typedef ConstVectorIterator<LinkedSkeletonAnimSourceList> 
+            LinkedSkeletonAnimSourceIterator;
+        /// Get the linked skeletons used as animation sources
+        virtual const LinkedSkeletonAnimSourceList& getLinkedSkeletonAnimationSources() const
+        {
+            return mLinkedSkeletonAnimSourceList;
+        }
 
-		/// Internal method for marking the manual bones as dirty
-		virtual void _notifyManualBonesDirty(void);
-		/// Internal method for notifying that a bone is manual
-		virtual void _notifyManualBoneStateChange(Bone* bone);
+        /// @deprecated use getLinkedSkeletonAnimationSources
+        OGRE_DEPRECATED virtual LinkedSkeletonAnimSourceIterator
+            getLinkedSkeletonAnimationSourceIterator(void) const;
 
-		/// Have manual bones been modified since the skeleton was last updated?
-		virtual bool getManualBonesDirty(void) const { return mManualBonesDirty; }
-		/// Are there any manually controlled bones?
-		virtual bool hasManualBones(void) const { return !mManualBones.empty(); }
+        /// Internal method for marking the manual bones as dirty
+        virtual void _notifyManualBonesDirty(void);
+        /// Internal method for notifying that a bone is manual
+        virtual void _notifyManualBoneStateChange(Bone* bone);
+
+        /// Have manual bones been modified since the skeleton was last updated?
+        virtual bool getManualBonesDirty(void) const { return mManualBonesDirty; }
+        /// Are there any manually controlled bones?
+        virtual bool hasManualBones(void) const { return !mManualBones.empty(); }
 
         /// Map to translate bone handle from one skeleton to another skeleton.
-        typedef vector<ushort>::type BoneHandleMap;
+        typedef std::vector<ushort> BoneHandleMap;
 
         /** Merge animations from another Skeleton object into this skeleton.
         @remarks
@@ -358,7 +378,7 @@ namespace Ogre {
             'compatible' here means identically bones will have same hierarchy,
             but skeletons are not necessary to have same number of bones (if
             number bones of source skeleton's more than this skeleton, they will
-            copied as is, except that duplicate names are unallowed; and in the
+            copied as is, except that duplicate names are disallowed; and in the
             case of bones missing in source skeleton, nothing happen for those
             bones).
         @par
@@ -366,10 +386,10 @@ namespace Ogre {
             will adjust keyframes of the source skeleton to match this skeleton
             automatically.
         @par
-            It's useful for export skeleton animations seperately. i.e. export
+            It's useful for exporting skeleton animations separately. i.e. export
             mesh and 'master' skeleton at the same time, and then other animations
-            will export seperately (even if used completely difference binding
-            pose), finally, merge seperately exported animations into 'master'
+            will export separately (even if used completely difference binding
+            pose), finally, merge separately exported animations into 'master'
             skeleton.
         @param
             source Pointer to source skeleton. It'll keep unmodified.
@@ -403,12 +423,12 @@ namespace Ogre {
         virtual void _buildMapBoneByName(const Skeleton* source,
             BoneHandleMap& boneHandleMap) const;
 
-	protected:
-		SkeletonAnimationBlendMode mBlendState;
+    protected:
+        SkeletonAnimationBlendMode mBlendState;
         /// Storage of bones, indexed by bone handle
         BoneList mBoneList;
         /// Lookup by bone name
-        typedef map<String, Bone*>::type BoneListByName;
+        typedef std::map<String, Bone*> BoneListByName;
         BoneListByName mBoneListByName;
 
 
@@ -416,19 +436,19 @@ namespace Ogre {
         mutable BoneList mRootBones;
         /// Bone automatic handles
         unsigned short mNextAutoHandle;
-		typedef set<Bone*>::type BoneSet;
-		/// Manual bones
-		BoneSet mManualBones;
-		/// Manual bones dirty?
-		bool mManualBonesDirty;
+        typedef std::set<Bone*> BoneSet;
+        /// Manual bones
+        BoneSet mManualBones;
+        /// Manual bones dirty?
+        bool mManualBonesDirty;
 
 
         /// Storage of animations, lookup by name
-        typedef map<String, Animation*>::type AnimationList;
+        typedef std::map<String, Animation*> AnimationList;
         AnimationList mAnimationsList;
 
-		/// List of references to other skeletons to use animations from 
-		mutable LinkedSkeletonAnimSourceList mLinkedSkeletonAnimSourceList;
+        /// List of references to other skeletons to use animations from 
+        mutable LinkedSkeletonAnimSourceList mLinkedSkeletonAnimSourceList;
 
         /** Internal method which parses the bones to derive the root bone. 
         @remarks
@@ -440,91 +460,34 @@ namespace Ogre {
         /// Debugging method
         void _dumpContents(const String& filename);
 
-        /** @copydoc Resource::loadImpl
-        */
-        void loadImpl(void);
+        void loadImpl() {}
+        void unloadImpl() { unprepareImpl(); }
 
-        /** @copydoc Resource::unloadImpl
-        */
-        void unloadImpl(void);
-		/// @copydoc Resource::calculateSize
-		size_t calculateSize(void) const { return 0; } // TODO 
+        void prepareImpl(void);
+        void unprepareImpl(void);
+        /// @copydoc Resource::calculateSize
+        size_t calculateSize(void) const;
 
     };
 
-    /** Specialisation of SharedPtr to allow SharedPtr to be assigned to SkeletonPtr 
-    @note Has to be a subclass since we need operator=.
-    We could templatise this instead of repeating per Resource subclass, 
-    except to do so requires a form VC6 does not support i.e.
-    ResourceSubclassPtr<T> : public SharedPtr<T>
-    */
-    class _OgreExport SkeletonPtr : public SharedPtr<Skeleton> 
+    /// Link to another skeleton to share animations
+    struct LinkedSkeletonAnimationSource
     {
-    public:
-        SkeletonPtr() : SharedPtr<Skeleton>() {}
-        explicit SkeletonPtr(Skeleton* rep) : SharedPtr<Skeleton>(rep) {}
-        SkeletonPtr(const SkeletonPtr& r) : SharedPtr<Skeleton>(r) {} 
-        SkeletonPtr(const ResourcePtr& r) : SharedPtr<Skeleton>()
-        {
-			// lock & copy other mutex pointer
-            OGRE_MUTEX_CONDITIONAL(r.OGRE_AUTO_MUTEX_NAME)
-            {
-			    OGRE_LOCK_MUTEX(*r.OGRE_AUTO_MUTEX_NAME)
-			    OGRE_COPY_AUTO_SHARED_MUTEX(r.OGRE_AUTO_MUTEX_NAME)
-                pRep = static_cast<Skeleton*>(r.getPointer());
-                pUseCount = r.useCountPointer();
-                if (pUseCount)
-                {
-                    ++(*pUseCount);
-                }
-            }
-        }
-
-        /// Operator used to convert a ResourcePtr to a SkeletonPtr
-        SkeletonPtr& operator=(const ResourcePtr& r)
-        {
-            if (pRep == static_cast<Skeleton*>(r.getPointer()))
-                return *this;
-            release();
-			// lock & copy other mutex pointer
-            OGRE_MUTEX_CONDITIONAL(r.OGRE_AUTO_MUTEX_NAME)
-            {
-			    OGRE_LOCK_MUTEX(*r.OGRE_AUTO_MUTEX_NAME)
-			    OGRE_COPY_AUTO_SHARED_MUTEX(r.OGRE_AUTO_MUTEX_NAME)
-                pRep = static_cast<Skeleton*>(r.getPointer());
-                pUseCount = r.useCountPointer();
-                if (pUseCount)
-                {
-                    ++(*pUseCount);
-                }
-            }
-			else
-			{
-				// RHS must be a null pointer
-				assert(r.isNull() && "RHS must be null if it has no mutex!");
-				setNull();
-			}
-            return *this;
-        }
+        String skeletonName;
+        SkeletonPtr pSkeleton;
+        Real scale;
+        LinkedSkeletonAnimationSource(const String& skelName, Real scl)
+            : skeletonName(skelName), scale(scl) {}
+            LinkedSkeletonAnimationSource(const String& skelName, Real scl, 
+                SkeletonPtr skelPtr)
+                : skeletonName(skelName), pSkeleton(skelPtr), scale(scl) {}
     };
-
-	/// Link to another skeleton to share animations
-	struct LinkedSkeletonAnimationSource
-	{
-		String skeletonName;
-		SkeletonPtr pSkeleton;
-		Real scale;
-		LinkedSkeletonAnimationSource(const String& skelName, Real scl)
-			: skeletonName(skelName), scale(scl) {}
-			LinkedSkeletonAnimationSource(const String& skelName, Real scl, 
-				SkeletonPtr skelPtr)
-				: skeletonName(skelName), pSkeleton(skelPtr), scale(scl) {}
-	};
-	/** @} */
-	/** @} */
+    /** @} */
+    /** @} */
 
 }
 
+#include "OgreHeaderSuffix.h"
 
 #endif
 
