@@ -4,7 +4,7 @@ This source file is part of OGRE
     (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -31,18 +31,19 @@ THE SOFTWARE.
 // Precompiler options
 #include "OgrePrerequisites.h"
 
-#include "OgreVector3.h"
+#include "OgreVector.h"
+#include "OgrePlane.h"
 
 namespace Ogre {
 
 
-	/** \addtogroup Core
-	*  @{
-	*/
-	/** \addtogroup Math
-	*  @{
-	*/
-	/** A sphere primitive, mostly used for bounds checking. 
+    /** \addtogroup Core
+    *  @{
+    */
+    /** \addtogroup Math
+    *  @{
+    */
+    /** A sphere primitive, mostly used for bounds checking. 
     @remarks
         A sphere in math texts is normally represented by the function
         x^2 + y^2 + z^2 = r^2 (for sphere's centered on the origin). Ogre stores spheres
@@ -75,58 +76,61 @@ namespace Ogre {
         /** Sets the center point of the sphere. */
         void setCenter(const Vector3& center) { mCenter = center; }
 
-		/** Returns whether or not this sphere intersects another sphere. */
-		bool intersects(const Sphere& s) const
-		{
+        /** Returns whether or not this sphere intersects another sphere. */
+        bool intersects(const Sphere& s) const
+        {
             return (s.mCenter - mCenter).squaredLength() <=
                 Math::Sqr(s.mRadius + mRadius);
-		}
-		/** Returns whether or not this sphere intersects a box. */
-		bool intersects(const AxisAlignedBox& box) const
-		{
-			return Math::intersects(*this, box);
-		}
-		/** Returns whether or not this sphere intersects a plane. */
-		bool intersects(const Plane& plane) const
-		{
-			return Math::intersects(*this, plane);
-		}
-		/** Returns whether or not this sphere intersects a point. */
-		bool intersects(const Vector3& v) const
-		{
+        }
+        /** Returns whether or not this sphere intersects a box. */
+        bool intersects(const AxisAlignedBox& box) const
+        {
+            return Math::intersects(*this, box);
+        }
+        /** Returns whether or not this sphere intersects a plane. */
+        bool intersects(const Plane& plane) const
+        {
+            return Math::Abs(plane.getDistance(getCenter())) <= getRadius();
+        }
+        /** Returns whether or not this sphere intersects a point. */
+        bool intersects(const Vector3& v) const
+        {
             return ((v - mCenter).squaredLength() <= Math::Sqr(mRadius));
-		}
-		/** Merges another Sphere into the current sphere */
-		void merge(const Sphere& oth)
-		{
-			Vector3 diff = oth.getCenter() - mCenter;
-			Real lengthSq = diff.squaredLength();
-			Real radiusDiff = oth.getRadius() - mRadius;
-			
-			// Early-out
-			if (Math::Sqr(radiusDiff) >= lengthSq) 
-			{
-				// One fully contains the other
-				if (radiusDiff <= 0.0f) 
-					return; // no change
-				else 
-				{
-					mCenter = oth.getCenter();
-					mRadius = oth.getRadius();
-					return;
-				}
-			}
+        }
+        /** Merges another Sphere into the current sphere */
+        void merge(const Sphere& oth)
+        {
+            Vector3 diff = oth.getCenter() - mCenter;
+            Real lengthSq = diff.squaredLength();
+            Real radiusDiff = oth.getRadius() - mRadius;
+            
+            // Early-out
+            if (Math::Sqr(radiusDiff) >= lengthSq) 
+            {
+                // One fully contains the other
+                if (radiusDiff <= 0.0f) 
+                    return; // no change
+                else 
+                {
+                    mCenter = oth.getCenter();
+                    mRadius = oth.getRadius();
+                    return;
+                }
+            }
 
-			Real length = Math::Sqrt(lengthSq);
+            Real length = Math::Sqrt(lengthSq);
             Real t = (length + radiusDiff) / (2.0f * length);
             mCenter = mCenter + diff * t;
-			mRadius = 0.5f * (length + mRadius + oth.getRadius());
-		}
-        
-
+            mRadius = 0.5f * (length + mRadius + oth.getRadius());
+        }
     };
-	/** @} */
-	/** @} */
+
+    inline bool Math::intersects(const Sphere& sphere, const Plane& plane)
+    {
+        return sphere.intersects(plane);
+    }
+    /** @} */
+    /** @} */
 
 }
 
