@@ -36,6 +36,7 @@ THE SOFTWARE.
 #include "Threading/OgreThreadHeaders.h"
 
 struct AAssetManager;
+struct AAsset;
 
 namespace Ogre {
 
@@ -72,12 +73,13 @@ namespace Ogre {
     public:
         EmbeddedZipArchiveFactory();
         virtual ~EmbeddedZipArchiveFactory();
-        /// @copydoc FactoryObj::getType
-        const String& getType(void) const;
+
+        const String& getType(void) const override;
 
         using ArchiveFactory::createInstance;
 
-        Archive *createInstance( const String& name, bool readOnly );
+        Archive *createInstance( const String& name, bool readOnly ) override;
+        void destroyInstance( Archive* ptr) override;
         
         /** a function type to decrypt embedded zip file
         @param pos pos in file
@@ -99,17 +101,16 @@ namespace Ogre {
 #if OGRE_PLATFORM == OGRE_PLATFORM_ANDROID
     class APKZipArchiveFactory : public EmbeddedZipArchiveFactory
     {
+        std::map<String, AAsset*> mOpenAssets;
     protected:
         AAssetManager* mAssetMgr;
     public:
         APKZipArchiveFactory(AAssetManager* assetMgr) : mAssetMgr(assetMgr) {}
         virtual ~APKZipArchiveFactory() {}
 
-        /// @copydoc FactoryObj::getType
-        const String& getType(void) const;
-
-        /// @copydoc ArchiveFactory::createInstance
-        Archive *createInstance( const String& name, bool readOnly );
+        const String& getType(void) const override;
+        Archive *createInstance( const String& name, bool readOnly ) override;
+        void destroyInstance( Archive* ptr) override;
     };
 #endif
 
