@@ -4,7 +4,7 @@ This source file is part of OGRE
     (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -27,13 +27,6 @@ THE SOFTWARE.
 */
 #include "OgreStableHeaders.h"
 
-#include "OgreArchiveManager.h"
-
-#include "OgreArchiveFactory.h"
-#include "OgreArchive.h"
-#include "OgreException.h"
-#include "OgreLogManager.h"
-
 namespace Ogre {
     typedef void (*createFunc)( Archive**, const String& );
 
@@ -48,9 +41,9 @@ namespace Ogre {
         assert( msSingleton );  return ( *msSingleton );  
     }
     //-----------------------------------------------------------------------
-	ArchiveManager::ArchiveManager()
-	{
-	}
+    ArchiveManager::ArchiveManager()
+    {
+    }
     //-----------------------------------------------------------------------
     Archive* ArchiveManager::load( const String& filename, const String& archiveType, bool readOnly)
     {
@@ -62,9 +55,11 @@ namespace Ogre {
             // Search factories
             ArchiveFactoryMap::iterator it = mArchFactories.find(archiveType);
             if (it == mArchFactories.end())
+            {
                 // Factory not found
                 OGRE_EXCEPT(Exception::ERR_ITEM_NOT_FOUND, "Cannot find an archive factory "
                     "to deal with archive of type " + archiveType, "ArchiveManager::load");
+            }
 
             pArch = it->second->createInstance(filename, readOnly);
             pArch->load();
@@ -74,56 +69,54 @@ namespace Ogre {
         else
         {
             pArch = i->second;
+            OgreAssert(pArch->isReadOnly() == readOnly, "existing archive location has different readOnly status");
         }
+
         return pArch;
     }
-	//-----------------------------------------------------------------------
-	void ArchiveManager::unload(Archive* arch)
-	{
-		unload(arch->getName());
-	}
-	//-----------------------------------------------------------------------
-	void ArchiveManager::unload(const String& filename)
-	{
-		ArchiveMap::iterator i = mArchives.find(filename);
+    //-----------------------------------------------------------------------
+    void ArchiveManager::unload(Archive* arch)
+    {
+        unload(arch->getName());
+    }
+    //-----------------------------------------------------------------------
+    void ArchiveManager::unload(const String& filename)
+    {
+        ArchiveMap::iterator i = mArchives.find(filename);
 
-		if (i != mArchives.end())
-		{
-			i->second->unload();
-			// Find factory to destroy
-			ArchiveFactoryMap::iterator fit = mArchFactories.find(i->second->getType());
-			if (fit == mArchFactories.end())
-			{
-				// Factory not found
-				OGRE_EXCEPT(Exception::ERR_ITEM_NOT_FOUND, "Cannot find an archive factory "
-					"to deal with archive of type " + i->second->getType(), "ArchiveManager::~ArchiveManager");
-			}
-			fit->second->destroyInstance(i->second);
-			mArchives.erase(i);
-		}
-	}
-	//-----------------------------------------------------------------------
-	ArchiveManager::ArchiveMapIterator ArchiveManager::getArchiveIterator(void)
-	{
-		return ArchiveMapIterator(mArchives.begin(), mArchives.end());
-	}
+        if (i != mArchives.end())
+        {
+            i->second->unload();
+            // Find factory to destroy. An archive factory created this file, it should still be there!
+            ArchiveFactoryMap::iterator fit = mArchFactories.find(i->second->getType());
+            assert( fit != mArchFactories.end() && "Cannot find an archive factory "
+                    "to deal with archive this type" );
+            fit->second->destroyInstance(i->second);
+            mArchives.erase(i);
+        }
+    }
+    //-----------------------------------------------------------------------
+    ArchiveManager::ArchiveMapIterator ArchiveManager::getArchiveIterator(void)
+    {
+        return ArchiveMapIterator(mArchives.begin(), mArchives.end());
+    }
     //-----------------------------------------------------------------------
     ArchiveManager::~ArchiveManager()
     {
+        // Thanks to http://www.viva64.com/en/examples/V509/ for finding the error for us!
+        // (originally, it detected we were throwing using OGRE_EXCEPT in the destructor)
+        // We now raise an assert.
+
         // Unload & delete resources in turn
         for( ArchiveMap::iterator it = mArchives.begin(); it != mArchives.end(); ++it )
         {
             Archive* arch = it->second;
             // Unload
             arch->unload();
-            // Find factory to destroy
+            // Find factory to destroy. An archive factory created this file, it should still be there!
             ArchiveFactoryMap::iterator fit = mArchFactories.find(arch->getType());
-            if (fit == mArchFactories.end())
-            {
-                // Factory not found
-                OGRE_EXCEPT(Exception::ERR_ITEM_NOT_FOUND, "Cannot find an archive factory "
-                "to deal with archive of type " + arch->getType(), "ArchiveManager::~ArchiveManager");
-            }
+            assert( fit != mArchFactories.end() && "Cannot find an archive factory "
+                    "to deal with archive this type" );
             fit->second->destroyInstance(arch);
             
         }
@@ -132,8 +125,8 @@ namespace Ogre {
     }
     //-----------------------------------------------------------------------
     void ArchiveManager::addArchiveFactory(ArchiveFactory* factory)
-    {        
-        mArchFactories.insert( ArchiveFactoryMap::value_type( factory->getType(), factory ) );
+    {
+        mArchFactories.emplace(factory->getType(), factory);
         LogManager::getSingleton().logMessage("ArchiveFactory for archive type " +     factory->getType() + " registered.");
     }
 
