@@ -32,7 +32,18 @@ THE SOFTWARE.
 #include "OgreBillboard.h"
 
 namespace Ogre {
-    String rendererTypeName = "billboard";
+    static String rendererTypeName = "billboard";
+
+    static class CmdStacksAndSlices : public ParamCommand
+    {
+    public:
+        String doGet(const void* target) const { return BLANKSTRING; }
+        void doSet(void* target, const String& val)
+        {
+            Vector2 tmp = StringConverter::parseVector2(val);
+            static_cast<BillboardParticleRenderer*>(target)->setTextureStacksAndSlices(tmp.x, tmp.y);
+        }
+    } msStacksAndSlicesCmd;
 
     //-----------------------------------------------------------------------
     BillboardParticleRenderer::CmdBillboardType BillboardParticleRenderer::msBillboardTypeCmd;
@@ -101,6 +112,10 @@ namespace Ogre {
                 "Cannot be combined with point rendering.",
                 PT_BOOL),
                 &msAccurateFacingCmd);
+
+            dict->addParameter(ParameterDef("texture_sheet_size", "",
+                PT_UNSIGNED_INT),
+                &msStacksAndSlicesCmd);
         }
 
         // Create billboard set
@@ -129,30 +144,14 @@ namespace Ogre {
         mBillboardSet->setCullIndividually(cullIndividually);
 
         // Update billboard set geometry
-        Vector3 bboxMin = Math::POS_INFINITY * Vector3::UNIT_SCALE;
-        Vector3 bboxMax = Math::NEG_INFINITY * Vector3::UNIT_SCALE;
-        Real radius = 0.0f;
         mBillboardSet->beginBillboards(currentParticles.size());
         Billboard bb;
-        Affine3 invWorld;
-
-        bool invert = mBillboardSet->getBillboardsInWorldSpace() && mBillboardSet->getParentSceneNode();
-        if (invert)
-            invWorld = mBillboardSet->getParentSceneNode()->_getFullTransform().inverse();
 
         for (std::list<Particle*>::iterator i = currentParticles.begin();
             i != currentParticles.end(); ++i)
         {
             Particle* p = *i;
             bb.mPosition = p->mPosition;
-            Vector3 pos = p->mPosition;
-
-            if (invert)
-                pos = invWorld * pos;
-
-            bboxMin.makeFloor( pos );
-            bboxMax.makeCeil( pos );
-            radius = std::max( radius, p->mPosition.length() );
 
             if (mBillboardSet->getBillboardType() == BBT_ORIENTED_SELF ||
                 mBillboardSet->getBillboardType() == BBT_PERPENDICULAR_SELF)
@@ -170,140 +169,17 @@ namespace Ogre {
                 bb.mHeight = p->mHeight;
             }
             mBillboardSet->injectBillboard(bb);
-
         }
 
-        // Only set bounds if there are any active particles
-        if(currentParticles.size())
-            mBillboardSet->setBounds( AxisAlignedBox( bboxMin, bboxMax ), radius );
-
         mBillboardSet->endBillboards();
 
         // Update the queue
         mBillboardSet->_updateRenderQueue(queue);
     }
-    //---------------------------------------------------------------------
-    void BillboardParticleRenderer::visitRenderables(Renderable::Visitor* visitor, 
-        bool debugRenderables)
+
+    void BillboardParticleRenderer::_notifyBoundingBox(const AxisAlignedBox& aabb)
     {
-        mBillboardSet->visitRenderables(visitor, debugRenderables);
-    }
-    //-----------------------------------------------------------------------
-    void BillboardParticleRenderer::_setMaterial(MaterialPtr& mat)
-    {
-        mBillboardSet->setMaterialName(mat->getName(), mat->getGroup());
-    }
-    //-----------------------------------------------------------------------
-    void BillboardParticleRenderer::setBillboardType(BillboardType bbt)
-    {
-        mBillboardSet->setBillboardType(bbt);
-    }
-    //-----------------------------------------------------------------------
-    void BillboardParticleRenderer::setUseAccurateFacing(bool acc)
-    {
-        mBillboardSet->setUseAccurateFacing(acc);
-    }
-    //-----------------------------------------------------------------------
-    bool BillboardParticleRenderer::getUseAccurateFacing(void) const
-    {
-        return mBillboardSet->getUseAccurateFacing();
-    }
-    //-----------------------------------------------------------------------
-    BillboardType BillboardParticleRenderer::getBillboardType(void) const
-    {
-        return mBillboardSet->getBillboardType();
-    }
-    //-----------------------------------------------------------------------
-    void BillboardParticleRenderer::setBillboardRotationType(BillboardRotationType rotationType)
-    {
-        mBillboardSet->setBillboardRotationType(rotationType);
-    }
-    //-----------------------------------------------------------------------
-    BillboardRotationType BillboardParticleRenderer::getBillboardRotationType(void) const
-    {
-        return mBillboardSet->getBillboardRotationType();
-    }
-    //-----------------------------------------------------------------------
-    void BillboardParticleRenderer::setCommonDirection(const Vector3& vec)
-    {
-        mBillboardSet->setCommonDirection(vec);
-    }
-    //-----------------------------------------------------------------------
-    const Vector3& BillboardParticleRenderer::getCommonDirection(void) const
-    {
-        return mBillboardSet->getCommonDirection();
-    }
-    //-----------------------------------------------------------------------
-    void BillboardParticleRenderer::setCommonUpVector(const Vector3& vec)
-    {
-        mBillboardSet->setCommonUpVector(vec);
-    }
-    //-----------------------------------------------------------------------
-    const Vector3& BillboardParticleRenderer::getCommonUpVector(void) const
-    {
-        return mBillboardSet->getCommonUpVector();
-    }
-    //-----------------------------------------------------------------------
-    void BillboardParticleRenderer::_notifyCurrentCamera(Camera* cam)
-    {
-        mBillboardSet->_notifyCurrentCamera(cam);
-    }
-    //-----------------------------------------------------------------------
-    void BillboardParticleRenderer::_notifyParticleRotated(void)
-    {
-        mBillboardSet->_notifyBillboardRotated();
-    }
-    //-----------------------------------------------------------------------
-    void BillboardParticleRenderer::_notifyDefaultDimensions(Real width, Real height)
-    {
-        mBillboardSet->setDefaultDimensions(width, height);
-    }
-    //-----------------------------------------------------------------------
-    void BillboardParticleRenderer::_notifyParticleResized(void)
-    {
-        mBillboardSet->_notifyBillboardResized();
-    }
-    //-----------------------------------------------------------------------
-    void BillboardParticleRenderer::_notifyParticleQuota(size_t quota)
-    {
-        mBillboardSet->setPoolSize(quota);
-    }
-    //-----------------------------------------------------------------------
-    void BillboardParticleRenderer::_notifyAttached(Node* parent, bool isTagPoint)
-    {
-        mBillboardSet->_notifyAttached(parent, isTagPoint);
-    }
-    //-----------------------------------------------------------------------
-    void BillboardParticleRenderer::setRenderQueueGroup(uint8 queueID)
-    {
-        assert(queueID <= RENDER_QUEUE_MAX && "Render queue out of range!");
-        mBillboardSet->setRenderQueueGroup(queueID);
-    }
-    //-----------------------------------------------------------------------
-    void BillboardParticleRenderer::setRenderQueueGroupAndPriority(uint8 queueID, ushort priority)
-    {
-        assert(queueID <= RENDER_QUEUE_MAX && "Render queue out of range!");
-        mBillboardSet->setRenderQueueGroupAndPriority(queueID, priority);
-    }
-    //-----------------------------------------------------------------------
-    void BillboardParticleRenderer::setKeepParticlesInLocalSpace(bool keepLocal)
-    {
-        mBillboardSet->setBillboardsInWorldSpace(!keepLocal);
-    }
-    //-----------------------------------------------------------------------
-    SortMode BillboardParticleRenderer::_getSortMode(void) const
-    {
-        return mBillboardSet->_getSortMode();
-    }
-    //-----------------------------------------------------------------------
-    void BillboardParticleRenderer::setPointRenderingEnabled(bool enabled)
-    {
-        mBillboardSet->setPointRenderingEnabled(enabled);
-    }
-    //-----------------------------------------------------------------------
-    bool BillboardParticleRenderer::isPointRenderingEnabled(void) const
-    {
-        return mBillboardSet->isPointRenderingEnabled();
+        mBillboardSet->setBounds(aabb, Math::boundingRadiusFromAABB(aabb));
     }
     //-----------------------------------------------------------------------
     //-----------------------------------------------------------------------
