@@ -34,18 +34,16 @@ THE SOFTWARE.
 
 namespace Ogre {
     // Init statics
-    RadixSort<BillboardSet::ActiveBillboardList, Billboard*, float> BillboardSet::mRadixSorter;
+    RadixSort<BillboardSet::BillboardPool, Billboard*, float> BillboardSet::mRadixSorter;
 
     //-----------------------------------------------------------------------
     BillboardSet::BillboardSet() :
         mBoundingRadius(0.0f), 
         mOriginType( BBO_CENTER ),
         mRotationType( BBR_TEXCOORD ),
-        mAllDefaultSize( true ),
         mAutoExtendPool( true ),
         mSortingEnabled(false),
         mAccurateFacing(false),
-        mAllDefaultRotation(true),
         mWorldSpace(false),
         mCullIndividual( false ),
         mBillboardType(BBT_POINT),
@@ -74,12 +72,11 @@ namespace Ogre {
         mBoundingRadius(0.0f), 
         mOriginType( BBO_CENTER ),
         mRotationType( BBR_TEXCOORD ),
-        mAllDefaultSize( true ),
         mAutoExtendPool( true ),
         mSortingEnabled(false),
         mAccurateFacing(false),
-        mAllDefaultRotation(true),
         mWorldSpace(false),
+        mActiveBillboards(0),
         mCullIndividual( false ),
         mBillboardType(BBT_POINT),
         mCommonDirection(Ogre::Vector3::UNIT_Z),
@@ -116,7 +113,7 @@ namespace Ogre {
         const Vector3& position,
         const ColourValue& colour )
     {
-        if( mFreeBillboards.empty() )
+        if( mActiveBillboards == mBillboardPool.size() )
         {
             if( mAutoExtendPool )
             {
@@ -129,9 +126,7 @@ namespace Ogre {
         }
 
         // Get a new billboard
-        Billboard* newBill = mFreeBillboards.front();
-        mActiveBillboards.splice(
-            mActiveBillboards.end(), mFreeBillboards, mFreeBillboards.begin());
+        Billboard* newBill = mBillboardPool[mActiveBillboards++];
         newBill->setPosition(position);
         newBill->setColour(colour);
         newBill->mDirection = Vector3::ZERO;
@@ -154,138 +149,31 @@ namespace Ogre {
         return newBill;
     }
 
-    //-----------------------------------------------------------------------
-    Billboard* BillboardSet::createBillboard(
-        Real x, Real y, Real z,
-        const ColourValue& colour )
-    {
-        return createBillboard( Vector3( x, y, z ), colour );
-    }
-
-    //-----------------------------------------------------------------------
-    int BillboardSet::getNumBillboards(void) const
-    {
-        return static_cast< int >( mActiveBillboards.size() );
-    }
-
     //-----------------------------------------------------------------------
     void BillboardSet::clear()
     {
-        // Move actives to free list
-        mFreeBillboards.splice(mFreeBillboards.end(), mActiveBillboards);
+        mActiveBillboards = 0;
     }
 
     //-----------------------------------------------------------------------
     Billboard* BillboardSet::getBillboard( unsigned int index ) const
     {
-        assert(
-            index < mActiveBillboards.size() &&
-            "Billboard index out of bounds." );
-
-        /* We can't access it directly, so we check whether it's in the first
-           or the second half, then we start either from the beginning or the
-           end of the list
-        */
-        ActiveBillboardList::const_iterator it;
-        if( index >= ( mActiveBillboards.size() >> 1 ) )
-        {
-            index = static_cast<unsigned int>(mActiveBillboards.size()) - index;
-            for( it = mActiveBillboards.end(); index; --index, --it );
-        }
-        else
-        {
-            for( it = mActiveBillboards.begin(); index; --index, ++it );
-        }
-
-        return *it;
+        assert(index < mActiveBillboards && "Billboard index out of bounds.");
+        return mBillboardPool[index];
     }
 
     //-----------------------------------------------------------------------
     void BillboardSet::removeBillboard(unsigned int index)
     {
-        assert(
-            index < mActiveBillboards.size() &&
-            "Billboard index out of bounds." );
-
-        /* We can't access it directly, so we check whether it's in the first
-           or the second half, then we start either from the beginning or the
-           end of the list.
-           We then remove the billboard form the 'used' list and add it to
-           the 'free' list.
-        */
-        ActiveBillboardList::iterator it;
-        if( index >= ( mActiveBillboards.size() >> 1 ) )
-        {
-            index = static_cast<unsigned int>(mActiveBillboards.size()) - index;
-            for( it = mActiveBillboards.end(); index; --index, --it );
-        }
-        else
-        {
-            for( it = mActiveBillboards.begin(); index; --index, ++it );
-        }
-
-        mFreeBillboards.splice(mFreeBillboards.end(), mActiveBillboards, it);
+        assert(index < mActiveBillboards && "Billboard isn't in the active list.");
+        std::swap(mBillboardPool[index], mBillboardPool[--mActiveBillboards]);
     }
 
     //-----------------------------------------------------------------------
     void BillboardSet::removeBillboard( Billboard* pBill )
     {
-        ActiveBillboardList::iterator it =
-            std::find(mActiveBillboards.begin(), mActiveBillboards.end(), pBill);
-        assert(
-            it != mActiveBillboards.end() &&
-            "Billboard isn't in the active list." );
-
-        mFreeBillboards.splice(mFreeBillboards.end(), mActiveBillboards, it);
-    }
-
-    //-----------------------------------------------------------------------
-    void BillboardSet::setBillboardOrigin( BillboardOrigin origin )
-    {
-        mOriginType = origin;
-    }
-
-    //-----------------------------------------------------------------------
-    BillboardOrigin BillboardSet::getBillboardOrigin(void) const
-    {
-        return mOriginType;
-    }
-
-    //-----------------------------------------------------------------------
-    void BillboardSet::setBillboardRotationType(BillboardRotationType rotationType)
-    {
-        mRotationType = rotationType;
-    }
-    //-----------------------------------------------------------------------
-    BillboardRotationType BillboardSet::getBillboardRotationType(void) const
-    {
-        return mRotationType;
-    }
-    //-----------------------------------------------------------------------
-    void BillboardSet::setDefaultDimensions( Real width, Real height )
-    {
-        mDefaultWidth = width;
-        mDefaultHeight = height;
-    }
-    //-----------------------------------------------------------------------
-    void BillboardSet::setDefaultWidth(Real width)
-    {
-        mDefaultWidth = width;
-    }
-    //-----------------------------------------------------------------------
-    Real BillboardSet::getDefaultWidth(void) const
-    {
-        return mDefaultWidth;
-    }
-    //-----------------------------------------------------------------------
-    void BillboardSet::setDefaultHeight(Real height)
-    {
-        mDefaultHeight = height;
-    }
-    //-----------------------------------------------------------------------
-    Real BillboardSet::getDefaultHeight(void) const
-    {
-        return mDefaultHeight;
+        auto it = std::find(mBillboardPool.begin(), mBillboardPool.begin() + mActiveBillboards, pBill);
+        removeBillboard(std::distance(mBillboardPool.begin(), it));
     }
     //-----------------------------------------------------------------------
     void BillboardSet::setMaterialName( const String& name , const String& groupName /* = ResourceGroupManager::AUTODETECT_RESOURCE_GROUP_NAME */ )
@@ -302,22 +190,18 @@ namespace Ogre {
         mMaterial->load();
     }
 
-    //-----------------------------------------------------------------------
-    const String& BillboardSet::getMaterialName(void) const
-    {
-        return mMaterial->getName();
-    }
-
     //-----------------------------------------------------------------------
     void BillboardSet::_sortBillboards( Camera* cam)
     {
         switch (_getSortMode())
         {
         case SM_DIRECTION:
-            mRadixSorter.sort(mActiveBillboards, SortByDirectionFunctor(-mCamDir));
+            mRadixSorter.sort(mBillboardPool.begin(), mBillboardPool.begin() + mActiveBillboards,
+                              SortByDirectionFunctor(-mCamDir));
             break;
         case SM_DISTANCE:
-            mRadixSorter.sort(mActiveBillboards, SortByDistanceFunctor(mCamPos));
+            mRadixSorter.sort(mBillboardPool.begin(), mBillboardPool.begin() + mActiveBillboards,
+                              SortByDistanceFunctor(mCamPos));
             break;
         }
     }
@@ -468,55 +352,38 @@ namespace Ogre {
         // Skip if not visible (NB always true if not bounds checking individual billboards)
         if (!billboardVisible(mCurrentCamera, bb)) return;
 
-        if (!mPointRendering &&
-            (mBillboardType == BBT_ORIENTED_SELF ||
-            mBillboardType == BBT_PERPENDICULAR_SELF ||
-            (mAccurateFacing && mBillboardType != BBT_PERPENDICULAR_COMMON)))
+        // Increment visibles
+        mNumVisibleBillboards++;
+
+        if(mPointRendering)
+        {
+            genPointVertices(bb);
+            return;
+        }
+
+        if ((mBillboardType == BBT_ORIENTED_SELF || mBillboardType == BBT_PERPENDICULAR_SELF ||
+             (mAccurateFacing && mBillboardType != BBT_PERPENDICULAR_COMMON)))
         {
             // Have to generate axes & offsets per billboard
             genBillboardAxes(&mCamX, &mCamY, &bb);
         }
 
-        // If they're all the same size or we're point rendering
-        if( mAllDefaultSize || mPointRendering)
+        if ((mBillboardType == BBT_ORIENTED_SELF || mBillboardType == BBT_PERPENDICULAR_SELF ||
+             bb.mOwnDimensions || (mAccurateFacing && mBillboardType != BBT_PERPENDICULAR_COMMON)))
         {
-            /* No per-billboard checking, just blast through.
-            Saves us an if clause every billboard which may
-            make a difference.
-            */
-
-            if (!mPointRendering &&
-                (mBillboardType == BBT_ORIENTED_SELF ||
-                mBillboardType == BBT_PERPENDICULAR_SELF ||
-                (mAccurateFacing && mBillboardType != BBT_PERPENDICULAR_COMMON)))
-            {
-                genVertOffsets(mLeftOff, mRightOff, mTopOff, mBottomOff,
-                    mDefaultWidth, mDefaultHeight, mCamX, mCamY, mVOffset);
-            }
-            genVertices(mVOffset, bb);
-        }
-        else // not all default size and not point rendering
-        {
-            Vector3 vOwnOffset[4];
             // If it has own dimensions, or self-oriented, gen offsets
-            if (mBillboardType == BBT_ORIENTED_SELF ||
-                mBillboardType == BBT_PERPENDICULAR_SELF ||
-                bb.mOwnDimensions ||
-                (mAccurateFacing && mBillboardType != BBT_PERPENDICULAR_COMMON))
-            {
-                // Generate using own dimensions
-                genVertOffsets(mLeftOff, mRightOff, mTopOff, mBottomOff,
-                    bb.mWidth, bb.mHeight, mCamX, mCamY, vOwnOffset);
-                // Create vertex data
-                genVertices(vOwnOffset, bb);
-            }
-            else // Use default dimension, already computed before the loop, for faster creation
-            {
-                genVertices(mVOffset, bb);
-            }
+            Vector3 vOwnOffset[4];
+            Real width = bb.mOwnDimensions ? bb.mWidth : mDefaultWidth;
+            Real height = bb.mOwnDimensions ? bb.mHeight : mDefaultHeight;
+            genVertOffsets(mLeftOff, mRightOff, mTopOff, mBottomOff,
+                width, height, mCamX, mCamY, vOwnOffset);
+            genQuadVertices(vOwnOffset, bb);
+        }
+        else
+        {
+            // Use default dimension, already computed before the loop, for faster creation
+            genQuadVertices(mVOffset, bb);
         }
-        // Increment visibles
-        mNumVisibleBillboards++;
     }
     //-----------------------------------------------------------------------
     void BillboardSet::endBillboards(void)
@@ -532,7 +399,7 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void BillboardSet::_updateBounds(void)
     {
-        if (mActiveBillboards.empty())
+        if (mActiveBillboards == 0)
         {
             // No billboards, null bbox
             mAABB.setNull();
@@ -540,49 +407,34 @@ namespace Ogre {
         }
         else
         {
-            Real maxSqLen = -1.0f;
-
-            Vector3 min(Math::POS_INFINITY, Math::POS_INFINITY, Math::POS_INFINITY);
-            Vector3 max(Math::NEG_INFINITY, Math::NEG_INFINITY, Math::NEG_INFINITY);
-            ActiveBillboardList::iterator i, iend;
-
-            iend = mActiveBillboards.end();
+            mAABB.setNull();
+            auto iend = mBillboardPool.begin() + mActiveBillboards;
             Affine3 invWorld;
             bool invert = mWorldSpace && getParentSceneNode();
             if (invert)
                 invWorld = getParentSceneNode()->_getFullTransform().inverse();
 
-            for (i = mActiveBillboards.begin(); i != iend; ++i)
+            for (auto i = mBillboardPool.begin(); i != iend; ++i)
             {
                 Vector3 pos = (*i)->getPosition();
                 // transform from world space to local space
                 if (invert)
                     pos = invWorld * pos;
-                min.makeFloor(pos);
-                max.makeCeil(pos);
 
-                maxSqLen = std::max(maxSqLen, pos.squaredLength());
+                mAABB.merge(pos);
             }
             // Adjust for billboard size
             Real adjust = std::max(mDefaultWidth, mDefaultHeight);
             Vector3 vecAdjust(adjust, adjust, adjust);
-            min -= vecAdjust;
-            max += vecAdjust;
-
-            mAABB.setExtents(min, max);
-            mBoundingRadius = Math::Sqrt(maxSqLen);
 
+            mAABB.setExtents(mAABB.getMinimum() - vecAdjust, mAABB.getMaximum() + vecAdjust);
+            mBoundingRadius = Math::boundingRadiusFromAABB(mAABB);
         }
 
         if (mParentNode)
             mParentNode->needUpdate();
 
     }
-    //-----------------------------------------------------------------------
-    const AxisAlignedBox& BillboardSet::getBoundingBox(void) const
-    {
-        return mAABB;
-    }
 
     //-----------------------------------------------------------------------
     void BillboardSet::_updateRenderQueue(RenderQueue* queue)
@@ -595,11 +447,9 @@ namespace Ogre {
                 _sortBillboards(mCurrentCamera);
             }
 
-            beginBillboards(mActiveBillboards.size());
-            ActiveBillboardList::iterator it;
-            for(it = mActiveBillboards.begin();
-                it != mActiveBillboards.end();
-                ++it )
+            beginBillboards(mActiveBillboards);
+            auto iend = mBillboardPool.begin() + mActiveBillboards;
+            for (auto it = mBillboardPool.begin(); it != iend; ++it)
             {
                 injectBillboard(*(*it));
             }
@@ -622,25 +472,10 @@ namespace Ogre {
 
     }
 
-    //-----------------------------------------------------------------------
-    const MaterialPtr& BillboardSet::getMaterial(void) const
-    {
-        return mMaterial;
-    }
-
     void BillboardSet::setMaterial( const MaterialPtr& material )
     {
+        OgreAssert(material, "material is NULL");
         mMaterial = material;
-        
-        if (!mMaterial)
-        {
-            LogManager::getSingleton().logMessage("Can't assign material " + material->getName()+
-                                                  " to BillboardSet of " + getName() + " because this "
-                                                  "Material does not exist in group "+material->getGroup()+". Have you forgotten to define it in a "
-                                                  ".material script?", LML_CRITICAL);
-
-            mMaterial = MaterialManager::getSingleton().getDefaultMaterial();
-        }
 
         // Ensure new material loaded (will not load again if already loaded)
         mMaterial->load();
@@ -686,30 +521,6 @@ namespace Ogre {
         }
     }
 
-    //-----------------------------------------------------------------------
-    void BillboardSet::setAutoextend( bool autoextend )
-    {
-        mAutoExtendPool = autoextend;
-    }
-
-    //-----------------------------------------------------------------------
-    bool BillboardSet::getAutoextend(void) const
-    {
-        return mAutoExtendPool;
-    }
-
-    //-----------------------------------------------------------------------
-    void BillboardSet::setSortingEnabled( bool sortenable )
-    {
-        mSortingEnabled = sortenable;
-    }
-
-    //-----------------------------------------------------------------------
-    bool BillboardSet::getSortingEnabled(void) const
-    {
-        return mSortingEnabled;
-    }
-
     //-----------------------------------------------------------------------
     void BillboardSet::setPoolSize( size_t size )
     {
@@ -722,12 +533,6 @@ namespace Ogre {
                 return;
 
             this->increasePool(size);
-
-            for( size_t i = currSize; i < size; ++i )
-            {
-                // Add new items to the queue
-                mFreeBillboards.push_back( mBillboardPool[i] );
-            }
         }
 
         mPoolSize = size;
@@ -774,7 +579,7 @@ namespace Ogre {
 
         size_t offset = 0;
         offset += decl->addElement(0, offset, VET_FLOAT3, VES_POSITION).getSize();
-        offset += decl->addElement(0, offset, VET_COLOUR, VES_DIFFUSE).getSize();
+        offset += decl->addElement(0, offset, VET_UBYTE4_NORM, VES_DIFFUSE).getSize();
         // Texture coords irrelevant when enabled point rendering (generated
         // in point sprite mode, and unused in standard point mode)
         if (!mPointRendering)
@@ -846,23 +651,6 @@ namespace Ogre {
 
         mBuffersCreated = false;
     }
-    //-----------------------------------------------------------------------
-    unsigned int BillboardSet::getPoolSize(void) const
-    {
-        return static_cast< unsigned int >( mBillboardPool.size() );
-    }
-
-    //-----------------------------------------------------------------------
-    void BillboardSet::_notifyBillboardResized(void)
-    {
-        mAllDefaultSize = false;
-    }
-
-    //-----------------------------------------------------------------------
-    void BillboardSet::_notifyBillboardRotated(void)
-    {
-        mAllDefaultRotation = false;
-    }
 
     //-----------------------------------------------------------------------
     void BillboardSet::getParametricOffsets(
@@ -935,16 +723,6 @@ namespace Ogre {
         }
     }
     //-----------------------------------------------------------------------
-    bool BillboardSet::getCullIndividually(void) const
-    {
-        return mCullIndividual;
-    }
-    //-----------------------------------------------------------------------
-    void BillboardSet::setCullIndividually(bool cullIndividual)
-    {
-        mCullIndividual = cullIndividual;
-    }
-    //-----------------------------------------------------------------------
     bool BillboardSet::billboardVisible(Camera* cam, const Billboard& bill)
     {
         // Return always visible if not culling individually
@@ -976,7 +754,6 @@ namespace Ogre {
         size_t oldSize = mBillboardPool.size();
 
         // Increase size
-        mBillboardPool.reserve(size);
         mBillboardPool.resize(size);
 
         // Create new billboards
@@ -1054,69 +831,33 @@ namespace Ogre {
 
     }
     //-----------------------------------------------------------------------
-    void BillboardSet::setBillboardType(BillboardType bbt)
-    {
-        mBillboardType = bbt;
-    }
-    //-----------------------------------------------------------------------
-    BillboardType BillboardSet::getBillboardType(void) const
-    {
-        return mBillboardType;
-    }
-    //-----------------------------------------------------------------------
-    void BillboardSet::setCommonDirection(const Vector3& vec)
-    {
-        mCommonDirection = vec;
-    }
-    //-----------------------------------------------------------------------
-    const Vector3& BillboardSet::getCommonDirection(void) const
-    {
-        return mCommonDirection;
-    }
-    //-----------------------------------------------------------------------
-    void BillboardSet::setCommonUpVector(const Vector3& vec)
-    {
-        mCommonUpVector = vec;
-    }
-    //-----------------------------------------------------------------------
-    const Vector3& BillboardSet::getCommonUpVector(void) const
-    {
-        return mCommonUpVector;
-    }
-    //-----------------------------------------------------------------------
     uint32 BillboardSet::getTypeFlags(void) const
     {
         return SceneManager::FX_TYPE_MASK;
     }
     //-----------------------------------------------------------------------
-    void BillboardSet::genVertices(
-        const Vector3* const offsets, const Billboard& bb)
+    void BillboardSet::genPointVertices(const Billboard& bb)
     {
-        RGBA colour;
-        Root::getSingleton().convertColourValue(bb.mColour, &colour);
-        RGBA* pCol;
+        RGBA colour = bb.mColour.getAsBYTE();
+        // Single vertex per billboard, ignore offsets
+        // position
+        *mLockPtr++ = bb.mPosition.x;
+        *mLockPtr++ = bb.mPosition.y;
+        *mLockPtr++ = bb.mPosition.z;
+        // Colour
+        memcpy(mLockPtr++, &colour, sizeof(RGBA));
+        // No texture coords in point rendering
+    }
+    void BillboardSet::genQuadVertices(const Vector3* const offsets, const Billboard& bb)
+    {
+        RGBA colour = bb.mColour.getAsBYTE();
 
         // Texcoords
         assert( bb.mUseTexcoordRect || bb.mTexcoordIndex < mTextureCoords.size() );
         const Ogre::FloatRect & r =
             bb.mUseTexcoordRect ? bb.mTexcoordRect : mTextureCoords[bb.mTexcoordIndex];
 
-        if (mPointRendering)
-        {
-            // Single vertex per billboard, ignore offsets
-            // position
-            *mLockPtr++ = bb.mPosition.x;
-            *mLockPtr++ = bb.mPosition.y;
-            *mLockPtr++ = bb.mPosition.z;
-            // Colour
-            // Convert float* to RGBA*
-            pCol = static_cast<RGBA*>(static_cast<void*>(mLockPtr));
-            *pCol++ = colour;
-            // Update lock pointer
-            mLockPtr = static_cast<float*>(static_cast<void*>(pCol));
-            // No texture coords in point rendering
-        }
-        else if (mAllDefaultRotation || bb.mRotation == Radian(0))
+        if (bb.mRotation == Radian(0))
         {
             // Left-top
             // Positions
@@ -1124,11 +865,7 @@ namespace Ogre {
             *mLockPtr++ = offsets[0].y + bb.mPosition.y;
             *mLockPtr++ = offsets[0].z + bb.mPosition.z;
             // Colour
-            // Convert float* to RGBA*
-            pCol = static_cast<RGBA*>(static_cast<void*>(mLockPtr));
-            *pCol++ = colour;
-            // Update lock pointer
-            mLockPtr = static_cast<float*>(static_cast<void*>(pCol));
+            memcpy(mLockPtr++, &colour, sizeof(RGBA));
             // Texture coords
             *mLockPtr++ = r.left;
             *mLockPtr++ = r.top;
@@ -1139,11 +876,7 @@ namespace Ogre {
             *mLockPtr++ = offsets[1].y + bb.mPosition.y;
             *mLockPtr++ = offsets[1].z + bb.mPosition.z;
             // Colour
-            // Convert float* to RGBA*
-            pCol = static_cast<RGBA*>(static_cast<void*>(mLockPtr));
-            *pCol++ = colour;
-            // Update lock pointer
-            mLockPtr = static_cast<float*>(static_cast<void*>(pCol));
+            memcpy(mLockPtr++, &colour, sizeof(RGBA));
             // Texture coords
             *mLockPtr++ = r.right;
             *mLockPtr++ = r.top;
@@ -1154,11 +887,7 @@ namespace Ogre {
             *mLockPtr++ = offsets[2].y + bb.mPosition.y;
             *mLockPtr++ = offsets[2].z + bb.mPosition.z;
             // Colour
-            // Convert float* to RGBA*
-            pCol = static_cast<RGBA*>(static_cast<void*>(mLockPtr));
-            *pCol++ = colour;
-            // Update lock pointer
-            mLockPtr = static_cast<float*>(static_cast<void*>(pCol));
+            memcpy(mLockPtr++, &colour, sizeof(RGBA));
             // Texture coords
             *mLockPtr++ = r.left;
             *mLockPtr++ = r.bottom;
@@ -1169,11 +898,7 @@ namespace Ogre {
             *mLockPtr++ = offsets[3].y + bb.mPosition.y;
             *mLockPtr++ = offsets[3].z + bb.mPosition.z;
             // Colour
-            // Convert float* to RGBA*
-            pCol = static_cast<RGBA*>(static_cast<void*>(mLockPtr));
-            *pCol++ = colour;
-            // Update lock pointer
-            mLockPtr = static_cast<float*>(static_cast<void*>(pCol));
+            memcpy(mLockPtr++, &colour, sizeof(RGBA));
             // Texture coords
             *mLockPtr++ = r.right;
             *mLockPtr++ = r.bottom;
@@ -1195,11 +920,7 @@ namespace Ogre {
             *mLockPtr++ = pt.y + bb.mPosition.y;
             *mLockPtr++ = pt.z + bb.mPosition.z;
             // Colour
-            // Convert float* to RGBA*
-            pCol = static_cast<RGBA*>(static_cast<void*>(mLockPtr));
-            *pCol++ = colour;
-            // Update lock pointer
-            mLockPtr = static_cast<float*>(static_cast<void*>(pCol));
+            memcpy(mLockPtr++, &colour, sizeof(RGBA));
             // Texture coords
             *mLockPtr++ = r.left;
             *mLockPtr++ = r.top;
@@ -1211,11 +932,7 @@ namespace Ogre {
             *mLockPtr++ = pt.y + bb.mPosition.y;
             *mLockPtr++ = pt.z + bb.mPosition.z;
             // Colour
-            // Convert float* to RGBA*
-            pCol = static_cast<RGBA*>(static_cast<void*>(mLockPtr));
-            *pCol++ = colour;
-            // Update lock pointer
-            mLockPtr = static_cast<float*>(static_cast<void*>(pCol));
+            memcpy(mLockPtr++, &colour, sizeof(RGBA));
             // Texture coords
             *mLockPtr++ = r.right;
             *mLockPtr++ = r.top;
@@ -1227,11 +944,7 @@ namespace Ogre {
             *mLockPtr++ = pt.y + bb.mPosition.y;
             *mLockPtr++ = pt.z + bb.mPosition.z;
             // Colour
-            // Convert float* to RGBA*
-            pCol = static_cast<RGBA*>(static_cast<void*>(mLockPtr));
-            *pCol++ = colour;
-            // Update lock pointer
-            mLockPtr = static_cast<float*>(static_cast<void*>(pCol));
+            memcpy(mLockPtr++, &colour, sizeof(RGBA));
             // Texture coords
             *mLockPtr++ = r.left;
             *mLockPtr++ = r.bottom;
@@ -1243,11 +956,7 @@ namespace Ogre {
             *mLockPtr++ = pt.y + bb.mPosition.y;
             *mLockPtr++ = pt.z + bb.mPosition.z;
             // Colour
-            // Convert float* to RGBA*
-            pCol = static_cast<RGBA*>(static_cast<void*>(mLockPtr));
-            *pCol++ = colour;
-            // Update lock pointer
-            mLockPtr = static_cast<float*>(static_cast<void*>(pCol));
+            memcpy(mLockPtr++, &colour, sizeof(RGBA));
             // Texture coords
             *mLockPtr++ = r.right;
             *mLockPtr++ = r.bottom;
@@ -1273,11 +982,7 @@ namespace Ogre {
             *mLockPtr++ = offsets[0].y + bb.mPosition.y;
             *mLockPtr++ = offsets[0].z + bb.mPosition.z;
             // Colour
-            // Convert float* to RGBA*
-            pCol = static_cast<RGBA*>(static_cast<void*>(mLockPtr));
-            *pCol++ = colour;
-            // Update lock pointer
-            mLockPtr = static_cast<float*>(static_cast<void*>(pCol));
+            memcpy(mLockPtr++, &colour, sizeof(RGBA));
             // Texture coords
             *mLockPtr++ = mid_u - cos_rot_w + sin_rot_h;
             *mLockPtr++ = mid_v - sin_rot_w - cos_rot_h;
@@ -1288,11 +993,7 @@ namespace Ogre {
             *mLockPtr++ = offsets[1].y + bb.mPosition.y;
             *mLockPtr++ = offsets[1].z + bb.mPosition.z;
             // Colour
-            // Convert float* to RGBA*
-            pCol = static_cast<RGBA*>(static_cast<void*>(mLockPtr));
-            *pCol++ = colour;
-            // Update lock pointer
-            mLockPtr = static_cast<float*>(static_cast<void*>(pCol));
+            memcpy(mLockPtr++, &colour, sizeof(RGBA));
             // Texture coords
             *mLockPtr++ = mid_u + cos_rot_w + sin_rot_h;
             *mLockPtr++ = mid_v + sin_rot_w - cos_rot_h;
@@ -1303,11 +1004,7 @@ namespace Ogre {
             *mLockPtr++ = offsets[2].y + bb.mPosition.y;
             *mLockPtr++ = offsets[2].z + bb.mPosition.z;
             // Colour
-            // Convert float* to RGBA*
-            pCol = static_cast<RGBA*>(static_cast<void*>(mLockPtr));
-            *pCol++ = colour;
-            // Update lock pointer
-            mLockPtr = static_cast<float*>(static_cast<void*>(pCol));
+            memcpy(mLockPtr++, &colour, sizeof(RGBA));
             // Texture coords
             *mLockPtr++ = mid_u - cos_rot_w - sin_rot_h;
             *mLockPtr++ = mid_v - sin_rot_w + cos_rot_h;
@@ -1318,16 +1015,11 @@ namespace Ogre {
             *mLockPtr++ = offsets[3].y + bb.mPosition.y;
             *mLockPtr++ = offsets[3].z + bb.mPosition.z;
             // Colour
-            // Convert float* to RGBA*
-            pCol = static_cast<RGBA*>(static_cast<void*>(mLockPtr));
-            *pCol++ = colour;
-            // Update lock pointer
-            mLockPtr = static_cast<float*>(static_cast<void*>(pCol));
+            memcpy(mLockPtr++, &colour, sizeof(RGBA));
             // Texture coords
             *mLockPtr++ = mid_u + cos_rot_w - sin_rot_h;
             *mLockPtr++ = mid_v + sin_rot_w + cos_rot_h;
         }
-
     }
     //-----------------------------------------------------------------------
     void BillboardSet::genVertOffsets(Real inleft, Real inright, Real intop, Real inbottom,
@@ -1363,11 +1055,6 @@ namespace Ogre {
         return mParentNode->getSquaredViewDepth(cam);
     }
     //-----------------------------------------------------------------------
-    Real BillboardSet::getBoundingRadius(void) const
-    {
-        return mBoundingRadius;
-    }
-    //-----------------------------------------------------------------------
     const LightList& BillboardSet::getLights(void) const
     {
         // It's actually quite unlikely that this will be called,
@@ -1383,18 +1070,14 @@ namespace Ogre {
     }
 
 
-    void BillboardSet::setTextureCoords( Ogre::FloatRect const * coords, uint16 numCoords )
+    void BillboardSet::setTextureCoords(const std::vector<FloatRect>& coords)
     {
-      if( !numCoords || !coords ) {
+      if( coords.empty() ) {
         setTextureStacksAndSlices( 1, 1 );
         return;
       }
-      //  clear out any previous allocation (as vectors may not shrink)
-      TextureCoordSets().swap( mTextureCoords );
-      //  make room
-      mTextureCoords.resize( numCoords );
-      //  copy in data
-      std::copy( coords, coords+numCoords, &mTextureCoords.front() );
+
+      mTextureCoords = coords;
     }
 
     void BillboardSet::setTextureStacksAndSlices( uchar stacks, uchar slices )
@@ -1500,11 +1183,4 @@ namespace Ogre {
         }
 
     }
-    //-----------------------------------------------------------------------
-    void BillboardSetFactory::destroyInstance( MovableObject* obj)
-    {
-        OGRE_DELETE obj;
-    }
-
-
 }
