@@ -40,7 +40,6 @@ namespace Ogre {
         mAutoAspectRatio(false),
         mUseRenderingDistance(true),
         mUseMinPixelSize(false),
-        mSceneMgr(sm),
         mSceneDetail(PM_SOLID),
 #ifdef OGRE_NODELESS_POSITIONING
         mOrientation(Quaternion::IDENTITY),
@@ -81,7 +80,7 @@ namespace Ogre {
         mReflect = false;
 
         mVisible = false;
-
+        mManager = sm;
     }
 
     //-----------------------------------------------------------------------
@@ -96,7 +95,7 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     SceneManager* Camera::getSceneManager(void) const
     {
-        return mSceneMgr;
+        return mManager;
     }
 
 
@@ -154,7 +153,9 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void Camera::setDirection(Real x, Real y, Real z)
     {
+        OGRE_IGNORE_DEPRECATED_BEGIN
         setDirection(Vector3(x,y,z));
+        OGRE_IGNORE_DEPRECATED_END
     }
 
     //-----------------------------------------------------------------------
@@ -172,16 +173,9 @@ namespace Ogre {
 
         Quaternion targetWorldOrientation;
 
-
         if( mYawFixed )
         {
-            Vector3 xVec = mYawFixedAxis.crossProduct( zAdjustVec );
-            xVec.normalise();
-
-            Vector3 yVec = zAdjustVec.crossProduct( xVec );
-            yVec.normalise();
-
-            targetWorldOrientation.FromAxes( xVec, yVec, zAdjustVec );
+            targetWorldOrientation = Math::lookRotation(zAdjustVec, mYawFixedAxis);
         }
         else
         {
@@ -247,14 +241,18 @@ namespace Ogre {
     void Camera::lookAt(const Vector3& targetPoint)
     {
         updateView();
+        OGRE_IGNORE_DEPRECATED_BEGIN
         this->setDirection(targetPoint - mRealPosition);
+        OGRE_IGNORE_DEPRECATED_END
     }
 
     //-----------------------------------------------------------------------
     void Camera::lookAt( Real x, Real y, Real z )
     {
         Vector3 vTemp( x, y, z );
+        OGRE_IGNORE_DEPRECATED_BEGIN
         this->lookAt(vTemp);
+        OGRE_IGNORE_DEPRECATED_END
     }
 
     //-----------------------------------------------------------------------
@@ -262,7 +260,9 @@ namespace Ogre {
     {
         // Rotate around local Z axis
         Vector3 zAxis = mOrientation * Vector3::UNIT_Z;
+        OGRE_IGNORE_DEPRECATED_BEGIN
         rotate(zAxis, angle);
+        OGRE_IGNORE_DEPRECATED_END
 
         invalidateView();
     }
@@ -283,7 +283,9 @@ namespace Ogre {
             yAxis = mOrientation * Vector3::UNIT_Y;
         }
 
+        OGRE_IGNORE_DEPRECATED_BEGIN
         rotate(yAxis, angle);
+        OGRE_IGNORE_DEPRECATED_END
 
         invalidateView();
     }
@@ -293,7 +295,9 @@ namespace Ogre {
     {
         // Rotate around local X axis
         Vector3 xAxis = mOrientation * Vector3::UNIT_X;
+        OGRE_IGNORE_DEPRECATED_BEGIN
         rotate(xAxis, angle);
+        OGRE_IGNORE_DEPRECATED_END
 
         invalidateView();
 
@@ -304,7 +308,9 @@ namespace Ogre {
     {
         Quaternion q;
         q.FromAngleAxis(angle,axis);
+        OGRE_IGNORE_DEPRECATED_BEGIN
         rotate(q);
+        OGRE_IGNORE_DEPRECATED_END
     }
 
     //-----------------------------------------------------------------------
@@ -338,7 +344,9 @@ namespace Ogre {
         // NB assumes that all scene nodes have been updated
         if (mAutoTrackTarget)
         {
+            OGRE_IGNORE_DEPRECATED_BEGIN
             lookAt(mAutoTrackTarget->_getFullTransform() * mAutoTrackOffset);
+            OGRE_IGNORE_DEPRECATED_END
         }
     }
 
@@ -484,7 +492,7 @@ namespace Ogre {
         }
 
         //render scene
-        mSceneMgr->_renderScene(this, vp, includeOverlays);
+        mManager->_renderScene(this, vp, includeOverlays);
 
         // Listener list may have change
         listenersCopy = mListeners;
