@@ -4,7 +4,7 @@ This source file is part of OGRE
     (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -28,8 +28,6 @@ THE SOFTWARE.
 #include "OgreStableHeaders.h"
 #include "OgreCompositionTargetPass.h"
 #include "OgreCompositionPass.h"
-#include "OgreMaterialManager.h"
-#include "OgreRoot.h"
 
 namespace Ogre {
 
@@ -39,13 +37,13 @@ CompositionTargetPass::CompositionTargetPass(CompositionTechnique *parent):
     mOnlyInitial(false),
     mVisibilityMask(0xFFFFFFFF),
     mLodBias(1.0f),
-	mMaterialScheme(MaterialManager::DEFAULT_SCHEME_NAME), 
-	mShadowsEnabled(true)
+    mMaterialScheme(MaterialManager::DEFAULT_SCHEME_NAME), 
+    mShadowsEnabled(true)
 {
-	if (Root::getSingleton().getRenderSystem())
-	{
-		mMaterialScheme = Root::getSingleton().getRenderSystem()->_getDefaultViewportMaterialScheme();
-	}
+    if (Root::getSingleton().getRenderSystem())
+    {
+        mMaterialScheme = Root::getSingleton().getRenderSystem()->_getDefaultViewportMaterialScheme();
+    }
 }
 //-----------------------------------------------------------------------
 CompositionTargetPass::~CompositionTargetPass()
@@ -105,27 +103,28 @@ float CompositionTargetPass::getLodBias()
 //-----------------------------------------------------------------------
 void CompositionTargetPass::setMaterialScheme(const String& schemeName)
 {
-	mMaterialScheme = schemeName;
+    mMaterialScheme = schemeName;
 }
 //-----------------------------------------------------------------------
 const String& CompositionTargetPass::getMaterialScheme(void) const
 {
-	return mMaterialScheme;
+    return mMaterialScheme;
 }
 //-----------------------------------------------------------------------
 void CompositionTargetPass::setShadowsEnabled(bool enabled)
 {
-	mShadowsEnabled = enabled;
+    mShadowsEnabled = enabled;
 }
 //-----------------------------------------------------------------------
 bool CompositionTargetPass::getShadowsEnabled(void) const
 {
-	return mShadowsEnabled;
+    return mShadowsEnabled;
 }
 //-----------------------------------------------------------------------
-CompositionPass *CompositionTargetPass::createPass()
+CompositionPass *CompositionTargetPass::createPass(CompositionPass::PassType type)
 {
     CompositionPass *t = OGRE_NEW CompositionPass(this);
+    t->setType(type);
     mPasses.push_back(t);
     return t;
 }
@@ -179,10 +178,10 @@ bool CompositionTargetPass::_isSupported(void)
 {
     // A target pass is supported if all passes are supported
 
-    PassIterator passi = getPassIterator();
-    while (passi.hasMoreElements())
+    Passes::const_iterator passi = mPasses.begin();
+    for (;passi != mPasses.end(); ++passi)
     {
-        CompositionPass* pass = passi.getNext();
+        CompositionPass* pass = *passi;
         if (!pass->_isSupported())
         {
             return false;
