@@ -194,13 +194,6 @@ namespace Ogre {
     { 
     }
     //---------------------------------------------------------------------
-    DataStreamPtr DDSCodec::encode(const MemoryDataStreamPtr& input, const Codec::CodecDataPtr& pData) const
-    {        
-        OGRE_EXCEPT(Exception::ERR_NOT_IMPLEMENTED,
-            "DDS encoding not supported",
-            "DDSCodec::encode" ) ;
-    }
-    //---------------------------------------------------------------------
     void DDSCodec::encodeToFile(const MemoryDataStreamPtr& input, const String& outFileName,
                                 const Codec::CodecDataPtr& pData) const
     {
@@ -1054,20 +1047,6 @@ namespace Ogre {
     {
         return mType;
     }
-    //---------------------------------------------------------------------    
-    void DDSCodec::flipEndian(void * pData, size_t size, size_t count)
-    {
-#if OGRE_ENDIAN == OGRE_ENDIAN_BIG
-		Bitwise::bswapChunks(pData, size, count);
-#endif
-    }
-    //---------------------------------------------------------------------    
-    void DDSCodec::flipEndian(void * pData, size_t size)
-    {
-#if OGRE_ENDIAN == OGRE_ENDIAN_BIG
-        Bitwise::bswapBuffer(pData, size);
-#endif
-    }
     //---------------------------------------------------------------------
     String DDSCodec::magicNumberToFileExt(const char *magicNumberPtr, size_t maxbytes) const
     {
