@@ -196,63 +196,6 @@ namespace Ogre {
         memcpy(mData + offset, pSource, length);
     }
     //-----------------------------------------------------------------------
-    DefaultHardwareCounterBuffer::DefaultHardwareCounterBuffer(HardwareBufferManagerBase* mgr, size_t sizeBytes, HardwareBuffer::Usage usage, bool useShadowBuffer, const String& name)
-    : HardwareCounterBuffer(mgr, sizeBytes, usage, useShadowBuffer, name)
-    {
-        // Allocate aligned memory for better SIMD processing friendly.
-        mData = static_cast<unsigned char*>(OGRE_MALLOC_SIMD(mSizeInBytes, MEMCATEGORY_GEOMETRY));
-    }
-    //-----------------------------------------------------------------------
-    DefaultHardwareCounterBuffer::~DefaultHardwareCounterBuffer()
-    {
-        OGRE_FREE_SIMD(mData, MEMCATEGORY_GEOMETRY);
-    }
-    //-----------------------------------------------------------------------
-    void* DefaultHardwareCounterBuffer::lockImpl(size_t offset, size_t length, LockOptions options)
-    {
-        // Only for use internally, no 'locking' as such
-        return mData + offset;
-    }
-    //-----------------------------------------------------------------------
-    void DefaultHardwareCounterBuffer::unlockImpl(void)
-    {
-        // Nothing to do
-    }
-    /*
-     bool DefaultHardwareCounterBuffer::updateStructure(const Any& renderSystemInfo)
-     {
-     // Nothing to do
-     return true;
-     }
-     */
-    //-----------------------------------------------------------------------
-    void* DefaultHardwareCounterBuffer::lock(size_t offset, size_t length, LockOptions options)
-    {
-        mIsLocked = true;
-        return mData + offset;
-    }
-    //-----------------------------------------------------------------------
-    void DefaultHardwareCounterBuffer::unlock(void)
-    {
-        mIsLocked = false;
-        // Nothing to do
-    }
-    //-----------------------------------------------------------------------
-    void DefaultHardwareCounterBuffer::readData(size_t offset, size_t length, void* pDest)
-    {
-        assert((offset + length) <= mSizeInBytes);
-        memcpy(pDest, mData + offset, length);
-    }
-    //-----------------------------------------------------------------------
-    void DefaultHardwareCounterBuffer::writeData(size_t offset, size_t length, const void* pSource,
-                                                 bool discardWholeBuffer)
-    {
-        assert((offset + length) <= mSizeInBytes);
-        // ignore discard, memory is not guaranteed to be zeroised
-        memcpy(mData + offset, pSource, length);
-    }
-    //-----------------------------------------------------------------------
-    //-----------------------------------------------------------------------
     DefaultHardwareBufferManagerBase::DefaultHardwareBufferManagerBase()
     {
     }
@@ -278,15 +221,6 @@ namespace Ogre {
         DefaultHardwareIndexBuffer* ib = OGRE_NEW DefaultHardwareIndexBuffer(itype, numIndexes, usage);
         return HardwareIndexBufferSharedPtr(ib);
     }
-    //-----------------------------------------------------------------------
-    RenderToVertexBufferSharedPtr
-        DefaultHardwareBufferManagerBase::createRenderToVertexBuffer()
-    {
-        OGRE_EXCEPT(Exception::ERR_RENDERINGAPI_ERROR, 
-            "Cannot create RenderToVertexBuffer in DefaultHardwareBufferManagerBase", 
-            "DefaultHardwareBufferManagerBase::createRenderToVertexBuffer");
-    }
-
     HardwareUniformBufferSharedPtr 
         DefaultHardwareBufferManagerBase::createUniformBuffer(size_t sizeBytes, 
                                     HardwareBuffer::Usage usage, bool useShadowBuffer, const String& name)
@@ -298,7 +232,7 @@ namespace Ogre {
     DefaultHardwareBufferManagerBase::createCounterBuffer(size_t sizeBytes,
                                                           HardwareBuffer::Usage usage, bool useShadowBuffer, const String& name)
     {
-        DefaultHardwareCounterBuffer* ub = OGRE_NEW DefaultHardwareCounterBuffer(this, sizeBytes, usage, useShadowBuffer);
+        DefaultHardwareUniformBuffer* ub = OGRE_NEW DefaultHardwareUniformBuffer(this, sizeBytes, usage, useShadowBuffer);
         return HardwareCounterBufferSharedPtr(ub);
     }
 }
