@@ -4,7 +4,7 @@ This source file is part of OGRE
     (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -27,16 +27,13 @@ THE SOFTWARE.
 */
 #include "OgreStableHeaders.h"
 #include "OgreEdgeListBuilder.h"
-#include "OgreLogManager.h"
-#include "OgreStringConverter.h"
 #include "OgreVertexIndexData.h"
-#include "OgreException.h"
 #include "OgreOptimisedUtil.h"
 
 namespace Ogre {
 
-	EdgeData::EdgeData() : isClosed(false){}
-	
+    EdgeData::EdgeData() : isClosed(false){}
+    
     void EdgeData::log(Log* l)
     {
         EdgeGroupList::iterator i, iend;
@@ -82,10 +79,6 @@ namespace Ogre {
     {
     }
     //---------------------------------------------------------------------
-    EdgeListBuilder::~EdgeListBuilder()
-    {
-    }
-    //---------------------------------------------------------------------
     void EdgeListBuilder::addVertexData(const VertexData* vertexData)
     {
         if (vertexData->vertexStart != 0)
@@ -230,35 +223,20 @@ namespace Ogre {
         // The edge group now we are dealing with.
         EdgeData::EdgeGroup& eg = mEdgeData->edgeGroups[vertexSet];
 
-		// locate position element & the buffer to go with it
+        // locate position element & the buffer to go with it
         const VertexData* vertexData = mVertexDataList[vertexSet];
-		const VertexElement* posElem = vertexData->vertexDeclaration->findElementBySemantic(VES_POSITION);
-		HardwareVertexBufferSharedPtr vbuf = 
-			vertexData->vertexBufferBinding->getBuffer(posElem->getSource());
-		// lock the buffer for reading
-		unsigned char* pBaseVertex = static_cast<unsigned char*>(
-			vbuf->lock(HardwareBuffer::HBL_READ_ONLY));
+        const VertexElement* posElem = vertexData->vertexDeclaration->findElementBySemantic(VES_POSITION);
+        HardwareVertexBufferSharedPtr vbuf = 
+            vertexData->vertexBufferBinding->getBuffer(posElem->getSource());
+        // lock the buffer for reading
+        HardwareBufferLockGuard vertexLock(vbuf, HardwareBuffer::HBL_READ_ONLY);
+        unsigned char* pBaseVertex = static_cast<unsigned char*>(vertexLock.pData);
 
         // Get the indexes ready for reading
-		bool idx32bit = (indexData->indexBuffer->getType() == HardwareIndexBuffer::IT_32BIT);
-		size_t indexSize = idx32bit ? sizeof(uint32) : sizeof(uint16);
-#if defined(_MSC_VER) && _MSC_VER <= 1300
-        // NB: Can't use un-named union with VS.NET 2002 when /RTC1 compile flag enabled.
-        void* pIndex = indexData->indexBuffer->lock(HardwareBuffer::HBL_READ_ONLY);
-		pIndex = static_cast<void*>(
-			static_cast<char*>(pIndex) + indexData->indexStart * indexSize);
-        unsigned short* p16Idx = static_cast<unsigned short*>(pIndex);
-        unsigned int* p32Idx = static_cast<unsigned int*>(pIndex);
-#else
-        union {
-            void* pIndex;
-            unsigned short* p16Idx;
-            unsigned int* p32Idx;
-        };
-        pIndex = indexData->indexBuffer->lock(HardwareBuffer::HBL_READ_ONLY);
-		pIndex = static_cast<void*>(
-			static_cast<char*>(pIndex) + indexData->indexStart * indexSize);
-#endif
+        bool idx32bit = (indexData->indexBuffer->getType() == HardwareIndexBuffer::IT_32BIT);
+        HardwareBufferLockGuard indexLock(indexData->indexBuffer, HardwareBuffer::HBL_READ_ONLY);
+        unsigned short* p16Idx = static_cast<unsigned short*>(indexLock.pData) + indexData->indexStart;
+        unsigned int* p32Idx = static_cast<unsigned int*>(indexLock.pData) + indexData->indexStart;
 
         // Iterate over all the groups of 3 indexes
         unsigned int index[3];
@@ -360,9 +338,6 @@ namespace Ogre {
         // Update triCount for the edge group. Note that we are assume
         // geometries sorted by vertex set.
         eg.triCount = triangleIndex - eg.triStart;
-
-        indexData->indexBuffer->unlock();
-        vbuf->unlock();
     }
     //---------------------------------------------------------------------
     void EdgeListBuilder::connectOrCreateEdge(size_t vertexSet, size_t triangleIndex, 
@@ -385,9 +360,8 @@ namespace Ogre {
         else
         {
             // Not found, create new edge
-            mEdgeMap.insert(EdgeMap::value_type(
-                std::pair<size_t, size_t>(sharedVertIndex0, sharedVertIndex1),
-                std::pair<size_t, size_t>(vertexSet, mEdgeData->edgeGroups[vertexSet].edges.size())));
+            mEdgeMap.emplace(std::pair<size_t, size_t>(sharedVertIndex0, sharedVertIndex1),
+                             std::pair<size_t, size_t>(vertexSet, mEdgeData->edgeGroups[vertexSet].edges.size()));
             EdgeData::Edge e;
             e.degenerate = true; // initialise as degenerate
 
@@ -408,8 +382,7 @@ namespace Ogre {
         // Because the algorithm doesn't care about manifold or not, we just identifying
         // the common vertex by EXACT same position.
         // Hint: We can use quantize method for welding almost same position vertex fastest.
-        std::pair<CommonVertexMap::iterator, bool> inserted =
-            mCommonVertexMap.insert(CommonVertexMap::value_type(vec, mVertices.size()));
+        std::pair<CommonVertexMap::iterator, bool> inserted = mCommonVertexMap.emplace(vec, mVertices.size());
         if (!inserted.second)
         {
             // Already existing, return old one
@@ -433,14 +406,14 @@ namespace Ogre {
         assert(triangleFaceNormals.size() == triangleLightFacings.size());
 
         // Use optimised util to determine if triangle's face normal are light facing
-		if(!triangleFaceNormals.empty())
-		{
-			OptimisedUtil::getImplementation()->calculateLightFacing(
-				lightPos,
-				&triangleFaceNormals.front(),
-				&triangleLightFacings.front(),
-				triangleLightFacings.size());
-		}
+        if(!triangleFaceNormals.empty())
+        {
+            OptimisedUtil::getImplementation()->calculateLightFacing(
+                lightPos,
+                &triangleFaceNormals.front(),
+                &triangleLightFacings.front(),
+                triangleLightFacings.size());
+        }
     }
     //---------------------------------------------------------------------
     void EdgeData::updateFaceNormals(size_t vertexSet, 
@@ -452,23 +425,28 @@ namespace Ogre {
         // Triangle face normals should be 1:1 with triangles
         assert(triangleFaceNormals.size() == triangles.size());
 
-        // Lock buffer for reading
-        float* pVert = static_cast<float*>(
-            positionBuffer->lock(HardwareBuffer::HBL_READ_ONLY));
-
         // Calculate triangles which are using this vertex set
         const EdgeData::EdgeGroup& eg = edgeGroups[vertexSet];
-		if (eg.triCount != 0) 
-		{
-			OptimisedUtil::getImplementation()->calculateFaceNormals(
-				pVert,
-				&triangles[eg.triStart],
-				&triangleFaceNormals[eg.triStart],
-				eg.triCount);
-		}
-
-        // unlock the buffer
-        positionBuffer->unlock();
+        if (eg.triCount != 0) 
+        {
+            HardwareBufferLockGuard positionsLock(positionBuffer, HardwareBuffer::HBL_READ_ONLY);
+            OptimisedUtil::getImplementation()->calculateFaceNormals(
+                static_cast<float*>(positionsLock.pData),
+                &triangles[eg.triStart],
+                &triangleFaceNormals[eg.triStart],
+                eg.triCount);
+        }
+    }
+    //---------------------------------------------------------------------
+    EdgeData* EdgeData::clone()
+    {
+        EdgeData* newEdgeData = OGRE_NEW EdgeData();
+        newEdgeData->triangles = triangles;
+        newEdgeData->triangleFaceNormals = triangleFaceNormals;
+        newEdgeData->triangleLightFacings = triangleLightFacings;
+        newEdgeData->edgeGroups = edgeGroups;
+        newEdgeData->isClosed = isClosed;
+        return newEdgeData;
     }
     //---------------------------------------------------------------------
     void EdgeListBuilder::log(Log* l)
@@ -478,7 +456,7 @@ namespace Ogre {
         l->logMessage("Number of vertex sets: " + StringConverter::toString(mVertexDataList.size()));
         l->logMessage("Number of index sets: " + StringConverter::toString(mGeometryList.size()));
         
-        size_t i, j;
+        size_t i, j, k;
         // Log original vertex data
         for(i = 0; i < mVertexDataList.size(); ++i)
         {
@@ -491,8 +469,8 @@ namespace Ogre {
             HardwareVertexBufferSharedPtr vbuf = 
                 vData->vertexBufferBinding->getBuffer(posElem->getSource());
             // lock the buffer for reading
-            unsigned char* pBaseVertex = static_cast<unsigned char*>(
-                vbuf->lock(HardwareBuffer::HBL_READ_ONLY));
+            HardwareBufferLockGuard vertexLock(vbuf, HardwareBuffer::HBL_READ_ONLY);
+            unsigned char* pBaseVertex = static_cast<unsigned char*>(vertexLock.pData);
             float* pFloat;
             for (j = 0; j < vData->vertexCount; ++j)
             {
@@ -503,7 +481,6 @@ namespace Ogre {
                     ", " + StringConverter::toString(pFloat[2]) + ")");
                 pBaseVertex += vbuf->getVertexSize();
             }
-            vbuf->unlock();
         }
 
         // Log original index data
@@ -517,31 +494,22 @@ namespace Ogre {
             "vertex set " + StringConverter::toString(mGeometryList[i].vertexSet) + " - " + 
             "operationType " + StringConverter::toString(mGeometryList[i].opType));
             // Get the indexes ready for reading
-            unsigned short* p16Idx = 0;
-            unsigned int* p32Idx = 0;
-
-            if (iData->indexBuffer->getType() == HardwareIndexBuffer::IT_32BIT)
-            {
-                p32Idx = static_cast<unsigned int*>(
-                    iData->indexBuffer->lock(HardwareBuffer::HBL_READ_ONLY));
-            }
-            else
-            {
-                p16Idx = static_cast<unsigned short*>(
-                    iData->indexBuffer->lock(HardwareBuffer::HBL_READ_ONLY));
-            }
+            HardwareBufferLockGuard indexLock(iData->indexBuffer, HardwareBuffer::HBL_READ_ONLY);
+            unsigned short* p16Idx = static_cast<unsigned short*>(indexLock.pData);
+            unsigned int* p32Idx = static_cast<unsigned int*>(indexLock.pData);
+            bool isIT32 = iData->indexBuffer->getType() == HardwareIndexBuffer::IT_32BIT;
 
             for (j = 0; j < iData->indexCount;  )
             {
-                if (iData->indexBuffer->getType() == HardwareIndexBuffer::IT_32BIT)
+                if (isIT32)
                 {
                     if (mGeometryList[i].opType == RenderOperation::OT_TRIANGLE_LIST
                         || j == 0)
                     {
-		    	unsigned int n1 = *p32Idx++;
-		    	unsigned int n2 = *p32Idx++;
-		    	unsigned int n3 = *p32Idx++;
-                        l->logMessage("Triangle " + StringConverter::toString(j) + 
+                        unsigned int n1 = *p32Idx++;
+                        unsigned int n2 = *p32Idx++;
+                        unsigned int n3 = *p32Idx++;
+                        l->logMessage("Triangle " + StringConverter::toString(j) +
                             ": (" + StringConverter::toString(n1) + 
                             ", " + StringConverter::toString(n2) + 
                             ", " + StringConverter::toString(n3) + ")");
@@ -559,10 +527,10 @@ namespace Ogre {
                     if (mGeometryList[i].opType == RenderOperation::OT_TRIANGLE_LIST
                         || j == 0)
                     {
-		    	unsigned short n1 = *p16Idx++;
-		    	unsigned short n2 = *p16Idx++;
-		    	unsigned short n3 = *p16Idx++;
-                        l->logMessage("Index " + StringConverter::toString(j) + 
+                        unsigned short n1 = *p16Idx++;
+                        unsigned short n2 = *p16Idx++;
+                        unsigned short n3 = *p16Idx++;
+                        l->logMessage("Index " + StringConverter::toString(j) +
                             ": (" + StringConverter::toString(n1) + 
                             ", " + StringConverter::toString(n2) + 
                             ", " + StringConverter::toString(n3) + ")");
@@ -575,21 +543,16 @@ namespace Ogre {
                         j++;
                     }
                 }
-
-
             }
 
-            iData->indexBuffer->unlock();
-
-
             // Log common vertex list
             l->logMessage(".");
             l->logMessage("Common vertex list - vertex count " + 
                 StringConverter::toString(mVertices.size()));
-            for (i = 0; i < mVertices.size(); ++i)
+            for (k = 0; k < mVertices.size(); ++k)
             {
-                CommonVertex& c = mVertices[i];
-                l->logMessage("Common vertex " + StringConverter::toString(i) + 
+                CommonVertex& c = mVertices[k];
+                l->logMessage("Common vertex " + StringConverter::toString(k) + 
                     ": (vertexSet=" + StringConverter::toString(c.vertexSet) + 
                     ", originalIndex=" + StringConverter::toString(c.originalIndex) + 
                     ", position=" + StringConverter::toString(c.position));
