@@ -288,7 +288,9 @@ namespace Ogre {
         // Use the current render system to determine if possible
         if (Root::getSingletonPtr() && Root::getSingletonPtr()->getRenderSystem())
         {
+            OGRE_IGNORE_DEPRECATED_BEGIN
             return Root::getSingleton().getRenderSystem()->getColourVertexElementType();
+            OGRE_IGNORE_DEPRECATED_END
         }
         else
         {
@@ -327,8 +329,9 @@ namespace Ogre {
 #if OGRE_PLATFORM != OGRE_PLATFORM_WIN32 && OGRE_PLATFORM != OGRE_PLATFORM_WINRT
         default:
 #endif
+        case VET_UBYTE4_NORM:
         case VET_COLOUR_ABGR: 
-            return src.getAsABGR();
+            return src.getAsBYTE();
         };
 
     }
@@ -829,22 +832,4 @@ namespace Ogre {
         mBindingMap.swap(newBindingMap);
         mHighIndex = targetIndex;
     }
-    //-----------------------------------------------------------------------------
-    bool VertexBufferBinding::hasInstanceData() const
-    {
-        VertexBufferBinding::VertexBufferBindingMap::const_iterator i, iend;
-        iend = mBindingMap.end();
-        for (i = mBindingMap.begin(); i != iend; ++i)
-        {
-            if ( i->second->isInstanceData() )
-            {
-                return true;
-            }
-        }
-        return false;
-    }
-
-
-
-
 }
