@@ -4,7 +4,7 @@ This source file is part of OGRE
     (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -29,7 +29,6 @@ THE SOFTWARE.
 #include "OgreStableHeaders.h"
 #include "OgreLodStrategyManager.h"
 
-#include "OgreException.h"
 #include "OgreDistanceLodStrategy.h"
 #include "OgrePixelCountLodStrategy.h"
 
@@ -101,18 +100,22 @@ namespace Ogre {
     {
         // Get beginning iterator
         for (StrategyMap::iterator it = mStrategies.begin(); it != mStrategies.end(); ++it)
-		{
-			OGRE_DELETE it->second;
-		}
-		mStrategies.clear();
+        {
+            OGRE_DELETE it->second;
+        }
+        mStrategies.clear();
     }
     //-----------------------------------------------------------------------
     LodStrategy *LodStrategyManager::getStrategy(const String& name)
     {
         // If name is "default", return the default strategy instead of performing a lookup
-        if (name == "default")
+        if (name == "default") {
             return getDefaultStrategy();
-
+        } else if (name == "Distance") {
+            return getStrategy("distance_box"); // Backward compatibility for loading old meshes.
+        } else if (name == "PixelCount") {
+            return getStrategy("pixel_count"); // Backward compatibility for loading old meshes.
+        }
         // Find strategy with specified name
         StrategyMap::iterator it = mStrategies.find(name);
 
