@@ -4,7 +4,7 @@ This source file is part of OGRE
     (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -26,57 +26,21 @@ THE SOFTWARE.
 -----------------------------------------------------------------------------
 */
 #include "OgreStableHeaders.h"
-
 #include "OgreOptimisedUtil.h"
 
-#include "OgrePlatformInformation.h"
-
 //#define __DO_PROFILE__
-#ifdef __DO_PROFILE__
-#include "OgreRoot.h"
-#endif
 
 namespace Ogre {
 
     //---------------------------------------------------------------------
     // External functions
     extern OptimisedUtil* _getOptimisedUtilGeneral(void);
-#if __OGRE_HAVE_SSE
+#if __OGRE_HAVE_SSE || __OGRE_HAVE_NEON
     extern OptimisedUtil* _getOptimisedUtilSSE(void);
-//#elif __OGRE_HAVE_NEON
-//    extern OptimisedUtil* _getOptimisedUtilNEON(void);
-//#elif __OGRE_HAVE_VFP
-//    extern OptimisedUtil* _getOptimisedUtilVFP(void);
-#endif
-#if __OGRE_HAVE_DIRECTXMATH
-    extern OptimisedUtil* _getOptimisedUtilDirectXMath(void);
 #endif
 
 #ifdef __DO_PROFILE__
     //---------------------------------------------------------------------
-#if OGRE_COMPILER == OGRE_COMPILER_MSVC
-    typedef unsigned __int64 uint64;
-#pragma warning(push)
-#pragma warning(disable: 4035)  // no return value
-    static FORCEINLINE uint64 getCpuTimestamp(void)
-    {
-        __asm rdtsc
-        // Return values in edx:eax, No return statement requirement here for VC.
-    }
-#pragma warning(pop)
-
-#elif (OGRE_COMPILER == OGRE_COMPILER_GNUC || OGRE_COMPILER == OGRE_COMPILER_CLANG)
-    typedef unsigned long long uint64;
-    static FORCEINLINE uint64 getCpuTimestamp(void)
-    {
-        uint64 result;
-        __asm__ __volatile__ ( "rdtsc" : "=A" (result) );
-        return result;
-    }
-
-#endif  // OGRE_COMPILER
-
-    //---------------------------------------------------------------------
     class OptimisedUtilProfiler : public OptimisedUtil
     {
     protected:
@@ -84,12 +48,8 @@ namespace Ogre {
         enum
         {
             IMPL_DEFAULT,
-#if __OGRE_HAVE_SSE
+#if __OGRE_HAVE_SSE || __OGRE_HAVE_NEON
             IMPL_SSE,
-//#elif __OGRE_HAVE_NEON
-//            IMPL_NEON,
-//#elif __OGRE_HAVE_VFP
-//            IMPL_VFP,
 #endif
             IMPL_COUNT
         };
@@ -111,12 +71,12 @@ namespace Ogre {
 
             void begin(void)
             {
-                mStartTick = getCpuTimestamp();
+                mStartTick = clock();
             }
 
             void end(void)
             {
-                uint64 ticks = getCpuTimestamp() - mStartTick;
+                uint64 ticks = clock() - mStartTick;
                 mTotalTicks += ticks;
                 ++mCount;
                 mAvgTicks = mTotalTicks / mCount;
@@ -125,28 +85,18 @@ namespace Ogre {
 
         typedef ProfileItem ProfileItems[IMPL_COUNT];
 
-        typedef vector<OptimisedUtil*>::type OptimisedUtilList;
+        typedef std::vector<OptimisedUtil*> OptimisedUtilList;
         OptimisedUtilList mOptimisedUtils;
 
     public:
         OptimisedUtilProfiler(void)
         {
             mOptimisedUtils.push_back(_getOptimisedUtilGeneral());
-#if __OGRE_HAVE_SSE
-            if (PlatformInformation::getCpuFeatures() & PlatformInformation::CPU_FEATURE_SSE)
+#if __OGRE_HAVE_SSE || __OGRE_HAVE_NEON
+            //if (PlatformInformation::getCpuFeatures() & PlatformInformation::CPU_FEATURE_SSE)
             {
                 mOptimisedUtils.push_back(_getOptimisedUtilSSE());
             }
-//#elif __OGRE_HAVE_VFP
-//            if (PlatformInformation::getCpuFeatures() & PlatformInformation::CPU_FEATURE_VFP)
-//            {
-//                mOptimisedUtils.push_back(_getOptimisedUtilVFP());
-//            }
-//#elif __OGRE_HAVE_NEON
-//            if (PlatformInformation::getCpuFeatures() & PlatformInformation::CPU_FEATURE_NEON)
-//            {
-//                mOptimisedUtils.push_back(_getOptimisedUtilNEON());
-//            }
 #endif
         }
 
@@ -154,7 +104,7 @@ namespace Ogre {
             const float *srcPosPtr, float *destPosPtr,
             const float *srcNormPtr, float *destNormPtr,
             const float *blendWeightPtr, const unsigned char* blendIndexPtr,
-            const Matrix4* const* blendMatrices,
+            const Affine3* const* blendMatrices,
             size_t srcPosStride, size_t destPosStride,
             size_t srcNormStride, size_t destNormStride,
             size_t blendWeightStride, size_t blendIndexStride,
@@ -180,6 +130,8 @@ namespace Ogre {
                 numVertices);
             profile.end();
 
+            LogManager::getSingleton().logMessage(StringUtil::format(
+                "OptimisedUtilProfiler: %s - impl %zu = %u avg ticks\n", __FUNCTION__, index, profile.mAvgTicks));
             // You can put break point here while running test application, to
             // watch profile results.
             ++index;    // So we can put break point here even if in release build
@@ -189,9 +141,9 @@ namespace Ogre {
             Real t,
             const float *srcPos1, const float *srcPos2,
             float *dstPos,
-			size_t pos1VSize, size_t pos2VSize, size_t dstVSize, 
+            size_t pos1VSize, size_t pos2VSize, size_t dstVSize, 
             size_t numVertices,
-			bool morphNormals)
+            bool morphNormals)
         {
             static ProfileItems results;
             static size_t index;
@@ -204,20 +156,23 @@ namespace Ogre {
                 t,
                 srcPos1, srcPos2,
                 dstPos,
-				pos1VSize, pos2VSize, dstVSize,
+                pos1VSize, pos2VSize, dstVSize,
                 numVertices,
-				morphNormals);
+                morphNormals);
             profile.end();
 
+            LogManager::getSingleton().logMessage(StringUtil::format(
+                "OptimisedUtilProfiler: %s - impl %zu = %u avg ticks\n", __FUNCTION__, index, profile.mAvgTicks));
+
             // You can put break point here while running test application, to
             // watch profile results.
             ++index;    // So we can put break point here even if in release build
         }
 
         virtual void concatenateAffineMatrices(
-            const Matrix4& baseMatrix,
-            const Matrix4* srcMatrices,
-            Matrix4* dstMatrices,
+            const Affine3& baseMatrix,
+            const Affine3* srcMatrices,
+            Affine3* dstMatrices,
             size_t numMatrices)
         {
             static ProfileItems results;
@@ -234,6 +189,9 @@ namespace Ogre {
                 numMatrices);
             profile.end();
 
+            LogManager::getSingleton().logMessage(StringUtil::format(
+                "OptimisedUtilProfiler: %s - impl %zu = %u avg ticks\n", __FUNCTION__, index, profile.mAvgTicks));
+
             // You can put break point here while running test application, to
             // watch profile results.
             ++index;    // So we can put break point here even if in release build
@@ -269,6 +227,9 @@ namespace Ogre {
             //      SSE         223559                  399495
             //
 
+            LogManager::getSingleton().logMessage(StringUtil::format(
+                "OptimisedUtilProfiler: %s - impl %zu = %u avg ticks\n", __FUNCTION__, index, profile.mAvgTicks));
+
             // You can put break point here while running test application, to
             // watch profile results.
             ++index;    // So we can put break point here even if in release build
@@ -304,6 +265,9 @@ namespace Ogre {
             //      SSE          47934                  63995
             //
 
+            LogManager::getSingleton().logMessage(StringUtil::format(
+                "OptimisedUtilProfiler: %s - impl %zu = %u avg ticks\n", __FUNCTION__, index, profile.mAvgTicks));
+
             // You can put break point here while running test application, to
             // watch profile results.
             ++index;    // So we can put break point here even if in release build
@@ -343,6 +307,9 @@ namespace Ogre {
             //      Point Light, SSE             56817              106663
             //
 
+            LogManager::getSingleton().logMessage(StringUtil::format(
+                "OptimisedUtilProfiler: %s - impl %zu = %u avg ticks\n", __FUNCTION__, index, profile.mAvgTicks));
+
             // You can put break point here while running test application, to
             // watch profile results.
             ++index;    // So we can put break point here even if in release build
@@ -407,26 +374,16 @@ namespace Ogre {
             return _getOptimisedUtilSSE();
         }
         else
-//#elif __OGRE_HAVE_VFP
-//        if (PlatformInformation::getCpuFeatures() & PlatformInformation::CPU_FEATURE_VFP)
-//        {
-//            return _getOptimisedUtilVFP();
-//        }
-//        else
-//#elif __OGRE_HAVE_NEON
-//        if (PlatformInformation::getCpuFeatures() & PlatformInformation::CPU_FEATURE_NEON)
-//        {
-//            return _getOptimisedUtilNEON();
-//        }
-//        else
+#elif __OGRE_HAVE_NEON
+        if (PlatformInformation::getCpuFeatures() & PlatformInformation::CPU_FEATURE_NEON)
+        {
+            return _getOptimisedUtilSSE();
+        }
+        else
 #endif  // __OGRE_HAVE_SSE
         {
-#if __OGRE_HAVE_DIRECTXMATH
-            return _getOptimisedUtilDirectXMath();
-#else // __OGRE_HAVE_DIRECTXMATH
-             return _getOptimisedUtilGeneral();
-#endif
-		}
+            return _getOptimisedUtilGeneral();
+        }
 
 #endif  // __DO_PROFILE__
     }
