@@ -31,7 +31,6 @@ THE SOFTWARE.
 #include "OgreParticleEmitter.h"
 #include "OgreParticleAffector.h"
 #include "OgreParticle.h"
-#include "OgreIteratorWrappers.h"
 #include "OgreParticleAffectorFactory.h"
 #include "OgreParticleSystemRenderer.h"
 #include "OgreControllerManager.h"
@@ -156,10 +155,9 @@ namespace Ogre {
         // Deallocate all particles
         destroyVisualParticles(0, mParticlePool.size());
         // Free pool items
-        ParticlePool::iterator i;
-        for (i = mParticlePool.begin(); i != mParticlePool.end(); ++i)
+        for (auto p : mParticlePool)
         {
-            OGRE_DELETE *i;
+            OGRE_DELETE p;
         }
 
         if (mRenderer)
@@ -199,11 +197,8 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void ParticleSystem::removeEmitter(ParticleEmitter* emitter)
     {
-        ParticleEmitterList::iterator ei =
-            std::find(mEmitters.begin(), mEmitters.end(), emitter);
-        assert(
-            ei != mEmitters.end() &&
-            "Emitter is not a part of ParticleSystem!");
+        auto ei = std::find(mEmitters.begin(), mEmitters.end(), emitter);
+        OgreAssert(ei != mEmitters.end(), "Emitter is not a part of ParticleSystem!");
         ParticleSystemManager::getSingleton()._destroyEmitter(*ei);
         mEmitters.erase(ei);
     }
@@ -211,10 +206,9 @@ namespace Ogre {
     void ParticleSystem::removeAllEmitters(void)
     {
         // DON'T delete directly, we don't know what heap these have been created on
-        ParticleEmitterList::iterator ei;
-        for (ei = mEmitters.begin(); ei != mEmitters.end(); ++ei)
+        for (auto e : mEmitters)
         {
-            ParticleSystemManager::getSingleton()._destroyEmitter(*ei);
+            ParticleSystemManager::getSingleton()._destroyEmitter(e);
         }
         mEmitters.clear();
     }
@@ -249,10 +243,9 @@ namespace Ogre {
     void ParticleSystem::removeAllAffectors(void)
     {
         // DON'T delete directly, we don't know what heap these have been created on
-        ParticleAffectorList::iterator ai;
-        for (ai = mAffectors.begin(); ai != mAffectors.end(); ++ai)
+        for (auto a : mAffectors)
         {
-            ParticleSystemManager::getSingleton()._destroyAffector(*ai);
+            ParticleSystemManager::getSingleton()._destroyAffector(a);
         }
         mAffectors.clear();
     }
@@ -333,11 +326,10 @@ namespace Ogre {
     void ParticleSystem::setEmittedEmitterQuota(size_t size)
     {
         // Never shrink below size()
-        EmittedEmitterPool::iterator i;
         size_t currSize = 0;
-        for (i = mEmittedEmitterPool.begin(); i != mEmittedEmitterPool.end(); ++i)
+        for (auto& kv : mEmittedEmitterPool)
         {
-            currSize += i->second.size();
+            currSize += kv.second.size();
         }
 
         if( currSize < size )
@@ -556,7 +548,6 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void ParticleSystem::_executeTriggerEmitters(ParticleEmitter* emitter, unsigned requested, Real timeElapsed)
     {
-        ParticleAffectorList::iterator  itAff, itAffEnd;
         Real timePoint = 0.0f;
 
 
@@ -594,22 +585,12 @@ namespace Ogre {
             p->mPosition += (p->mDirection * timePoint);
 
             // apply particle initialization by the affectors
-            itAffEnd = mAffectors.end();
-            for (itAff = mAffectors.begin(); itAff != itAffEnd; ++itAff)
-                (*itAff)->_initParticle(p);
+            for (auto a : mAffectors)
+                a->_initParticle(p);
 
             // Increment time fragment
             timePoint += timeInc;
 
-            if (p->mParticleType == Particle::Emitter)
-            {
-                // If the particle is an emitter, the position on the emitter side must also be initialised
-                // Note, that position of the emitter becomes a position in worldspace if mLocalSpace is set 
-                // to false (will this become a problem?)
-                ParticleEmitter* pParticleEmitter = static_cast<ParticleEmitter*>(p);
-                pParticleEmitter->setPosition(p->mPosition);
-            }
-
             // Notify renderer
             mRenderer->_notifyParticleEmitted(p);
         }
@@ -617,24 +598,9 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void ParticleSystem::_applyMotion(Real timeElapsed)
     {
-        ActiveParticleList::iterator i, itEnd;
-        Particle* pParticle;
-        ParticleEmitter* pParticleEmitter;
-
-        itEnd = mActiveParticles.end();
-        for (i = mActiveParticles.begin(); i != itEnd; ++i)
+        for (auto pParticle : mActiveParticles)
         {
-            pParticle = static_cast<Particle*>(*i);
             pParticle->mPosition += (pParticle->mDirection * timeElapsed);
-
-            if (pParticle->mParticleType == Particle::Emitter)
-            {
-                // If it is an emitter, the emitter position must also be updated
-                // Note, that position of the emitter becomes a position in worldspace if mLocalSpace is set 
-                // to false (will this become a problem?)
-                pParticleEmitter = static_cast<ParticleEmitter*>(*i);
-                pParticleEmitter->setPosition(pParticle->mPosition);
-            }
         }
 
         // Notify renderer
@@ -643,14 +609,10 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void ParticleSystem::_triggerAffectors(Real timeElapsed)
     {
-        ParticleAffectorList::iterator i, itEnd;
-        
-        itEnd = mAffectors.end();
-        for (i = mAffectors.begin(); i != itEnd; ++i)
+        for (auto a : mAffectors)
         {
-            (*i)->_affectParticles(this, timeElapsed);
+            a->_affectParticles(this, timeElapsed);
         }
-
     }
     //-----------------------------------------------------------------------
     void ParticleSystem::increasePool(size_t size)
@@ -658,7 +620,6 @@ namespace Ogre {
         size_t oldSize = mParticlePool.size();
 
         // Increase size
-        mParticlePool.reserve(size);
         mParticlePool.resize(size);
 
         // Create new particles
@@ -696,8 +657,6 @@ namespace Ogre {
             // Fast creation (don't use superclass since emitter will init)
             p = mFreeParticles.front();
             mActiveParticles.splice(mActiveParticles.end(), mFreeParticles, mFreeParticles.begin());
-
-            p->_notifyOwner(this);
         }
 
         return p;
@@ -720,8 +679,6 @@ namespace Ogre {
             // that are emitted. Don't use mActiveParticles for that (although they are added to
             // mActiveParticles also), because it would take too long to traverse.
             mActiveEmittedEmitters.push_back(static_cast<ParticleEmitter*>(p));
-            
-            p->_notifyOwner(this);
         }
 
         return p;
@@ -839,23 +796,20 @@ namespace Ogre {
                     min.x = min.y = min.z = Math::POS_INFINITY;
                     max.x = max.y = max.z = Math::NEG_INFINITY;
                 }
-                ActiveParticleList::iterator p;
                 Vector3 halfScale = Vector3::UNIT_SCALE * 0.5;
-                Vector3 defaultPadding = 
-                    halfScale * std::max(mDefaultHeight, mDefaultWidth);
-                for (p = mActiveParticles.begin(); p != mActiveParticles.end(); ++p)
+                Vector3 defaultPadding = halfScale * std::max(mDefaultHeight, mDefaultWidth);
+                for (auto p : mActiveParticles)
                 {
-                    if ((*p)->mOwnDimensions)
+                    if (p->mOwnDimensions)
                     {
-                        Vector3 padding = 
-                            halfScale * std::max((*p)->mWidth, (*p)->mHeight);
-                        min.makeFloor((*p)->mPosition - padding);
-                        max.makeCeil((*p)->mPosition + padding);
+                        Vector3 padding = halfScale * std::max(p->mWidth, p->mHeight);
+                        min.makeFloor(p->mPosition - padding);
+                        max.makeCeil(p->mPosition + padding);
                     }
                     else
                     {
-                        min.makeFloor((*p)->mPosition - defaultPadding);
-                        max.makeCeil((*p)->mPosition + defaultPadding);
+                        min.makeFloor(p->mPosition - defaultPadding);
+                        max.makeCeil(p->mPosition + defaultPadding);
                     }
                 }
                 mWorldAABB.setExtents(min, max);
@@ -880,6 +834,9 @@ namespace Ogre {
             }
 
             mParentNode->needUpdate();
+
+            if (mRenderer)
+                mRenderer->_notifyBoundingBox(mAABB);
         }
     }
     //-----------------------------------------------------------------------
@@ -908,22 +865,6 @@ namespace Ogre {
         return ParticleSystemFactory::FACTORY_TYPE_NAME;
     }
     //-----------------------------------------------------------------------
-    void ParticleSystem::_notifyParticleResized(void)
-    {
-        if (mRenderer)
-        {
-            mRenderer->_notifyParticleResized();
-        }
-    }
-    //-----------------------------------------------------------------------
-    void ParticleSystem::_notifyParticleRotated(void)
-    {
-        if (mRenderer)
-        {
-            mRenderer->_notifyParticleRotated();
-        }
-    }
-    //-----------------------------------------------------------------------
     void ParticleSystem::setDefaultDimensions( Real width, Real height )
     {
         assert(width >= 0 && height >= 0 && "Particle dimensions can not be negative");
@@ -1040,8 +981,10 @@ namespace Ogre {
             mRenderer->_notifyParticleCleared(mActiveParticles);
         }
 
-        // Move actives to free list
-        mFreeParticles.splice(mFreeParticles.end(), mActiveParticles);
+        // reset active and free lists
+        mActiveParticles.clear();
+        mFreeParticles.clear();
+        mFreeParticles.insert(mFreeParticles.end(), mParticlePool.begin(), mParticlePool.end());
 
         // Add active emitted emitters to free list
         addActiveEmittedEmittersToFreeList();
@@ -1079,11 +1022,9 @@ namespace Ogre {
         {
             this->increasePool(size);
 
-            for( size_t i = currSize; i < size; ++i )
-            {
-                // Add new items to the queue
-                mFreeParticles.push_back( mParticlePool[i] );
-            }
+            // Add new items to the queue
+            mFreeParticles.insert(mFreeParticles.end(), mParticlePool.begin() + currSize,
+                                  mParticlePool.end());
 
             // Tell the renderer, if already configured
             if (mRenderer && mIsRendererConfigured)
@@ -1136,26 +1077,24 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void ParticleSystem::createVisualParticles(size_t poolstart, size_t poolend)
     {
-        ParticlePool::iterator i = mParticlePool.begin();
-        ParticlePool::iterator iend = mParticlePool.begin();
-        std::advance(i, poolstart);
-        std::advance(iend, poolend);
+        ParticlePool::iterator i = mParticlePool.begin() + poolstart;
+        ParticlePool::iterator iend = mParticlePool.begin() + poolend;
         for (; i != iend; ++i)
         {
-            (*i)->_notifyVisualData(
-                mRenderer->_createVisualData());
+            (*i)->_notifyOwner(this);
+            (*i)->_notifyVisualData(mRenderer->_createVisualData());
         }
     }
     //-----------------------------------------------------------------------
     void ParticleSystem::destroyVisualParticles(size_t poolstart, size_t poolend)
     {
-        ParticlePool::iterator i = mParticlePool.begin();
-        ParticlePool::iterator iend = mParticlePool.begin();
-        std::advance(i, poolstart);
-        std::advance(iend, poolend);
+        ParticlePool::iterator i = mParticlePool.begin() + poolstart;
+        ParticlePool::iterator iend = mParticlePool.begin() + poolend;
         for (; i != iend; ++i)
         {
+            OGRE_IGNORE_DEPRECATED_BEGIN
             mRenderer->_destroyVisualData((*i)->getVisualData());
+            OGRE_IGNORE_DEPRECATED_END
             (*i)->_notifyVisualData(0);
         }
     }
@@ -1268,10 +1207,9 @@ namespace Ogre {
         }
         else
         {
-            EmittedEmitterPool::iterator i;
-            for (i = mEmittedEmitterPool.begin(); i != mEmittedEmitterPool.end(); ++i)
+            for (auto& kv : mEmittedEmitterPool)
             {
-                currSize += i->second.size();
+                currSize += kv.second.size();
             }
         }
 
@@ -1293,27 +1231,19 @@ namespace Ogre {
             return;
 
         // Run through mEmitters and add keys to the pool
-        ParticleEmitterList::iterator emitterIterator;
-        ParticleEmitterList::iterator emitterIteratorInner;
-        ParticleEmitter* emitterInner = 0;
-        for (emitterIterator = mEmitters.begin(); emitterIterator != mEmitters.end(); ++emitterIterator)
+        for (ParticleEmitter* emitter : mEmitters)
         {
             // Determine the names of all emitters that are emitted
-            ParticleEmitter* emitter = *emitterIterator ;
             if (emitter && !emitter->getEmittedEmitter().empty())
             {
                 // This one will be emitted, register its name and leave the vector empty!
-                EmittedEmitterList empty;
-                mEmittedEmitterPool.insert(make_pair(emitter->getEmittedEmitter(), empty));
+                mEmittedEmitterPool[emitter->getEmittedEmitter()];
             }
 
             // Determine whether the emitter itself will be emitted and set the 'mEmitted' attribute
-            for (emitterIteratorInner = mEmitters.begin(); emitterIteratorInner != mEmitters.end(); ++emitterIteratorInner)
+            for (ParticleEmitter* emitterInner : mEmitters)
             {
-                emitterInner = *emitterIteratorInner;
-                if (emitter && 
-                    emitterInner && 
-                    !emitter->getName().empty() &&
+                if (emitter && emitterInner && !emitter->getName().empty() &&
                     emitter->getName() == emitterInner->getEmittedEmitter())
                 {
                     emitter->setEmitted(true);
@@ -1336,35 +1266,28 @@ namespace Ogre {
         if (mEmittedEmitterPool.empty())
             return;
 
-        EmittedEmitterPool::iterator emittedEmitterPoolIterator;
-        ParticleEmitterList::iterator emitterIterator;
         ParticleEmitter* clonedEmitter = 0;
-        String name = BLANKSTRING;
-        EmittedEmitterList* e = 0;
         size_t maxNumberOfEmitters = size / mEmittedEmitterPool.size(); // equally distribute the number for each emitted emitter list
-        size_t oldSize = 0;
     
         // Run through mEmittedEmitterPool and search for every key (=name) its corresponding emitter in mEmitters
-        for (emittedEmitterPoolIterator = mEmittedEmitterPool.begin(); emittedEmitterPoolIterator != mEmittedEmitterPool.end(); ++emittedEmitterPoolIterator)
+        for (auto& kv : mEmittedEmitterPool)
         {
-            name = emittedEmitterPoolIterator->first;
-            e = &emittedEmitterPoolIterator->second;
+            const auto& name = kv.first;
+            auto& e = kv.second;
 
             // Search the correct emitter in the mEmitters vector
-            for (emitterIterator = mEmitters.begin(); emitterIterator != mEmitters.end(); ++emitterIterator)
+            for (ParticleEmitter* emitter : mEmitters)
             {
-                ParticleEmitter* emitter = *emitterIterator;
-                if (emitter && 
-                    name != BLANKSTRING && 
-                    name == emitter->getName())
-                {       
+                if (emitter && !name.empty() && name == emitter->getName())
+                {
                     // Found the right emitter, clone each emitter a number of times
-                    oldSize = e->size();
+                    size_t oldSize = e.size();
                     for (size_t t = oldSize; t < maxNumberOfEmitters; ++t)
                     {
                         clonedEmitter = ParticleSystemManager::getSingleton()._createEmitter(emitter->getType(), this);
                         emitter->copyParametersTo(clonedEmitter);
                         clonedEmitter->setEmitted(emitter->isEmitted()); // is always 'true' by the way, but just in case
+                        clonedEmitter->_notifyOwner(this);
 
                         // Initially deactivate the emitted emitter if duration/repeat_delay are set
                         if (clonedEmitter->getDuration() > 0.0f && 
@@ -1372,7 +1295,7 @@ namespace Ogre {
                             clonedEmitter->setEnabled(false);
 
                         // Add cloned emitters to the pool
-                        e->push_back(clonedEmitter);
+                        e.push_back(clonedEmitter);
                     }
                 }
             }
@@ -1386,24 +1309,19 @@ namespace Ogre {
             return;
 
         // Copy all pooled emitters to the free list
-        EmittedEmitterPool::iterator emittedEmitterPoolIterator;
-        EmittedEmitterList::iterator emittedEmitterIterator;
-        EmittedEmitterList* emittedEmitters = 0;
         std::list<ParticleEmitter*>* fee = 0;
-        String name = BLANKSTRING;
 
         // Run through the emittedEmitterPool map
-        for (emittedEmitterPoolIterator = mEmittedEmitterPool.begin(); emittedEmitterPoolIterator != mEmittedEmitterPool.end(); ++emittedEmitterPoolIterator)
+        for (auto& kv : mEmittedEmitterPool)
         {
-            name = emittedEmitterPoolIterator->first;
-            emittedEmitters = &emittedEmitterPoolIterator->second;
+            const auto& name = kv.first;
+            auto& emittedEmitters = kv.second;
             fee = findFreeEmittedEmitter(name);
 
             // If its not in the map, create an empty one
             if (!fee)
             {
-                FreeEmittedEmitterList empty;
-                mFreeEmittedEmitters.insert(make_pair(name, empty));
+                mFreeEmittedEmitters[name];
                 fee = findFreeEmittedEmitter(name);
             }
 
@@ -1412,26 +1330,22 @@ namespace Ogre {
                 return; // forget it!
 
             // Add all emitted emitters from the pool to the free list
-            for(emittedEmitterIterator = emittedEmitters->begin(); emittedEmitterIterator != emittedEmitters->end(); ++emittedEmitterIterator)
+            for(ParticleEmitter* emitter : emittedEmitters)
             {
-                fee->push_back(*emittedEmitterIterator);
+                fee->push_back(emitter);
             }
         }
     }
     //-----------------------------------------------------------------------
     void ParticleSystem::removeAllEmittedEmitters(void)
     {
-        EmittedEmitterPool::iterator emittedEmitterPoolIterator;
-        EmittedEmitterList::iterator emittedEmitterListIterator;
-        EmittedEmitterList* e = 0;
-        for (emittedEmitterPoolIterator = mEmittedEmitterPool.begin(); emittedEmitterPoolIterator != mEmittedEmitterPool.end(); ++emittedEmitterPoolIterator)
+        for (auto& kv : mEmittedEmitterPool)
         {
-            e = &emittedEmitterPoolIterator->second;
-            for (emittedEmitterListIterator = e->begin(); emittedEmitterListIterator != e->end(); ++emittedEmitterListIterator)
+            for (ParticleEmitter* emitter : kv.second)
             {
-                ParticleSystemManager::getSingleton()._destroyEmitter(*emittedEmitterListIterator);
+                ParticleSystemManager::getSingleton()._destroyEmitter(emitter);
             }
-            e->clear();
+            kv.second.clear();
         }
 
         // Don't leave any references behind
