@@ -4,7 +4,7 @@ This source file is part of OGRE
     (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -27,17 +27,11 @@ THE SOFTWARE.
 */
 #include "OgreStableHeaders.h"
 
-#include "OgreParticleSystemManager.h"
 #include "OgreParticleEmitterFactory.h"
 #include "OgreParticleAffectorFactory.h"
-#include "OgreException.h"
-#include "OgreRoot.h"
-#include "OgreLogManager.h"
-#include "OgreString.h"
 #include "OgreParticleSystemRenderer.h"
 #include "OgreBillboardParticleRenderer.h"
-#include "OgreStringConverter.h"
-#include "OgreScriptCompiler.h"
+#include "OgreParticleSystem.h"
 
 namespace Ogre {
     //-----------------------------------------------------------------------
@@ -57,36 +51,29 @@ namespace Ogre {
     ParticleSystemManager::ParticleSystemManager()
     {
         OGRE_LOCK_AUTO_MUTEX;
-		mFactory = OGRE_NEW ParticleSystemFactory();
-		Root::getSingleton().addMovableObjectFactory(mFactory);
+        mFactory = OGRE_NEW ParticleSystemFactory();
+        Root::getSingleton().addMovableObjectFactory(mFactory);
     }
     //-----------------------------------------------------------------------
     ParticleSystemManager::~ParticleSystemManager()
     {
+        removeAllTemplates(true); // Destroy all templates
         OGRE_LOCK_AUTO_MUTEX;
-
-        // Destroy all templates
-        ParticleTemplateMap::iterator t;
-        for (t = mSystemTemplates.begin(); t != mSystemTemplates.end(); ++t)
-        {
-            OGRE_DELETE t->second;
-        }
-        mSystemTemplates.clear();
         ResourceGroupManager::getSingleton()._unregisterScriptLoader(this);
         // delete billboard factory
         if (mBillboardRendererFactory)
-		{
+        {
             OGRE_DELETE mBillboardRendererFactory;
-			mBillboardRendererFactory = 0;
-		}
+            mBillboardRendererFactory = 0;
+        }
 
-		if (mFactory)
-		{
-			// delete particle system factory
-			Root::getSingleton().removeMovableObjectFactory(mFactory);
-			OGRE_DELETE mFactory;
-			mFactory = 0;
-		}
+        if (mFactory)
+        {
+            // delete particle system factory
+            Root::getSingleton().removeMovableObjectFactory(mFactory);
+            OGRE_DELETE mFactory;
+            mFactory = 0;
+        }
 
     }
     //-----------------------------------------------------------------------
@@ -103,7 +90,7 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void ParticleSystemManager::parseScript(DataStreamPtr& stream, const String& groupName)
     {
-		ScriptCompilerManager::getSingleton().parseScript(stream, groupName);
+        ScriptCompilerManager::getSingleton().parseScript(stream, groupName);
     }
     //-----------------------------------------------------------------------
     void ParticleSystemManager::addEmitterFactory(ParticleEmitterFactory* factory)
@@ -121,25 +108,25 @@ namespace Ogre {
         mAffectorFactories[name] = factory;
         LogManager::getSingleton().logMessage("Particle Affector Type '" + name + "' registered");
     }
-	//-----------------------------------------------------------------------
-	void ParticleSystemManager::addRendererFactory(ParticleSystemRendererFactory* factory)
-	{
+    //-----------------------------------------------------------------------
+    void ParticleSystemManager::addRendererFactory(ParticleSystemRendererFactory* factory)
+    {
             OGRE_LOCK_AUTO_MUTEX ;
-		String name = factory->getType();
+        String name = factory->getType();
         mRendererFactories[name] = factory;
         LogManager::getSingleton().logMessage("Particle Renderer Type '" + name + "' registered");
-	}
-	//-----------------------------------------------------------------------
+    }
+    //-----------------------------------------------------------------------
     void ParticleSystemManager::addTemplate(const String& name, ParticleSystem* sysTemplate)
     {
         OGRE_LOCK_AUTO_MUTEX;
-		// check name
-		if (mSystemTemplates.find(name) != mSystemTemplates.end())
-		{
-			OGRE_EXCEPT(Exception::ERR_DUPLICATE_ITEM, 
-				"ParticleSystem template with name '" + name + "' already exists.", 
-				"ParticleSystemManager::addTemplate");
-		}
+        // check name
+        if (mSystemTemplates.find(name) != mSystemTemplates.end())
+        {
+            OGRE_EXCEPT(Exception::ERR_DUPLICATE_ITEM, 
+                "ParticleSystem template with name '" + name + "' already exists.", 
+                "ParticleSystemManager::addTemplate");
+        }
 
         mSystemTemplates[name] = sysTemplate;
     }
@@ -175,36 +162,36 @@ namespace Ogre {
     void ParticleSystemManager::removeTemplatesByResourceGroup(const String& resourceGroup)
     {
         OGRE_LOCK_AUTO_MUTEX;
-		
-		ParticleTemplateMap::iterator i = mSystemTemplates.begin();
-		while (i != mSystemTemplates.end())
-		{
-			ParticleTemplateMap::iterator icur = i++;
+        
+        ParticleTemplateMap::iterator i = mSystemTemplates.begin();
+        while (i != mSystemTemplates.end())
+        {
+            ParticleTemplateMap::iterator icur = i++;
 
-			if(icur->second->getResourceGroupName() == resourceGroup)
-			{
-				delete icur->second;
-				mSystemTemplates.erase(icur);
-			}
-		}    
-	}
+            if(icur->second->getResourceGroupName() == resourceGroup)
+            {
+                delete icur->second;
+                mSystemTemplates.erase(icur);
+            }
+        }    
+    }
     //-----------------------------------------------------------------------
     ParticleSystem* ParticleSystemManager::createTemplate(const String& name, 
         const String& resourceGroup)
     {
         OGRE_LOCK_AUTO_MUTEX;
-		// check name
-		if (mSystemTemplates.find(name) != mSystemTemplates.end())
-		{
+        // check name
+        if (mSystemTemplates.find(name) != mSystemTemplates.end())
+        {
 #if OGRE_PLATFORM == OGRE_PLATFORM_WINRT
-			LogManager::getSingleton().logMessage("ParticleSystem template with name '" + name + "' already exists.");
-			return NULL;
+            LogManager::getSingleton().logMessage("ParticleSystem template with name '" + name + "' already exists.");
+            return NULL;
 #else
-			OGRE_EXCEPT(Exception::ERR_DUPLICATE_ITEM, 
-				"ParticleSystem template with name '" + name + "' already exists.", 
-				"ParticleSystemManager::createTemplate");
+            OGRE_EXCEPT(Exception::ERR_DUPLICATE_ITEM, 
+                "ParticleSystem template with name '" + name + "' already exists.", 
+                "ParticleSystemManager::createTemplate");
 #endif
-		}
+        }
 
         ParticleSystem* tpl = OGRE_NEW ParticleSystem(name, resourceGroup);
         addTemplate(name, tpl);
@@ -225,9 +212,9 @@ namespace Ogre {
             return 0;
         }
     }
-	//-----------------------------------------------------------------------
+    //-----------------------------------------------------------------------
     ParticleSystem* ParticleSystemManager::createSystemImpl(const String& name,
-		size_t quota, const String& resourceGroup)
+        size_t quota, const String& resourceGroup)
     {
         ParticleSystem* sys = OGRE_NEW ParticleSystem(name, resourceGroup);
         sys->setParticleQuota(quota);
@@ -235,7 +222,7 @@ namespace Ogre {
     }
     //-----------------------------------------------------------------------
     ParticleSystem* ParticleSystemManager::createSystemImpl(const String& name, 
-		const String& templateName)
+        const String& templateName)
     {
         // Look up template
         ParticleSystem* pTemplate = getTemplate(templateName);
@@ -253,9 +240,9 @@ namespace Ogre {
     }
     //-----------------------------------------------------------------------
     void ParticleSystemManager::destroySystemImpl(ParticleSystem* sys)
-	{
-		OGRE_DELETE sys;
-	}
+    {
+        OGRE_DELETE sys;
+    }
     //-----------------------------------------------------------------------
     ParticleEmitter* ParticleSystemManager::_createEmitter(
         const String& emitterType, ParticleSystem* psys)
@@ -327,7 +314,7 @@ namespace Ogre {
     }
     //-----------------------------------------------------------------------
     ParticleSystemRenderer* ParticleSystemManager::_createRenderer(const String& rendererType)
-	{
+    {
         OGRE_LOCK_AUTO_MUTEX;
         // Locate affector type
         ParticleSystemRendererFactoryMap::iterator pFact = mRendererFactories.find(rendererType);
@@ -339,10 +326,10 @@ namespace Ogre {
         }
 
         return pFact->second->createInstance(rendererType);
-	}
-	//-----------------------------------------------------------------------
+    }
+    //-----------------------------------------------------------------------
     void ParticleSystemManager::_destroyRenderer(ParticleSystemRenderer* renderer)
-	{
+    {
         if(!renderer)
             OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS, "Cannot destroy a null ParticleSystemRenderer.", "ParticleSystemManager::_destroyRenderer");
 
@@ -357,7 +344,7 @@ namespace Ogre {
         }
 
         pFact->second->destroyInstance(renderer);
-	}
+    }
     //-----------------------------------------------------------------------
     void ParticleSystemManager::_initialise(void)
     {
@@ -368,213 +355,79 @@ namespace Ogre {
 
     }
     //-----------------------------------------------------------------------
-    void ParticleSystemManager::parseNewEmitter(const String& type, DataStreamPtr& stream, ParticleSystem* sys)
+    ParticleSystemManager::ParticleAffectorFactoryIterator 
+    ParticleSystemManager::getAffectorFactoryIterator(void)
     {
-        // Create new emitter
-        ParticleEmitter* pEmit = sys->addEmitter(type);
-        // Parse emitter details
-        String line;
-
-        while(!stream->eof())
+        return ParticleAffectorFactoryIterator(
+            mAffectorFactories.begin(), mAffectorFactories.end());
+    }
+    //-----------------------------------------------------------------------
+    ParticleSystemManager::ParticleEmitterFactoryIterator 
+    ParticleSystemManager::getEmitterFactoryIterator(void)
+    {
+        return ParticleEmitterFactoryIterator(
+            mEmitterFactories.begin(), mEmitterFactories.end());
+    }
+    //-----------------------------------------------------------------------
+    ParticleSystemManager::ParticleRendererFactoryIterator 
+    ParticleSystemManager::getRendererFactoryIterator(void)
+    {
+        return ParticleRendererFactoryIterator(
+            mRendererFactories.begin(), mRendererFactories.end());
+    }
+    //-----------------------------------------------------------------------
+    //-----------------------------------------------------------------------
+    //-----------------------------------------------------------------------
+    String ParticleSystemFactory::FACTORY_TYPE_NAME = "ParticleSystem";
+    //-----------------------------------------------------------------------
+    MovableObject* ParticleSystemFactory::createInstanceImpl( const String& name, 
+            const NameValuePairList* params)
+    {
+        if (params != 0)
         {
-            line = stream->getLine();
-            // Ignore comments & blanks
-            if (!(line.length() == 0 || line.substr(0,2) == "//"))
+            NameValuePairList::const_iterator ni = params->find("templateName");
+            if (ni != params->end())
             {
-                if (line == "}")
-                {
-                    // Finished emitter
-                    break;
-                }
-                else
-                {
-                    // Attribute
-					StringUtil::toLowerCase(line);
-                    parseEmitterAttrib(line, pEmit);
-                }
+                String templateName = ni->second;
+                // create using manager
+                return ParticleSystemManager::getSingleton().createSystemImpl(
+                        name, templateName);
             }
         }
-
-
-        
-    }
-    //-----------------------------------------------------------------------
-    void ParticleSystemManager::parseNewAffector(const String& type, DataStreamPtr& stream, ParticleSystem* sys)
-    {
-        // Create new affector
-        ParticleAffector* pAff = sys->addAffector(type);
-        // Parse affector details
-        String line;
-
-        while(!stream->eof())
+        // Not template based, look for quota & resource name
+        size_t quota = 500;
+        String resourceGroup = ResourceGroupManager::DEFAULT_RESOURCE_GROUP_NAME;
+        if (params != 0)
         {
-            line = stream->getLine();
-            // Ignore comments & blanks
-            if (!(line.length() == 0 || line.substr(0,2) == "//"))
+            NameValuePairList::const_iterator ni = params->find("quota");
+            if (ni != params->end())
             {
-                if (line == "}")
-                {
-                    // Finished affector
-                    break;
-                }
-                else
-                {
-                    // Attribute
-					StringUtil::toLowerCase(line);
-                    parseAffectorAttrib(line, pAff);
-                }
+                quota = StringConverter::parseUnsignedInt(ni->second);
+            }
+            ni = params->find("resourceGroup");
+            if (ni != params->end())
+            {
+                resourceGroup = ni->second;
             }
         }
+        // create using manager
+        return ParticleSystemManager::getSingleton().createSystemImpl(
+                name, quota, resourceGroup);
+                
+
     }
     //-----------------------------------------------------------------------
-    void ParticleSystemManager::parseAttrib(const String& line, ParticleSystem* sys)
+    const String& ParticleSystemFactory::getType(void) const
     {
-        // Split params on space
-        vector<String>::type vecparams = StringUtil::split(line, "\t ", 1);
-
-        // Look up first param (command setting)
-        if (!sys->setParameter(vecparams[0], vecparams[1]))
-        {
-            // Attribute not supported by particle system, try the renderer
-            ParticleSystemRenderer* renderer = sys->getRenderer();
-            if (renderer)
-            {
-                if (!renderer->setParameter(vecparams[0], vecparams[1]))
-                {
-                    LogManager::getSingleton().logMessage("Bad particle system attribute line: '"
-                        + line + "' in " + sys->getName() + " (tried renderer)", LML_CRITICAL);
-                }
-            }
-            else
-            {
-                // BAD command. BAD!
-                LogManager::getSingleton().logMessage("Bad particle system attribute line: '"
-                    + line + "' in " + sys->getName() + " (no renderer)", LML_CRITICAL);
-            }
-        }
+        return FACTORY_TYPE_NAME;
     }
     //-----------------------------------------------------------------------
-    void ParticleSystemManager::parseEmitterAttrib(const String& line, ParticleEmitter* emit)
+    void ParticleSystemFactory::destroyInstance( MovableObject* obj) 
     {
-        // Split params on first space
-        vector<String>::type vecparams = StringUtil::split(line, "\t ", 1);
-
-        // Look up first param (command setting)
-        if (!emit->setParameter(vecparams[0], vecparams[1]))
-        {
-            // BAD command. BAD!
-            LogManager::getSingleton().logMessage("Bad particle emitter attribute line: '"
-                + line + "' for emitter " + emit->getType(), LML_CRITICAL);
-        }
-    }
-    //-----------------------------------------------------------------------
-    void ParticleSystemManager::parseAffectorAttrib(const String& line, ParticleAffector* aff)
-    {
-        // Split params on space
-        vector<String>::type vecparams = StringUtil::split(line, "\t ", 1);
-
-        // Look up first param (command setting)
-        if (!aff->setParameter(vecparams[0], vecparams[1]))
-        {
-            // BAD command. BAD!
-            LogManager::getSingleton().logMessage("Bad particle affector attribute line: '"
-                + line + "' for affector " + aff->getType(), LML_CRITICAL);
-        }
-    }
-    //-----------------------------------------------------------------------
-    void ParticleSystemManager::skipToNextCloseBrace(DataStreamPtr& stream)
-    {
-        String line;
-        while (!stream->eof() && line != "}")
-        {
-            line = stream->getLine();
-        }
+        // use manager
+        ParticleSystemManager::getSingleton().destroySystemImpl(
+            static_cast<ParticleSystem*>(obj));
 
     }
     //-----------------------------------------------------------------------
-    void ParticleSystemManager::skipToNextOpenBrace(DataStreamPtr& stream)
-    {
-        String line;
-        while (!stream->eof() && line != "{")
-        {
-            line = stream->getLine();
-        }
-
-    }
-	//-----------------------------------------------------------------------
-	ParticleSystemManager::ParticleAffectorFactoryIterator 
-	ParticleSystemManager::getAffectorFactoryIterator(void)
-	{
-		return ParticleAffectorFactoryIterator(
-			mAffectorFactories.begin(), mAffectorFactories.end());
-	}
-	//-----------------------------------------------------------------------
-	ParticleSystemManager::ParticleEmitterFactoryIterator 
-	ParticleSystemManager::getEmitterFactoryIterator(void)
-	{
-		return ParticleEmitterFactoryIterator(
-			mEmitterFactories.begin(), mEmitterFactories.end());
-	}
-	//-----------------------------------------------------------------------
-	ParticleSystemManager::ParticleRendererFactoryIterator 
-	ParticleSystemManager::getRendererFactoryIterator(void)
-	{
-		return ParticleRendererFactoryIterator(
-			mRendererFactories.begin(), mRendererFactories.end());
-	}
-	//-----------------------------------------------------------------------
-    //-----------------------------------------------------------------------
-    //-----------------------------------------------------------------------
-	String ParticleSystemFactory::FACTORY_TYPE_NAME = "ParticleSystem";
-    //-----------------------------------------------------------------------
-	MovableObject* ParticleSystemFactory::createInstanceImpl( const String& name, 
-			const NameValuePairList* params)
-	{
-		if (params != 0)
-		{
-			NameValuePairList::const_iterator ni = params->find("templateName");
-			if (ni != params->end())
-			{
-				String templateName = ni->second;
-				// create using manager
-				return ParticleSystemManager::getSingleton().createSystemImpl(
-						name, templateName);
-			}
-		}
-		// Not template based, look for quota & resource name
-		size_t quota = 500;
-		String resourceGroup = ResourceGroupManager::DEFAULT_RESOURCE_GROUP_NAME;
-		if (params != 0)
-		{
-			NameValuePairList::const_iterator ni = params->find("quota");
-			if (ni != params->end())
-			{
-				quota = StringConverter::parseUnsignedInt(ni->second);
-			}
-			ni = params->find("resourceGroup");
-			if (ni != params->end())
-			{
-				resourceGroup = ni->second;
-			}
-		}
-		// create using manager
-		return ParticleSystemManager::getSingleton().createSystemImpl(
-				name, quota, resourceGroup);
-				
-
-	}
-    //-----------------------------------------------------------------------
-	const String& ParticleSystemFactory::getType(void) const
-	{
-		return FACTORY_TYPE_NAME;
-	}
-    //-----------------------------------------------------------------------
-	void ParticleSystemFactory::destroyInstance( MovableObject* obj) 
-	{
-		// use manager
-		ParticleSystemManager::getSingleton().destroySystemImpl(
-			static_cast<ParticleSystem*>(obj));
-
-	}
-    //-----------------------------------------------------------------------
 }
