@@ -337,8 +337,6 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void Pass::setPointSpritesEnabled(bool enabled)
     {
-        if (!Root::getSingleton().getRenderSystem()->getCapabilities()->hasCapability(RSC_POINT_SPRITES))
-            return;
         mPointSpritesEnabled = enabled;
     }
     //-----------------------------------------------------------------------
@@ -514,14 +512,15 @@ namespace Ogre {
                     // This sprintf replaced a call to StringConverter::toString for performance reasons
                     state->setName( StringUtil::format("%lx", static_cast<long>(idx)));
                     
+                    OGRE_IGNORE_DEPRECATED_BEGIN
                     /** since the name was never set and a default one has been made, clear the alias name
                      so that when the texture unit name is set by the user, the alias name will be set to
                      that name
                     */
                     state->setTextureNameAlias(BLANKSTRING);
+                    OGRE_IGNORE_DEPRECATED_END
                 }
-                // Needs recompilation
-                mParent->_notifyNeedsRecompile();
+                _notifyNeedsRecompile();
                 _dirtyHash();
             }
             else
@@ -605,11 +604,7 @@ namespace Ogre {
         TextureUnitStates::iterator i = mTextureUnitStates.begin() + index;
         OGRE_DELETE *i;
         mTextureUnitStates.erase(i);
-        if (!mQueuedForDeletion)
-        {
-            // Needs recompilation
-            mParent->_notifyNeedsRecompile();
-        }
+        _notifyNeedsRecompile();
         _dirtyHash();
         mContentTypeLookupBuilt = false;
     }
@@ -624,11 +619,7 @@ namespace Ogre {
             OGRE_DELETE *i;
         }
         mTextureUnitStates.clear();
-        if (!mQueuedForDeletion)
-        {
-            // Needs recompilation
-            mParent->_notifyNeedsRecompile();
-        }
+        _notifyNeedsRecompile();
         _dirtyHash();
         mContentTypeLookupBuilt = false;
     }
@@ -1232,7 +1223,7 @@ namespace Ogre {
             programUsage->setProgram(program, resetParams);
         }
         // Needs recompilation
-        mParent->_notifyNeedsRecompile();
+        _notifyNeedsRecompile();
 
         if( Pass::getHashFunction() == Pass::getBuiltinHashFunction( Pass::MIN_GPU_PROGRAM_CHANGE ) )
         {
@@ -1424,6 +1415,9 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void Pass::_dirtyHash(void)
     {
+        if (mQueuedForDeletion)
+            return;
+
         Material* mat = mParent->getParent();
         if (mat->isLoading() || mat->isLoaded())
         {
@@ -1446,7 +1440,8 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void Pass::_notifyNeedsRecompile(void)
     {
-        mParent->_notifyNeedsRecompile();
+        if (!mQueuedForDeletion)
+            mParent->_notifyNeedsRecompile();
     }
     //-----------------------------------------------------------------------
     void Pass::setTextureFiltering(TextureFilterOptions filterType)
@@ -1565,8 +1560,7 @@ namespace Ogre {
             }
             mShadowCasterVertexProgramUsage->setProgramName(name);
         }
-        // Needs recompilation
-        mParent->_notifyNeedsRecompile();
+        _notifyNeedsRecompile();
     }
     //-----------------------------------------------------------------------
     void Pass::setShadowCasterVertexProgramParameters(GpuProgramParametersSharedPtr params)
@@ -1619,8 +1613,7 @@ namespace Ogre {
             }
             mShadowCasterFragmentProgramUsage->setProgramName(name);
         }
-        // Needs recompilation
-        mParent->_notifyNeedsRecompile();
+        _notifyNeedsRecompile();
     }
     //-----------------------------------------------------------------------
     void Pass::setShadowCasterFragmentProgramParameters(GpuProgramParametersSharedPtr params)
@@ -1679,8 +1672,7 @@ namespace Ogre {
             }
             mShadowReceiverVertexProgramUsage->setProgramName(name);
         }
-        // Needs recompilation
-        mParent->_notifyNeedsRecompile();
+        _notifyNeedsRecompile();
     }
     //-----------------------------------------------------------------------
     void Pass::setShadowReceiverVertexProgramParameters(GpuProgramParametersSharedPtr params)
@@ -1733,8 +1725,7 @@ namespace Ogre {
             }
             mShadowReceiverFragmentProgramUsage->setProgramName(name);
         }
-        // Needs recompilation
-        mParent->_notifyNeedsRecompile();
+        _notifyNeedsRecompile();
     }
     //-----------------------------------------------------------------------
     void Pass::setShadowReceiverFragmentProgramParameters(GpuProgramParametersSharedPtr params)
@@ -1787,8 +1778,10 @@ namespace Ogre {
 
         for (i = mTextureUnitStates.begin(); i != iend; ++i)
         {
+            OGRE_IGNORE_DEPRECATED_BEGIN
             if ((*i)->applyTextureAliases(aliasList, apply))
                 testResult = true;
+            OGRE_IGNORE_DEPRECATED_END
         }
 
         return testResult;
