@@ -4,7 +4,7 @@ This source file is part of OGRE
     (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -34,15 +34,9 @@ THE SOFTWARE.
 // http://www.boost.org/LICENSE_1_0.txt
 // http://www.geometrictools.com/License/Boost/LICENSE_1_0.txt
 
-#include "OgreQuaternion.h"
-
-#include "OgreMath.h"
-#include "OgreMatrix3.h"
-#include "OgreVector3.h"
-
 namespace Ogre {
 
-    const Real Quaternion::msEpsilon = 1e-03;
+    const float Quaternion::msEpsilon = 1e-03;
     const Quaternion Quaternion::ZERO(0,0,0,0);
     const Quaternion Quaternion::IDENTITY(1,0,0,0);
 
@@ -78,7 +72,7 @@ namespace Ogre {
             size_t k = s_iNext[j];
 
             fRoot = Math::Sqrt(kRot[i][i]-kRot[j][j]-kRot[k][k] + 1.0f);
-            Real* apkQuat[3] = { &x, &y, &z };
+            float* apkQuat[3] = { &x, &y, &z };
             *apkQuat[i] = 0.5f*fRoot;
             fRoot = 0.5f/fRoot;
             w = (kRot[k][j]-kRot[j][k])*fRoot;
@@ -122,7 +116,7 @@ namespace Ogre {
         //   q = cos(A/2)+sin(A/2)*(x*i+y*j+z*k)
 
         Radian fHalfAngle ( 0.5*rfAngle );
-        Real fSin = Math::Sin(fHalfAngle);
+        float fSin = Math::Sin(fHalfAngle);
         w = Math::Cos(fHalfAngle);
         x = fSin*rkAxis.x;
         y = fSin*rkAxis.y;
@@ -170,21 +164,8 @@ namespace Ogre {
     void Quaternion::FromAxes (const Vector3& xaxis, const Vector3& yaxis, const Vector3& zaxis)
     {
         Matrix3 kRot;
-
-        kRot[0][0] = xaxis.x;
-        kRot[1][0] = xaxis.y;
-        kRot[2][0] = xaxis.z;
-
-        kRot[0][1] = yaxis.x;
-        kRot[1][1] = yaxis.y;
-        kRot[2][1] = yaxis.z;
-
-        kRot[0][2] = zaxis.x;
-        kRot[1][2] = zaxis.y;
-        kRot[2][2] = zaxis.z;
-
+        kRot.FromAxes(xaxis, yaxis, zaxis);
         FromRotationMatrix(kRot);
-
     }
     //-----------------------------------------------------------------------
     void Quaternion::ToAxes (Vector3* akAxis) const
@@ -290,32 +271,6 @@ namespace Ogre {
         );
     }
     //-----------------------------------------------------------------------
-    Quaternion Quaternion::operator* (Real fScalar) const
-    {
-        return Quaternion(fScalar*w,fScalar*x,fScalar*y,fScalar*z);
-    }
-    //-----------------------------------------------------------------------
-    Quaternion operator* (Real fScalar, const Quaternion& rkQ)
-    {
-        return Quaternion(fScalar*rkQ.w,fScalar*rkQ.x,fScalar*rkQ.y,
-            fScalar*rkQ.z);
-    }
-    //-----------------------------------------------------------------------
-    Quaternion Quaternion::operator- () const
-    {
-        return Quaternion(-w,-x,-y,-z);
-    }
-    //-----------------------------------------------------------------------
-    Real Quaternion::Dot (const Quaternion& rkQ) const
-    {
-        return w*rkQ.w+x*rkQ.x+y*rkQ.y+z*rkQ.z;
-    }
-    //-----------------------------------------------------------------------
-    Real Quaternion::Norm () const
-    {
-        return w*w+x*x+y*y+z*z;
-    }
-    //-----------------------------------------------------------------------
     Quaternion Quaternion::Inverse () const
     {
         Real fNorm = w*w+x*x+y*y+z*z;
@@ -340,27 +295,28 @@ namespace Ogre {
     Quaternion Quaternion::Exp () const
     {
         // If q = A*(x*i+y*j+z*k) where (x,y,z) is unit length, then
-        // exp(q) = cos(A)+sin(A)*(x*i+y*j+z*k).  If sin(A) is near zero,
-        // use exp(q) = cos(A)+A*(x*i+y*j+z*k) since A/sin(A) has limit 1.
+        // exp(q) = e^w(cos(A)+sin(A)*(x*i+y*j+z*k)).  If sin(A) is near zero,
+        // use exp(q) = e^w(cos(A)+(x*i+y*j+z*k)) since sin(A)/A has limit 1.
 
         Radian fAngle ( Math::Sqrt(x*x+y*y+z*z) );
-        Real fSin = Math::Sin(fAngle);
+        float fSin = Math::Sin(fAngle);
+		float fExpW = Math::Exp(w);
 
         Quaternion kResult;
-        kResult.w = Math::Cos(fAngle);
+        kResult.w = fExpW*Math::Cos(fAngle);
 
-        if ( Math::Abs(fSin) >= msEpsilon )
+        if ( Math::Abs(fAngle.valueRadians()) >= msEpsilon )
         {
-            Real fCoeff = fSin/(fAngle.valueRadians());
+            float fCoeff = fExpW*(fSin/(fAngle.valueRadians()));
             kResult.x = fCoeff*x;
             kResult.y = fCoeff*y;
             kResult.z = fCoeff*z;
         }
         else
         {
-            kResult.x = x;
-            kResult.y = y;
-            kResult.z = z;
+            kResult.x = fExpW*x;
+            kResult.y = fExpW*y;
+            kResult.z = fExpW*z;
         }
 
         return kResult;
@@ -369,15 +325,19 @@ namespace Ogre {
     Quaternion Quaternion::Log () const
     {
         // If q = cos(A)+sin(A)*(x*i+y*j+z*k) where (x,y,z) is unit length, then
-        // log(q) = A*(x*i+y*j+z*k).  If sin(A) is near zero, use log(q) =
-        // sin(A)*(x*i+y*j+z*k) since sin(A)/A has limit 1.
+        // log(q) = (A/sin(A))*(x*i+y*j+z*k).  If sin(A) is near zero, use
+        // log(q) = (x*i+y*j+z*k) since A/sin(A) has limit 1.
 
         Quaternion kResult;
         kResult.w = 0.0;
 
         if ( Math::Abs(w) < 1.0 )
         {
-            Radian fAngle ( Math::ACos(w) );
+            // According to Neil Dantam, atan2 has the best stability.
+            // http://www.neil.dantam.name/note/dantam-quaternion.pdf
+            Real fNormV = Math::Sqrt(x*x + y*y + z*z);
+            Radian fAngle ( Math::ATan2(fNormV, w) );
+
             Real fSin = Math::Sin(fAngle);
             if ( Math::Abs(fSin) >= msEpsilon )
             {
@@ -409,17 +369,6 @@ namespace Ogre {
 		return v + uv + uuv;
 
     }
-    //-----------------------------------------------------------------------
-	bool Quaternion::equals(const Quaternion& rhs, const Radian& tolerance) const
-	{
-        Real fCos = Dot(rhs);
-        Radian angle = Math::ACos(fCos);
-
-		return (Math::Abs(angle.valueRadians()) <= tolerance.valueRadians())
-            || Math::RealEqual(angle.valueRadians(), Math::PI, tolerance.valueRadians());
-
-
-	}
     //-----------------------------------------------------------------------
     Quaternion Quaternion::Slerp (Real fT, const Quaternion& rkP,
         const Quaternion& rkQ, bool shortestPath)
@@ -506,14 +455,6 @@ namespace Ogre {
         Quaternion kSlerpQ = Slerp(fT, rkA, rkB);
         return Slerp(fSlerpT, kSlerpP ,kSlerpQ);
     }
-    //-----------------------------------------------------------------------
-    Real Quaternion::normalise(void)
-    {
-        Real len = Norm();
-        Real factor = 1.0f / Math::Sqrt(len);
-        *this = *this * factor;
-        return len;
-    }
     //-----------------------------------------------------------------------
 	Radian Quaternion::getRoll(bool reprojectAxis) const
 	{
