@@ -48,7 +48,7 @@ namespace Ogre {
 
         // set default queue
         mDefaultQueueGroup = RENDER_QUEUE_MAIN;
-        mDefaultRenderablePriority = OGRE_RENDERABLE_DEFAULT_PRIORITY;
+        mDefaultRenderablePriority = Renderable::DEFAULT_PRIORITY;
 
     }
     //---------------------------------------------------------------------
@@ -102,19 +102,14 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void RenderQueue::clear(bool destroyPassMaps)
     {
-        // Clear the queues
-        SceneManagerEnumerator::SceneManagerIterator scnIt =
-            SceneManagerEnumerator::getSingleton().getSceneManagerIterator();
-
         // Note: We clear dirty passes from all RenderQueues in all 
         // SceneManagers, because the following recalculation of pass hashes
         // also considers all RenderQueues and could become inconsistent, otherwise.
-        while (scnIt.hasMoreElements())
+        for (auto p : SceneManagerEnumerator::getSingleton().getSceneManagers())
         {
-            SceneManager* sceneMgr = scnIt.getNext();
-            RenderQueue* queue = sceneMgr->getRenderQueue();
+            RenderQueue* queue = p.second->getRenderQueue();
 
-            for (size_t i = 0; i < RENDER_QUEUE_MAX; ++i)
+            for (size_t i = 0; i < RENDER_QUEUE_COUNT; ++i)
             {
                 if(queue->mGroups[i])
                     queue->mGroups[i]->clear(destroyPassMaps);
@@ -180,7 +175,7 @@ namespace Ogre {
     {
         mSplitPassesByLightingType = split;
 
-        for (size_t i = 0; i < RENDER_QUEUE_MAX; ++i)
+        for (size_t i = 0; i < RENDER_QUEUE_COUNT; ++i)
         {
             if(mGroups[i])
                 mGroups[i]->setSplitPassesByLightingType(split);
@@ -196,7 +191,7 @@ namespace Ogre {
     {
         mSplitNoShadowPasses = split;
 
-        for (size_t i = 0; i < RENDER_QUEUE_MAX; ++i)
+        for (size_t i = 0; i < RENDER_QUEUE_COUNT; ++i)
         {
             if(mGroups[i])
                 mGroups[i]->setSplitNoShadowPasses(split);
@@ -212,7 +207,7 @@ namespace Ogre {
     {
         mShadowCastersCannotBeReceivers = ind;
 
-        for (size_t i = 0; i < RENDER_QUEUE_MAX; ++i)
+        for (size_t i = 0; i < RENDER_QUEUE_COUNT; ++i)
         {
             if(mGroups[i])
                 mGroups[i]->setShadowCastersCannotBeReceivers(ind);
@@ -226,7 +221,7 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void RenderQueue::merge( const RenderQueue* rhs )
     {
-        for (size_t i = 0; i < RENDER_QUEUE_MAX; ++i)
+        for (size_t i = 0; i < RENDER_QUEUE_COUNT; ++i)
         {
             if(!rhs->mGroups[i])
                 continue;
