@@ -67,6 +67,8 @@ mShadowTextureSelfShadow(false),
 mShadowTextureConfigDirty(true),
 mShadowCasterRenderBackFaces(true)
 {
+    mShadowCasterQueryListener.reset(new ShadowCasterSceneQueryListener(mSceneManager));
+
     // set up default shadow camera setup
     mDefaultShadowCameraSetup = DefaultShadowCameraSetup::create();
 
@@ -151,7 +153,7 @@ void SceneManager::ShadowRenderer::renderAdditiveStencilShadowedQueueGroupObject
 
         // Now iterate per light
         // Iterate over lights, render all volumes to stencil
-        for (Light* l : mSceneManager->mLightsAffectingFrustum)
+        for (Light* l : mSceneManager->_getLightsAffectingFrustum())
         {
             // Set light state
             if (lightList.empty())
@@ -186,7 +188,6 @@ void SceneManager::ShadowRenderer::renderAdditiveStencilShadowedQueueGroupObject
             // Reset stencil params
             mDestRenderSystem->setStencilBufferParams();
             mDestRenderSystem->setStencilCheckEnabled(false);
-            mDestRenderSystem->_setDepthBufferParams();
 
             if (scissored == CLIPPED_SOME)
                 mSceneManager->resetScissor();
@@ -250,7 +251,7 @@ void SceneManager::ShadowRenderer::renderModulativeStencilShadowedQueueGroupObje
     mSceneManager->setAmbientLight(mShadowColour);
 
     // Iterate over lights, render all volumes to stencil
-    for (Light* l : mSceneManager->mLightsAffectingFrustum)
+    for (Light* l : mSceneManager->_getLightsAffectingFrustum())
     {
         if (l->getCastShadows())
         {
@@ -267,7 +268,6 @@ void SceneManager::ShadowRenderer::renderModulativeStencilShadowedQueueGroupObje
             // Reset stencil params
             mDestRenderSystem->setStencilBufferParams();
             mDestRenderSystem->setStencilCheckEnabled(false);
-            mDestRenderSystem->_setDepthBufferParams();
         }
 
     }// for each light
@@ -385,22 +385,20 @@ void SceneManager::ShadowRenderer::renderModulativeTextureShadowedQueueGroupObje
     {
         mSceneManager->mIlluminationStage = IRS_RENDER_RECEIVER_PASS;
 
-        LightList::iterator i, iend;
-        ShadowTextureList::iterator si, siend;
-        iend = mSceneManager->mLightsAffectingFrustum.end();
-        siend = mShadowTextures.end();
-        for (i = mSceneManager->mLightsAffectingFrustum.begin(), si = mShadowTextures.begin();
-            i != iend && si != siend; ++i)
+        LightList::const_iterator i, iend;
+        iend = mSceneManager->_getLightsAffectingFrustum().end();
+
+        size_t si = 0;
+        for (i = mSceneManager->_getLightsAffectingFrustum().begin();
+             i != iend && si < mShadowTextures.size(); ++i)
         {
             Light* l = *i;
 
             if (!l->getCastShadows())
                 continue;
 
-            // Store current shadow texture
-            const auto& currentShadowTexture = *si;
             // Get camera for current shadow texture
-            Camera *cam = currentShadowTexture->getBuffer()->getRenderTarget()->getViewport(0)->getCamera();
+            Camera *cam = mShadowTextures[si]->getBuffer()->getRenderTarget()->getViewport(0)->getCamera();
             // Hook up receiver texture
             Pass* targetPass = mShadowTextureCustomReceiverPass ?
                     mShadowTextureCustomReceiverPass : mShadowReceiverPass;
@@ -451,15 +449,10 @@ void SceneManager::ShadowRenderer::renderModulativeTextureShadowedQueueGroupObje
                 targetPass = betterTechnique->getPass(0);
             }
 
-            targetPass->getTextureUnitState(0)->setTexture(currentShadowTexture);
-            // Hook up projection frustum if fixed-function, but also need to
-            // disable it explicitly for program pipeline.
             TextureUnitState* texUnit = targetPass->getTextureUnitState(0);
-            texUnit->setProjectiveTexturing(!targetPass->hasVertexProgram(), cam);
             // clamp to border colour in case this is a custom material
             texUnit->setSampler(mBorderSampler);
-
-            mSceneManager->mAutoParamDataSource->setTextureProjector(cam, 0);
+            resolveShadowTexture(texUnit, si, 0);
 
             // Set lighting / blending modes
             targetPass->setSceneBlending(SBF_DEST_COLOUR, SBF_ZERO);
@@ -474,7 +467,7 @@ void SceneManager::ShadowRenderer::renderModulativeTextureShadowedQueueGroupObje
 
             ++si;
 
-        }// for each light
+        } // for each light
 
         mSceneManager->mIlluminationStage = IRS_NONE;
 
@@ -524,18 +517,12 @@ void SceneManager::ShadowRenderer::renderAdditiveTextureShadowedQueueGroupObject
         if (mSceneManager->mIlluminationStage == IRS_NONE)
         {
             // Iterate over lights, render masked
-            ShadowTextureList::iterator si, siend;
-            siend = mShadowTextures.end();
-            si = mShadowTextures.begin();
+            size_t si = 0;
 
-            for (Light* l : mSceneManager->mLightsAffectingFrustum)
+            for (Light* l : mSceneManager->_getLightsAffectingFrustum())
             {
-                if (l->getCastShadows() && si != siend)
+                if (l->getCastShadows() && si < mShadowTextures.size())
                 {
-                    // Store current shadow texture
-                    const auto& currentShadowTexture = *si;
-                    // Get camera for current shadow texture
-                    Camera *cam = currentShadowTexture->getBuffer()->getRenderTarget()->getViewport(0)->getCamera();
                     // Hook up receiver texture
                     Pass* targetPass = mShadowTextureCustomReceiverPass ?
                         mShadowTextureCustomReceiverPass : mShadowReceiverPass;
@@ -546,14 +533,11 @@ void SceneManager::ShadowRenderer::renderAdditiveTextureShadowedQueueGroupObject
                         targetPass = betterTechnique->getPass(0);
                     }
 
-                    targetPass->getTextureUnitState(0)->setTexture(currentShadowTexture);
-                    // Hook up projection frustum if fixed-function, but also need to
-                    // disable it explicitly for program pipeline.
                     TextureUnitState* texUnit = targetPass->getTextureUnitState(0);
-                    texUnit->setProjectiveTexturing(!targetPass->hasVertexProgram(), cam);
                     // clamp to border colour in case this is a custom material
                     texUnit->setSampler(mBorderSampler);
-                    mSceneManager->mAutoParamDataSource->setTextureProjector(cam, 0);
+                    resolveShadowTexture(texUnit, si, 0);
+
                     // Remove any spot fader layer
                     if (targetPass->getNumTextureUnitStates() > 1 &&
                         targetPass->getTextureUnitState(1)->getTextureName() == "spot_shadow_fade.dds")
@@ -662,6 +646,7 @@ void SceneManager::ShadowRenderer::ensureShadowTexturesCreated()
         mBorderSampler = TextureManager::getSingleton().createSampler();
         mBorderSampler->setAddressingMode(TAM_BORDER);
         mBorderSampler->setBorderColour(ColourValue::White);
+        mBorderSampler->setFiltering(FT_MIP, FO_NONE); // we do not have mips. GLES2 is particularly picky here.
     }
 
     if (mShadowTextureConfigDirty)
@@ -873,6 +858,9 @@ void SceneManager::ShadowRenderer::prepareShadowTextures(Camera* cam, Viewport*
             // This is required to pick up the correct shadow_caster_material and similar properties.
             shadowView->setMaterialScheme(vp->getMaterialScheme());
 
+            // Set the viewport visibility flags
+            shadowView->setVisibilityMask(vp->getVisibilityMask());
+
             // update shadow cam - light mapping
             ShadowCamLightMapping::iterator camLightIt = mShadowCamLightMapping.find( texCam );
             assert(camLightIt != mShadowCamLightMapping.end());
@@ -911,7 +899,7 @@ void SceneManager::ShadowRenderer::renderShadowVolumesToStencil(const Light* lig
     const Camera* camera, bool calcScissor)
 {
     // Get the shadow caster list
-    const ShadowCasterList& casters = mSceneManager->findShadowCastersForLight(light, camera);
+    const ShadowCasterList& casters = findShadowCastersForLight(light, camera);
     // Check there are some shadow casters to render
     if (casters.empty())
     {
@@ -946,8 +934,7 @@ void SceneManager::ShadowRenderer::renderShadowVolumesToStencil(const Light* lig
 
     // Do we have access to vertex programs?
     bool extrudeInSoftware = true;
-    bool finiteExtrude = !mShadowUseInfiniteFarPlane ||
-        !mDestRenderSystem->getCapabilities()->hasCapability(RSC_INFINITE_FAR_PLANE);
+    bool finiteExtrude = !mShadowUseInfiniteFarPlane;
     if (mDestRenderSystem->getCapabilities()->hasCapability(RSC_VERTEX_PROGRAM))
     {
         extrudeInSoftware = false;
@@ -1125,13 +1112,11 @@ void SceneManager::ShadowRenderer::renderShadowVolumesToStencil(const Light* lig
             renderShadowVolumeObjects(shadowRenderables, mShadowDebugPass, &lightList, flags,
                 true, false, false);
             mDestRenderSystem->setColourBlendState(disabled);
-            mDestRenderSystem->_setDepthBufferFunction(CMPF_LESS);
+            mDestRenderSystem->_setDepthBufferParams(true, false, CMPF_LESS);
         }
     }
 
-    // revert depth state
-    mDestRenderSystem->_setDepthBufferParams();
-
+    // revert stencil state
     mDestRenderSystem->setStencilCheckEnabled(false);
 
     mDestRenderSystem->unbindGpuProgram(GPT_VERTEX_PROGRAM);
@@ -1197,11 +1182,11 @@ void SceneManager::ShadowRenderer::renderShadowVolumeObjects(const ShadowCaster:
                     mDestRenderSystem->_setCullingMode(CULL_CLOCKWISE);
                     mSceneManager->mPassCullingMode = CULL_CLOCKWISE;
                     // must always fail depth check for front facing light caps
-                    mDestRenderSystem->_setDepthBufferFunction(CMPF_ALWAYS_FAIL);
+                    mDestRenderSystem->_setDepthBufferParams(true, false, CMPF_ALWAYS_FAIL);
                     mSceneManager->renderSingleObject(lightCap, pass, false, false, manualLightList);
 
                     // reset depth function
-                    mDestRenderSystem->_setDepthBufferFunction(CMPF_LESS);
+                    mDestRenderSystem->_setDepthBufferParams(true, false, CMPF_LESS);
                     // reset culling mode
                     mDestRenderSystem->_setCullingMode(CULL_NONE);
                     mSceneManager->mPassCullingMode = CULL_NONE;
@@ -1214,11 +1199,11 @@ void SceneManager::ShadowRenderer::renderShadowVolumeObjects(const ShadowCaster:
                 else
                 {
                     // must always fail depth check for front facing light caps
-                    mDestRenderSystem->_setDepthBufferFunction(CMPF_ALWAYS_FAIL);
+                    mDestRenderSystem->_setDepthBufferParams(true, false, CMPF_ALWAYS_FAIL);
                     mSceneManager->renderSingleObject(lightCap, pass, false, false, manualLightList);
 
                     // reset depth function
-                    mDestRenderSystem->_setDepthBufferFunction(CMPF_LESS);
+                    mDestRenderSystem->_setDepthBufferParams(true, false, CMPF_LESS);
                 }
             }
         }
@@ -1295,8 +1280,8 @@ void SceneManager::ShadowRenderer::setShadowTextureCasterMaterial(const Material
     }
     else
     {
-
-        mShadowTextureCustomCasterPass = mat->getBestTechnique()->getPass(0);
+        OgreAssert(!mat->getTechnique(0)->getPasses().empty(), "technique 0 has no passes");
+        mShadowTextureCustomCasterPass = mat->getTechnique(0)->getPass(0);
         if (mShadowTextureCustomCasterPass->hasVertexProgram())
         {
             // Save vertex program and params in case we have to swap them out
@@ -1594,6 +1579,8 @@ void SceneManager::ShadowRenderer::initShadowVolumeMaterials()
             mShadowCasterPlainBlackPass->setDiffuse(ColourValue::Black);
             mShadowCasterPlainBlackPass->setSelfIllumination(ColourValue::Black);
             mShadowCasterPlainBlackPass->setSpecular(ColourValue::Black);
+            // set depth bias in case this is used with PF_DEPTH
+            mShadowCasterPlainBlackPass->setDepthBias(-1, -1);
             // Override fog
             mShadowCasterPlainBlackPass->setFog(true, FOG_NONE);
             // no textures or anything else, we will bind vertex programs
@@ -1614,8 +1601,6 @@ void SceneManager::ShadowRenderer::initShadowVolumeMaterials()
             mShadowReceiverPass = matShadRec->getTechnique(0)->getPass(0);
             // Don't set lighting and blending modes here, depends on additive / modulative
             TextureUnitState* t = mShadowReceiverPass->createTextureUnitState();
-            t->setTextureAddressingMode(TextureUnitState::TAM_CLAMP);
-            t->setTextureFiltering(FT_MIP, FO_NONE); // we do not have mips. GLES2 is particularly picky here.
             t->setProjectiveTexturing(true, NULL); // will be set later, but the RTSS needs to know about this
         }
         else
@@ -1777,9 +1762,8 @@ const Pass* SceneManager::ShadowRenderer::deriveShadowCasterPass(const Pass* pas
             }
         }
 
-        // handle the case where there is no fixed pipeline support
-        if( retPass->getParent()->getParent()->getCompilationRequired() )
-            retPass->getParent()->getParent()->compile();
+        // give the RTSS a chance to generate a better technique
+        retPass->getParent()->getParent()->load();
 
         Technique* btech = retPass->getParent()->getParent()->getBestTechnique();
         if( btech )
@@ -2153,4 +2137,162 @@ const TexturePtr& SceneManager::ShadowRenderer::getShadowTexture(size_t shadowIn
 
     return mShadowTextures[shadowIndex];
 }
+
+void SceneManager::ShadowRenderer::resolveShadowTexture(TextureUnitState* tu, size_t shadowIndex, size_t shadowTexUnitIndex) const
+{
+    Camera* cam = NULL;
+    TexturePtr shadowTex;
+    if (shadowIndex < mShadowTextures.size())
+    {
+        shadowTex = mShadowTextures[shadowIndex];
+        // Hook up projection frustum
+        cam = shadowTex->getBuffer()->getRenderTarget()->getViewport(0)->getCamera();
+        // Enable projective texturing if fixed-function, but also need to
+        // disable it explicitly for program pipeline.
+        tu->setProjectiveTexturing(!tu->getParent()->hasVertexProgram(), cam);
+    }
+    else
+    {
+        // Use fallback 'null' shadow texture
+        // no projection since all uniform colour anyway
+        shadowTex = mNullShadowTexture;
+        tu->setProjectiveTexturing(false);
+    }
+    mSceneManager->mAutoParamDataSource->setTextureProjector(cam, shadowTexUnitIndex);
+    tu->_setTexturePtr(shadowTex);
+}
+
+//---------------------------------------------------------------------
+bool SceneManager::ShadowRenderer::ShadowCasterSceneQueryListener::queryResult(
+    MovableObject* object)
+{
+    if (object->getCastShadows() && object->isVisible() &&
+        mSceneMgr->isRenderQueueToBeProcessed(object->getRenderQueueGroup()) &&
+        // objects need an edge list to cast shadows (shadow volumes only)
+        ((mSceneMgr->getShadowTechnique() & SHADOWDETAILTYPE_TEXTURE) ||
+        ((mSceneMgr->getShadowTechnique() & SHADOWDETAILTYPE_STENCIL) && object->hasEdgeList())
+        )
+       )
+    {
+        if (mFarDistSquared)
+        {
+            // Check object is within the shadow far distance
+            Real dist =  object->getParentNode()->getSquaredViewDepth(mCamera);
+            Real radius = object->getBoundingRadiusScaled();
+            if (dist - (radius * radius) > mFarDistSquared)
+            {
+                // skip, beyond max range
+                return true;
+            }
+        }
+
+        // If the object is in the frustum, we can always see the shadow
+        if (mCamera->isVisible(object->getWorldBoundingBox()))
+        {
+            mCasterList->push_back(object);
+            return true;
+        }
+
+        // Otherwise, object can only be casting a shadow into our view if
+        // the light is outside the frustum (or it's a directional light,
+        // which are always outside), and the object is intersecting
+        // on of the volumes formed between the edges of the frustum and the
+        // light
+        if (!mIsLightInFrustum || mLight->getType() == Light::LT_DIRECTIONAL)
+        {
+            // Iterate over volumes
+            PlaneBoundedVolumeList::const_iterator i, iend;
+            iend = mLightClipVolumeList->end();
+            for (i = mLightClipVolumeList->begin(); i != iend; ++i)
+            {
+                if (i->intersects(object->getWorldBoundingBox()))
+                {
+                    mCasterList->push_back(object);
+                    return true;
+                }
+
+            }
+
+        }
+    }
+    return true;
+}
+//---------------------------------------------------------------------
+bool SceneManager::ShadowRenderer::ShadowCasterSceneQueryListener::queryResult(
+    SceneQuery::WorldFragment* fragment)
+{
+    // don't deal with world geometry
+    return true;
+}
+//---------------------------------------------------------------------
+const SceneManager::ShadowRenderer::ShadowCasterList&
+SceneManager::ShadowRenderer::findShadowCastersForLight(const Light* light, const Camera* camera)
+{
+    mShadowCasterList.clear();
+
+    if (light->getType() == Light::LT_DIRECTIONAL)
+    {
+        // Basic AABB query encompassing the frustum and the extrusion of it
+        AxisAlignedBox aabb;
+        const Vector3* corners = camera->getWorldSpaceCorners();
+        Vector3 min, max;
+        Vector3 extrude = light->getDerivedDirection() * -mShadowDirLightExtrudeDist;
+        // do first corner
+        min = max = corners[0];
+        min.makeFloor(corners[0] + extrude);
+        max.makeCeil(corners[0] + extrude);
+        for (size_t c = 1; c < 8; ++c)
+        {
+            min.makeFloor(corners[c]);
+            max.makeCeil(corners[c]);
+            min.makeFloor(corners[c] + extrude);
+            max.makeCeil(corners[c] + extrude);
+        }
+        aabb.setExtents(min, max);
+
+        if (!mShadowCasterAABBQuery)
+            mShadowCasterAABBQuery.reset(mSceneManager->createAABBQuery(aabb));
+        else
+            mShadowCasterAABBQuery->setBox(aabb);
+        // Execute, use callback
+        mShadowCasterQueryListener->prepare(false,
+            &(light->_getFrustumClipVolumes(camera)),
+            light, camera, &mShadowCasterList, light->getShadowFarDistanceSquared());
+        mShadowCasterAABBQuery->execute(mShadowCasterQueryListener.get());
+
+
+    }
+    else
+    {
+        Sphere s(light->getDerivedPosition(), light->getAttenuationRange());
+        // eliminate early if camera cannot see light sphere
+        if (camera->isVisible(s))
+        {
+            if (!mShadowCasterSphereQuery)
+                mShadowCasterSphereQuery.reset(mSceneManager->createSphereQuery(s));
+            else
+                mShadowCasterSphereQuery->setSphere(s);
+
+            // Determine if light is inside or outside the frustum
+            bool lightInFrustum = camera->isVisible(light->getDerivedPosition());
+            const PlaneBoundedVolumeList* volList = 0;
+            if (!lightInFrustum)
+            {
+                // Only worth building an external volume list if
+                // light is outside the frustum
+                volList = &(light->_getFrustumClipVolumes(camera));
+            }
+
+            // Execute, use callback
+            mShadowCasterQueryListener->prepare(lightInFrustum,
+                volList, light, camera, &mShadowCasterList, light->getShadowFarDistanceSquared());
+            mShadowCasterSphereQuery->execute(mShadowCasterQueryListener.get());
+
+        }
+
+    }
+
+
+    return mShadowCasterList;
+}
 }
