@@ -30,7 +30,6 @@ THE SOFTWARE.
 #include "OgreEntity.h"
 #include "OgreEdgeListBuilder.h"
 #include "OgreLodStrategy.h"
-#include "OgreIteratorWrappers.h"
 #include "OgreSubEntity.h"
 
 namespace Ogre {
@@ -910,11 +909,6 @@ namespace Ogre {
         return mLodBucketList[mCurrentLod]->getEdgeList();
     }
     //--------------------------------------------------------------------------
-    bool StaticGeometry::Region::hasEdgeList(void)
-    {
-        return getEdgeList() != 0;
-    }
-    //--------------------------------------------------------------------------
     void StaticGeometry::Region::dump(std::ofstream& of) const
     {
         of << "Region " << mRegionID << std::endl;
