@@ -4,7 +4,7 @@ This source file is part of OGRE
     (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -26,36 +26,31 @@ THE SOFTWARE.
 -----------------------------------------------------------------------------
 */
 #include "OgreStableHeaders.h"
-#include "OgreWireBoundingBox.h"
-
-#include "OgreSimpleRenderable.h"
-#include "OgreHardwareBufferManager.h"
-#include "OgreCamera.h"
 
 namespace Ogre {
     #define POSITION_BINDING 0
 
-	WireBoundingBox::WireBoundingBox()
-	: SimpleRenderable()
-	{
-		_initWireBoundingBox();
-	}
+    WireBoundingBox::WireBoundingBox()
+    : SimpleRenderable()
+    {
+        _initWireBoundingBox();
+    }
 
-	WireBoundingBox::WireBoundingBox(const String& name) 
-	: SimpleRenderable(name)
-	{
-		_initWireBoundingBox();
-	}
+    WireBoundingBox::WireBoundingBox(const String& name) 
+    : SimpleRenderable(name)
+    {
+        _initWireBoundingBox();
+    }
 
-	void WireBoundingBox::_initWireBoundingBox()
+    void WireBoundingBox::_initWireBoundingBox()
     {
         mRenderOp.vertexData = OGRE_NEW VertexData();
 
         mRenderOp.indexData = 0;
-		mRenderOp.vertexData->vertexCount = 24; 
-		mRenderOp.vertexData->vertexStart = 0; 
-		mRenderOp.operationType = RenderOperation::OT_LINE_LIST; 
-		mRenderOp.useIndexes = false; 
+        mRenderOp.vertexData->vertexCount = 24; 
+        mRenderOp.vertexData->vertexStart = 0; 
+        mRenderOp.operationType = RenderOperation::OT_LINE_LIST; 
+        mRenderOp.useIndexes = false; 
         mRenderOp.useGlobalInstancingVertexBufferIsAvailable = false;
 
         VertexDeclaration* decl = mRenderOp.vertexData->vertexDeclaration;
@@ -74,159 +69,149 @@ namespace Ogre {
         bind->setBinding(POSITION_BINDING, vbuf);
 
         // set basic white material
-        this->setMaterial("BaseWhiteNoLighting");
-
-
-        
-	}
-	
-	WireBoundingBox::~WireBoundingBox() 
+        mMaterial = MaterialManager::getSingleton().getDefaultMaterial(false);
+        mMaterial->load();
+    }
+    
+    WireBoundingBox::~WireBoundingBox() 
     {
         OGRE_DELETE mRenderOp.vertexData;
-	}
+    }
 
-	void WireBoundingBox::setupBoundingBox(const AxisAlignedBox& aabb) 
+    void WireBoundingBox::setupBoundingBox(const AxisAlignedBox& aabb) 
     {
-		// init the vertices to the aabb
-		setupBoundingBoxVertices(aabb);
+        // init the vertices to the aabb
+        setupBoundingBoxVertices(aabb);
 
-    	// setup the bounding box of this SimpleRenderable
-		setBoundingBox(aabb);
+        // setup the bounding box of this SimpleRenderable
+        setBoundingBox(aabb);
 
-	}
+    }
 
-	// Override this method to prevent parent transforms (rotation,translation,scale)
+    // Override this method to prevent parent transforms (rotation,translation,scale)
     void WireBoundingBox::getWorldTransforms( Matrix4* xform ) const
     {
-		// return identity matrix to prevent parent transforms
+        // return identity matrix to prevent parent transforms
         *xform = Matrix4::IDENTITY;
     }
     //-----------------------------------------------------------------------
-	void WireBoundingBox::setupBoundingBoxVertices(const AxisAlignedBox& aab) {
+    void WireBoundingBox::setupBoundingBoxVertices(const AxisAlignedBox& aab) {
 
-		Vector3 vmax = aab.getMaximum();
-		Vector3 vmin = aab.getMinimum();
+        Vector3 vmax = aab.getMaximum();
+        Vector3 vmin = aab.getMinimum();
 
         Real sqLen = std::max(vmax.squaredLength(), vmin.squaredLength());
         mRadius = Math::Sqrt(sqLen);
-		
+        
 
-		
-		
-		Real maxx = vmax.x;
-		Real maxy = vmax.y;
-		Real maxz = vmax.z;
-		
-		Real minx = vmin.x;
-		Real miny = vmin.y;
-		Real minz = vmin.z;
-		
-		// fill in the Vertex buffer: 12 lines with 2 endpoints each make up a box
+        
+        
+        Real maxx = vmax.x;
+        Real maxy = vmax.y;
+        Real maxz = vmax.z;
+        
+        Real minx = vmin.x;
+        Real miny = vmin.y;
+        Real minz = vmin.z;
+        
+        // fill in the Vertex buffer: 12 lines with 2 endpoints each make up a box
         HardwareVertexBufferSharedPtr vbuf =
             mRenderOp.vertexData->vertexBufferBinding->getBuffer(POSITION_BINDING);     
 
-        float* pPos = static_cast<float*>(
-            vbuf->lock(HardwareBuffer::HBL_DISCARD));
+        HardwareBufferLockGuard vbufLock(vbuf, HardwareBuffer::HBL_DISCARD);
+        float* pPos = static_cast<float*>(vbufLock.pData);
 
-		// line 0
+        // line 0
         *pPos++ = minx;
         *pPos++ = miny;
         *pPos++ = minz;
         *pPos++ = maxx;
         *pPos++ = miny;
         *pPos++ = minz;
-		// line 1
+        // line 1
         *pPos++ = minx;
         *pPos++ = miny;
         *pPos++ = minz;
         *pPos++ = minx;
         *pPos++ = miny;
         *pPos++ = maxz;
-		// line 2
+        // line 2
         *pPos++ = minx;
         *pPos++ = miny;
         *pPos++ = minz;
         *pPos++ = minx;
         *pPos++ = maxy;
         *pPos++ = minz;
-		// line 3
+        // line 3
         *pPos++ = minx;
         *pPos++ = maxy;
         *pPos++ = minz;
         *pPos++ = minx;
         *pPos++ = maxy;
         *pPos++ = maxz;
-		// line 4
+        // line 4
         *pPos++ = minx;
         *pPos++ = maxy;
         *pPos++ = minz;
         *pPos++ = maxx;
         *pPos++ = maxy;
         *pPos++ = minz;
-		// line 5
+        // line 5
         *pPos++ = maxx;
         *pPos++ = miny;
         *pPos++ = minz;
         *pPos++ = maxx;
         *pPos++ = miny;
         *pPos++ = maxz;
-		// line 6
+        // line 6
         *pPos++ = maxx;
         *pPos++ = miny;
         *pPos++ = minz;
         *pPos++ = maxx;
         *pPos++ = maxy;
         *pPos++ = minz;
-		// line 7
+        // line 7
         *pPos++ = minx;
         *pPos++ = maxy;
         *pPos++ = maxz;
         *pPos++ = maxx;
         *pPos++ = maxy;
         *pPos++ = maxz;
-		// line 8
+        // line 8
         *pPos++ = minx;
         *pPos++ = maxy;
         *pPos++ = maxz;
         *pPos++ = minx;
         *pPos++ = miny;
         *pPos++ = maxz;
-		// line 9
+        // line 9
         *pPos++ = maxx;
         *pPos++ = maxy;
         *pPos++ = minz;
         *pPos++ = maxx;
         *pPos++ = maxy;
         *pPos++ = maxz;
-		// line 10
+        // line 10
         *pPos++ = maxx;
         *pPos++ = miny;
         *pPos++ = maxz;
         *pPos++ = maxx;
         *pPos++ = maxy;
         *pPos++ = maxz;
-		// line 11
+        // line 11
         *pPos++ = minx;
         *pPos++ = miny;
         *pPos++ = maxz;
         *pPos++ = maxx;
         *pPos++ = miny;
         *pPos++ = maxz;
-        vbuf->unlock();
-	}
+    }
 
     //-----------------------------------------------------------------------
-	Real WireBoundingBox::getSquaredViewDepth(const Camera* cam) const
-	{
-		Vector3 min, max, mid, dist;
-		min = mBox.getMinimum();
-		max = mBox.getMaximum();
-		mid = ((max - min) * 0.5) + min;
-		dist = cam->getDerivedPosition() - mid;
-
-
-		return dist.squaredLength();
-	}
+    Real WireBoundingBox::getSquaredViewDepth(const Camera* cam) const
+    {
+        return (cam->getDerivedPosition() - mBox.getCenter()).squaredLength();
+    }
 
 
 
