@@ -28,16 +28,37 @@ THE SOFTWARE.
 
 #include "OgreBspSceneManagerPlugin.h"
 #include "OgreRoot.h"
+#include "OgreCodec.h"
+#include "OgreQuake3ShaderManager.h"
 
 namespace Ogre 
 {
+namespace {
+    struct BspSceneCodec : public Codec
+    {
+        String magicNumberToFileExt(const char* magicNumberPtr, size_t maxbytes) const { return ""; }
+        String getType() const override { return "bsp"; }
+        void decode(const DataStreamPtr& stream, const Any& output) const override
+        {
+            auto group = ResourceGroupManager::getSingleton().getWorldResourceGroupName();
+            auto rootNode = any_cast<SceneNode*>(output);
+            BspSceneManager* mgr = dynamic_cast<BspSceneManager*>(rootNode->getCreator());
+
+            OgreAssert(mgr, "only loading into a BspSceneManager supported");
+
+            mgr->setLevel(BspLevelPtr()); // clear
+
+            auto bspLevel = std::make_shared<BspLevel>(nullptr, "bsplevel", 0, group, false, nullptr);
+            bspLevel->load(stream);
+
+            mgr->setLevel(bspLevel);
+        }
+    };
+}
     const String sPluginName = "BSP Scene Manager";
     //---------------------------------------------------------------------
-    BspSceneManagerPlugin::BspSceneManagerPlugin()
-        :mBspFactory(0), mBspSceneLoader(0)
-    {
-
-    }
+    BspSceneManagerPlugin::BspSceneManagerPlugin() : mBspFactory(0) {}
+    BspSceneManagerPlugin::~BspSceneManagerPlugin() {}
     //---------------------------------------------------------------------
     const String& BspSceneManagerPlugin::getName() const
     {
@@ -55,8 +76,12 @@ namespace Ogre
     {
         // Register (factory not dependent on rsys resources)
         Root::getSingleton().addSceneManagerFactory(mBspFactory);
-        // Create resource manager (registers itself)
-        mBspSceneLoader = new BspSceneLoader();
+
+        // Also create related shader manager (singleton managed)
+        mShaderMgr = OGRE_NEW Quake3ShaderManager();
+
+        mCodec.reset(new BspSceneCodec());
+        Codec::registerCodec(mCodec.get());
     }
     //---------------------------------------------------------------------
     void BspSceneManagerPlugin::shutdown()
@@ -64,10 +89,10 @@ namespace Ogre
         // Unregister SM factory
         Root::getSingleton().removeSceneManagerFactory(mBspFactory);
 
-        // delete resource manager, will unregister itself
-        OGRE_DELETE mBspSceneLoader;
-        mBspSceneLoader = 0;
+        Codec::unregisterCodec(mCodec.get());
+        mCodec.reset();
 
+        OGRE_DELETE mShaderMgr;
     }
     //---------------------------------------------------------------------
     void BspSceneManagerPlugin::uninstall()
