@@ -47,15 +47,10 @@ namespace Ogre {
         if (checkMovables)
         {
             // Check membership of attached objects
-            ObjectMap::const_iterator it, itend;
-            itend = mObjectsByName.end();
-            for (it = mObjectsByName.begin(); it != itend; ++it)
+            for (auto mov : getAttachedObjects())
             {
-                MovableObject* mov = *it;
-
-                static_cast<BspSceneManager*>(mCreator)->_notifyObjectMoved(
+                static_cast<BspSceneManager*>(getCreator())->_notifyObjectMoved(
                     mov, this->_getDerivedPosition());
-
             }
         }
 
@@ -64,7 +59,7 @@ namespace Ogre {
     MovableObject* BspSceneNode::detachObject(unsigned short index)
     {
         MovableObject* ret = SceneNode::detachObject(index);
-        static_cast<BspSceneManager*>(mCreator)->_notifyObjectDetached(ret);
+        static_cast<BspSceneManager*>(getCreator())->_notifyObjectDetached(ret);
         return ret;
         
     }
@@ -72,41 +67,36 @@ namespace Ogre {
     MovableObject* BspSceneNode::detachObject(const String& name)
     {
         MovableObject* ret = SceneNode::detachObject(name);
-        static_cast<BspSceneManager*>(mCreator)->_notifyObjectDetached(ret);
+        static_cast<BspSceneManager*>(getCreator())->_notifyObjectDetached(ret);
         return ret;
     }
     //-------------------------------------------------------------------------
     void BspSceneNode::detachAllObjects(void)
     {
-        ObjectMap::const_iterator i, iend;
-        iend = mObjectsByName.end();
-        for (i = mObjectsByName.begin(); i != iend; ++i)
+        for (auto o : getAttachedObjects())
         {
-            static_cast<BspSceneManager*>(mCreator)
-                ->_notifyObjectDetached(*i);
+            static_cast<BspSceneManager*>(getCreator())
+                ->_notifyObjectDetached(o);
         }
         SceneNode::detachAllObjects();
     }
     //-------------------------------------------------------------------------
     void BspSceneNode::setInSceneGraph(bool inGraph)
     {
-        if (mIsInSceneGraph != inGraph)
+        if (isInSceneGraph() != inGraph)
         {
-            ObjectMap::const_iterator i, iend;
-            iend = mObjectsByName.end();
-            for (i = mObjectsByName.begin(); i != iend; ++i)
+            for (auto o : getAttachedObjects())
             {
                 if (!inGraph)
                 {
                     // Equivalent to detaching
-                    static_cast<BspSceneManager*>(mCreator)
-                        ->_notifyObjectDetached(*i);
+                    static_cast<BspSceneManager*>(getCreator())->_notifyObjectDetached(o);
                 }
                 else
                 {
                     // move deals with re-adding
-                    static_cast<BspSceneManager*>(mCreator)->_notifyObjectMoved(
-                        *i, this->_getDerivedPosition());
+                    static_cast<BspSceneManager*>(getCreator())
+                        ->_notifyObjectMoved(o, this->_getDerivedPosition());
                 }
             }
         }
