@@ -136,6 +136,7 @@ namespace Ogre {
 				args.push_back("dcls");
 			}
 		}
+		args.push_back("-DOGRE_CG");
 		// Now split args into that god-awful char** that Cg insists on
 		freeCgArgs();
 		mCgArguments = OGRE_ALLOC_T(char*, args.size() + 1, MEMCATEGORY_RESOURCE);
@@ -192,7 +193,7 @@ namespace Ogre {
 		if (mDelegate)
 		{
 			mDelegate->setSource(mProgramString);
-			mDelegate->setAdjacencyInfoRequired(isAdjacencyInfoRequired());
+
 			if (mSelectedCgProfile == CG_PROFILE_GLSLG)
 			{
 				// need to set input and output operations
@@ -316,7 +317,7 @@ namespace Ogre {
 		}
 		buildArgs();
 		// deal with includes
-		String sourceToUse = _resolveIncludes(mSource, this, mFilename);
+		String sourceToUse = _resolveIncludes(mSource, this, mFilename, true);
 
 		cgProgram = cgCreateProgram(mCgContext, CG_SOURCE, sourceToUse.c_str(),
 			mSelectedCgProfile, mEntryPoint.c_str(), const_cast<const char**>(mCgArguments));
@@ -486,8 +487,6 @@ namespace Ogre {
 					mType,
 					mSelectedProfile);
 			}
-			// Shader params need to be forwarded to low level implementation
-			mAssemblerProgram->setAdjacencyInfoRequired(isAdjacencyInfoRequired());
 		}
 	}
 	//-----------------------------------------------------------------------
@@ -801,7 +800,7 @@ namespace Ogre {
 			return HighLevelGpuProgram::isVertexTextureFetchRequired();
 	}
 	//-----------------------------------------------------------------------
-	GpuProgramParametersSharedPtr CgProgram::getDefaultParameters(void)
+	const GpuProgramParametersPtr& CgProgram::getDefaultParameters(void)
 	{
 		loadHighLevelSafe();
 		if (mDelegate)
@@ -902,7 +901,6 @@ namespace Ogre {
 		GpuConstantDefinitionMap::const_iterator iterE = mParametersMap.end();
 		for (; iter != iterE ; iter++)
 		{
-			const String & paramName = iter->first;
 			GpuConstantDefinition def = iter->second;
 
 			mConstantDefs->map.emplace(iter->first, iter->second);
@@ -922,9 +920,6 @@ namespace Ogre {
 						GpuLogicalIndexUse(def.physicalIndex, def.arraySize * def.elementSize, GPV_GLOBAL));
 				mIntLogicalToPhysical->bufferSize += def.arraySize * def.elementSize;
 			}
-
-			// Deal with array indexing
-			mConstantDefs->generateConstantDefinitionArrayEntries(paramName, def);
 		}
 	}
 	//---------------------------------------------------------------------
@@ -1212,6 +1207,7 @@ namespace Ogre {
 		ManualResourceLoader* loader, CGcontext context)
 		: HighLevelGpuProgram(creator, name, handle, group, isManual, loader),
 		mCgContext(context),
+        mEntryPoint("main"),
 		mSelectedCgProfile(CG_PROFILE_UNKNOWN), mCgArguments(0), mParametersMapSizeAsBuffer(0)
 	{
 		if (createParamDictionary("CgProgram"))
