@@ -4,7 +4,7 @@ This source file is part of OGRE
 (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -42,8 +42,8 @@ class O_IStream: public Imf::IStream
 {
 public:
 
-    O_IStream(MemoryDataStream& stream, const char fileName[]):
-        IStream (fileName), _stream(stream) {}
+    O_IStream(MemoryDataStream& stream, const char file_name[]):
+        IStream (file_name), _stream(stream) {}
 
     virtual bool    read (char c[], int n);
     virtual Imf::Int64   tellg ();
