@@ -4,7 +4,7 @@ This source file is part of OGRE
 (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2012 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -32,12 +32,11 @@ begin                : Mon Sep 30 2002
 copyright            : (C) 2002 by Jon Anderson
 email                : janders@users.sf.net
 
-Enhancements 2003 - 2004 (C) The OGRE Team
-
 ***************************************************************************/
 
-#include <OgreOctree.h>
-#include <OgreOctreeNode.h>
+#include "OgreOctree.h"
+#include "OgreOctreeNode.h"
+#include "OgreWireBoundingBox.h"
 
 namespace Ogre
 {
@@ -46,9 +45,9 @@ namespace Ogre
 */
 bool Octree::_isTwiceSize( const AxisAlignedBox &box ) const
 {
-	// infinite boxes never fit in a child - always root node
-	if (box.isInfinite())
-		return false;
+    // infinite boxes never fit in a child - always root node
+    if (box.isInfinite())
+        return false;
 
     Vector3 halfMBoxSize = mBox.getHalfSize();
     Vector3 boxSize = box.getSize();
