@@ -61,7 +61,7 @@ OctreeNode::~OctreeNode()
 {}
 void OctreeNode::_removeNodeAndChildren( )
 {
-    static_cast< OctreeSceneManager * > ( mCreator ) -> _removeOctreeNode( this ); 
+    static_cast< OctreeSceneManager * > ( getCreator() ) -> _removeOctreeNode( this );
     //remove all the children nodes as well from the octree.
     ChildNodeMap::iterator it = mChildren.begin();
     while( it != mChildren.end() )
@@ -111,28 +111,20 @@ void OctreeNode::_updateBounds( void )
     mLocalAABB.setNull();
 
     // Update bounds from own attached objects
-    ObjectMap::iterator i = mObjectsByName.begin();
-    AxisAlignedBox bx;
-
-    while ( i != mObjectsByName.end() )
+    for ( auto o : getAttachedObjects() )
     {
-
         // Get local bounds of object
-        bx = (*i)->getBoundingBox();
-
-        mLocalAABB.merge( bx );
-
-        mWorldAABB.merge( (*i)->getWorldBoundingBox(true) );
-        ++i;
+        mLocalAABB.merge( o->getBoundingBox() );
+        mWorldAABB.merge( o->getWorldBoundingBox(true) );
     }
 
 
     //update the OctreeSceneManager that things might have moved.
     // if it hasn't been added to the octree, add it, and if has moved
     // enough to leave it's current node, we'll update it.
-    if ( ! mWorldAABB.isNull() && mIsInSceneGraph )
+    if ( !_getWorldAABB().isNull() && isInSceneGraph() )
     {
-        static_cast < OctreeSceneManager * > ( mCreator ) -> _updateOctreeNode( this );
+        static_cast < OctreeSceneManager * > ( getCreator() ) -> _updateOctreeNode( this );
     }
 
 }
@@ -142,13 +134,13 @@ void OctreeNode::_updateBounds( void )
 bool OctreeNode::_isIn( AxisAlignedBox &box )
 {
     // Always fail if not in the scene graph or box is null
-    if (!mIsInSceneGraph || box.isNull()) return false;
+    if (!isInSceneGraph() || box.isNull()) return false;
 
     // Always succeed if AABB is infinite
     if (box.isInfinite())
         return true;
 
-    Vector3 center = mWorldAABB.getMaximum().midPoint( mWorldAABB.getMinimum() );
+    Vector3 center = _getWorldAABB().getMaximum().midPoint( _getWorldAABB().getMinimum() );
 
     Vector3 bmin = box.getMinimum();
     Vector3 bmax = box.getMaximum();
@@ -162,7 +154,7 @@ bool OctreeNode::_isIn( AxisAlignedBox &box )
     // end up in parent due to cascade but when updating need to deal with
     // bbox growing too large for this child
     Vector3 octreeSize = bmax - bmin;
-    Vector3 nodeSize = mWorldAABB.getMaximum() - mWorldAABB.getMinimum();
+    Vector3 nodeSize = _getWorldAABB().getMaximum() - _getWorldAABB().getMinimum();
     return nodeSize < octreeSize;
 
 }
@@ -171,17 +163,10 @@ bool OctreeNode::_isIn( AxisAlignedBox &box )
 void OctreeNode::_addToRenderQueue( Camera* cam, RenderQueue *queue, 
     bool onlyShadowCasters, VisibleObjectsBoundsInfo* visibleBounds )
 {
-    ObjectMap::iterator mit = mObjectsByName.begin();
-
-    while ( mit != mObjectsByName.end() )
+    for ( auto mo : getAttachedObjects() )
     {
-        MovableObject * mo = *mit;
-        
         queue->processVisibleObject(mo, cam, onlyShadowCasters, visibleBounds);
-
-        ++mit;
     }
-
 }
 
 
