@@ -537,14 +537,9 @@ namespace Ogre
                     // add the node to the render queue
                     pczsn -> _addToRenderQueue(camera, queue, onlyShadowCasters, visibleBounds );
                     // if we are displaying nodes, add the node renderable to the queue
-                    if ( displayNodes )
+                    if (mPCZSM->getDebugDrawer())
                     {
-                        queue -> addRenderable( pczsn->getDebugRenderable() );
-                    }
-                    // if the scene manager or the node wants the bounding box shown, add it to the queue
-                    if (pczsn->getShowBoundingBox() || showBoundingBoxes)
-                    {
-                        pczsn->_addBoundingBoxToQueue(queue);
+                        mPCZSM->getDebugDrawer()->drawSceneNode(pczsn);
                     }
                     // flag the node as being visible this frame
                     pczsn->setLastVisibleFrame(mLastVisibleFrame);
@@ -571,14 +566,9 @@ namespace Ogre
                     // add the node to the render queue
                     pczsn->_addToRenderQueue(camera, queue, onlyShadowCasters, visibleBounds );
                     // if we are displaying nodes, add the node renderable to the queue
-                    if ( displayNodes )
+                    if (mPCZSM->getDebugDrawer())
                     {
-                        queue -> addRenderable( pczsn->getDebugRenderable() );
-                    }
-                    // if the scene manager or the node wants the bounding box shown, add it to the queue
-                    if (pczsn->getShowBoundingBox() || showBoundingBoxes)
-                    {
-                        pczsn->_addBoundingBoxToQueue(queue);
+                        mPCZSM->getDebugDrawer()->drawSceneNode(pczsn);
                     }
                     // flag the node as being visible this frame
                     pczsn->setLastVisibleFrame(mLastVisibleFrame);
