@@ -145,23 +145,6 @@ namespace Ogre {
         float mGreenAdj;
         float mBlueAdj;
         float mAlphaAdj;
-
-        /** Internal method for adjusting while clamping to [0,1] */
-        inline void applyAdjustWithClamp(float* pComponent, float adjust)
-        {
-            *pComponent += adjust;
-            // Limit to 0
-            if (*pComponent < 0.0)
-            {
-                *pComponent = 0.0f;
-            }
-            // Limit to 1
-            else if (*pComponent > 1.0)
-            {
-                *pComponent = 1.0f;
-            }
-        }
-
     };
 
     /** @} */
