@@ -4,7 +4,7 @@ This source file is part of OGRE
 (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -69,25 +69,14 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void ColourFaderAffector::_affectParticles(ParticleSystem* pSystem, Real timeElapsed)
     {
-        ParticleIterator pi = pSystem->_getIterator();
-        Particle *p;
-        float dr, dg, db, da;
-
         // Scale adjustments by time
-        dr = mRedAdj * timeElapsed;
-        dg = mGreenAdj * timeElapsed;
-        db = mBlueAdj * timeElapsed;
-        da = mAlphaAdj * timeElapsed;
+        auto dc = ColourValue(mRedAdj, mGreenAdj, mBlueAdj, mAlphaAdj) * timeElapsed;
 
-        while (!pi.end())
+        for (auto p : pSystem->_getActiveParticles())
         {
-            p = pi.getNext();
-            applyAdjustWithClamp(&p->colour.r, dr);
-            applyAdjustWithClamp(&p->colour.g, dg);
-            applyAdjustWithClamp(&p->colour.b, db);
-            applyAdjustWithClamp(&p->colour.a, da);
+            p->mColour += dc;
+            p->mColour.saturate();
         }
-
     }
     //-----------------------------------------------------------------------
     void ColourFaderAffector::setAdjust(float red, float green, float blue, float alpha)
