@@ -100,43 +100,15 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void ColourFaderAffector2::_affectParticles(ParticleSystem* pSystem, Real timeElapsed)
     {
-        ParticleIterator pi = pSystem->_getIterator();
-        Particle *p;
-        float dr1, dg1, db1, da1;
-        float dr2, dg2, db2, da2;
-
         // Scale adjustments by time
-        dr1 = mRedAdj1   * timeElapsed;
-        dg1 = mGreenAdj1 * timeElapsed;
-        db1 = mBlueAdj1  * timeElapsed;
-        da1 = mAlphaAdj1 * timeElapsed;
+        auto dc1 = ColourValue(mRedAdj1, mGreenAdj1, mBlueAdj1, mAlphaAdj1) * timeElapsed;
+        auto dc2 = ColourValue(mRedAdj2, mGreenAdj2, mBlueAdj2, mAlphaAdj2) * timeElapsed;
 
-        // Scale adjustments by time
-        dr2 = mRedAdj2   * timeElapsed;
-        dg2 = mGreenAdj2 * timeElapsed;
-        db2 = mBlueAdj2  * timeElapsed;
-        da2 = mAlphaAdj2 * timeElapsed;
-
-        while (!pi.end())
+        for (auto p : pSystem->_getActiveParticles())
         {
-            p = pi.getNext();
-
-            if( p->mTimeToLive > StateChangeVal )
-            {
-                applyAdjustWithClamp(&p->mColour.r, dr1);
-                applyAdjustWithClamp(&p->mColour.g, dg1);
-                applyAdjustWithClamp(&p->mColour.b, db1);
-                applyAdjustWithClamp(&p->mColour.a, da1);
-            }
-            else
-            {
-                applyAdjustWithClamp(&p->mColour.r, dr2);
-                applyAdjustWithClamp(&p->mColour.g, dg2);
-                applyAdjustWithClamp(&p->mColour.b, db2);
-                applyAdjustWithClamp(&p->mColour.a, da2);
-            }
+            p->mColour += p->mTimeToLive > StateChangeVal ? dc1 : dc2;
+            p->mColour.saturate();
         }
-
     }
     //-----------------------------------------------------------------------
     void ColourFaderAffector2::setAdjust1(float red, float green, float blue, float alpha)
