@@ -4,7 +4,7 @@ This source file is part of OGRE
     (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -33,19 +33,22 @@ THE SOFTWARE.
 
 namespace Ogre {
 
-	ParticleFXPlugin* plugin;
+    static ParticleFXPlugin* plugin;
+    extern "C" void _OgreParticleFXExport dllStartPlugin(void);
+    extern "C" void _OgreParticleFXExport dllStopPlugin(void);
+
     //-----------------------------------------------------------------------
-    extern "C" void _OgreParticleFXExport dllStartPlugin(void) throw()
+    extern "C" void _OgreParticleFXExport dllStartPlugin(void)
     {
-		plugin = OGRE_NEW ParticleFXPlugin();
-		Root::getSingleton().installPlugin(plugin);
+        plugin = OGRE_NEW ParticleFXPlugin();
+        Root::getSingleton().installPlugin(plugin);
     }
 
     //-----------------------------------------------------------------------
     extern "C" void _OgreParticleFXExport dllStopPlugin(void)
     {
-		Root::getSingleton().uninstallPlugin(plugin);
-		OGRE_DELETE plugin;
+        Root::getSingleton().uninstallPlugin(plugin);
+        OGRE_DELETE plugin;
 
     }
 
