@@ -4,7 +4,7 @@ This source file is part of OGRE
 (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -33,23 +33,22 @@ THE SOFTWARE.
 
 namespace Ogre
 {
-	/** Factory class for D3D11 HLSL programs. */
-	class D3D11HLSLProgramFactory : public HighLevelGpuProgramFactory
-	{
-	protected:
-		static String sLanguageName;
-		D3D11Device & mDevice;
-	public:
-		D3D11HLSLProgramFactory(D3D11Device & device);
-		~D3D11HLSLProgramFactory();
-		/// Get the name of the language this factory creates programs for
-		const String& getLanguage(void) const;
-		HighLevelGpuProgram* create(ResourceManager* creator, 
-			const String& name, ResourceHandle handle,
-			const String& group, bool isManual, ManualResourceLoader* loader);
-		void destroy(HighLevelGpuProgram* prog);
+    /** Factory class for D3D11 HLSL programs. */
+    class _OgreD3D11Export D3D11HLSLProgramFactory : public HighLevelGpuProgramFactory
+    {
+    protected:
+        static String sLanguageName;
+        D3D11Device & mDevice;
+    public:
+        D3D11HLSLProgramFactory(D3D11Device & device);
+        ~D3D11HLSLProgramFactory();
+        /// Get the name of the language this factory creates programs for
+        const String& getLanguage(void) const;
+        GpuProgram* create(ResourceManager* creator,
+            const String& name, ResourceHandle handle,
+            const String& group, bool isManual, ManualResourceLoader* loader);
 
-	};
+    };
 }
 
 #endif
