@@ -42,6 +42,16 @@ THE SOFTWARE.
 
 #define OGRE_EXCEPT_EX(code, num, desc, src) throw Ogre::D3D11RenderingAPIException(num, desc, src, __FILE__, __LINE__)
 
+#define OGRE_CHECK_DX_ERROR(dxcall) \
+{ \
+    HRESULT hr = dxcall; \
+    if (FAILED(hr) || mDevice.isError()) \
+    { \
+        String desc = mDevice.getErrorDescription(hr); \
+        throw Ogre::D3D11RenderingAPIException(hr, desc, __FUNCTION__, __FILE__, __LINE__); \
+    } \
+}
+
 // some D3D commonly used macros
 #define SAFE_DELETE(p)       { if(p) { delete (p);     (p)=NULL; } }
 #define SAFE_DELETE_ARRAY(p) { if(p) { delete[] (p);   (p)=NULL; } }
@@ -141,8 +151,8 @@ namespace Ogre
         int getHResult() const { return hresult; }
 
         const String& getFullDescription(void) const {
-            StringStream ss(RenderingAPIException::getFullDescription());
-            ss << " HRESULT=" << hresult;
+            StringStream ss;
+            ss << RenderingAPIException::getFullDescription() << " HRESULT=0x" << std::hex << hresult;
             fullDesc = ss.str();
             return fullDesc;
         }
