@@ -60,6 +60,7 @@ namespace Ogre
         , protected D3D11DeviceResourceManager
     {
     private:
+	    friend class D3D11Sampler;
         Ogre::String mDriverName;    // it`s hint rather than hard requirement, could be ignored if empty or device removed
         D3D_DRIVER_TYPE mDriverType; // should be XXX_HARDWARE, XXX_SOFTWARE or XXX_WARP, never XXX_UNKNOWN or XXX_NULL
         D3D_FEATURE_LEVEL mFeatureLevel;
@@ -86,9 +87,6 @@ namespace Ogre
 
         void freeDevice(void);
         void createDevice();
-
-        /// return anisotropy level
-        DWORD _getCurrentAnisotropy(size_t unit);
         
         D3D11HardwareBufferManager* mHardwareBufferManager;
         GpuProgramManager* mGpuProgramManager;
@@ -111,10 +109,6 @@ namespace Ogre
         bool checkVertexTextureFormats(void);
         void detachRenderTargetImpl(const String& name);
 
-        CompareFunction mSceneAlphaRejectFunc; // should be merged with - mBlendDesc
-        unsigned char mSceneAlphaRejectValue; // should be merged with - mBlendDesc
-        bool mSceneAlphaToCoverage;
-
         D3D11_BLEND_DESC    mBlendDesc;
         bool                mBlendDescChanged;
 
@@ -127,11 +121,6 @@ namespace Ogre
 
         PolygonMode mPolygonMode;
 
-        FilterOptions FilterMinification[OGRE_MAX_TEXTURE_LAYERS];
-        FilterOptions FilterMagnification[OGRE_MAX_TEXTURE_LAYERS];
-        FilterOptions FilterMips[OGRE_MAX_TEXTURE_LAYERS];
-        bool          CompareEnabled;
-
         D3D11_RECT mScissorRect;
         
         bool mReadBackAsTexture;
@@ -172,7 +161,7 @@ namespace Ogre
 
             /// texture 
             ID3D11ShaderResourceView  *pTex;
-            D3D11_SAMPLER_DESC  samplerDesc;
+            ID3D11SamplerState    *pSampler;
             bool used;
         } mTexStageDesc[OGRE_MAX_TEXTURE_LAYERS];
 
@@ -255,13 +244,22 @@ namespace Ogre
 
         void getCustomAttribute(const String& name, void* pData);
         // Low-level overridden members
+        /**
+         Specific options:
+
+        | Key |  Default | Description |
+        |-----|---------------|---------|
+        | Min Requested Feature Levels | 9.1 | Min D3D_FEATURE_LEVEL |
+        | Max Requested Feature Levels | 11.0 | Min D3D_FEATURE_LEVEL |
+        | Information Queue Exceptions Bottom Level | No information queue exceptions | Throw exception on message from validation layer |
+        | Driver type | Hardware | D3D_DRIVER_TYPE |
+        | Rendering Device | (default) |  |
+        */
         void setConfigOption( const String &name, const String &value );
-        void reinitialise();
         void shutdown();
         void validateDevice(bool forceDeviceElection = false);
         void handleDeviceLost();
         void destroyRenderTarget(const String& name);
-        VertexElementType getColourVertexElementType(void) const;
         void setStencilCheckEnabled(bool enabled);
         void setStencilBufferParams(CompareFunction func = CMPF_ALWAYS_PASS, 
             uint32 refValue = 0, uint32 compareMask = 0xFFFFFFFF, uint32 writeMask = 0xFFFFFFFF,
@@ -280,24 +278,20 @@ namespace Ogre
         D3D11HLSLProgram* _getBoundComputeProgram() const;
         void _setTexture(size_t unit, bool enabled, const TexturePtr &texPtr);
         void _setSampler(size_t unit, Sampler& sampler);
-        void _setTextureAddressingMode(size_t stage, const Sampler::UVWAddressingMode& uvw);
-        void _setSeparateSceneBlending(SceneBlendFactor sourceFactor, SceneBlendFactor destFactor, SceneBlendFactor sourceFactorAlpha, 
-            SceneBlendFactor destFactorAlpha, SceneBlendOperation op = SBO_ADD, SceneBlendOperation alphaOp = SBO_ADD);
         void _setAlphaRejectSettings( CompareFunction func, unsigned char value, bool alphaToCoverage );
         void _setViewport( Viewport *vp );
-        void _beginFrame(void);
         void _endFrame(void);
         void _setCullingMode( CullingMode mode );
+        void _setDepthClamp(bool enable);
         void _setDepthBufferParams( bool depthTest = true, bool depthWrite = true, CompareFunction depthFunction = CMPF_LESS_EQUAL );
         void _setDepthBufferCheckEnabled( bool enabled = true );
         bool _getDepthBufferCheckEnabled( void );
-        void _setColourBufferWriteEnabled(bool red, bool green, bool blue, bool alpha);
+        void setColourBlendState(const ColourBlendState& state);
         void _setDepthBufferWriteEnabled(bool enabled = true);
         void _setDepthBufferFunction( CompareFunction func = CMPF_LESS_EQUAL );
         void _setDepthBias(float constantBias, float slopeScaleBias);
 		void _convertProjectionMatrix(const Matrix4& matrix, Matrix4& dest, bool forGpuProgram = false);
         void _setPolygonMode(PolygonMode level);
-        void _setTextureUnitFiltering(size_t unit, FilterType ftype, FilterOptions filter);
         void setVertexDeclaration(VertexDeclaration* decl);
         void setVertexDeclaration(VertexDeclaration* decl, VertexBufferBinding* binding);
         void setVertexBufferBinding(VertexBufferBinding* binding);
@@ -312,7 +306,7 @@ namespace Ogre
 
         void bindGpuProgramParameters(GpuProgramType gptype, const GpuProgramParametersPtr& params, uint16 mask);
 
-        void setScissorTest(bool enabled, size_t left = 0, size_t top = 0, size_t right = 800, size_t bottom = 600);
+        void setScissorTest(bool enabled, const Rect& rect = Rect());
         void clearFrameBuffer(unsigned int buffers, 
             const ColourValue& colour = ColourValue::Black, 
             Real depth = 1.0f, unsigned short stencil = 0);
@@ -321,10 +315,6 @@ namespace Ogre
         Real getVerticalTexelOffset(void);
         Real getMinimumDepthInputValue(void);
         Real getMaximumDepthInputValue(void);
-        void registerThread();
-        void unregisterThread();
-        void preExtraThreadsStarted();
-        void postExtraThreadsStarted();
 
         /**
          * Set current render target to target, enabling its GL context if needed
@@ -333,9 +323,6 @@ namespace Ogre
 
         void determineFSAASettings(uint fsaa, const String& fsaaHint, DXGI_FORMAT format, DXGI_SAMPLE_DESC* outFSAASettings);
 
-        /// @copydoc RenderSystem::getDisplayMonitorCount
-        unsigned int getDisplayMonitorCount() const {return 1;} //todo
-
         D3D11Device &_getDevice() { return mDevice; }
         
         
