@@ -4,7 +4,7 @@ This source file is part of OGRE
 (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -32,40 +32,40 @@ THE SOFTWARE.
 #include "OgreD3D11Prerequisites.h"
 
 namespace Ogre {
-	/**
-	An object which renders geometry to a vertex.
-	@remarks
-	This is especially useful together with geometry shaders, as you can
-	render procedural geometry which will get saved to a vertex buffer for
-	reuse later, without regenerating it again. You can also create shaders
-	that run on previous results of those shaders, creating stateful 
-	shaders.
-	*/
-	class D3D11RenderToVertexBuffer :
-		public RenderToVertexBuffer
-	{
-	public:
-		D3D11RenderToVertexBuffer(D3D11Device & device, D3D11HardwareBufferManagerBase * bufManager);
-		virtual ~D3D11RenderToVertexBuffer(void);
+    /**
+    An object which renders geometry to a vertex.
+    @remarks
+    This is especially useful together with geometry shaders, as you can
+    render procedural geometry which will get saved to a vertex buffer for
+    reuse later, without regenerating it again. You can also create shaders
+    that run on previous results of those shaders, creating stateful 
+    shaders.
+    */
+    class _OgreD3D11Export D3D11RenderToVertexBuffer :
+        public RenderToVertexBuffer
+    {
+    public:
+        D3D11RenderToVertexBuffer(D3D11Device & device, D3D11HardwareBufferManagerBase * bufManager);
+        virtual ~D3D11RenderToVertexBuffer(void);
 
-		/**
-		Get the render operation for this buffer 
-		*/
-		virtual void getRenderOperation(RenderOperation& op);
+        /**
+        Get the render operation for this buffer 
+        */
+        virtual void getRenderOperation(RenderOperation& op);
 
-		/**
-		Update the contents of this vertex buffer by rendering
-		*/
-		virtual void update(SceneManager* sceneMgr);
-		void reallocateBuffer(size_t index);
-	protected:
-		void setupGeometryShaderLinkageToStreamOut(Pass* pass);
+        /**
+        Update the contents of this vertex buffer by rendering
+        */
+        virtual void update(SceneManager* sceneMgr);
+        void reallocateBuffer(size_t index);
+    protected:
+        void setupGeometryShaderLinkageToStreamOut(Pass* pass);
 
-		ID3D11GeometryShader* mpGeometryShader;
+        ID3D11GeometryShader* mpGeometryShader;
         D3D11Device & mDevice;
-		HardwareVertexBufferSharedPtr mVertexBuffers[2];
-		size_t mFrontBufferIndex;
-		D3D11HardwareBufferManagerBase * mBufManager;
-	};
+        HardwareVertexBufferSharedPtr mVertexBuffers[2];
+        size_t mFrontBufferIndex;
+        D3D11HardwareBufferManagerBase * mBufManager;
+    };
 }
 #endif
