@@ -124,7 +124,7 @@ namespace Ogre {
         if(!mStagingBuffer)
             createStagingBuffer();
 
-        if(flags == D3D11_MAP_READ_WRITE || flags == D3D11_MAP_READ || flags == D3D11_MAP_WRITE)  
+        if(flags == D3D11_MAP_READ_WRITE || flags == D3D11_MAP_READ)
         {
             D3D11_BOX boxDx11 = getSubresourceBox(mLockedBox); // both src and dest
             UINT subresource = getSubresourceIndex(mLockedBox.front);
@@ -133,7 +133,10 @@ namespace Ogre {
                 mParentTexture->getTextureResource(), subresource, &boxDx11);
         }
         else if(flags == D3D11_MAP_WRITE_DISCARD)
+        {
             flags = D3D11_MAP_WRITE; // stagingbuffer doesn't support discarding
+            mCurrentLockOptions = HBL_WRITE_ONLY;
+        }
 
         _map(mStagingBuffer.Get(), flags, box);
     }
@@ -174,21 +177,16 @@ namespace Ogre {
             break;
         };
 
-        if(mUsage == HBU_STATIC || mUsage & HBU_DYNAMIC)
-        {
-            if(mUsage == HBU_STATIC || options == HBL_READ_ONLY || options == HBL_NORMAL || options == HBL_WRITE_ONLY)
-                _mapstagingbuffer(flags, rval);
-            else
-                _map(mParentTexture->getTextureResource(), flags, rval);
-        }
+        mCurrentLockOptions = options;
+
+        int usage = mUsage & 0xF; // drop TU_* flags
+        if(usage == HBU_GPU_ONLY || usage == HBU_GPU_TO_CPU || options == HBL_READ_ONLY || options == HBL_NORMAL)
+            _mapstagingbuffer(flags, rval);
         else
-        {
-            mDataForStaticUsageLock.resize(rval.getConsecutiveSize());
-            rval.data = (uchar*)mDataForStaticUsageLock.data();
-        }
+            _map(mParentTexture->getTextureResource(), flags, rval);
+
         // save without offset
         mCurrentLock = rval;
-        mCurrentLockOptions = options;
 
         return rval;
     }
@@ -207,27 +205,6 @@ namespace Ogre {
         }
     }
     //-----------------------------------------------------------------------------  
-    void D3D11HardwarePixelBuffer::_unmapstaticbuffer()
-    {
-        D3D11_BOX dstBoxDx11 = getSubresourceBox(mLockedBox);
-        UINT subresource = getSubresourceIndex(mLockedBox.front);
-        UINT srcRowPitch = PixelUtil::getMemorySize(mCurrentLock.getWidth(), 1, 1, mFormat);
-        UINT srcDepthPitch = PixelUtil::getMemorySize(mCurrentLock.getWidth(), mCurrentLock.getHeight(), 1, mFormat); // H * rowPitch is invalid for compressed formats
-
-        mDevice.GetImmediateContext()->UpdateSubresource(
-                    mParentTexture->getTextureResource(), subresource, &dstBoxDx11,
-                    mDataForStaticUsageLock.data(), srcRowPitch, srcDepthPitch);
-        if (mDevice.isError())
-        {
-            String errorDescription; errorDescription
-                .append("D3D11 device cannot update staging ").append(toString(mParentTexture->getTextureType()))
-                .append("\nError Description:").append(mDevice.getErrorDescription());
-            OGRE_EXCEPT(Exception::ERR_RENDERINGAPI_ERROR, errorDescription, "D3D11HardwarePixelBuffer::_unmapstaticbuffer");
-        }
-
-        mDataForStaticUsageLock.shrink_to_fit();
-    }
-    //-----------------------------------------------------------------------------  
     void D3D11HardwarePixelBuffer::_unmapstagingbuffer(bool copyback)
     {
         _unmap(mStagingBuffer.Get());
@@ -247,26 +224,13 @@ namespace Ogre {
     //-----------------------------------------------------------------------------  
     void D3D11HardwarePixelBuffer::unlockImpl(void)
     {
-        if(mUsage == HBU_STATIC)
-            _unmapstagingbuffer();
-        else if(mUsage & HBU_DYNAMIC)
+        int usage = mUsage & 0xF; // drop TU_* flags
+        if(usage == HBU_GPU_ONLY || usage == HBU_GPU_TO_CPU || mCurrentLockOptions == HBL_NORMAL || mCurrentLockOptions == HBL_READ_ONLY)
         {
-            if(mCurrentLockOptions == HBL_READ_ONLY || mCurrentLockOptions == HBL_NORMAL || mCurrentLockOptions == HBL_WRITE_ONLY)
-            {
-                PixelBox box;
-                box.format = mFormat;
-                _map(mParentTexture->getTextureResource(), D3D11_MAP_WRITE_DISCARD, box);
-                void *data = box.data; 
-				memcpy(data, mCurrentLock.data, mSizeInBytes);
-                // unmap the texture and the staging buffer
-                _unmap(mParentTexture->getTextureResource());
-                _unmapstagingbuffer(false);
-            }
-            else
-                _unmap(mParentTexture->getTextureResource());
+            _unmapstagingbuffer(mCurrentLockOptions == HBL_NORMAL || mCurrentLockOptions == HBL_WRITE_ONLY);
         }
         else
-            _unmapstaticbuffer();
+            _unmap(mParentTexture->getTextureResource());
 
         _genMipmaps();
     }
