@@ -39,9 +39,6 @@ namespace Ogre {
     protected:     
         /// Internal method for creates a new vertex declaration, may be overridden by certain rendering APIs
         VertexDeclaration* createVertexDeclarationImpl(void);
-        /// Internal method for destroys a vertex declaration, may be overridden by certain rendering APIs
-        void destroyVertexDeclarationImpl(VertexDeclaration* decl);
-
     public:
         D3D9HardwareBufferManager();
         ~D3D9HardwareBufferManager();
