@@ -468,16 +468,9 @@ namespace Ogre
         DWORD ret = 0;
         if (usage & HardwareBuffer::HBU_DYNAMIC)
         {
-#if OGRE_D3D_MANAGE_BUFFERS
-            // Only add the dynamic flag for default pool, and
-            // we use default pool when buffer is discardable
-            if (usage & HardwareBuffer::HBU_DISCARDABLE)
-                ret |= D3DUSAGE_DYNAMIC;
-#else
             ret |= D3DUSAGE_DYNAMIC;
-#endif
         }
-        if (usage & HardwareBuffer::HBU_WRITE_ONLY)
+        if (usage & HBU_DETAIL_WRITE_ONLY)
         {
             ret |= D3DUSAGE_WRITEONLY;
         }
@@ -489,38 +482,24 @@ namespace Ogre
         DWORD ret = 0;
         if (options == HardwareBuffer::HBL_DISCARD)
         {
-#if OGRE_D3D_MANAGE_BUFFERS
-            // Only add the discard flag for dynamic usgae and default pool
-            if ((usage & HardwareBuffer::HBU_DYNAMIC) &&
-                (usage & HardwareBuffer::HBU_DISCARDABLE))
-                ret |= D3DLOCK_DISCARD;
-#else
             // D3D doesn't like discard or no_overwrite on non-dynamic buffers
             if (usage & HardwareBuffer::HBU_DYNAMIC)
                 ret |= D3DLOCK_DISCARD;
-#endif
         }
         if (options == HardwareBuffer::HBL_READ_ONLY)
         {
             // D3D debug runtime doesn't like you locking managed buffers readonly
             // when they were created with write-only (even though you CAN read
             // from the software backed version)
-            if (!(usage & HardwareBuffer::HBU_WRITE_ONLY))
+            if (!(usage & HBU_DETAIL_WRITE_ONLY))
                 ret |= D3DLOCK_READONLY;
 
         }
         if (options == HardwareBuffer::HBL_NO_OVERWRITE)
         {
-#if OGRE_D3D_MANAGE_BUFFERS
-            // Only add the nooverwrite flag for dynamic usgae and default pool
-            if ((usage & HardwareBuffer::HBU_DYNAMIC) &&
-                (usage & HardwareBuffer::HBU_DISCARDABLE))
-                ret |= D3DLOCK_NOOVERWRITE;
-#else
             // D3D doesn't like discard or no_overwrite on non-dynamic buffers
             if (usage & HardwareBuffer::HBU_DYNAMIC)
                 ret |= D3DLOCK_NOOVERWRITE;
-#endif 
         }
 
         return ret;
@@ -788,6 +767,11 @@ namespace Ogre
             return PF_FLOAT16_RGBA;
         case PF_FLOAT32_RGB:
             return PF_FLOAT32_RGBA;
+        case PF_DEPTH16:
+            return PF_L16;
+        case PF_DEPTH32:
+        case PF_DEPTH32F:
+            return PF_FLOAT32_R;
         case PF_UNKNOWN:
         default:
             return PF_A8R8G8B8;
