@@ -124,16 +124,9 @@ namespace Ogre {
         }
         if (mLinked)
         {
-            GLenum glErr = glGetError();
-            if(glErr != GL_NO_ERROR)
-            {
-                reportGLSLError( glErr, "GLSLLinkProgram::Activate",
-                    "Error prior to using GLSL Program Object : ", mGLProgramHandle, false, false);
-            }
-
             glUseProgramObjectARB( mGLProgramHandle );
 
-            glErr = glGetError();
+            GLenum glErr = glGetError();
             if(glErr != GL_NO_ERROR)
             {
                 reportGLSLError( glErr, "GLSLLinkProgram::Activate",
