@@ -108,9 +108,8 @@ namespace Ogre {
     //---------------------------------------------------------------------
     GLenum GLHardwareBufferManager::getGLUsage(unsigned int usage)
     {
-        return  (usage & HardwareBuffer::HBU_DISCARDABLE) ? GL_STREAM_DRAW_ARB :
-                (usage & HardwareBuffer::HBU_STATIC) ? GL_STATIC_DRAW_ARB :
-                GL_DYNAMIC_DRAW_ARB;
+        return (usage == HBU_GPU_TO_CPU) ? GL_STATIC_READ
+                                         : (usage == HBU_GPU_ONLY) ? GL_STATIC_DRAW : GL_DYNAMIC_DRAW;
     }
     //---------------------------------------------------------------------
     GLenum GLHardwareBufferManager::getGLType(unsigned int type)
