@@ -4,7 +4,7 @@ This source file is part of OGRE
 (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -34,37 +34,34 @@ THE SOFTWARE.
 
 namespace Ogre {
 
-	/** Specialisation of the GL low-level program for ATI Fragment Shader programs. */
-	class _OgreGLExport ATI_FS_GLGpuProgram : public GLGpuProgram
-	{
-	public:
+    /** Specialisation of the GL low-level program for ATI Fragment Shader programs. */
+    class _OgreGLExport ATI_FS_GLGpuProgram : public GLGpuProgram
+    {
+    public:
         ATI_FS_GLGpuProgram(ResourceManager* creator, 
             const String& name, ResourceHandle handle, 
             const String& group, bool isManual, ManualResourceLoader* loader);
-		virtual ~ATI_FS_GLGpuProgram();
+        virtual ~ATI_FS_GLGpuProgram();
 
 
-		/// Execute the binding functions for this program
-		void bindProgram(void);
-		/// Execute the unbinding functions for this program
-		void unbindProgram(void);
-		/// Execute the param binding functions for this program
-		void bindProgramParameters(GpuProgramParametersSharedPtr params, uint16 mask);
-		/** Execute the pass iteration param binding functions for this program.
-            Only binds those parameters used for multipass rendering
-        */
-        void bindProgramPassIterationParameters(GpuProgramParametersSharedPtr params);
+        /// Execute the binding functions for this program
+        void bindProgram(void);
+        /// Execute the unbinding functions for this program
+        void unbindProgram(void);
+        /// Execute the param binding functions for this program
+        void bindProgramParameters(GpuProgramParametersSharedPtr params, uint16 mask);
 
-		/// Get the assigned GL program id
-		GLuint getProgramID(void) const
-		{ return mProgramID; }
+        /// Get the assigned GL program id
+        GLuint getProgramID(void) const
+        { return mProgramID; }
 
-	protected:
-		/// @copydoc Resource::unload
-		void unloadImpl(void);
-		void loadFromSource(void);
+    protected:
+        /// @copydoc Resource::unload
+        void unloadImpl(void);
+        void loadFromSource(void);
+        GLenum mProgramType;
 
-	}; // class ATI_FS_GLGpuProgram
+    }; // class ATI_FS_GLGpuProgram
 
 
 
