@@ -4,7 +4,7 @@ This source file is part of OGRE
 (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -42,7 +42,7 @@ ATI_FS_GLGpuProgram::ATI_FS_GLGpuProgram(ResourceManager* creator,
         const String& group, bool isManual, ManualResourceLoader* loader) :
     GLGpuProgram(creator, name, handle, group, isManual, loader)
 {
-	mProgramType = GL_FRAGMENT_SHADER_ATI;
+    mProgramType = GL_FRAGMENT_SHADER_ATI;
     mProgramID = glGenFragmentShadersATI(1);
 }
 
@@ -55,56 +55,43 @@ ATI_FS_GLGpuProgram::~ATI_FS_GLGpuProgram()
 
 void ATI_FS_GLGpuProgram::bindProgram(void)
 {
-	glEnable(mProgramType);
-	glBindFragmentShaderATI(mProgramID);
+    glEnable(mProgramType);
+    glBindFragmentShaderATI(mProgramID);
 }
 
 void ATI_FS_GLGpuProgram::unbindProgram(void)
 {
-	glDisable(mProgramType);
+    glDisable(mProgramType);
 }
 
 
 void ATI_FS_GLGpuProgram::bindProgramParameters(GpuProgramParametersSharedPtr params, uint16 mask)
 {
-	// only supports float constants
-	GpuLogicalBufferStructPtr floatStruct = params->getFloatLogicalBufferStruct();
+    // only supports float constants
+    GpuLogicalBufferStructPtr floatStruct = params->getFloatLogicalBufferStruct();
 
-	for (GpuLogicalIndexUseMap::const_iterator i = floatStruct->map.begin();
-		i != floatStruct->map.end(); ++i)
-	{
-		if (i->second.variability & mask)
-		{
-			size_t logicalIndex = i->first;
-			const float* pFloat = params->getFloatPointer(i->second.physicalIndex);
-			// Iterate over the params, set in 4-float chunks (low-level)
-			for (size_t j = 0; j < i->second.currentSize; j+=4)
-			{
-				glSetFragmentShaderConstantATI(GL_CON_0_ATI + logicalIndex, pFloat);
-				pFloat += 4;
-				++logicalIndex;
-			}
-		}
-	}
+    for (GpuLogicalIndexUseMap::const_iterator i = floatStruct->map.begin();
+        i != floatStruct->map.end(); ++i)
+    {
+        if (i->second.variability & mask)
+        {
+            size_t logicalIndex = i->first;
+            const float* pFloat = params->getFloatPointer(i->second.physicalIndex);
+            // Iterate over the params, set in 4-float chunks (low-level)
+            for (size_t j = 0; j < i->second.currentSize; j+=4)
+            {
+                glSetFragmentShaderConstantATI(GL_CON_0_ATI + logicalIndex, pFloat);
+                pFloat += 4;
+                ++logicalIndex;
+            }
+        }
+    }
 
 }
 
-
-void ATI_FS_GLGpuProgram::bindProgramPassIterationParameters(GpuProgramParametersSharedPtr params)
-{
-	if (params->hasPassIterationNumber())
-	{
-		size_t physicalIndex = params->getPassIterationNumberIndex();
-		size_t logicalIndex = params->getFloatLogicalIndexForPhysicalIndex(physicalIndex);
-		const float* pFloat = params->getFloatPointer(physicalIndex);
-		glSetFragmentShaderConstantATI( GL_CON_0_ATI + (GLuint)logicalIndex, pFloat);
-	}
-}
-
-
 void ATI_FS_GLGpuProgram::unloadImpl(void)
 {
-	glDeleteFragmentShaderATI(mProgramID);
+    glDeleteFragmentShaderATI(mProgramID);
 }
 
 
@@ -112,39 +99,39 @@ void ATI_FS_GLGpuProgram::loadFromSource(void)
 {
 
     PS_1_4 PS1_4Assembler;
-	// attempt to compile the source
+    // attempt to compile the source
 #ifdef _DEBUG
-	PS1_4Assembler.test(); // run compiler tests in debug mode
+    PS1_4Assembler.test(); // run compiler tests in debug mode
 #endif
 
     bool Error = !PS1_4Assembler.compile(mSource.c_str());
 
     if(!Error) { 
-		glBindFragmentShaderATI(mProgramID);
-		glBeginFragmentShaderATI();
-			// compile was successful so send the machine instructions thru GL to GPU
-			Error = !PS1_4Assembler.bindAllMachineInstToFragmentShader();
+        glBindFragmentShaderATI(mProgramID);
+        glBeginFragmentShaderATI();
+            // compile was successful so send the machine instructions thru GL to GPU
+            Error = !PS1_4Assembler.bindAllMachineInstToFragmentShader();
         glEndFragmentShaderATI();
 
-		// check GL for GPU machine instruction bind erros
-		if (Error)
-		{
-			OGRE_EXCEPT(Exception::ERR_INTERNAL_ERROR, 
-				"Cannot Bind ATI fragment shader :" + mName, mName); 
-		}
+        // check GL for GPU machine instruction bind erros
+        if (Error)
+        {
+            OGRE_EXCEPT(Exception::ERR_INTERNAL_ERROR, 
+                "Cannot Bind ATI fragment shader :" + mName, mName); 
+        }
 
     }
     else
-	{
-		// an error occurred when compiling the ps_1_4 source code
-		char buff[50];
+    {
+        // an error occurred when compiling the ps_1_4 source code
+        char buff[50];
         sprintf(buff,"error on line %d in pixel shader source\n", PS1_4Assembler.mCurrentLine);
 
-		LogManager::getSingleton().logMessage("Warning: atifs compiler reported the following errors:");
-		LogManager::getSingleton().logMessage(buff + mName);
+        LogManager::getSingleton().logMessage("Warning: atifs compiler reported the following errors:");
+        LogManager::getSingleton().logMessage(buff + mName);
 
-		OGRE_EXCEPT(Exception::ERR_INTERNAL_ERROR, 
-			"Cannot Compile ATI fragment shader : " + mName + "\n\n" + buff , mName);// + 
+        OGRE_EXCEPT(Exception::ERR_INTERNAL_ERROR, 
+            "Cannot Compile ATI fragment shader : " + mName + "\n\n" + buff , mName);// + 
     }
 
 
