@@ -34,24 +34,15 @@ Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 namespace Ogre {
 
-
-    // Default threshold at which glMapBuffer becomes more efficient than glBufferSubData (32k?)
-    //TODO Double check that this still holds.
-#       define OGRE_GL_DEFAULT_MAP_BUFFER_THRESHOLD (1024 * 32)
-
     /** Implementation of HardwareBufferManager for OpenGL. */
     class _OgreGL3PlusExport GL3PlusHardwareBufferManager : public HardwareBufferManager
     {
     protected:
         GL3PlusRenderSystem* mRenderSystem;
-        char* mScratchBufferPool;
-        OGRE_MUTEX(mScratchMutex);
-        size_t mMapBufferThreshold;
 
         UniformBufferList mShaderStorageBuffers;
 
         VertexDeclaration* createVertexDeclarationImpl(void);
-        void destroyVertexDeclarationImpl(VertexDeclaration* decl);
     public:
         GL3PlusHardwareBufferManager();
         ~GL3PlusHardwareBufferManager();
@@ -83,23 +74,6 @@ namespace Ogre {
 
         GL3PlusStateCacheManager * getStateCacheManager();
         void notifyContextDestroyed(GLContext* context);
-
-        /** Allocator method to allow us to use a pool of memory as a scratch
-            area for hardware buffers. This is because glMapBuffer is incredibly
-            inefficient, seemingly no matter what options we give it. So for the
-            period of lock/unlock, we will instead allocate a section of a local
-            memory pool, and use glBufferSubDataARB / glGetBufferSubDataARB
-            instead.
-        */
-        void* allocateScratch(uint32 size);
-
-        /// @see allocateScratch
-        void deallocateScratch(void* ptr);
-
-        /** Threshold after which glMapBuffer is used and not glBufferSubData
-         */
-        size_t getGLMapBufferThreshold() const;
-        void setGLMapBufferThreshold( const size_t value );
     };
 }
 
