@@ -459,15 +459,13 @@ namespace Ogre {
                      const char *iMacroValue, size_t iMacroValueLen);
 
         /**
-         * Define a numerical macro.
+         * Define a symbolical macro.
          * @param iMacroName
          *     The name of the defined macro
          * @param iMacroNameLen
          *     The length of the name of the defined macro
-         * @param iMacroValue
-         *     The value of the defined macro
          */
-        void Define (const char *iMacroName, size_t iMacroNameLen, long iMacroValue);
+        void Define (const char *iMacroName, size_t iMacroNameLen);
 
         /**
          * Undefine a macro.
