@@ -150,7 +150,7 @@ namespace Ogre {
 
     void CPreprocessor::Token::SetValue (long iValue)
     {
-        char tmp [21];
+        static char tmp [21];
         int len = snprintf (tmp, sizeof (tmp), "%ld", iValue);
         Length = 0;
         Append (tmp, len);
@@ -210,15 +210,25 @@ namespace Ogre {
         for (; i < Args.size(); i++)
             cpp.Define (Args [i].String, Args [i].Length, "", 0);
 
-        // Now run the macro expansion through the supplimentary preprocessor
-        Token xt = cpp.Parse (Value);
+        Token xt;
+        // make sure that no one down the line sets Value.Allocated = 0
+        Token new_xt = Token(Token::TK_TEXT, Value.String, Value.Length);
+        bool first = true;
+        do {
+            xt = new_xt;
+            // Now run the macro expansion through the supplimentary preprocessor
+            new_xt = cpp.Parse (xt);
+
+            // Remove the extra macros we have defined, only needed once.
+            if (first) {
+                first = false;
+                for (int j = Args.size() - 1; j >= 0; j--)
+                    cpp.Undef (Args [j].String, Args [j].Length);
+            }
+            // Repeat until there is no more change between parses
+        } while (xt.String != new_xt.String);
 
         Expanding = false;
-
-        // Remove the extra macros we have defined
-        for (int j = Args.size() - 1; j >= 0; j--)
-            cpp.Undef (Args [j].String, Args [j].Length);
-
         std::swap(cpp.MacroList, iMacros);
 
         return xt;
@@ -413,6 +423,11 @@ namespace Ogre {
                     Source = t.String;
                     Line -= t.CountNL ();
                 }
+                // If a macro is defined with arguments but gets not "called" it should behave like normal text
+                if (args.size() == 0 && (t.Type != Token::TK_PUNCTUATION || t.String [0] != '('))
+                {
+                    return iToken;
+                }
             }
 
             if (args.size() > cur->Args.size())
@@ -1236,11 +1251,9 @@ namespace Ogre {
     }
 
 
-    void CPreprocessor::Define (const char *iMacroName, size_t iMacroNameLen,
-                                long iMacroValue)
+    void CPreprocessor::Define (const char *iMacroName, size_t iMacroNameLen)
     {
         MacroList.emplace_front(Token(Token::TK_KEYWORD, iMacroName, iMacroNameLen));
-        MacroList.front().Value.SetValue(iMacroValue);
     }
 
 
