@@ -530,13 +530,11 @@ namespace Ogre
 
         int profile;
         int minVersion;
-        int maxVersion = 5;
 
         switch(mContextProfile) {
         case CONTEXT_COMPATIBILITY:
             profile = GLX_CONTEXT_COMPATIBILITY_PROFILE_BIT_ARB;
             minVersion = 1;
-            maxVersion = 3; // requesting 3.1 might return 3.2 core profile
             break;
         case CONTEXT_ES:
             profile = GLX_CONTEXT_ES2_PROFILE_BIT_EXT;
@@ -549,7 +547,7 @@ namespace Ogre
         }
 
         int context_attribs[] = {
-                GLX_CONTEXT_MAJOR_VERSION_ARB, maxVersion,
+                GLX_CONTEXT_MAJOR_VERSION_ARB, minVersion,
                 GLX_CONTEXT_MINOR_VERSION_ARB, 0,
                 GLX_CONTEXT_PROFILE_MASK_ARB, profile,
                 None
@@ -562,35 +560,14 @@ namespace Ogre
         PFNGLXCREATECONTEXTATTRIBSARBPROC _glXCreateContextAttribsARB;
         _glXCreateContextAttribsARB = (PFNGLXCREATECONTEXTATTRIBSARBPROC)getProcAddress("glXCreateContextAttribsARB");
 
-	OgreAssert(_glXCreateContextAttribsARB, "glXCreateContextAttribsARB() function not found");
+        ctxErrorOccurred = false;
 
-        while(!glxContext && (context_attribs[1] >= minVersion))
+        if(_glXCreateContextAttribsARB)
         {
-            ctxErrorOccurred = false;
             glxContext = _glXCreateContextAttribsARB(mGLDisplay, fbConfig, shareList, direct, context_attribs);
-            // Sync to ensure any errors generated are processed.
-            XSync( mGLDisplay, False );
-            if ( !ctxErrorOccurred && glxContext )
-            {
-                LogManager::getSingleton().logMessage("Created GL " + StringConverter::toString(context_attribs[1]) + "." + StringConverter::toString(context_attribs[3]) + " context" );
-            }
-            else
-            {
-                if(context_attribs[3] == 0)
-                {
-                    context_attribs[1] -= 1;
-                    context_attribs[3] = 6;
-                }
-                else
-                {
-                    context_attribs[3] -= 1;
-                }
-            }
         }
-
-        if (!glxContext) {
-            ctxErrorOccurred = false;
-
+        else
+        {
             // try old style context creation as a last resort
             // Needed at least by MESA 8.0.4 on Ubuntu 12.04.
             if (mContextProfile != CONTEXT_COMPATIBILITY) {
@@ -607,10 +584,9 @@ namespace Ogre
         // Restore the original error handler
         XSetErrorHandler( oldHandler );
 
-        if (ctxErrorOccurred || !glxContext) {
-          LogManager::getSingleton().logMessage(
-              "Failed to create an OpenGL context. " + ctxErrorMessage,
-              LML_CRITICAL);
+        if (ctxErrorOccurred || !glxContext)
+        {
+            LogManager::getSingleton().logError("Failed to create an OpenGL context - " + ctxErrorMessage);
         }
 
         return glxContext;
