@@ -4,7 +4,7 @@ This source file is part of OGRE
     (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -25,29 +25,25 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 -----------------------------------------------------------------------------
 */
-#include <cppunit/TestFixture.h>
-#include <cppunit/extensions/HelperMacros.h>
+
+#ifndef __EdgeBuilderTests_H__
+#define __EdgeBuilderTests_H__
+
+#include <gtest/gtest.h>
 #include "OgreLogManager.h"
 #include "OgreHardwareBufferManager.h"
 
 using namespace Ogre;
 
-class EdgeBuilderTests : public CppUnit::TestFixture
+class EdgeBuilderTests : public ::testing::Test
 {
-    // CppUnit macros for setting up the test suite
-    CPPUNIT_TEST_SUITE( EdgeBuilderTests );
-    CPPUNIT_TEST(testSingleIndexBufSingleVertexBuf);
-    CPPUNIT_TEST(testMultiIndexBufSingleVertexBuf);
-    CPPUNIT_TEST(testMultiIndexBufMultiVertexBuf);
-    CPPUNIT_TEST_SUITE_END();
+
 protected:
     HardwareBufferManager* mBufMgr;
-    LogManager* mLogMgr;
-public:
-    void setUp();
-    void tearDown();
-    void testSingleIndexBufSingleVertexBuf();
-    void testMultiIndexBufSingleVertexBuf();
-    void testMultiIndexBufMultiVertexBuf();
 
+public:
+    void SetUp();
+    void TearDown();
 };
+
+#endif
