@@ -4,7 +4,7 @@ This source file is part of OGRE
 (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -25,44 +25,29 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 -----------------------------------------------------------------------------
 */
-#include <cppunit/TestFixture.h>
-#include <cppunit/extensions/HelperMacros.h>
+
+#ifndef __FileSystemArchiveTests_H__
+#define __FileSystemArchiveTests_H__
+
+#include <gtest/gtest.h>
 #include "OgreString.h"
+#include "OgreFileSystem.h"
 
 using namespace Ogre;
 
-class FileSystemArchiveTests : public CppUnit::TestFixture
+class FileSystemArchiveTests : public ::testing::Test
 {
-    // CppUnit macros for setting up the test suite
-    CPPUNIT_TEST_SUITE( FileSystemArchiveTests );
-    CPPUNIT_TEST(testListNonRecursive);
-    CPPUNIT_TEST(testListRecursive);
-    CPPUNIT_TEST(testListFileInfoNonRecursive);
-    CPPUNIT_TEST(testListFileInfoRecursive);
-    CPPUNIT_TEST(testFindNonRecursive);
-    CPPUNIT_TEST(testFindRecursive);
-    CPPUNIT_TEST(testFindFileInfoNonRecursive);
-    CPPUNIT_TEST(testFindFileInfoRecursive);
-    CPPUNIT_TEST(testFileRead);
-    CPPUNIT_TEST(testReadInterleave);
-	CPPUNIT_TEST(testCreateAndRemoveFile);
-    CPPUNIT_TEST_SUITE_END();
+
 protected:
-    String testPath;
+    FileSystemArchiveFactory mFactory;
+    Archive* mArch;
+    String mTestPath;
+    size_t mFileSizeRoot1;
+    size_t mFileSizeRoot2;
+
 public:
-    void setUp();
-    void tearDown();
-
-    void testListNonRecursive();
-    void testListRecursive();
-    void testListFileInfoNonRecursive();
-    void testListFileInfoRecursive();
-    void testFindNonRecursive();
-    void testFindRecursive();
-    void testFindFileInfoNonRecursive();
-    void testFindFileInfoRecursive();
-    void testFileRead();
-    void testReadInterleave();
-	void testCreateAndRemoveFile();
-
+    void SetUp();
+    void TearDown();
 };
+
+#endif
