@@ -4,7 +4,7 @@ This source file is part of OGRE
 (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -25,49 +25,24 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 -----------------------------------------------------------------------------
 */
-#include <cppunit/TestFixture.h>
-#include <cppunit/extensions/HelperMacros.h>
-#include "OgreLogManager.h"
+
+#ifndef __MeshWithoutIndexDataTests_H__
+#define __MeshWithoutIndexDataTests_H__
+
+#include <gtest/gtest.h>
 
 using namespace Ogre;
-using Ogre::ushort;
 
-class MeshWithoutIndexDataTests : public CppUnit::TestFixture
+class MeshWithoutIndexDataTests : public ::testing::Test
 {
-    // CppUnit macros for setting up the test suite
-    CPPUNIT_TEST_SUITE( MeshWithoutIndexDataTests );
-    CPPUNIT_TEST(testCreateSimpleLine);
-    CPPUNIT_TEST(testCreateLineList);
-    CPPUNIT_TEST(testCreateLineStrip);
-    CPPUNIT_TEST(testCreatePointList);
-    CPPUNIT_TEST(testCreateLineWithMaterial);
-    CPPUNIT_TEST(testCreateMesh);
-    CPPUNIT_TEST(testCloneMesh);
-    CPPUNIT_TEST(testEdgeList);
-    CPPUNIT_TEST(testGenerateExtremes);
-    CPPUNIT_TEST(testBuildTangentVectors);
-    CPPUNIT_TEST(testGenerateLodLevels);
-    CPPUNIT_TEST_SUITE_END();
 
 protected:
     HardwareBufferManager* mBufMgr;
     MeshManager* mMeshMgr;
-    ArchiveManager* archiveMgr;
-    LogManager *mLogManager;
+    ArchiveManager* mArchiveMgr;
 
 public:
-    void setUp();
-    void tearDown();
-    void testCreateSimpleLine();
-    void testCreateLineList();
-    void testCreateLineStrip();
-    void testCreatePointList();
-    void testCreateLineWithMaterial();
-    void testCreateMesh();
-    void testCloneMesh();
-    void testEdgeList();
-    void testGenerateExtremes();
-    void testBuildTangentVectors();
-    void testGenerateLodLevels();
-
+    void SetUp();
+    void TearDown();
 };
+#endif
