@@ -4,7 +4,7 @@ This source file is part of OGRE
 (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -25,29 +25,17 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 -----------------------------------------------------------------------------
 */
-#include <cppunit/TestFixture.h>
-#include <cppunit/extensions/HelperMacros.h>
 
-class RadixSortTests : public CppUnit::TestFixture
+#ifndef __RadixSortTests_H__
+#define __RadixSortTests_H__
+
+#include <gtest/gtest.h>
+
+class RadixSortTests : public ::testing::Test
 {
-	// CppUnit macros for setting up the test suite
-	CPPUNIT_TEST_SUITE( RadixSortTests );
-	CPPUNIT_TEST(testFloatVector);
-	CPPUNIT_TEST(testFloatList);
-	CPPUNIT_TEST(testUnsignedIntList);
-	CPPUNIT_TEST(testIntList);
-	CPPUNIT_TEST(testUnsignedIntVector);
-	CPPUNIT_TEST(testIntVector);
-	CPPUNIT_TEST_SUITE_END();
-protected:
 public:
-	void setUp();
-	void tearDown();
-	void testFloatVector();
-	void testFloatList();
-	void testUnsignedIntList();
-	void testIntList();
-	void testUnsignedIntVector();
-	void testIntVector();
-
+    void SetUp();
+    void TearDown();
 };
+
+#endif
