@@ -49,6 +49,8 @@ THE SOFTWARE.
 #include "OgreFileSystem.h"
 #include "OgreArchiveManager.h"
 
+#include "OgreHighLevelGpuProgram.h"
+
 #include <random>
 using std::minstd_rand;
 
@@ -210,10 +212,10 @@ TEST(MaterialSerializer, Basic)
     ASSERT_TRUE(mat2);
     EXPECT_EQ(mat2->getTechniques().size(), mat->getTechniques().size());
     EXPECT_EQ(mat2->getTechniques()[0]->getPasses()[0]->getAmbient(), ColourValue::Green);
+    EXPECT_EQ(mat2->getTechniques()[0]->getPasses()[0]->getTextureUnitState(0)->getName(),
+              "Test TUS");
     EXPECT_EQ(mat2->getTechniques()[0]->getPasses()[0]->getTextureUnitState("Test TUS")->getContentType(),
               TextureUnitState::CONTENT_SHADOW);
-    EXPECT_EQ(mat2->getTechniques()[0]->getPasses()[0]->getTextureUnitState("Test TUS")->getTextureNameAlias(),
-              "Test TUS");
     EXPECT_EQ(mat2->getTechniques()[0]->getPasses()[0]->getTextureUnitState(1)->getTextureName(),
               "TextureName");
 }
@@ -235,11 +237,32 @@ TEST(Image, FlipV)
 
     // img.save(testPath+"/decal1vflip.png");
 
+    STBIImageCodec::shutdown();
     ASSERT_TRUE(!memcmp(img.getData(), ref.getData(), ref.getSize()));
+}
+
+TEST(Image, Resize)
+{
+    ResourceGroupManager mgr;
+    STBIImageCodec::startup();
+    ConfigFile cf;
+    cf.load(FileSystemLayer(OGRE_VERSION_NAME).getConfigFilePath("resources.cfg"));
+    auto testPath = cf.getSettings("Tests").begin()->second;
+
+    Image ref;
+    ref.load(Root::openFileStream(testPath+"/decal1small.png"), "png");
+
+    Image img;
+    img.load(Root::openFileStream(testPath+"/decal1.png"), "png");
+    img.resize(128, 128);
+
+    //img.save(testPath+"/decal1small.png");
 
     STBIImageCodec::shutdown();
+    ASSERT_TRUE(!memcmp(img.getData(), ref.getData(), ref.getSize()));
 }
 
+
 TEST(Image, Combine)
 {
     ResourceGroupManager mgr;
@@ -261,15 +284,12 @@ TEST(Image, Combine)
     combined.loadTwoImagesAsRGBA("rockwall.tga", "flare.png", RGN_DEFAULT, PF_BYTE_RGBA);
 
     // combined.save(testPath+"/rockwall_flare.png");
-    ASSERT_TRUE(!memcmp(combined.getData(), ref.getData(), ref.getSize()));
-
     STBIImageCodec::shutdown();
+    ASSERT_TRUE(!memcmp(combined.getData(), ref.getData(), ref.getSize()));
 }
 
 struct UsePreviousResourceLoadingListener : public ResourceLoadingListener
 {
-    DataStreamPtr resourceLoading(const String &name, const String &group, Resource *resource) { return DataStreamPtr(); }
-    void resourceStreamOpened(const String &name, const String &group, Resource *resource, DataStreamPtr& dataStream) {}
     bool resourceCollision(Resource *resource, ResourceManager *resourceManager) { return false; }
 };
 
@@ -303,8 +323,6 @@ TEST_F(ResourceLoading, CollsionUseExisting)
 
 struct DeletePreviousResourceLoadingListener : public ResourceLoadingListener
 {
-    DataStreamPtr resourceLoading(const String &name, const String &group, Resource *resource) { return DataStreamPtr(); }
-    void resourceStreamOpened(const String &name, const String &group, Resource *resource, DataStreamPtr& dataStream) {}
     bool resourceCollision(Resource* resource, ResourceManager* resourceManager)
     {
         resourceManager->remove(resource->getName(), resource->getGroup());
@@ -336,7 +354,56 @@ TEST_F(TextureTests, Blank)
     EXPECT_EQ(tus->getNumMipmaps(), MIP_DEFAULT);
     EXPECT_EQ(tus->getDesiredFormat(), PF_UNKNOWN);
     EXPECT_EQ(tus->getFrameTextureName(0), "");
-    EXPECT_EQ(tus->getIsAlpha(), false);
     EXPECT_EQ(tus->getGamma(), 1.0f);
     EXPECT_EQ(tus->isHardwareGammaEnabled(), false);
+}
+
+TEST(GpuSharedParameters, align)
+{
+    Root root("");
+    GpuSharedParameters params("dummy");
+
+    // trivial case
+    params.addConstantDefinition("a", GCT_FLOAT1);
+    EXPECT_EQ(params.getConstantDefinition("a").logicalIndex, 0);
+
+    // 16 byte alignment
+    params.addConstantDefinition("b", GCT_FLOAT4);
+    EXPECT_EQ(params.getConstantDefinition("b").logicalIndex, 16);
+
+    // break alignment again
+    params.addConstantDefinition("c", GCT_FLOAT1);
+    EXPECT_EQ(params.getConstantDefinition("c").logicalIndex, 32);
+
+    // 16 byte alignment
+    params.addConstantDefinition("d", GCT_MATRIX_4X4);
+    EXPECT_EQ(params.getConstantDefinition("d").logicalIndex, 48);
+}
+
+typedef RootWithoutRenderSystemFixture HighLevelGpuProgramTest;
+TEST_F(HighLevelGpuProgramTest, resolveIncludes)
+{
+    auto mat = MaterialManager::getSingleton().create("Dummy", RGN_DEFAULT);
+
+    auto& rgm = ResourceGroupManager::getSingleton();
+    rgm.addResourceLocation(".", "FileSystem", RGN_DEFAULT, false, false);
+
+    // recursive inclusion
+    String bar = "World";
+    rgm.createResource("bar.cg", RGN_DEFAULT)->write(bar.c_str(), bar.size());
+    String foo = "Hello\n#include <bar.cg>\n";
+    rgm.createResource("foo.cg", RGN_DEFAULT)->write(foo.c_str(), foo.size());
+    const char* src = "#include <foo.cg>";
+
+    String res = HighLevelGpuProgram::_resolveIncludes(src, mat.get(), "main.cg", true);
+    rgm.deleteResource("foo.cg", RGN_DEFAULT);
+    rgm.deleteResource("bar.cg", RGN_DEFAULT);
+
+    String ref = "#line 1  \"foo.cg\"\n"
+                 "Hello\n"
+                 "#line 1  \"bar.cg\"\n"
+                 "World\n"
+                 "#line 2 \"foo.cg\"";
+
+    ASSERT_EQ(res.substr(0, ref.size()), ref);
 }
\ No newline at end of file
