@@ -4,7 +4,7 @@ This source file is part of OGRE
 (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2013 Torus Knot Software Ltd
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -27,46 +27,46 @@ THE SOFTWARE.
 */
 #include <stdio.h>
 #include "Ogre.h"
-#include "OgreProgressiveMeshGenerator.h"
 #include "OgreDistanceLodStrategy.h"
 #include "OgreDefaultHardwareBufferManager.h"
 #include "OgreFileSystem.h"
 #include "OgreArchiveManager.h"
 #include "MeshWithoutIndexDataTests.h"
+#include "OgreLodStrategyManager.h"
+#include "OgreLodConfig.h"
 
 
-// Register the suite
-CPPUNIT_TEST_SUITE_REGISTRATION( MeshWithoutIndexDataTests );
+#ifdef OGRE_BUILD_COMPONENT_MESHLODGENERATOR
+#include "OgreMeshLodGenerator.h"
+#endif
 
-void MeshWithoutIndexDataTests::setUp()
-{
-    if(LogManager::getSingletonPtr() == 0)
-        mLogManager = OGRE_NEW LogManager();
+// Register the test suite
 
-	LogManager::getSingleton().createLog("MeshWithoutIndexDataTests.log", true);
-    LogManager::getSingleton().setLogDetail(LL_LOW);
-	OGRE_NEW ResourceGroupManager();
-	OGRE_NEW LodStrategyManager();
+//--------------------------------------------------------------------------
+void MeshWithoutIndexDataTests::SetUp()
+{    
+    OGRE_NEW ResourceGroupManager();
+    OGRE_NEW LodStrategyManager();
     mBufMgr = OGRE_NEW DefaultHardwareBufferManager();
     mMeshMgr = OGRE_NEW MeshManager();
-    archiveMgr = OGRE_NEW ArchiveManager();
-    archiveMgr->addArchiveFactory(OGRE_NEW FileSystemArchiveFactory());
+    mArchiveMgr = OGRE_NEW ArchiveManager();
+    mArchiveMgr->addArchiveFactory(OGRE_NEW FileSystemArchiveFactory());
 
-	MaterialManager* matMgr = OGRE_NEW MaterialManager();
-	matMgr->initialise();
+    MaterialManager* matMgr = OGRE_NEW MaterialManager();
+    matMgr->initialise();
 }
-void MeshWithoutIndexDataTests::tearDown()
+//--------------------------------------------------------------------------
+void MeshWithoutIndexDataTests::TearDown()
 {
+    OGRE_DELETE MaterialManager::getSingletonPtr();
+    OGRE_DELETE mArchiveMgr;
     OGRE_DELETE mMeshMgr;
     OGRE_DELETE mBufMgr;
-    OGRE_DELETE archiveMgr;
-	OGRE_DELETE MaterialManager::getSingletonPtr();
-	OGRE_DELETE LodStrategyManager::getSingletonPtr();
-	OGRE_DELETE ResourceGroupManager::getSingletonPtr();
-    OGRE_DELETE mLogManager;
+    OGRE_DELETE LodStrategyManager::getSingletonPtr();
+    OGRE_DELETE ResourceGroupManager::getSingletonPtr();
 }
-
-void MeshWithoutIndexDataTests::testCreateSimpleLine()
+//--------------------------------------------------------------------------
+TEST_F(MeshWithoutIndexDataTests,CreateSimpleLine)
 {
     ManualObject* line = OGRE_NEW ManualObject("line");
     line->begin("BaseWhiteNoLighting", RenderOperation::OT_LINE_LIST);
@@ -77,33 +77,33 @@ void MeshWithoutIndexDataTests::testCreateSimpleLine()
     MeshPtr lineMesh = line->convertToMesh(fileName);
     OGRE_DELETE line;
 
-    CPPUNIT_ASSERT(lineMesh->getNumSubMeshes() == 1);
-    CPPUNIT_ASSERT(lineMesh->getSubMesh(0)->indexData->indexCount == 0);
+    EXPECT_TRUE(lineMesh->getNumSubMeshes() == 1);
+    EXPECT_TRUE(lineMesh->getSubMesh(0)->indexData->indexCount == 0);
     RenderOperation rop;
     lineMesh->getSubMesh(0)->_getRenderOperation(rop);
-    CPPUNIT_ASSERT(rop.useIndexes == false);
-    CPPUNIT_ASSERT(lineMesh->getSubMesh(0)->vertexData->vertexCount == 2);
+    EXPECT_TRUE(rop.useIndexes == false);
+    EXPECT_TRUE(lineMesh->getSubMesh(0)->vertexData->vertexCount == 2);
 
     MeshSerializer meshWriter;
     meshWriter.exportMesh(lineMesh.get(), fileName);
 
-    mMeshMgr->remove( fileName );
+    mMeshMgr->remove(fileName, "General");
 
     ResourceGroupManager::getSingleton().addResourceLocation(".", "FileSystem");
     MeshPtr loadedLine = mMeshMgr->load(fileName, "General");
 
     remove(fileName.c_str());
 
-    CPPUNIT_ASSERT(loadedLine->getNumSubMeshes() == 1);
-    CPPUNIT_ASSERT(loadedLine->getSubMesh(0)->indexData->indexCount == 0);
+    EXPECT_TRUE(loadedLine->getNumSubMeshes() == 1);
+    EXPECT_TRUE(loadedLine->getSubMesh(0)->indexData->indexCount == 0);
     loadedLine->getSubMesh(0)->_getRenderOperation(rop);
-    CPPUNIT_ASSERT(rop.useIndexes == false);
-    CPPUNIT_ASSERT(lineMesh->getSubMesh(0)->vertexData->vertexCount == 2);
+    EXPECT_TRUE(rop.useIndexes == false);
+    EXPECT_TRUE(lineMesh->getSubMesh(0)->vertexData->vertexCount == 2);
 
-    mMeshMgr->remove( fileName );
+    mMeshMgr->remove(fileName, "General");
 }
-
-void MeshWithoutIndexDataTests::testCreateLineList()
+//--------------------------------------------------------------------------
+TEST_F(MeshWithoutIndexDataTests,CreateLineList)
 {
     ManualObject* lineList = OGRE_NEW ManualObject("line");
     lineList->begin("BaseWhiteNoLighting", RenderOperation::OT_LINE_LIST);
@@ -118,33 +118,33 @@ void MeshWithoutIndexDataTests::testCreateLineList()
     MeshPtr lineListMesh = lineList->convertToMesh(fileName);
     OGRE_DELETE lineList;
 
-    CPPUNIT_ASSERT(lineListMesh->getNumSubMeshes() == 1);
-    CPPUNIT_ASSERT(lineListMesh->getSubMesh(0)->indexData->indexCount == 0);
+    EXPECT_TRUE(lineListMesh->getNumSubMeshes() == 1);
+    EXPECT_TRUE(lineListMesh->getSubMesh(0)->indexData->indexCount == 0);
     RenderOperation rop;
     lineListMesh->getSubMesh(0)->_getRenderOperation(rop);
-    CPPUNIT_ASSERT(rop.useIndexes == false);
-    CPPUNIT_ASSERT(lineListMesh->getSubMesh(0)->vertexData->vertexCount == 6);
+    EXPECT_TRUE(rop.useIndexes == false);
+    EXPECT_TRUE(lineListMesh->getSubMesh(0)->vertexData->vertexCount == 6);
 
     MeshSerializer meshWriter;
     meshWriter.exportMesh(lineListMesh.get(), fileName);
 
-    mMeshMgr->remove( fileName );
+    mMeshMgr->remove(fileName, "General");
 
     ResourceGroupManager::getSingleton().addResourceLocation(".", "FileSystem");
     MeshPtr loadedLineList = mMeshMgr->load(fileName, "General");
 
     remove(fileName.c_str());
 
-    CPPUNIT_ASSERT(loadedLineList->getNumSubMeshes() == 1);
-    CPPUNIT_ASSERT(loadedLineList->getSubMesh(0)->indexData->indexCount == 0);
+    EXPECT_TRUE(loadedLineList->getNumSubMeshes() == 1);
+    EXPECT_TRUE(loadedLineList->getSubMesh(0)->indexData->indexCount == 0);
     loadedLineList->getSubMesh(0)->_getRenderOperation(rop);
-    CPPUNIT_ASSERT(rop.useIndexes == false);
-    CPPUNIT_ASSERT(loadedLineList->getSubMesh(0)->vertexData->vertexCount == 6);
+    EXPECT_TRUE(rop.useIndexes == false);
+    EXPECT_TRUE(loadedLineList->getSubMesh(0)->vertexData->vertexCount == 6);
 
-    mMeshMgr->remove( fileName );
+    mMeshMgr->remove(fileName, "General");
 }
-
-void MeshWithoutIndexDataTests::testCreateLineStrip()
+//--------------------------------------------------------------------------
+TEST_F(MeshWithoutIndexDataTests,CreateLineStrip)
 {
     ManualObject* lineStrip = OGRE_NEW ManualObject("line");
     lineStrip->begin("BaseWhiteNoLighting", RenderOperation::OT_LINE_STRIP);
@@ -157,33 +157,33 @@ void MeshWithoutIndexDataTests::testCreateLineStrip()
     MeshPtr lineStripMesh = lineStrip->convertToMesh(fileName);
     OGRE_DELETE lineStrip;
 
-    CPPUNIT_ASSERT(lineStripMesh->getNumSubMeshes() == 1);
-    CPPUNIT_ASSERT(lineStripMesh->getSubMesh(0)->indexData->indexCount == 0);
+    EXPECT_TRUE(lineStripMesh->getNumSubMeshes() == 1);
+    EXPECT_TRUE(lineStripMesh->getSubMesh(0)->indexData->indexCount == 0);
     RenderOperation rop;
     lineStripMesh->getSubMesh(0)->_getRenderOperation(rop);
-    CPPUNIT_ASSERT(rop.useIndexes == false);
-    CPPUNIT_ASSERT(lineStripMesh->getSubMesh(0)->vertexData->vertexCount == 4);
+    EXPECT_TRUE(rop.useIndexes == false);
+    EXPECT_TRUE(lineStripMesh->getSubMesh(0)->vertexData->vertexCount == 4);
 
     MeshSerializer meshWriter;
     meshWriter.exportMesh(lineStripMesh.get(), fileName);
 
-    mMeshMgr->remove( fileName );
+    mMeshMgr->remove(fileName, "General");
 
     ResourceGroupManager::getSingleton().addResourceLocation(".", "FileSystem");
     MeshPtr loadedLineStrip = mMeshMgr->load(fileName, "General");
 
     remove(fileName.c_str());
 
-    CPPUNIT_ASSERT(loadedLineStrip->getNumSubMeshes() == 1);
-    CPPUNIT_ASSERT(loadedLineStrip->getSubMesh(0)->indexData->indexCount == 0);
+    EXPECT_TRUE(loadedLineStrip->getNumSubMeshes() == 1);
+    EXPECT_TRUE(loadedLineStrip->getSubMesh(0)->indexData->indexCount == 0);
     loadedLineStrip->getSubMesh(0)->_getRenderOperation(rop);
-    CPPUNIT_ASSERT(rop.useIndexes == false);
-    CPPUNIT_ASSERT(loadedLineStrip->getSubMesh(0)->vertexData->vertexCount == 4);
+    EXPECT_TRUE(rop.useIndexes == false);
+    EXPECT_TRUE(loadedLineStrip->getSubMesh(0)->vertexData->vertexCount == 4);
 
-    mMeshMgr->remove( fileName );
+    mMeshMgr->remove(fileName, "General");
 }
-
-void MeshWithoutIndexDataTests::testCreatePointList()
+//--------------------------------------------------------------------------
+TEST_F(MeshWithoutIndexDataTests,CreatePointList)
 {
     ManualObject* pointList = OGRE_NEW ManualObject("line");
     pointList->begin("BaseWhiteNoLighting", RenderOperation::OT_POINT_LIST);
@@ -196,36 +196,36 @@ void MeshWithoutIndexDataTests::testCreatePointList()
     MeshPtr pointListMesh = pointList->convertToMesh(fileName);
     OGRE_DELETE pointList;
 
-    CPPUNIT_ASSERT(pointListMesh->getNumSubMeshes() == 1);
-    CPPUNIT_ASSERT(pointListMesh->getSubMesh(0)->indexData->indexCount == 0);
+    EXPECT_TRUE(pointListMesh->getNumSubMeshes() == 1);
+    EXPECT_TRUE(pointListMesh->getSubMesh(0)->indexData->indexCount == 0);
     RenderOperation rop;
     pointListMesh->getSubMesh(0)->_getRenderOperation(rop);
-    CPPUNIT_ASSERT(rop.useIndexes == false);
-    CPPUNIT_ASSERT(pointListMesh->getSubMesh(0)->vertexData->vertexCount == 4);
+    EXPECT_TRUE(rop.useIndexes == false);
+    EXPECT_TRUE(pointListMesh->getSubMesh(0)->vertexData->vertexCount == 4);
 
     MeshSerializer meshWriter;
     meshWriter.exportMesh(pointListMesh.get(), fileName);
 
-    mMeshMgr->remove( fileName );
+    mMeshMgr->remove(fileName, "General");
 
     ResourceGroupManager::getSingleton().addResourceLocation(".", "FileSystem");
     MeshPtr loadedPointList = mMeshMgr->load(fileName, "General");
 
     remove(fileName.c_str());
 
-    CPPUNIT_ASSERT(loadedPointList->getNumSubMeshes() == 1);
-    CPPUNIT_ASSERT(loadedPointList->getSubMesh(0)->indexData->indexCount == 0);
+    EXPECT_TRUE(loadedPointList->getNumSubMeshes() == 1);
+    EXPECT_TRUE(loadedPointList->getSubMesh(0)->indexData->indexCount == 0);
     loadedPointList->getSubMesh(0)->_getRenderOperation(rop);
-    CPPUNIT_ASSERT(rop.useIndexes == false);
-    CPPUNIT_ASSERT(loadedPointList->getSubMesh(0)->vertexData->vertexCount == 4);
+    EXPECT_TRUE(rop.useIndexes == false);
+    EXPECT_TRUE(loadedPointList->getSubMesh(0)->vertexData->vertexCount == 4);
 
-    mMeshMgr->remove( fileName );
+    mMeshMgr->remove(fileName, "General");
 }
-
-void MeshWithoutIndexDataTests::testCreateLineWithMaterial()
+//--------------------------------------------------------------------------
+TEST_F(MeshWithoutIndexDataTests,CreateLineWithMaterial)
 {
     String matName = "lineMat";
-    MaterialPtr matPtr = MaterialManager::getSingleton().create(matName, "General").staticCast<Material>();
+    MaterialPtr matPtr = MaterialManager::getSingleton().create(matName, "General");
     Pass* pass = matPtr->getTechnique(0)->getPass(0);
     pass->setDiffuse(1.0, 0.1, 0.1, 0);
 
@@ -238,21 +238,21 @@ void MeshWithoutIndexDataTests::testCreateLineWithMaterial()
     MeshPtr lineMesh = line->convertToMesh(fileName);
     OGRE_DELETE line;
 
-    CPPUNIT_ASSERT(lineMesh->getNumSubMeshes() == 1);
-    CPPUNIT_ASSERT(lineMesh->getSubMesh(0)->indexData->indexCount == 0);
+    EXPECT_TRUE(lineMesh->getNumSubMeshes() == 1);
+    EXPECT_TRUE(lineMesh->getSubMesh(0)->indexData->indexCount == 0);
     RenderOperation rop;
     lineMesh->getSubMesh(0)->_getRenderOperation(rop);
-    CPPUNIT_ASSERT(rop.useIndexes == false);
-    CPPUNIT_ASSERT(lineMesh->getSubMesh(0)->vertexData->vertexCount == 2);
+    EXPECT_TRUE(rop.useIndexes == false);
+    EXPECT_TRUE(lineMesh->getSubMesh(0)->vertexData->vertexCount == 2);
 
     MeshSerializer meshWriter;
     meshWriter.exportMesh(lineMesh.get(), fileName);
     MaterialSerializer matWriter;
     matWriter.exportMaterial(
-        MaterialManager::getSingleton().getByName(matName).staticCast<Material>(),
+        MaterialManager::getSingleton().getByName(matName),
         matName + ".material");
 
-    mMeshMgr->remove( fileName );
+    mMeshMgr->remove(fileName, "General");
 
     ResourceGroupManager::getSingleton().addResourceLocation(".", "FileSystem");
     MeshPtr loadedLine = mMeshMgr->load(fileName, "General");
@@ -260,39 +260,39 @@ void MeshWithoutIndexDataTests::testCreateLineWithMaterial()
     remove(fileName.c_str());
     remove((matName + ".material").c_str());
 
-    CPPUNIT_ASSERT(loadedLine->getNumSubMeshes() == 1);
-    CPPUNIT_ASSERT(loadedLine->getSubMesh(0)->indexData->indexCount == 0);
+    EXPECT_TRUE(loadedLine->getNumSubMeshes() == 1);
+    EXPECT_TRUE(loadedLine->getSubMesh(0)->indexData->indexCount == 0);
     loadedLine->getSubMesh(0)->_getRenderOperation(rop);
-    CPPUNIT_ASSERT(rop.useIndexes == false);
-    CPPUNIT_ASSERT(lineMesh->getSubMesh(0)->vertexData->vertexCount == 2);
+    EXPECT_TRUE(rop.useIndexes == false);
+    EXPECT_TRUE(lineMesh->getSubMesh(0)->vertexData->vertexCount == 2);
 
-    mMeshMgr->remove( fileName );
+    mMeshMgr->remove(fileName, "General");
 }
-
-void createMeshWithMaterial(String fileName)
+//--------------------------------------------------------------------------
+static void createMeshWithMaterial(String fileName)
 {
     String matFileNameSuffix = ".material";
     String matName1 = "red";
     String matFileName1 = matName1 + matFileNameSuffix;
-    MaterialPtr matPtr = MaterialManager::getSingleton().create(matName1, "General").staticCast<Material>();
+    MaterialPtr matPtr = MaterialManager::getSingleton().create(matName1, "General");
     Pass* pass = matPtr->getTechnique(0)->getPass(0);
     pass->setDiffuse(1.0, 0.1, 0.1, 0);
 
     String matName2 = "green";
     String matFileName2 = matName2 + matFileNameSuffix;
-    matPtr = MaterialManager::getSingleton().create(matName2, "General").staticCast<Material>();
+    matPtr = MaterialManager::getSingleton().create(matName2, "General");
     pass = matPtr->getTechnique(0)->getPass(0);
     pass->setDiffuse(0.1, 1.0, 0.1, 0);
 
     String matName3 = "blue";
     String matFileName3 = matName3 + matFileNameSuffix;
-    matPtr = MaterialManager::getSingleton().create(matName3, "General").staticCast<Material>();
+    matPtr = MaterialManager::getSingleton().create(matName3, "General");
     pass = matPtr->getTechnique(0)->getPass(0);
     pass->setDiffuse(0.1, 0.1, 1.0, 0);
 
     String matName4 = "yellow";
     String matFileName4 = matName4 + matFileNameSuffix;
-    matPtr = MaterialManager::getSingleton().create(matName4, "General").staticCast<Material>();
+    matPtr = MaterialManager::getSingleton().create(matName4, "General");
     pass = matPtr->getTechnique(0)->getPass(0);
     pass->setDiffuse(1.0, 1.0, 0.1, 0);
 
@@ -327,65 +327,64 @@ void createMeshWithMaterial(String fileName)
     manObj->end();
     manObj->convertToMesh(fileName);
     OGRE_DELETE manObj;
-
 }
-
-void MeshWithoutIndexDataTests::testCreateMesh()
+//--------------------------------------------------------------------------
+TEST_F(MeshWithoutIndexDataTests,CreateMesh)
 {
     String fileName = "indexMix.mesh";
     createMeshWithMaterial(fileName);
-    MeshPtr mesh = mMeshMgr->getByName(fileName).staticCast<Mesh>();
+    MeshPtr mesh = mMeshMgr->getByName(fileName, "General");
 
-    CPPUNIT_ASSERT(mesh->getNumSubMeshes() == 4);
+    EXPECT_TRUE(mesh->getNumSubMeshes() == 4);
     RenderOperation rop;
     for (int i=0; i<4; ++i)
     {
         mesh->getSubMesh(i)->_getRenderOperation(rop);
-        // first submesh has indexes; the others not
-        CPPUNIT_ASSERT( rop.useIndexes == (i == 0) );
+        // First submesh has indexes, the others does not.
+        EXPECT_TRUE( rop.useIndexes == (i == 0) );
     }
 
     MeshSerializer meshWriter;
     meshWriter.exportMesh(mesh.get(), fileName);
 
-    mMeshMgr->remove( fileName );
+    mMeshMgr->remove(fileName, "General");
 
     ResourceGroupManager::getSingleton().addResourceLocation(".", "FileSystem");
     MeshPtr loadedMesh = mMeshMgr->load(fileName, "General");
 
     remove(fileName.c_str());
 
-    CPPUNIT_ASSERT(loadedMesh->getNumSubMeshes() == 4);
+    EXPECT_TRUE(loadedMesh->getNumSubMeshes() == 4);
 
-    mMeshMgr->remove( fileName );
+    mMeshMgr->remove(fileName, "General");
 }
-
-void MeshWithoutIndexDataTests::testCloneMesh()
+//--------------------------------------------------------------------------
+TEST_F(MeshWithoutIndexDataTests,CloneMesh)
 {
     String originalName = "toClone.mesh";
     createMeshWithMaterial(originalName);
-    MeshPtr mesh = mMeshMgr->getByName(originalName).staticCast<Mesh>();
+    MeshPtr mesh = mMeshMgr->getByName(originalName, "General");
 
     String fileName = "clone.mesh";
     MeshPtr clone = mesh->clone(fileName);
-    CPPUNIT_ASSERT(mesh->getNumSubMeshes() == 4);
+    EXPECT_TRUE(mesh->getNumSubMeshes() == 4);
 
     MeshSerializer meshWriter;
     meshWriter.exportMesh(mesh.get(), fileName);
 
-    mMeshMgr->remove( fileName );
+    mMeshMgr->remove(fileName, "General");
 
     ResourceGroupManager::getSingleton().addResourceLocation(".", "FileSystem");
     MeshPtr loadedMesh = mMeshMgr->load(fileName, "General");
 
     remove(fileName.c_str());
 
-    CPPUNIT_ASSERT(loadedMesh->getNumSubMeshes() == 4);
+    EXPECT_TRUE(loadedMesh->getNumSubMeshes() == 4);
 
-    mMeshMgr->remove( fileName );
+    mMeshMgr->remove(fileName, "General");
 }
-
-void MeshWithoutIndexDataTests::testEdgeList()
+//--------------------------------------------------------------------------
+TEST_F(MeshWithoutIndexDataTests,EdgeList)
 {
     String fileName = "testEdgeList.mesh";
     ManualObject* line = OGRE_NEW ManualObject("line");
@@ -397,8 +396,8 @@ void MeshWithoutIndexDataTests::testEdgeList()
     OGRE_DELETE line;
 
     // whole mesh must not contain index data, for this test
-    CPPUNIT_ASSERT(mesh->getNumSubMeshes() == 1);
-    CPPUNIT_ASSERT(mesh->getSubMesh(0)->indexData->indexCount == 0);
+    EXPECT_TRUE(mesh->getNumSubMeshes() == 1);
+    EXPECT_TRUE(mesh->getSubMesh(0)->indexData->indexCount == 0);
 
     mesh->buildEdgeList();
     MeshSerializer meshWriter;
@@ -407,14 +406,14 @@ void MeshWithoutIndexDataTests::testEdgeList()
 
     remove(fileName.c_str());
 
-    mMeshMgr->remove( fileName );
+    mMeshMgr->remove(fileName, "General");
 }
-
-void MeshWithoutIndexDataTests::testGenerateExtremes()
+//--------------------------------------------------------------------------
+TEST_F(MeshWithoutIndexDataTests,GenerateExtremes)
 {
     String fileName = "testGenerateExtremes.mesh";
     createMeshWithMaterial(fileName);
-    MeshPtr mesh = mMeshMgr->getByName(fileName).staticCast<Mesh>();
+    MeshPtr mesh = mMeshMgr->getByName(fileName, "General");
 
     const size_t NUM_EXTREMES = 4;
     for (ushort i = 0; i < mesh->getNumSubMeshes(); ++i)
@@ -425,56 +424,40 @@ void MeshWithoutIndexDataTests::testGenerateExtremes()
     {
         SubMesh* subMesh = mesh->getSubMesh(i);
         // According to generateExtremes, extremes are built based upon the bounding box indices.
-        // But it also creates indices for all bbox's even if the mesh does not have any.
-        // So...there should always be some extremity points. The number of which may vary
+        // But it also creates indices for all bounding boxes even if the mesh does not have any.
+        // So...there should always be some extremity points. The number of which may vary.
         if (subMesh->indexData->indexCount > 0)
         {
-            CPPUNIT_ASSERT(subMesh->extremityPoints.size() == NUM_EXTREMES);
+            EXPECT_TRUE(subMesh->extremityPoints.size() == NUM_EXTREMES);
         }
     }
 
-    mMeshMgr->remove( fileName );
+    mMeshMgr->remove(fileName, "General");
 }
-
-void MeshWithoutIndexDataTests::testBuildTangentVectors()
+//--------------------------------------------------------------------------
+TEST_F(MeshWithoutIndexDataTests,BuildTangentVectors)
 {
     String fileName = "testBuildTangentVectors.mesh";
     createMeshWithMaterial(fileName);
-    MeshPtr mesh = mMeshMgr->getByName(fileName).staticCast<Mesh>();
+    MeshPtr mesh = mMeshMgr->getByName(fileName, "General");
 
-    try
-    {
-        // make sure correct exception is thrown
-        mesh->buildTangentVectors();
-        CPPUNIT_FAIL("Expected InvalidParametersException!");
-    }
-    catch (const InvalidParametersException&)
-    {
-    	// ok
-    }
+    EXPECT_THROW(mesh->buildTangentVectors(), InvalidParametersException);
     
-    mMeshMgr->remove( fileName );
+    mMeshMgr->remove(fileName, "General");
 }
-
-void MeshWithoutIndexDataTests::testGenerateLodLevels()
+//--------------------------------------------------------------------------
+TEST_F(MeshWithoutIndexDataTests,GenerateLodLevels)
 {
+#ifdef OGRE_BUILD_COMPONENT_MESHLODGENERATOR
     String fileName = "testGenerateLodLevels.mesh";
     createMeshWithMaterial(fileName);
-    MeshPtr mesh = mMeshMgr->getByName(fileName).staticCast<Mesh>();
+    MeshPtr mesh = mMeshMgr->getByName(fileName, "General");
 
-	LodConfig lodConfig;
-    lodConfig.levels.clear();
-    lodConfig.mesh = MeshPtr(mesh);
-    lodConfig.strategy = DistanceLodSphereStrategy::getSingletonPtr();
-    LodLevel lodLevel;
-    lodLevel.reductionMethod = LodLevel::VRM_CONSTANT;
-    lodLevel.distance = 600.0;
-    lodLevel.reductionValue = 2;
-    lodConfig.levels.push_back(lodLevel);
-    ProgressiveMeshGenerator pm;
-    pm.generateLodLevels(lodConfig);
-    // FAIL: Levels == 1
-    CPPUNIT_ASSERT(mesh->getNumLodLevels() == 2);
+    LodConfig lodConfig(mesh);
+    lodConfig.createGeneratedLodLevel(600, 2, LodLevel::VRM_CONSTANT);
+    MeshLodGenerator().generateLodLevels(lodConfig);
+    // It may be less then 2, when two levels have the same vertex count it will be optimized out and lodLevel.outSkipped=true
+    EXPECT_TRUE(mesh->getNumLodLevels() == 2);
     for (ushort i = 0; i < mesh->getNumSubMeshes(); ++i)
     {
         SubMesh* subMesh = mesh->getSubMesh(i);
@@ -482,12 +465,13 @@ void MeshWithoutIndexDataTests::testGenerateLodLevels()
         {
             if (subMesh->indexData->indexCount > 0)
             {
-                CPPUNIT_ASSERT(subMesh->mLodFaceList[j]->indexCount > 0);
+                // This may not be true for all meshes, but in this test we don't have reduced to 0.
+                EXPECT_TRUE(subMesh->mLodFaceList[j]->indexCount > 0);
             }
             else
             {
                 // Should be 3 because of the dummy triangle being generated
-                CPPUNIT_ASSERT(subMesh->mLodFaceList[j]->indexCount == 3);
+                EXPECT_TRUE(subMesh->mLodFaceList[j]->indexCount == 3);
             }
         }
     }
@@ -497,5 +481,7 @@ void MeshWithoutIndexDataTests::testGenerateLodLevels()
 
     remove(fileName.c_str());
 
-    mMeshMgr->remove( fileName );
+    mMeshMgr->remove(fileName, "General");
+#endif
 }
+//--------------------------------------------------------------------------//--------------------------------------------------------------------------
