@@ -31,7 +31,8 @@ THE SOFTWARE.
 
 #include "OgreBuildSettings.h"
 
-#include "SdkSample.h"
+#include "Sample.h"
+#include "Ogre.h"
 
 // resource group that will be automatically unloaded after the close of the sample
 #define TRANSIENT_RESOURCE_GROUP "VisualTestTransient"
@@ -44,23 +45,13 @@ class VisualTest : public OgreBites::Sample
 
     VisualTest()
     {
-        mInfo["Title"] = "Untitled Test";
-        mInfo["Description"] = "";
         mInfo["Category"] = "Tests";
         mInfo["Thumbnail"] = "thumb_visual_tests.png";
-        mInfo["Help"] = "";
         Ogre::ResourceGroupManager& rgm = Ogre::ResourceGroupManager::getSingleton();
         if (!rgm.resourceGroupExists(TRANSIENT_RESOURCE_GROUP))
             rgm.createResourceGroup(TRANSIENT_RESOURCE_GROUP, true);
     }
 
-    /** Adds a screenshot frame to the list - this should
-     *    be done during setup of the test. */
-    void addScreenshotFrame(unsigned int frame)
-    {
-        mScreenshotFrames.insert(frame);
-    }
-
     /** set up the camera and viewport */
     virtual void setupView()
     {
@@ -87,23 +78,6 @@ class VisualTest : public OgreBites::Sample
         mAnimStateList.clear();
     }
 
-    /** Returns whether or not a screenshot should be taken at the given frame */
-    virtual bool isScreenshotFrame(unsigned int frame)
-    {
-        if (mScreenshotFrames.empty())
-        {
-            mDone = true;
-        }
-        else if (frame == *(mScreenshotFrames.begin()))
-        {
-            mScreenshotFrames.erase(mScreenshotFrames.begin());
-            if (mScreenshotFrames.empty())
-                mDone = true;
-            return true;
-        }
-        return false;
-    }
-
     /** Default frame started callback, advances animations */
     virtual bool frameStarted(const Ogre::FrameEvent& evt)
     {
@@ -113,19 +87,8 @@ class VisualTest : public OgreBites::Sample
     }
 
  protected:
-
-    // a set of frame numbers at which to trigger screenshots
-    std::set<unsigned int> mScreenshotFrames;
-
     // a list of animation states to automatically update
     std::vector<Ogre::AnimationState*> mAnimStateList;
-
-    // The camera for this sample
-    Ogre::Camera* mCamera;
-    Ogre::SceneNode* mCameraNode;
-    // The viewport for this sample
-    Ogre::Viewport* mViewport;
-
 };
 
 #endif
