@@ -421,7 +421,7 @@ class _OgreSampleClassExport PlayPen_ClearScene : public VisualTest
 public:
 
     PlayPen_ClearScene();
-    bool isScreenshotFrame(unsigned int frame);
+    bool isScreenshotFrame(int frame) override;
 
 protected:
     void setupContent();
@@ -1136,12 +1136,6 @@ public:
 
     PlayPen_TextureShadowsTransparentCaster();
 
-    void testCapabilities(const Ogre::RenderSystemCapabilities* caps)
-    {
-        if(!caps->hasCapability(RSC_FIXED_FUNCTION))
-            throw Ogre::Exception(999, "API doesn't support fixed function.", "testCapabilities");
-    }
-
 protected:
 
     void setupContent();
@@ -1451,20 +1445,6 @@ protected:
 
 };
 
-//------------------------------------------------------------------------------
-/** Tests simple image operations */
-class _OgreSampleClassExport PlayPen_ImageCombine : public VisualTest
-{
-public:
-
-    PlayPen_ImageCombine();
-
-protected:
-
-    void setupContent();
-
-};
-
 //------------------------------------------------------------------------------
 /** Tests non-unique resource names in different resource groups */
 class _OgreSampleClassExport PlayPen_NonUniqueResourceNames : public VisualTest
@@ -1608,6 +1588,14 @@ protected:
 
 };
 
+class _OgreSampleClassExport PlayPen_BillboardText : public VisualTest
+{
+public:
+    PlayPen_BillboardText();
+
+protected:
+    void setupContent();
+};
 //------------------------------------------------------------------------------
 
 // some common tasks for these tests:
